/**
 * @semantic-ui/core v0.12.4
 * Semantic empowers designers and developers by creating a shared vocabulary for UI.
 *
 * @license MIT
 * @copyright (c) 2025 Jack Lukic <jack@semantic-ui.com>
 * @homepage http://next.semantic-ui.com
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

// src/components/button/button.js
import { defineComponent } from "https://cdn.jsdelivr.net/npm/@semantic-ui/component@0.12.4/dist/index.min.js";

// packages/utils/src/types.js
var isObject = (x) => {
  return x !== null && typeof x == "object";
};
var isArray = (x) => {
  return Array.isArray(x);
};

// packages/utils/src/objects.js
var get = function(obj, path = "") {
  if (typeof path !== "string") {
    return void 0;
  }
  function extractArrayLikeAccess(part) {
    const key = part.substring(0, part.indexOf("["));
    const index = parseInt(part.substring(part.indexOf("[") + 1, part.indexOf("]")), 10);
    return { key, index };
  }
  function getCombinedKey(path2) {
    const dotIndex = path2.indexOf(".");
    if (dotIndex !== -1) {
      const nextDotIndex = path2.indexOf(".", dotIndex + 1);
      if (nextDotIndex !== -1) {
        return path2.slice(0, nextDotIndex);
      }
    }
    return path2;
  }
  if (obj === null || !isObject(obj)) {
    return void 0;
  }
  const parts = path.split(".");
  let currentObject = obj;
  for (let i = 0; i < parts.length; i++) {
    if (currentObject === null || !isObject(currentObject)) {
      return void 0;
    }
    let part = parts[i];
    if (part.includes("[")) {
      const { key, index } = extractArrayLikeAccess(part);
      if (key in currentObject && isArray(currentObject[key]) && index < currentObject[key].length) {
        currentObject = currentObject[key][index];
      } else {
        return void 0;
      }
    } else {
      if (part in currentObject) {
        currentObject = currentObject[part];
      } else {
        const remainingPath = parts.slice(i).join(".");
        if (remainingPath in currentObject) {
          currentObject = currentObject[remainingPath];
          break;
        } else {
          const combinedKey = getCombinedKey(`${part}.${parts[i + 1]}`);
          if (combinedKey in currentObject) {
            currentObject = currentObject[combinedKey];
            i++;
          } else {
            return void 0;
          }
        }
      }
    }
  }
  return currentObject;
};

// packages/utils/src/arrays.js
var inArray = (value, array = []) => {
  return array.indexOf(value) > -1;
};

// packages/utils/src/colors.js
var GAMMA_EXPONENT = 1 / 2.4;

// src/components/button/specs/button-component.json
var button_component_default = {
  tagName: "ui-button",
  content: [
    "icon"
  ],
  contentAttributes: [
    "icon"
  ],
  types: [
    "emphasis",
    "toggle",
    "animated"
  ],
  variations: [
    "attached",
    "basic",
    "type",
    "circular",
    "color",
    "compact",
    "social",
    "positive",
    "warning",
    "negative",
    "info",
    "transparent",
    "floated",
    "fluid",
    "size",
    "inverted"
  ],
  states: [
    "hover",
    "focused",
    "active",
    "disabled",
    "loading"
  ],
  settings: [
    "icon-only",
    "icon-after",
    "href"
  ],
  attributes: [
    "icon",
    "emphasis",
    "toggle",
    "animated",
    "hover",
    "focused",
    "active",
    "disabled",
    "loading",
    "attached",
    "basic",
    "type",
    "circular",
    "color",
    "compact",
    "social",
    "positive",
    "warning",
    "negative",
    "info",
    "transparent",
    "floated",
    "fluid",
    "size",
    "inverted",
    "icon-only",
    "icon-after",
    "href"
  ],
  optionAttributes: {
    primary: "emphasis",
    secondary: "emphasis",
    "horizontal-animated": "animated",
    "vertical-animated": "animated",
    "fade-animated": "animated",
    disabled: "disabled",
    "clickable-disabled": "disabled",
    "top-attached": "attached",
    attached: "attached",
    "bottom-attached": "attached",
    "left-attached": "attached",
    "right-attached": "attached",
    basic: "basic",
    "very-basic": "basic",
    submit: "type",
    reset: "type",
    red: "color",
    orange: "color",
    yellow: "color",
    olive: "color",
    green: "color",
    teal: "color",
    blue: "color",
    violet: "color",
    purple: "color",
    pink: "color",
    brown: "color",
    grey: "color",
    black: "color",
    compact: "compact",
    "very-compact": "compact",
    instagram: "social",
    facebook: "social",
    twitter: "social",
    linkedin: "social",
    youtube: "social",
    positive: "positive",
    "subtle-positive": "positive",
    warning: "warning",
    "subtle-warning": "warning",
    negative: "negative",
    "subtle-negative": "negative",
    info: "info",
    "subtle-info": "info",
    "left-floated": "floated",
    "right-floated": "floated",
    mini: "size",
    tiny: "size",
    small: "size",
    medium: "size",
    large: "size",
    big: "size",
    huge: "size",
    massive: "size"
  },
  propertyTypes: {
    icon: "string",
    emphasis: "string",
    toggle: "boolean",
    animated: "string",
    hover: "boolean",
    focused: "boolean",
    active: "boolean",
    disabled: "string",
    loading: "boolean",
    attached: "string",
    basic: "string",
    type: "string",
    circular: "boolean",
    color: "string",
    compact: "string",
    social: "string",
    positive: "string",
    warning: "string",
    negative: "string",
    info: "string",
    transparent: "boolean",
    floated: "string",
    fluid: "boolean",
    size: "string",
    inverted: "boolean",
    "icon-only": "boolean",
    "icon-after": "boolean",
    href: "string"
  },
  allowedValues: {
    emphasis: [
      "primary",
      "secondary"
    ],
    animated: [
      "horizontal-animated",
      "vertical-animated",
      "fade-animated"
    ],
    disabled: [
      "disabled",
      "clickable-disabled"
    ],
    attached: [
      "top-attached",
      "attached",
      "bottom-attached",
      "left-attached",
      "right-attached"
    ],
    basic: [
      "basic",
      "very-basic"
    ],
    type: [
      "submit",
      "reset"
    ],
    color: [
      "red",
      "orange",
      "yellow",
      "olive",
      "green",
      "teal",
      "blue",
      "violet",
      "purple",
      "pink",
      "brown",
      "grey",
      "black"
    ],
    compact: [
      "compact",
      "very-compact"
    ],
    social: [
      "instagram",
      "facebook",
      "twitter",
      "linkedin",
      "youtube"
    ],
    positive: [
      "positive",
      "subtle-positive"
    ],
    warning: [
      "warning",
      "subtle-warning"
    ],
    negative: [
      "negative",
      "subtle-negative"
    ],
    info: [
      "info",
      "subtle-info"
    ],
    floated: [
      "left-floated",
      "right-floated"
    ],
    size: [
      "mini",
      "tiny",
      "small",
      "medium",
      "large",
      "big",
      "huge",
      "massive"
    ]
  },
  attributeClasses: [
    "icon",
    "animated",
    "disabled",
    "attached",
    "social"
  ],
  inheritedPluralVariations: [
    "inverted",
    "size",
    "floated",
    "compact",
    "color",
    "attached"
  ]
};

// src/components/button/button.html?raw
var button_default = '{#if href}\n  <a class="{ui}button" href="{href}">\n    {> content}\n  </a>\n{else}\n  <div class="{ui}button" tabindex="0" part="button">\n    {> content}\n  </div>\n{/if}\n\n{#snippet content}\n  {#if animated}\n    {> animated}\n  {else}\n    {#if isIconBefore}\n      {> icon}\n    {/if}\n    {#if not iconOnly}\n      <span class="text">\n        {> slot}\n      </span>\n    {/if}\n    {#if isIconAfter}\n      {> icon}\n    {/if}\n  {/if}\n{/snippet}\n\n{#snippet icon}\n  <ui-icon icon={icon} class="icon" part="icon"></ui-icon>\n{/snippet}\n\n{#snippet animated}\n  <span class="hidden content">\n    {>slot hidden}\n  </span>\n  <span class="visible content">\n    {>slot visible}\n  </span>\n{/snippet}\n';

// src/components/button/button-bundle.css?raw
var button_bundle_default = '/**\n  ---DO NOT EDIT THIS FILE DIRECTLY---\n  This CSS file was concatenated from files listed in the css/ folder as part of a build process\n  This is to allow for js import with @import links which will not be followed\n**/\n\n/* src/components/button/css/definition/content/button.css */\n@layer button.definition.content.button {\n  :host {\n    -webkit-user-select: none;\n    user-select: none;\n    font-size: 1rem;\n  }\n  *,\n  :after,\n  :before {\n    box-sizing: border-box;\n    user-select: none;\n    -webkit-user-select: none;\n    -webkit-touch-callout: none;\n  }\n  .button {\n    cursor: pointer;\n    display: inline-block;\n    min-height: 1em;\n    border: var(--button-border);\n    margin: 0em var(--button-horizontal-margin) var(--button-vertical-margin) 0em;\n    vertical-align: var(--button-vertical-align);\n    background: var(--button-background);\n    color: var(--button-text-color);\n    font-family: var(--button-font-family);\n    padding: var(--button-padding);\n    text-transform: var(--button-text-transform);\n    text-shadow: var(--button-text-shadow);\n    font-weight: var(--button-font-weight);\n    line-height: var(--button-line-height);\n    font-style: normal;\n    text-align: center;\n    text-decoration: none;\n    border-radius: var(--button-border-radius);\n    box-shadow: var(--button-box-shadow);\n    -webkit-user-select: none;\n    user-select: none;\n    transition: var(--button-transition);\n    will-change: var(--button-will-change);\n    -webkit-tap-highlight-color: var(--button-tap-color);\n    outline: var(--button-border);\n  }\n}\n\n/* src/components/button/css/definition/content/icon.css */\n@layer button.definition.content.icon {\n  .button ui-icon {\n    vertical-align: top;\n    opacity: var(--button-icon-opacity);\n  }\n  .button ui-icon:only-child {\n    margin: 0rem;\n  }\n}\n\n/* src/components/button/css/definition/content/label.css */\n@layer button.definition.content.label {\n  .button .label {\n  }\n}\n\n/* src/components/button/css/definition/plural/buttons.css */\n@layer button.definition.plural {\n  .buttons {\n    display: inline-flex;\n    flex-direction: row;\n    vertical-align: baseline;\n    margin: var(--button-vertical-margin) var(--button-horizontal-margin) 0em 0em;\n  }\n  .buttons:not(.basic):not(.inverted) {\n    box-shadow: var(--button-group-box-shadow);\n  }\n}\n\n/* src/components/button/css/definition/states/hover.css */\n@layer button.definition.states.hover {\n  @media (pointer: fine) {\n    .button.hover,\n    .button:hover {\n      background-color: var(--button-hover-background-color);\n      background-image: var(--button-hover-background-image);\n      box-shadow: var(--button-hover-box-shadow);\n      color: var(--button-hover-color);\n    }\n    .button.hover .icon,\n    .button:hover .icon {\n      opacity: var(--button-hover-icon-opacity);\n    }\n  }\n}\n\n/* src/components/button/css/definition/states/focus.css */\n@layer button.definition.states.focus {\n  .button.focused,\n  .button:focus {\n    background-color: var(--button-focus-background-color);\n    background-image: var(--button-focus-background-image);\n    color: var(--button-focus-color);\n    box-shadow: var(--button-focus-box-shadow);\n  }\n  .button.focused .icon,\n  .button:focus .icon {\n    opacity: var(--button-focus-icon-opacity);\n  }\n  .button:focus-visible {\n    box-shadow: var(--button-focus-box-shadow), var(--focused-ring-shadow) !important;\n  }\n}\n\n/* src/components/button/css/definition/states/pressed.css */\n@layer button.definition.states.pressed {\n  @media (pointer: fine) {\n    .button:active,\n    .active.button:active {\n      background-color: var(--button-pressed-background-color);\n      background-image: var(--button-pressed-background-image);\n      color: var(--button-pressed-color);\n      box-shadow: var(--button-pressed-box-shadow);\n    }\n  }\n  .pressed.button,\n  .active.pressed.button {\n    background-color: var(--button-pressed-background-color);\n    background-image: var(--button-pressed-background-image);\n    color: var(--button-pressed-color);\n    box-shadow: var(--button-pressed-box-shadow);\n  }\n}\n\n/* src/components/button/css/definition/states/active.css */\n@layer button.definition.states.active {\n  .active.button {\n    background-color: var(--button-active-background-color);\n    background-image: var(--button-active-background-image);\n    box-shadow: var(--button-active-box-shadow);\n    color: var(--button-active-color);\n  }\n  .active.button:hover {\n    background-color: var(--button-active-hover-background-color);\n    background-image: var(--button-active-hover-background-image);\n    color: var(--button-active-hover-color);\n    box-shadow: var(--button-active-hover-box-shadow);\n  }\n  .active.button:active {\n    background-color: var(--button-active-down-background-color);\n    background-image: var(--button-active-down-background-image);\n    color: var(--button-active-down-color);\n    box-shadow: var(--button-active-down-box-shadow);\n  }\n}\n\n/* src/components/button/css/definition/states/disabled.css */\n@layer button.definition.states.disabled {\n  .disabled.button,\n  .disabled.button:hover,\n  .disabled.active.button {\n    pointer-events: none;\n    cursor: var(--button-disabled-cursor);\n    opacity: var(--button-disabled-opacity) !important;\n    color: var(--button-disabled-color);\n    box-shadow: var(--button-disabled-box-shadow) !important;\n  }\n  .disabled.button.standard {\n    background-color: var(--button-disabled-background-color) !important;\n    background-image: var(--button-disabled-background-image) !important;\n  }\n  ui-button[disabled] {\n    cursor: var(--button-disabled-cursor);\n    pointer-events: none !important;\n  }\n  .clickable-disabled.button {\n    pointer-events: auto !important;\n    cursor: var(--button-clickable-disabled-cursor) !important;\n  }\n  .clickable-disabled.button:active {\n    box-shadow: var(--button-pressed-box-shadow) !important;\n  }\n  ui-button[clickable-disabled] {\n    pointer-events: auto !important;\n    cursor: var(--button-clickable-disabled-cursor) !important;\n  }\n}\n\n/* src/components/button/css/definition/states/loading.css */\n@layer button.definition.states.loading {\n  .loading.button:not(.icon) {\n    position: relative;\n    cursor: default;\n    text-shadow: none !important;\n    color: transparent !important;\n    opacity: var(--button-loading-opacity);\n    pointer-events: auto;\n    transition: var(--button-loading-transition);\n  }\n  .loading.icon.button .icon {\n    position: relative;\n    color: transparent !important;\n  }\n  .loading.icon.button > .icon:before,\n  .loading.button:not(.icon)::before {\n    position: absolute;\n    content: "";\n    top: 50%;\n    left: 50%;\n    margin: var(--loader-margin);\n    width: var(--loader-size);\n    height: var(--loader-size);\n    border-radius: var(--circular-radius);\n    border: var(--loader-line-width) solid var(--loader-fill-color);\n  }\n  .loading.icon.button > .icon:after,\n  .loading.button:not(.icon)::after {\n    position: absolute;\n    content: "";\n    top: 50%;\n    left: 50%;\n    margin: var(--loader-margin);\n    width: var(--loader-size);\n    height: var(--loader-size);\n    animation: button-spin var(--loader-speed) linear;\n    animation-iteration-count: infinite;\n    border-radius: var(--circular-radius);\n    border-color: var(--loader-line-color) transparent transparent;\n    border-style: solid;\n    border-width: var(--loader-line-width);\n    box-shadow: 0px 0px 0px 1px transparent;\n  }\n  @keyframes button-spin {\n    from {\n      transform: rotate(0deg);\n    }\n    to {\n      transform: rotate(360deg);\n    }\n  }\n  .loading.button.inverted .icon:before,\n  .loading.button.inverted:before {\n    border-color: var(--inverted-loader-fill-color);\n  }\n  .loading.button.inverted .icon:after,\n  .loading.button.inverted:after {\n    border-top-color: var(--inverted-loader-line-color);\n  }\n}\n\n/* src/components/button/css/definition/types/animated.css */\n@layer button.definition.types.animated {\n  .animated.button {\n    position: relative;\n    overflow: hidden;\n    padding-right: 0em !important;\n    vertical-align: var(--button-animated-vertical-align);\n    z-index: var(--button-animated-z-index);\n  }\n  .animated.button > .content {\n    display: inline-block;\n    box-sizing: border-box;\n    will-change: transform, opacity;\n  }\n  .animated.button > .visible.content {\n    position: relative;\n    margin-right: var(--button-horizontal-padding);\n  }\n  .animated.button > .hidden.content {\n    position: absolute;\n    width: 100%;\n  }\n  .animated.animated.button > .visible.content,\n  .animated.button > .hidden.content {\n    transition: right var(--button-animation-duration) var(--button-animation-easing) 0s;\n  }\n  .animated.button > .visible.content {\n    left: auto;\n    right: 0%;\n  }\n  .animated.button > .hidden.content {\n    top: 50%;\n    left: auto;\n    right: -100%;\n    margin-top: calc(var(--button-line-height) / 2 * -1);\n  }\n  .animated.button:focus > .visible.content,\n  .animated.button:hover > .visible.content {\n    left: auto;\n    right: 200%;\n  }\n  .animated.button:focus > .hidden.content,\n  .animated.button:hover > .hidden.content {\n    left: auto;\n    right: 0%;\n  }\n  .vertical-animated.button > .visible.content,\n  .vertical-animated.button > .hidden.content {\n    transition: top var(--button-animation-duration) var(--button-animation-easing), transform var(--button-animation-duration) var(--button-animation-easing);\n  }\n  .vertical-animated.button > .visible.content {\n    transform: translateY(0%);\n    right: auto;\n  }\n  .vertical-animated.button > .hidden.content {\n    top: -50%;\n    left: 0%;\n  }\n  .vertical-animated.button:focus > .visible.content,\n  .vertical-animated.button:hover > .visible.content {\n    transform: translateY(200%);\n    right: auto;\n  }\n  .vertical-animated.button:focus > .hidden.content,\n  .vertical-animated.button:hover > .hidden.content {\n    top: 50%;\n  }\n  .fade-animated.button > .visible.content,\n  .fade-animated.button > .hidden.content {\n    transition: opacity var(--button-animation-duration) var(--button-animation-easing), transform var(--button-animation-duration) var(--button-animation-easing);\n  }\n  .fade-animated.button > .visible.content {\n    left: auto;\n    right: auto;\n    opacity: 1;\n    transform: scale(1);\n  }\n  .fade-animated.button > .hidden.content {\n    opacity: 0;\n    left: 0%;\n    right: auto;\n    transform: scale(var(--button-fade-scale-high));\n  }\n  .fade-animated.button:focus > .visible.content,\n  .fade-animated.button:hover > .visible.content {\n    left: auto;\n    right: auto;\n    opacity: 0;\n    transform: scale(var(--button-fade-scale-low));\n  }\n  .fade-animated.button:focus > .hidden.content,\n  .fade-animated.button:hover > .hidden.content {\n    left: 0%;\n    right: auto;\n    opacity: 1;\n    transform: scale(1);\n  }\n}\n\n/* src/components/button/css/definition/types/emphasis.css */\n@layer button.definition.types.emphasis {\n  .primary.buttons .button,\n  .primary.button {\n    background-color: var(--button-primary-color);\n    color: var(--button-primary-text-color);\n    text-shadow: var(--button-primary-text-shadow);\n    background-image: var(--button-primary-background-image);\n  }\n  .primary.button {\n    box-shadow: var(--button-primary-box-shadow);\n  }\n  .primary.buttons .button:hover,\n  .primary.button:hover {\n    background-color: var(--button-primary-color-hover);\n    color: var(--button-primary-text-color);\n    text-shadow: var(--button-primary-text-shadow);\n    box-shadow: var(--button-hover-box-shadow);\n  }\n  .primary.buttons .button:focus,\n  .primary.button:focus {\n    background-color: var(--button-primary-color-focus);\n    color: var(--button-primary-text-color);\n    text-shadow: var(--button-primary-text-shadow);\n    box-shadow: var(--button-focus-box-shadow);\n  }\n  .primary.buttons .button.pressed,\n  .primary.buttons .button:active,\n  .primary.button.pressed,\n  .primary.button:active {\n    background-color: var(--button-primary-color-down);\n    color: var(--button-primary-text-color);\n    text-shadow: var(--button-primary-text-shadow);\n    box-shadow: var(--button-pressed-box-shadow);\n  }\n  .primary.buttons .active.button,\n  .primary.buttons .active.button:active,\n  .primary.active.button,\n  .primary.button .active.button:active {\n    background-color: var(--button-primary-color-active);\n    color: var(--button-primary-text-color);\n    text-shadow: var(--button-primary-text-shadow);\n    box-shadow: var(--button-active-box-shadow);\n  }\n  .secondary.buttons .button,\n  .secondary.button {\n    background-color: var(--button-secondary-color);\n    color: var(--button-secondary-text-color);\n    text-shadow: var(--button-secondary-text-shadow);\n    background-image: var(--button-colored-background-image);\n  }\n  .secondary.button {\n    box-shadow: var(--button-colored-box-shadow);\n  }\n  .secondary.buttons .button:hover,\n  .secondary.button:hover {\n    background-color: var(--button-secondary-color-hover);\n    color: var(--button-secondary-text-color);\n    text-shadow: var(--button-secondary-text-shadow);\n    box-shadow: var(--button-hover-box-shadow);\n  }\n  .secondary.buttons .button:focus,\n  .secondary.button:focus {\n    background-color: var(--button-secondary-color-focus);\n    color: var(--button-secondary-text-color);\n    text-shadow: var(--button-secondary-text-shadow);\n    box-shadow: var(--button-focus-box-shadow);\n  }\n  .secondary.buttons .button:active,\n  .secondary.buttons .button.pressed,\n  .secondary.button.pressed,\n  .secondary.button:active {\n    background-color: var(--button-secondary-color-down);\n    color: var(--button-secondary-text-color);\n    text-shadow: var(--button-secondary-text-shadow);\n    box-shadow: var(--button-pressed-box-shadow);\n  }\n  .secondary.buttons .active.button,\n  .secondary.buttons .active.button:active,\n  .secondary.active.button,\n  .secondary.button .active.button:active {\n    background-color: var(--button-secondary-color-active);\n    color: var(--button-secondary-text-color);\n    text-shadow: var(--button-secondary-text-shadow);\n    box-shadow: var(--button-active-box-shadow);\n  }\n}\n\n/* src/components/button/css/definition/types/icon.css */\n@layer button.definition.types.icon {\n  .icon-only.buttons .button,\n  .icon-only.button {\n    padding: var(--button-vertical-padding);\n  }\n  .icon-only.buttons .button > ui-icon,\n  .icon-only.button > ui-icon {\n    opacity: 1;\n    margin: 0em;\n    vertical-align: top;\n  }\n  .icon-after.buttons .button > ui-icon,\n  .icon-after.button > ui-icon {\n    margin-right: 0rem;\n    margin-left: var(--icon-distance-from-text);\n  }\n}\n\n/* src/components/button/css/definition/types/labeled.css */\n@layer button.definition.types.labeled {\n  .labeled.button:not(.icon) {\n    display: inline-flex;\n    flex-direction: row;\n    background: none !important;\n    padding: 0px !important;\n    border: none !important;\n    box-shadow: none !important;\n  }\n  .labeled.button > .button {\n    margin: 0px;\n  }\n  .labeled.button > .label {\n    display: flex;\n    align-items: var(--labeled-label-align);\n    margin: 0px 0px 0px var(--labeled-label-border-offset) !important;\n    padding: var(--labeled-label-padding);\n    font-size: var(--labeled-label-font-size);\n    border-color: var(--labeled-label-border-color);\n  }\n  .labeled.button > .tag.label::before {\n    width: var(--labeled-tag-label-size);\n    height: var(--labeled-tag-label-size);\n  }\n  .labeled.button:not([class*="left labeled"]) > .button {\n    border-top-right-radius: 0px;\n    border-bottom-right-radius: 0px;\n  }\n  .labeled.button:not([class*="left labeled"]) > .label {\n    border-top-left-radius: 0px;\n    border-bottom-left-radius: 0px;\n  }\n  [class*="left labeled"].button > .button {\n    border-top-left-radius: 0px;\n    border-bottom-left-radius: 0px;\n  }\n  [class*="left labeled"].button > .label {\n    border-top-right-radius: 0px;\n    border-bottom-right-radius: 0px;\n  }\n}\n\n/* src/components/button/css/definition/types/labeled-icon.css */\n@layer button.definition.types.labeled-icon {\n  .labeled.icon.buttons .button,\n  .labeled.icon.button {\n    position: relative;\n    padding-left: var(--labeled-icon-padding) !important;\n    padding-right: var(--horizontal-padding) !important;\n  }\n  .labeled.icon.buttons > .button > .icon,\n  .labeled.icon.button > .icon {\n    position: absolute;\n    height: 100%;\n    line-height: 1;\n    border-radius: 0px;\n    border-top-left-radius: inherit;\n    border-bottom-left-radius: inherit;\n    text-align: center;\n    margin: var(--labeled-icon-margin);\n    width: var(--labeled-icon-width);\n    background-color: var(--labeled-icon-background-color);\n    color: var(--labeled-icon-color);\n    box-shadow: var(--labeled-icon-left-shadow);\n  }\n  .labeled.icon.buttons > .button > .icon,\n  .labeled.icon.button > .icon {\n    top: 0em;\n    left: 0em;\n  }\n  [class*="right labeled"].icon.button {\n    padding-right: var(--labeled-icon-padding) !important;\n    padding-left: var(--horizontal-padding) !important;\n  }\n  [class*="right labeled"].icon.button > .icon {\n    left: auto;\n    right: 0em;\n    border-radius: 0px;\n    border-top-right-radius: inherit;\n    border-bottom-right-radius: inherit;\n    box-shadow: var(--labeled-icon-right-shadow);\n  }\n  .labeled.icon.buttons > .button > .icon::before,\n  .labeled.icon.button > .icon::before,\n  .labeled.icon.buttons > .button > .icon::after,\n  .labeled.icon.button > .icon::after {\n    display: block;\n    position: absolute;\n    width: 100%;\n    top: 50%;\n    text-align: center;\n    transform: translateY(-50%);\n  }\n  .labeled.icon.button > .icon.loading {\n    animation: none;\n  }\n  .labeled.icon.button > .icon.loading::before {\n    animation: labeled-button-icon-loading var(--loading-icon-duration) linear infinite;\n  }\n  @keyframes labeled-button-icon-loading {\n    from {\n      transform: translateY(-50%) rotate(0deg);\n    }\n    to {\n      transform: translateY(-50%) rotate(360deg);\n    }\n  }\n  .labeled.icon.buttons .button > .icon {\n    border-radius: 0em;\n  }\n  .labeled.icon.buttons .button:first-child > .icon {\n    border-top-left-radius: var(--border-radius);\n    border-bottom-left-radius: var(--border-radius);\n  }\n  .labeled.icon.buttons .button:last-child > .icon {\n    border-top-right-radius: var(--border-radius);\n    border-bottom-right-radius: var(--border-radius);\n  }\n  .vertical.labeled.icon.buttons .button:first-child > .icon {\n    border-radius: 0em;\n    border-top-left-radius: var(--border-radius);\n  }\n  .vertical.labeled.icon.buttons .button:last-child > .icon {\n    border-radius: 0em;\n    border-bottom-left-radius: var(--border-radius);\n  }\n  .fluid[class*="left labeled"].icon.button,\n  .fluid[class*="right labeled"].icon.button {\n    padding-left: var(--horizontal-padding) !important;\n    padding-right: var(--horizontal-padding) !important;\n  }\n}\n\n/* src/components/button/css/definition/types/transparent.css */\n@layer button.definition.types.transparent {\n  .transparent.button {\n    background-image: var(--button-transparent-background-image);\n    background-color: var(--button-transparent-background-color);\n    color: var(--button-transparent-text-color);\n    box-shadow: var(--button-transparent-box-shadow) !important;\n  }\n  .transparent.button:hover {\n    background-image: var(--button-transparent-hover-background-image);\n    background-color: var(--button-transparent-hover-background-color);\n    color: var(--button-transparent-hover-text-color);\n    box-shadow: var(--button-transparent-hover-box-shadow) !important;\n  }\n  .transparent.button:active {\n    background-image: var(--button-transparent-pressed-background-image);\n    background-color: var(--button-transparent-pressed-background-color);\n    color: var(--button-transparent-pressed-text-color);\n    box-shadow: var(--button-transparent-pressed-box-shadow) !important;\n  }\n  .transparent.button.active {\n    background-image: var(--button-transparent-active-background-image);\n    background-color: var(--button-transparent-active-background-color);\n    color: var(--button-transparent-active-text-color) !important;\n    box-shadow: var(--button-transparent-active-box-shadow) !important;\n  }\n  .transparent.inverted.button {\n    background-image: var(--button-transparent-inverted-background-image);\n    background-color: var(--button-transparent-inverted-background-color);\n    color: var(--button-transparent-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n    box-shadow: var(--button-transparent-inverted-box-shadow) !important;\n  }\n  .transparent.inverted.button:hover {\n    background-image: var(--button-transparent-inverted-hover-background-image);\n    background-color: var(--button-transparent-inverted-hover-background-color);\n    color: var(--button-transparent-inverted-hover-text-color);\n    box-shadow: var(--button-transparent-inverted-hover-box-shadow) !important;\n  }\n  .transparent.inverted.button:active {\n    background-image: var(--button-transparent-inverted-pressed-background-image);\n    background-color: var(--button-transparent-inverted-pressed-background-color);\n    color: var(--button-transparent-inverted-pressed-text-color);\n    box-shadow: var(--button-transparent-inverted-pressed-box-shadow) !important;\n  }\n  .transparent.inverted.button.active {\n    background-image: var(--button-transparent-inverted-active-background-image);\n    background-color: var(--button-transparent-inverted-active-background-color);\n    color: var(--button-transparent-inverted-active-text-color) !important;\n    box-shadow: var(--button-transparent-inverted-active-box-shadow) !important;\n  }\n}\n\n/* src/components/button/css/definition/types/toggle.css */\n@layer button.definition.types.toggle {\n  .toggle.buttons .active.button,\n  .buttons .button.toggle.active,\n  .button.toggle.active {\n    background-color: var(--button-toggle-active-background) !important;\n    color: var(--button-toggle-active-color) !important;\n    text-shadow: var(--button-toggle-active-text-shadow);\n  }\n  .button.toggle.active:hover {\n    background-color: var(--button-toggle-active-hover-background) !important;\n    color: var(--button-toggle-active-hover-color) !important;\n  }\n}\n\n/* src/components/button/css/definition/variations/basic.css */\n@layer button.definition.variations.basic {\n  .basic.buttons .button,\n  .basic.button {\n    background: var(--button-basic-background) !important;\n    color: var(--button-basic-text-color) !important;\n    font-weight: var(--button-basic-font-weight);\n    border-radius: var(--button-basic-border-radius);\n    text-transform: var(--button-basic-text-transform);\n    text-shadow: none !important;\n    box-shadow: var(--button-basic-box-shadow);\n  }\n  .basic.buttons {\n    box-shadow: var(--button-basic-group-box-shadow);\n    border: var(--button-basic-group-border);\n    border-radius: var(--button-border-radius);\n  }\n  .basic.buttons .button {\n    border-radius: 0em;\n  }\n  .basic.buttons .button:hover,\n  .basic.button:hover {\n    background: var(--button-basic-hover-background) !important;\n    color: var(--button-basic-hover-text-color) !important;\n    box-shadow: var(--button-basic-hover-box-shadow);\n  }\n  .basic.buttons .button:focus,\n  .basic.button:focus {\n    background: var(--button-basic-focus-background) !important;\n    color: var(--button-basic-focus-text-color) !important;\n    box-shadow: var(--button-basic-focus-box-shadow);\n  }\n  .basic.buttons .button:active,\n  .basic.button:active {\n    background: var(--button-basic-down-background) !important;\n    color: var(--button-basic-down-text-color) !important;\n    box-shadow: var(--button-basic-down-box-shadow);\n  }\n  .basic.buttons .active.button,\n  .basic.active.button {\n    background: var(--button-basic-active-background) !important;\n    box-shadow: var(--button-basic-active-box-shadow) !important;\n    color: var(--button-basic-active-text-color) !important;\n  }\n  .basic.buttons .active.button:hover,\n  .basic.active.button:hover {\n    background-color: var(--button-transparent-black);\n  }\n  .basic.buttons .button:hover {\n    box-shadow: var(--button-basic-hover-box-shadow) inset;\n  }\n  .basic.buttons .button:active {\n    box-shadow: var(--button-basic-down-box-shadow) inset;\n  }\n  .basic.buttons .active.button {\n    box-shadow: var(--button-basic-active-box-shadow) !important;\n  }\n  .basic.inverted.buttons .button,\n  .basic.inverted.button {\n    background-color: transparent !important;\n    color: var(--button-off-white) !important;\n    box-shadow: var(--button-basic-inverted-box-shadow) !important;\n  }\n  .basic.inverted.buttons .button:hover,\n  .basic.inverted.button:hover {\n    color: var(--button-white) !important;\n    box-shadow: var(--button-basic-inverted-hover-box-shadow) !important;\n  }\n  .basic.inverted.buttons .button:focus,\n  .basic.inverted.button:focus {\n    color: var(--button-white) !important;\n    box-shadow: var(--button-basic-inverted-focus-box-shadow) !important;\n  }\n  .basic.inverted.buttons .button:active,\n  .basic.inverted.button:active {\n    background-color: var(--button-transparent-white) !important;\n    color: var(--button-white) !important;\n    box-shadow: var(--button-basic-inverted-down-box-shadow) !important;\n  }\n  .basic.inverted.buttons .active.button,\n  .basic.inverted.active.button {\n    background-color: var(--button-transparent-white);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n    box-shadow: var(--button-basic-inverted-active-box-shadow);\n  }\n  .basic.inverted.buttons .active.button:hover,\n  .basic.inverted.active.button:hover {\n    background-color: var(--button-strong-transparent-white);\n    box-shadow: var(--button-basic-inverted-hover-box-shadow) !important;\n  }\n  .basic.buttons .button {\n    border-left: var(--button-basic-group-border);\n    box-shadow: none;\n  }\n  .basic.vertical.buttons .button {\n    border-left: none;\n  }\n  .basic.vertical.buttons .button {\n    border-left-width: 0px;\n    border-top: var(--button-basic-group-border);\n  }\n  .basic.vertical.buttons .button:first-child {\n    border-top-width: 0px;\n  }\n}\n\n/* src/components/button/css/definition/variations/attached.css */\n@layer button.definition.variations.attached {\n  .attached.button {\n    position: relative;\n    display: block;\n    margin: 0em;\n    border-radius: 0em;\n    box-shadow: var(--button-attached-box-shadow);\n  }\n  .attached.button:active {\n    box-shadow: var(--button-attached-pressed-box-shadow);\n  }\n  .top-attached.button {\n    border-radius: var(--button-border-radius) var(--button-border-radius) 0em 0em;\n  }\n  .bottom-attached.button {\n    border-radius: 0em 0em var(--button-border-radius) var(--button-border-radius);\n  }\n  .left-attached.button {\n    display: inline-block;\n    border-left: none;\n    text-align: right;\n    padding-right: var(--button-attached-horizontal-padding);\n    border-radius: var(--button-border-radius) 0em 0em var(--button-border-radius);\n  }\n  .right-attached.button {\n    display: inline-block;\n    text-align: left;\n    padding-left: var(--button-attached-horizontal-padding);\n    border-radius: 0em var(--button-border-radius) var(--button-border-radius) 0em;\n  }\n  .attached.buttons {\n    position: relative;\n    display: flex;\n    border-radius: 0em;\n    width: auto;\n    z-index: var(--button-attached-z-index);\n    margin-left: var(--button-attached-offset);\n    margin-right: var(--button-attached-offset);\n  }\n  .attached.buttons .button {\n    margin: 0em;\n  }\n  .attached.buttons .button:first-child {\n    border-radius: 0em;\n  }\n  .attached.buttons .button:last-child {\n    border-radius: 0em;\n  }\n  .top-attached.buttons {\n    margin-bottom: var(--button-attached-offset);\n    border-radius: var(--button-border-radius) var(--button-border-radius) 0em 0em;\n  }\n  .top-attached.buttons .button:first-child {\n    border-radius: var(--button-border-radius) 0em 0em 0em;\n  }\n  .top-attached.buttons .button:last-child {\n    border-radius: 0em var(--button-border-radius) 0em 0em;\n  }\n  .top-attached.buttons {\n    margin-top: var(--button-attached-offset);\n    border-radius: 0em 0em var(--button-border-radius) var(--button-border-radius);\n  }\n  .top-attached.buttons .button:first-child {\n    border-radius: 0em 0em 0em var(--button-border-radius);\n  }\n  .top-attached.buttons .button:last-child {\n    border-radius: 0em 0em var(--button-border-radius) 0em;\n  }\n  .left-attached.buttons {\n    display: inline-flex;\n    margin-right: 0em;\n    margin-left: var(--button-attached-offset);\n    border-radius: 0em var(--button-border-radius) var(--button-border-radius) 0em;\n  }\n  .left-attached.buttons .button:first-child {\n    margin-left: var(--button-attached-offset);\n    border-radius: 0em var(--button-border-radius) 0em 0em;\n  }\n  .left-attached.buttons .button:last-child {\n    margin-left: var(--button-attached-offset);\n    border-radius: 0em 0em var(--button-border-radius) 0em;\n  }\n  .right-attached.buttons {\n    display: inline-flex;\n    margin-left: 0em;\n    margin-right: var(--button-attached-offset);\n    border-radius: var(--button-border-radius) 0em 0em var(--button-border-radius);\n  }\n  .right-attached.buttons .button:first-child {\n    margin-left: var(--button-attached-offset);\n    border-radius: var(--button-border-radius) 0em 0em 0em;\n  }\n  .right-attached.buttons .button:last-child {\n    margin-left: var(--button-attached-offset);\n    border-radius: 0em 0em 0em var(--button-border-radius);\n  }\n}\n\n/* src/components/button/css/definition/variations/circular.css */\n@layer button.definition.variations.circular {\n  .circular.button {\n    border-radius: var(--circular-radius);\n  }\n  .circular.button > .icon {\n    width: 1em;\n    vertical-align: baseline;\n  }\n}\n\n/* src/components/button/css/definition/variations/colored.css */\n@layer button.definition.variations.colored {\n  .red.buttons,\n  .red.button {\n    --button-text-color: var(--button-red-text-color);\n    --button-text-shadow: var(--button-red-text-shadow);\n    --button-background: var(--button-red) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .red.buttons,\n  .red.button:hover {\n    --button-hover-color: var(--button-red-text-color);\n    --button-hover-text-shadow: var(--button-red-text-shadow);\n    --button-hover-background-color: var(--button-red-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .red.buttons,\n  .red.button:focus {\n    --button-focus-background-color: var(--button-red-focus);\n    --button-focus-color: var(--button-red-text-color);\n    --button-focus-text-shadow: var(--button-red-text-shadow);\n  }\n  .red.buttons,\n  .red.button.pressed,\n  .red.button:active {\n    --button-pressed-background-color: var(--button-red-pressed);\n    --button-pressed-color: var(--button-red-text-color);\n    --button-pressed-text-shadow: var(--button-red-text-shadow);\n  }\n  .red.buttons .active.button,\n  .red.buttons .active.button.pressed,\n  .red.buttons .active.button:active,\n  .red.active.button,\n  .red.button .active.button.pressed,\n  .red.button .active.button:active {\n    background-color: var(--button-red-active);\n    color: var(--button-red-text-color);\n    text-shadow: var(--button-red-text-shadow);\n  }\n  .orange.buttons,\n  .orange.button {\n    --button-text-color: var(--button-orange-text-color);\n    --button-text-shadow: var(--button-orange-text-shadow);\n    --button-background: var(--button-orange) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .orange.buttons,\n  .orange.button:hover {\n    --button-hover-color: var(--button-orange-text-color);\n    --button-hover-text-shadow: var(--button-orange-text-shadow);\n    --button-hover-background-color: var(--button-orange-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .orange.buttons,\n  .orange.button:focus {\n    --button-focus-background-color: var(--button-orange-focus);\n    --button-focus-color: var(--button-orange-text-color);\n    --button-focus-text-shadow: var(--button-orange-text-shadow);\n  }\n  .orange.buttons,\n  .orange.button.pressed,\n  .orange.button:active {\n    --button-pressed-background-color: var(--button-orange-pressed);\n    --button-pressed-color: var(--button-orange-text-color);\n    --button-pressed-text-shadow: var(--button-orange-text-shadow);\n  }\n  .orange.buttons .active.button,\n  .orange.buttons .active.button.pressed,\n  .orange.buttons .active.button:active,\n  .orange.active.button,\n  .orange.button .active.button.pressed,\n  .orange.button .active.button:active {\n    background-color: var(--button-orange-active);\n    color: var(--button-orange-text-color);\n    text-shadow: var(--button-orange-text-shadow);\n  }\n  .yellow.buttons,\n  .yellow.button {\n    --button-text-color: var(--button-yellow-text-color);\n    --button-text-shadow: var(--button-yellow-text-shadow);\n    --button-background: var(--button-yellow) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .yellow.buttons,\n  .yellow.button:hover {\n    --button-hover-color: var(--button-yellow-text-color);\n    --button-hover-text-shadow: var(--button-yellow-text-shadow);\n    --button-hover-background-color: var(--button-yellow-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .yellow.buttons,\n  .yellow.button:focus {\n    --button-focus-background-color: var(--button-yellow-focus);\n    --button-focus-color: var(--button-yellow-text-color);\n    --button-focus-text-shadow: var(--button-yellow-text-shadow);\n  }\n  .yellow.buttons,\n  .yellow.button.pressed,\n  .yellow.button:active {\n    --button-pressed-background-color: var(--button-yellow-pressed);\n    --button-pressed-color: var(--button-yellow-text-color);\n    --button-pressed-text-shadow: var(--button-yellow-text-shadow);\n  }\n  .yellow.buttons .active.button,\n  .yellow.buttons .active.button.pressed,\n  .yellow.buttons .active.button:active,\n  .yellow.active.button,\n  .yellow.button .active.button.pressed,\n  .yellow.button .active.button:active {\n    background-color: var(--button-yellow-active);\n    color: var(--button-yellow-text-color);\n    text-shadow: var(--button-yellow-text-shadow);\n  }\n  .olive.buttons,\n  .olive.button {\n    --button-text-color: var(--button-olive-text-color);\n    --button-text-shadow: var(--button-olive-text-shadow);\n    --button-background: var(--button-olive) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .olive.buttons,\n  .olive.button:hover {\n    --button-hover-color: var(--button-olive-text-color);\n    --button-hover-text-shadow: var(--button-olive-text-shadow);\n    --button-hover-background-color: var(--button-olive-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .olive.buttons,\n  .olive.button:focus {\n    --button-focus-background-color: var(--button-olive-focus);\n    --button-focus-color: var(--button-olive-text-color);\n    --button-focus-text-shadow: var(--button-olive-text-shadow);\n  }\n  .olive.buttons,\n  .olive.button.pressed,\n  .olive.button:active {\n    --button-pressed-background-color: var(--button-olive-pressed);\n    --button-pressed-color: var(--button-olive-text-color);\n    --button-pressed-text-shadow: var(--button-olive-text-shadow);\n  }\n  .olive.buttons .active.button,\n  .olive.buttons .active.button.pressed,\n  .olive.buttons .active.button:active,\n  .olive.active.button,\n  .olive.button .active.button.pressed,\n  .olive.button .active.button:active {\n    background-color: var(--button-olive-active);\n    color: var(--button-olive-text-color);\n    text-shadow: var(--button-olive-text-shadow);\n  }\n  .green.buttons,\n  .green.button {\n    --button-text-color: var(--button-green-text-color);\n    --button-text-shadow: var(--button-green-text-shadow);\n    --button-background: var(--button-green) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .green.buttons,\n  .green.button:hover {\n    --button-hover-color: var(--button-green-text-color);\n    --button-hover-text-shadow: var(--button-green-text-shadow);\n    --button-hover-background-color: var(--button-green-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .green.buttons,\n  .green.button:focus {\n    --button-focus-background-color: var(--button-green-focus);\n    --button-focus-color: var(--button-green-text-color);\n    --button-focus-text-shadow: var(--button-green-text-shadow);\n  }\n  .green.buttons,\n  .green.button.pressed,\n  .green.button:active {\n    --button-pressed-background-color: var(--button-green-pressed);\n    --button-pressed-color: var(--button-green-text-color);\n    --button-pressed-text-shadow: var(--button-green-text-shadow);\n  }\n  .green.buttons .active.button,\n  .green.buttons .active.button.pressed,\n  .green.buttons .active.button:active,\n  .green.active.button,\n  .green.button .active.button.pressed,\n  .green.button .active.button:active {\n    background-color: var(--button-green-active);\n    color: var(--button-green-text-color);\n    text-shadow: var(--button-green-text-shadow);\n  }\n  .teal.buttons,\n  .teal.button {\n    --button-text-color: var(--button-teal-text-color);\n    --button-text-shadow: var(--button-teal-text-shadow);\n    --button-background: var(--button-teal) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .teal.buttons,\n  .teal.button:hover {\n    --button-hover-color: var(--button-teal-text-color);\n    --button-hover-text-shadow: var(--button-teal-text-shadow);\n    --button-hover-background-color: var(--button-teal-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .teal.buttons,\n  .teal.button:focus {\n    --button-focus-background-color: var(--button-teal-focus);\n    --button-focus-color: var(--button-teal-text-color);\n    --button-focus-text-shadow: var(--button-teal-text-shadow);\n  }\n  .teal.buttons,\n  .teal.button.pressed,\n  .teal.button:active {\n    --button-pressed-background-color: var(--button-teal-pressed);\n    --button-pressed-color: var(--button-teal-text-color);\n    --button-pressed-text-shadow: var(--button-teal-text-shadow);\n  }\n  .teal.buttons .active.button,\n  .teal.buttons .active.button.pressed,\n  .teal.buttons .active.button:active,\n  .teal.active.button,\n  .teal.button .active.button.pressed,\n  .teal.button .active.button:active {\n    background-color: var(--button-teal-active);\n    color: var(--button-teal-text-color);\n    text-shadow: var(--button-teal-text-shadow);\n  }\n  .blue.buttons,\n  .blue.button {\n    --button-text-color: var(--button-blue-text-color);\n    --button-text-shadow: var(--button-blue-text-shadow);\n    --button-background: var(--button-blue) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .blue.buttons,\n  .blue.button:hover {\n    --button-hover-color: var(--button-blue-text-color);\n    --button-hover-text-shadow: var(--button-blue-text-shadow);\n    --button-hover-background-color: var(--button-blue-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .blue.buttons,\n  .blue.button:focus {\n    --button-focus-background-color: var(--button-blue-focus);\n    --button-focus-color: var(--button-blue-text-color);\n    --button-focus-text-shadow: var(--button-blue-text-shadow);\n  }\n  .blue.buttons,\n  .blue.button.pressed,\n  .blue.button:active {\n    --button-pressed-background-color: var(--button-blue-pressed);\n    --button-pressed-color: var(--button-blue-text-color);\n    --button-pressed-text-shadow: var(--button-blue-text-shadow);\n  }\n  .blue.buttons .active.button,\n  .blue.buttons .active.button.pressed,\n  .blue.buttons .active.button:active,\n  .blue.active.button,\n  .blue.button .active.button.pressed,\n  .blue.button .active.button:active {\n    background-color: var(--button-blue-active);\n    color: var(--button-blue-text-color);\n    text-shadow: var(--button-blue-text-shadow);\n  }\n  .violet.buttons,\n  .violet.button {\n    --button-text-color: var(--button-violet-text-color);\n    --button-text-shadow: var(--button-violet-text-shadow);\n    --button-background: var(--button-violet) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .violet.buttons,\n  .violet.button:hover {\n    --button-hover-color: var(--button-violet-text-color);\n    --button-hover-text-shadow: var(--button-violet-text-shadow);\n    --button-hover-background-color: var(--button-violet-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .violet.buttons,\n  .violet.button:focus {\n    --button-focus-background-color: var(--button-violet-focus);\n    --button-focus-color: var(--button-violet-text-color);\n    --button-focus-text-shadow: var(--button-violet-text-shadow);\n  }\n  .violet.buttons,\n  .violet.button.pressed,\n  .violet.button:active {\n    --button-pressed-background-color: var(--button-violet-pressed);\n    --button-pressed-color: var(--button-violet-text-color);\n    --button-pressed-text-shadow: var(--button-violet-text-shadow);\n  }\n  .violet.buttons .active.button,\n  .violet.buttons .active.button.pressed,\n  .violet.buttons .active.button:active,\n  .violet.active.button,\n  .violet.button .active.button.pressed,\n  .violet.button .active.button:active {\n    background-color: var(--button-violet-active);\n    color: var(--button-violet-text-color);\n    text-shadow: var(--button-violet-text-shadow);\n  }\n  .purple.buttons,\n  .purple.button {\n    --button-text-color: var(--button-purple-text-color);\n    --button-text-shadow: var(--button-purple-text-shadow);\n    --button-background: var(--button-purple) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .purple.buttons,\n  .purple.button:hover {\n    --button-hover-color: var(--button-purple-text-color);\n    --button-hover-text-shadow: var(--button-purple-text-shadow);\n    --button-hover-background-color: var(--button-purple-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .purple.buttons,\n  .purple.button:focus {\n    --button-focus-background-color: var(--button-purple-focus);\n    --button-focus-color: var(--button-purple-text-color);\n    --button-focus-text-shadow: var(--button-purple-text-shadow);\n  }\n  .purple.buttons,\n  .purple.button.pressed,\n  .purple.button:active {\n    --button-pressed-background-color: var(--button-purple-pressed);\n    --button-pressed-color: var(--button-purple-text-color);\n    --button-pressed-text-shadow: var(--button-purple-text-shadow);\n  }\n  .purple.buttons .active.button,\n  .purple.buttons .active.button.pressed,\n  .purple.buttons .active.button:active,\n  .purple.active.button,\n  .purple.button .active.button.pressed,\n  .purple.button .active.button:active {\n    background-color: var(--button-purple-active);\n    color: var(--button-purple-text-color);\n    text-shadow: var(--button-purple-text-shadow);\n  }\n  .pink.buttons,\n  .pink.button {\n    --button-text-color: var(--button-pink-text-color);\n    --button-text-shadow: var(--button-pink-text-shadow);\n    --button-background: var(--button-pink) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .pink.buttons,\n  .pink.button:hover {\n    --button-hover-color: var(--button-pink-text-color);\n    --button-hover-text-shadow: var(--button-pink-text-shadow);\n    --button-hover-background-color: var(--button-pink-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .pink.buttons,\n  .pink.button:focus {\n    --button-focus-background-color: var(--button-pink-focus);\n    --button-focus-color: var(--button-pink-text-color);\n    --button-focus-text-shadow: var(--button-pink-text-shadow);\n  }\n  .pink.buttons,\n  .pink.button.pressed,\n  .pink.button:active {\n    --button-pressed-background-color: var(--button-pink-pressed);\n    --button-pressed-color: var(--button-pink-text-color);\n    --button-pressed-text-shadow: var(--button-pink-text-shadow);\n  }\n  .pink.buttons .active.button,\n  .pink.buttons .active.button.pressed,\n  .pink.buttons .active.button:active,\n  .pink.active.button,\n  .pink.button .active.button.pressed,\n  .pink.button .active.button:active {\n    background-color: var(--button-pink-active);\n    color: var(--button-pink-text-color);\n    text-shadow: var(--button-pink-text-shadow);\n  }\n  .brown.buttons,\n  .brown.button {\n    --button-text-color: var(--button-brown-text-color);\n    --button-text-shadow: var(--button-brown-text-shadow);\n    --button-background: var(--button-brown) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .brown.buttons,\n  .brown.button:hover {\n    --button-hover-color: var(--button-brown-text-color);\n    --button-hover-text-shadow: var(--button-brown-text-shadow);\n    --button-hover-background-color: var(--button-brown-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .brown.buttons,\n  .brown.button:focus {\n    --button-focus-background-color: var(--button-brown-focus);\n    --button-focus-color: var(--button-brown-text-color);\n    --button-focus-text-shadow: var(--button-brown-text-shadow);\n  }\n  .brown.buttons,\n  .brown.button.pressed,\n  .brown.button:active {\n    --button-pressed-background-color: var(--button-brown-pressed);\n    --button-pressed-color: var(--button-brown-text-color);\n    --button-pressed-text-shadow: var(--button-brown-text-shadow);\n  }\n  .brown.buttons .active.button,\n  .brown.buttons .active.button.pressed,\n  .brown.buttons .active.button:active,\n  .brown.active.button,\n  .brown.button .active.button.pressed,\n  .brown.button .active.button:active {\n    background-color: var(--button-brown-active);\n    color: var(--button-brown-text-color);\n    text-shadow: var(--button-brown-text-shadow);\n  }\n  .grey.buttons,\n  .grey.button {\n    --button-text-color: var(--button-grey-text-color);\n    --button-text-shadow: var(--button-grey-text-shadow);\n    --button-background: var(--button-grey) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .grey.buttons,\n  .grey.button:hover {\n    --button-hover-color: var(--button-grey-text-color);\n    --button-hover-text-shadow: var(--button-grey-text-shadow);\n    --button-hover-background-color: var(--button-grey-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .grey.buttons,\n  .grey.button:focus {\n    --button-focus-background-color: var(--button-grey-focus);\n    --button-focus-color: var(--button-grey-text-color);\n    --button-focus-text-shadow: var(--button-grey-text-shadow);\n  }\n  .grey.buttons,\n  .grey.button.pressed,\n  .grey.button:active {\n    --button-pressed-background-color: var(--button-grey-pressed);\n    --button-pressed-color: var(--button-grey-text-color);\n    --button-pressed-text-shadow: var(--button-grey-text-shadow);\n  }\n  .grey.buttons .active.button,\n  .grey.buttons .active.button.pressed,\n  .grey.buttons .active.button:active,\n  .grey.active.button,\n  .grey.button .active.button.pressed,\n  .grey.button .active.button:active {\n    background-color: var(--button-grey-active);\n    color: var(--button-grey-text-color);\n    text-shadow: var(--button-grey-text-shadow);\n  }\n  .black.buttons,\n  .black.button {\n    --button-text-color: var(--button-black-text-color);\n    --button-text-shadow: var(--button-black-text-shadow);\n    --button-background: var(--button-black) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .black.buttons,\n  .black.button:hover {\n    --button-hover-color: var(--button-black-text-color);\n    --button-hover-text-shadow: var(--button-black-text-shadow);\n    --button-hover-background-color: var(--button-black-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .black.buttons,\n  .black.button:focus {\n    --button-focus-background-color: var(--button-black-focus);\n    --button-focus-color: var(--button-black-text-color);\n    --button-focus-text-shadow: var(--button-black-text-shadow);\n  }\n  .black.buttons,\n  .black.button.pressed,\n  .black.button:active {\n    --button-pressed-background-color: var(--button-black-pressed);\n    --button-pressed-color: var(--button-black-text-color);\n    --button-pressed-text-shadow: var(--button-black-text-shadow);\n  }\n  .black.buttons .active.button,\n  .black.buttons .active.button.pressed,\n  .black.buttons .active.button:active,\n  .black.active.button,\n  .black.button .active.button.pressed,\n  .black.button .active.button:active {\n    background-color: var(--button-black-active);\n    color: var(--button-black-text-color);\n    text-shadow: var(--button-black-text-shadow);\n  }\n}\n\n/* src/components/button/css/definition/variations/compact.css */\n@layer button.definition.variations.compact {\n  .compact.buttons .button,\n  .compact.button {\n    padding: var(--button-compact-vertical-padding) var(--button-compact-horizontal-padding);\n  }\n  .compact.icon.buttons .button,\n  .compact.icon.button {\n    padding: var(--button-compact-icon-padding);\n  }\n  .very-compact.buttons .button,\n  .very-compact.button {\n    padding: var(--button-very-compact-vertical-padding) var(--button-very-compact-horizontal-padding);\n  }\n  .very-compact.icon.buttons .button,\n  .very-compact.icon.button {\n    padding: var(--button-very-compact-icon-padding);\n  }\n}\n\n/* src/components/button/css/definition/variations/floated.css */\n@layer button.definition.variations.floated {\n  .left-floated.buttons,\n  .left-floated.button {\n    float: left;\n    margin-left: 0em;\n    margin-right: var(--button-floated-margin);\n  }\n  .right-floated.buttons,\n  .right-floated.button {\n    float: right;\n    margin-right: 0em;\n    margin-left: var(--button-floated-margin);\n  }\n}\n\n/* src/components/button/css/definition/variations/fluid.css */\n@layer button.definition.variations.fluid {\n  .fluid.buttons,\n  .fluid.button {\n    width: 100%;\n  }\n  .fluid.button {\n    display: block;\n  }\n  .two.buttons {\n    width: 100%;\n  }\n  .two.buttons > .button {\n    width: 50%;\n  }\n  .three.buttons {\n    width: 100%;\n  }\n  .three.buttons > .button {\n    width: 33.333%;\n  }\n  .four.buttons {\n    width: 100%;\n  }\n  .four.buttons > .button {\n    width: 25%;\n  }\n  .five.buttons {\n    width: 100%;\n  }\n  .five.buttons > .button {\n    width: 20%;\n  }\n  .six.buttons {\n    width: 100%;\n  }\n  .six.buttons > .button {\n    width: 16.666%;\n  }\n  .seven.buttons {\n    width: 100%;\n  }\n  .seven.buttons > .button {\n    width: 14.285%;\n  }\n  .eight.buttons {\n    width: 100%;\n  }\n  .eight.buttons > .button {\n    width: 12.500%;\n  }\n  .nine.buttons {\n    width: 100%;\n  }\n  .nine.buttons > .button {\n    width: 11.11%;\n  }\n  .ten.buttons {\n    width: 100%;\n  }\n  .ten.buttons > .button {\n    width: 10%;\n  }\n  .eleven.buttons {\n    width: 100%;\n  }\n  .eleven.buttons > .button {\n    width: 9.09%;\n  }\n  .twelve.buttons {\n    width: 100%;\n  }\n  .twelve.buttons > .button {\n    width: 8.3333%;\n  }\n  .fluid.vertical.buttons,\n  .fluid.vertical.buttons > .button {\n    display: flex;\n    width: auto;\n  }\n  .two.vertical.buttons > .button {\n    height: 50%;\n  }\n  .three.vertical.buttons > .button {\n    height: 33.333%;\n  }\n  .four.vertical.buttons > .button {\n    height: 25%;\n  }\n  .five.vertical.buttons > .button {\n    height: 20%;\n  }\n  .six.vertical.buttons > .button {\n    height: 16.666%;\n  }\n  .seven.vertical.buttons > .button {\n    height: 14.285%;\n  }\n  .eight.vertical.buttons > .button {\n    height: 12.500%;\n  }\n  .nine.vertical.buttons > .button {\n    height: 11.11%;\n  }\n  .ten.vertical.buttons > .button {\n    height: 10%;\n  }\n  .eleven.vertical.buttons > .button {\n    height: 9.09%;\n  }\n  .twelve.vertical.buttons > .button {\n    height: 8.3333%;\n  }\n}\n\n/* src/components/button/css/definition/variations/negative.css */\n@layer button.definition.variations.negative {\n  .negative.buttons .button,\n  .negative.button {\n    background-color: var(--button-negative-color);\n    color: var(--button-negative-text-color);\n    text-shadow: var(--button-negative-text-shadow);\n    background-image: var(--button-colored-background-image);\n  }\n  .negative.button {\n    box-shadow: var(--button-negative-box-shadow);\n  }\n  .negative.buttons .button:hover,\n  .negative.button:hover {\n    background-color: var(--button-negative-color-hover);\n    color: var(--button-negative-text-color);\n    text-shadow: var(--button-negative-text-shadow);\n    box-shadow: var(--button-hover-box-shadow);\n  }\n  .negative.buttons .button:focus,\n  .negative.button:focus {\n    background-color: var(--button-negative-color-focus);\n    color: var(--button-negative-text-color);\n    text-shadow: var(--button-negative-text-shadow);\n    box-shadow: var(--button-focus-box-shadow);\n  }\n  .negative.buttons .button.pressed,\n  .negative.button.pressed,\n  .negative.buttons .button:active,\n  .negative.button:active {\n    background-color: var(--button-negative-color-down);\n    color: var(--button-negative-text-color);\n    text-shadow: var(--button-negative-text-shadow);\n    box-shadow: var(--button-pressed-box-shadow);\n  }\n  .negative.buttons .active.button,\n  .negative.buttons .active.button:active,\n  .negative.active.button,\n  .negative.button .active.button:active {\n    background-color: var(--button-negative-color-active);\n    color: var(--button-negative-text-color);\n    text-shadow: var(--button-negative-text-shadow);\n    box-shadow: var(--button-active-box-shadow);\n  }\n  .subtle-negative.buttons .button,\n  .subtle-negative.button {\n    background-color: var(--button-subtle-negative-color);\n    color: var(--button-subtle-negative-text-color);\n    text-shadow: var(--button-subtle-negative-text-shadow);\n    background-image: var(--button-subtle-negative-background-image);\n  }\n  .subtle-negative.button {\n    box-shadow: var(--button-subtle-negative-box-shadow);\n  }\n  .subtle-negative.buttons .button:hover,\n  .subtle-negative.button:hover {\n    background-color: var(--button-subtle-negative-color-hover);\n    color: var(--button-subtle-negative-text-color);\n    text-shadow: var(--button-subtle-negative-text-shadow);\n    box-shadow: var(--button-hover-box-shadow);\n  }\n  .subtle-negative.buttons .button:focus,\n  .subtle-negative.button:focus {\n    background-color: var(--button-subtle-negative-color-focus);\n    color: var(--button-subtle-negative-text-color);\n    text-shadow: var(--button-subtle-negative-text-shadow);\n    box-shadow: var(--button-focus-box-shadow);\n  }\n  .subtle-negative.buttons .button.pressed,\n  .subtle-negative.button.pressed,\n  .subtle-negative.buttons .button:active,\n  .subtle-negative.button:active {\n    background-color: var(--button-subtle-negative-color-down);\n    color: var(--button-subtle-negative-text-color);\n    text-shadow: var(--button-subtle-negative-text-shadow);\n    box-shadow: var(--button-pressed-box-shadow);\n  }\n  .subtle-negative.buttons .active.button,\n  .subtle-negative.buttons .active.button:active,\n  .subtle-negative.active.button,\n  .subtle-negative.button .active.button:active {\n    background-color: var(--button-subtle-negative-color-active);\n    background-image: var(--button-subtle-negative-background-image);\n    color: var(--button-subtle-negative-text-color);\n    text-shadow: var(--button-subtle-negative-text-shadow);\n    box-shadow: var(--button-active-box-shadow);\n  }\n  .subtle-negative.buttons .button > .icon,\n  .subtle-negative.button > .icon {\n    color: var(--button-subtle-negative-text-color);\n  }\n}\n\n/* src/components/button/css/definition/variations/positive.css */\n@layer button.definition.variations.positive {\n  .positive.buttons .button,\n  .positive.button {\n    background-color: var(--button-positive-color);\n    color: var(--button-positive-text-color);\n    text-shadow: var(--button-positive-text-shadow);\n    background-image: var(--button-positive-background-image);\n  }\n  .positive.button {\n    box-shadow: var(--button-positive-box-shadow);\n  }\n  .positive.buttons .button:hover,\n  .positive.button:hover {\n    background-color: var(--button-positive-color-hover);\n    color: var(--button-positive-text-color);\n    text-shadow: var(--button-positive-text-shadow);\n    box-shadow: var(--button-hover-box-shadow);\n  }\n  .positive.buttons .button:focus,\n  .positive.button:focus {\n    background-color: var(--button-positive-color-focus);\n    color: var(--button-positive-text-color);\n    text-shadow: var(--button-positive-text-shadow);\n    box-shadow: var(--button-focus-box-shadow);\n  }\n  .positive.buttons .button.pressed,\n  .positive.button.pressed,\n  .positive.buttons .button:active,\n  .positive.button:active {\n    background-color: var(--button-positive-color-down);\n    color: var(--button-positive-text-color);\n    text-shadow: var(--button-positive-text-shadow);\n    box-shadow: var(--button-pressed-box-shadow);\n  }\n  .positive.buttons .active.button,\n  .positive.buttons .active.button:active,\n  .positive.active.button,\n  .positive.button .active.button:active {\n    background-color: var(--button-positive-color-active);\n    color: var(--button-positive-text-color);\n    text-shadow: var(--button-positive-text-shadow);\n    box-shadow: var(--button-active-box-shadow);\n  }\n  .subtle-positive.buttons .button,\n  .subtle-positive.button {\n    background-color: var(--button-subtle-positive-color);\n    color: var(--button-subtle-positive-text-color);\n    text-shadow: var(--button-subtle-positive-text-shadow);\n    background-image: var(--button-subtle-positive-background-image);\n  }\n  .subtle-positive.button {\n    box-shadow: var(--button-subtle-positive-box-shadow);\n  }\n  .subtle-positive.buttons .button:hover,\n  .subtle-positive.button:hover {\n    background-color: var(--button-subtle-positive-color-hover);\n    color: var(--button-subtle-positive-text-color);\n    text-shadow: var(--button-subtle-positive-text-shadow);\n    box-shadow: var(--button-hover-box-shadow);\n  }\n  .subtle-positive.buttons .button:focus,\n  .subtle-positive.button:focus {\n    background-color: var(--button-subtle-positive-color-focus);\n    color: var(--button-subtle-positive-text-color);\n    text-shadow: var(--button-subtle-positive-text-shadow);\n    box-shadow: var(--button-focus-box-shadow);\n  }\n  .subtle-positive.buttons .button.pressed,\n  .subtle-positive.button.pressed,\n  .subtle-positive.buttons .button:active,\n  .subtle-positive.button:active {\n    background-color: var(--button-subtle-positive-color-down);\n    color: var(--button-subtle-positive-text-color);\n    text-shadow: var(--button-subtle-positive-text-shadow);\n    box-shadow: var(--button-pressed-box-shadow);\n  }\n  .subtle-positive.buttons .active.button,\n  .subtle-positive.active.button,\n  .subtle-positive.buttons .active.button:active,\n  .subtle-positive.button .active.button:active {\n    background-color: var(--button-subtle-positive-color-active);\n    background-image: var(--button-subtle-positive-background-image);\n    color: var(--button-subtle-positive-text-color);\n    text-shadow: var(--button-subtle-positive-text-shadow);\n    box-shadow: var(--button-active-box-shadow);\n  }\n  .subtle-positive.buttons .button > .icon,\n  .subtle-positive.button > .icon {\n    color: var(--button-subtle-positive-text-color);\n  }\n}\n\n/* src/components/button/css/definition/variations/warning.css */\n@layer button.definition.variations.warning {\n  .warning.buttons .button,\n  .warning.button {\n    background-color: var(--button-warning-color);\n    color: var(--button-warning-text-color);\n    text-shadow: var(--button-warning-text-shadow);\n    background-image: var(--button-colored-background-image);\n  }\n  .warning.button {\n    box-shadow: var(--button-warning-box-shadow);\n  }\n  .warning.buttons .button:hover,\n  .warning.button:hover {\n    background-color: var(--button-warning-color-hover);\n    color: var(--button-warning-text-color);\n    text-shadow: var(--button-warning-text-shadow);\n    box-shadow: var(--button-hover-box-shadow);\n  }\n  .warning.buttons .button:focus,\n  .warning.button:focus {\n    background-color: var(--button-warning-color-focus);\n    color: var(--button-warning-text-color);\n    text-shadow: var(--button-warning-text-shadow);\n    box-shadow: var(--button-focus-box-shadow);\n  }\n  .warning.buttons .button:active,\n  .warning.button:active {\n    background-color: var(--button-warning-color-down);\n    color: var(--button-warning-text-color);\n    text-shadow: var(--button-warning-text-shadow);\n  }\n  .warning.buttons .active.button,\n  .warning.buttons .active.button:active,\n  .warning.active.button,\n  .warning.button .active.button:active {\n    background-color: var(--button-warning-color-active);\n    color: var(--button-warning-text-color);\n    text-shadow: var(--button-warning-text-shadow);\n  }\n  .subtle-warning.buttons .button,\n  .subtle-warning.button {\n    background-color: var(--button-subtle-warning-color);\n    color: var(--button-subtle-warning-text-color);\n    text-shadow: var(--button-subtle-warning-text-shadow);\n    background-image: var(--button-subtle-warning-background-image);\n  }\n  .subtle-warning.button {\n    box-shadow: var(--button-subtle-warning-box-shadow);\n  }\n  .subtle-warning.buttons .button:hover,\n  .subtle-warning.button:hover {\n    background-color: var(--button-subtle-warning-color-hover);\n    color: var(--button-subtle-warning-text-color);\n    text-shadow: var(--button-subtle-warning-text-shadow);\n    box-shadow: var(--button-hover-box-shadow);\n  }\n  .subtle-warning.buttons .button:focus,\n  .subtle-warning.button:focus {\n    background-color: var(--button-subtle-warning-color-focus);\n    color: var(--button-subtle-warning-text-color);\n    text-shadow: var(--button-subtle-warning-text-shadow);\n    box-shadow: var(--button-focus-box-shadow);\n  }\n  .subtle-warning.buttons .button:active,\n  .subtle-warning.button:active {\n    background-color: var(--button-subtle-warning-color-down);\n    color: var(--button-subtle-warning-text-color);\n    text-shadow: var(--button-subtle-warning-text-shadow);\n    box-shadow: var(--button-pressed-box-shadow);\n  }\n  .subtle-warning.buttons .active.button,\n  .subtle-warning.buttons .active.button:active,\n  .subtle-warning.active.button,\n  .subtle-warning.button .active.button:active {\n    background-color: var(--button-subtle-warning-color-active);\n    background-image: var(--button-subtle-warning-background-image);\n    color: var(--button-subtle-warning-text-color);\n    text-shadow: var(--button-subtle-warning-text-shadow);\n    box-shadow: var(--button-active-box-shadow);\n  }\n  .subtle-warning.buttons .button > .icon,\n  .subtle-warning.button > .icon {\n    color: var(--button-subtle-warning-text-color);\n  }\n}\n\n/* src/components/button/css/definition/variations/info.css */\n@layer button.definition.variations.info {\n  .info.buttons .button,\n  .info.button {\n    background-color: var(--button-info-color);\n    color: var(--button-info-text-color);\n    text-shadow: var(--button-info-text-shadow);\n    background-image: var(--button-colored-background-image);\n  }\n  .info.button {\n    box-shadow: var(--button-info-box-shadow);\n  }\n  .info.buttons .button:hover,\n  .info.button:hover {\n    background-color: var(--button-info-color-hover);\n    color: var(--button-info-text-color);\n    text-shadow: var(--button-info-text-shadow);\n  }\n  .info.buttons .button:focus,\n  .info.button:focus {\n    background-color: var(--button-info-color-focus);\n    color: var(--button-info-text-color);\n    text-shadow: var(--button-info-text-shadow);\n  }\n  .info.buttons .button.pressed,\n  .info.button.pressed,\n  .info.buttons .button:active,\n  .info.button:active {\n    background-color: var(--button-info-color-down);\n    color: var(--button-info-text-color);\n    text-shadow: var(--button-info-text-shadow);\n  }\n  .info.buttons .active.button,\n  .info.buttons .active.button:active,\n  .info.active.button,\n  .info.button .active.button:active {\n    background-color: var(--button-info-color-active);\n    color: var(--button-info-text-color);\n    text-shadow: var(--button-info-text-shadow);\n  }\n  .subtle-info.buttons .button,\n  .subtle-info.button {\n    background-color: var(--button-subtle-info-color);\n    color: var(--button-subtle-info-text-color);\n    text-shadow: var(--button-subtle-info-text-shadow);\n    background-image: var(--button-subtle-info-background-image);\n  }\n  .subtle-info.button {\n    box-shadow: var(--button-subtle-info-box-shadow);\n  }\n  .subtle-info.buttons .button:hover,\n  .subtle-info.button:hover {\n    background-color: var(--button-subtle-info-color-hover);\n    color: var(--button-subtle-info-text-color);\n    text-shadow: var(--button-subtle-info-text-shadow);\n  }\n  .subtle-info.buttons .button:focus,\n  .subtle-info.button:focus {\n    background-color: var(--button-subtle-info-color-focus);\n    color: var(--button-subtle-info-text-color);\n    text-shadow: var(--button-subtle-info-text-shadow);\n  }\n  .subtle-info.buttons .button.pressed,\n  .subtle-info.button.pressed,\n  .subtle-info.buttons .button:active,\n  .subtle-info.button:active {\n    background-color: var(--button-subtle-info-color-down);\n    color: var(--button-subtle-info-text-color);\n    text-shadow: var(--button-subtle-info-text-shadow);\n  }\n  .subtle-info.buttons .active.button,\n  .subtle-info.buttons .active.button:active,\n  .subtle-info.active.button,\n  .subtle-info.button .active.button:active {\n    background-color: var(--button-subtle-info-color-active);\n    background-image: var(--button-subtle-info-background-image);\n    color: var(--button-subtle-info-text-color);\n    text-shadow: var(--button-subtle-info-text-shadow);\n  }\n  .subtle-info.buttons .button > .icon,\n  .subtle-info.button > .icon {\n    color: var(--button-subtle-info-text-color);\n  }\n}\n\n/* src/components/button/css/definition/variations/sizing.css */\n@layer button.definition.variations.sizing {\n  .mini.button {\n    font-size: var(--button-mini);\n  }\n  .tiny.button {\n    font-size: var(--button-tiny);\n  }\n  .small.button {\n    font-size: var(--button-small);\n  }\n  :host {\n    font-size: var(--button-medium);\n  }\n  .large.button {\n    font-size: var(--button-large);\n  }\n  .big.button {\n    font-size: var(--button-big);\n  }\n  .huge.button {\n    font-size: var(--button-huge);\n  }\n  .massive.button {\n    font-size: var(--button-massive);\n  }\n  .mini.buttons {\n    --button-medium: var(--button-mini);\n  }\n  .tiny.buttons {\n    --button-medium: var(--button-tiny);\n  }\n  .small.buttons {\n    --button-medium: var(--button-small);\n  }\n  .large.buttons {\n    --button-medium: var(--button-large);\n  }\n  .big.buttons {\n    --button-medium: var(--button-big);\n  }\n  .huge.buttons {\n    --button-medium: var(--button-huge);\n  }\n  .massive.buttons {\n    --button-medium: var(--button-massive);\n  }\n}\n\n/* src/components/button/css/definition/variations/social.css */\n@layer button.definition.variations.social {\n  .social.button .icon {\n    opacity: 1;\n  }\n  .facebook.button {\n    background-color: var(--facebook-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n    background-image: var(--button-colored-background-image);\n    box-shadow: var(--button-colored-box-shadow);\n  }\n  .facebook.button:hover {\n    background-color: var(--facebook-hover-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .facebook.button:active {\n    background-color: var(--facebook-down-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .twitter.button {\n    background-color: var(--twitter-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n    background-image: var(--button-colored-background-image);\n    box-shadow: var(--button-colored-box-shadow);\n  }\n  .twitter.button:hover {\n    background-color: var(--twitter-hover-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .twitter.button:active {\n    background-color: var(--twitter-down-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .linkedin.button {\n    background-color: var(--linked-in-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .linkedin.button:hover {\n    background-color: var(--linked-in-hover-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .linkedin.button:active {\n    background-color: var(--linked-in-down-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .youtube.button {\n    background-color: var(--youtube-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n    background-image: var(--button-colored-background-image);\n    box-shadow: var(--button-colored-box-shadow);\n  }\n  .youtube.button:hover {\n    background-color: var(--youtube-hover-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .youtube.button:active {\n    background-color: var(--youtube-down-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .instagram.button {\n    background-color: var(--instagram-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n    background-image: var(--button-instagram-background-image);\n    box-shadow: var(--button-colored-box-shadow);\n  }\n  .instagram.button:hover {\n    background-color: var(--instagram-hover-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .instagram.button:active {\n    background-color: var(--instagram-down-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .pinterest.button {\n    background-color: var(--pinterest-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n    background-image: var(--button-colored-background-image);\n    box-shadow: var(--button-colored-box-shadow);\n  }\n  .pinterest.button:hover {\n    background-color: var(--pinterest-hover-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .pinterest.button:active {\n    background-color: var(--pinterest-down-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n}\n\n/* src/components/button/css/definition/variations/vertical.css */\n@layer button.definition.variations.vertical {\n  .vertical.buttons {\n    display: inline-flex;\n    flex-direction: column;\n  }\n  .vertical.buttons .button {\n    display: block;\n    float: none;\n    width: 100%;\n    margin: var(--vertical-group-offset);\n    box-shadow: var(--vertical-box-shadow);\n    border-radius: 0em;\n  }\n  .vertical.buttons .button:first-child {\n    border-top-left-radius: var(--border-radius);\n    border-top-right-radius: var(--border-radius);\n  }\n  .vertical.buttons .button:last-child {\n    margin-bottom: 0px;\n    border-bottom-left-radius: var(--border-radius);\n    border-bottom-right-radius: var(--border-radius);\n  }\n  .vertical.buttons .button:only-child {\n    border-radius: var(--border-radius);\n  }\n}\n\n/* src/components/button/css/definition/button-definition.css */\n\n/* src/components/button/css/theme/content/button-variables.css */\n@layer button.theme.content.button {\n  :host {\n    --button-vertical-align: baseline;\n    --button-vertical-margin: 0em;\n    --button-horizontal-margin: var(--3px);\n    --button-background-color: oklch(0.98 0 0 / 1);\n    --button-background-image: var(--subtle-gradient);\n    --button-background: var(--button-background-color) var(--button-background-image);\n    --button-line-height: 1em;\n    --button-vertical-padding: var(--input-vertical-padding);\n    --button-horizontal-padding: var(--relative-19px);\n    --button-padding: var(--button-vertical-padding) var(--button-horizontal-padding);\n    --button-text-transform: none;\n    --button-tap-color: transparent;\n    --button-font-family: var(--page-font);\n    --button-font-weight: var(--bold);\n    --button-text-color: var(--black-80);\n    --button-inverted-text-color: var(--white-80);\n    --button-text-shadow: none;\n    --button-inverted-text-shadow: var(--button-text-shadow);\n    --button-border-radius: var(--border-radius);\n    --button-border: none;\n    --button-border-color: var(--black-border-color);\n    --button-border-width: 1px;\n    --button-sharpen-box-shadow: 0px -1px 0px 0px rgba(0, 0, 0, 0.05) inset;\n    --button-border-box-shadow: 0px 0px 0px var(--button-border-width) var(--button-border-color) inset;\n    --button-shadow-box-shadow: var(--subtle-shadow);\n    --button-box-shadow:\n      var(--button-sharpen-box-shadow),\n      var(--button-border-box-shadow),\n      var(--button-shadow-box-shadow) ;\n    --button-transition-duration: var(--duration);\n    --button-transition-easing: var(--easing);\n    --button-transition:\n      opacity var(--button-transition-duration) var(--button-transition-easing),\n      background-color var(--button-transition-duration) var(--button-transition-easing),\n      color var(--button-transition-duration) var(--button-transition-easing),\n      box-shadow var(--button-transition-duration) var(--button-transition-easing),\n      background var(--button-transition-duration) var(--button-transition-easing) ;\n    --button-will-change: initial;\n  }\n}\n\n/* src/components/button/css/theme/content/icon-variables.css */\n@layer button.theme.content.icon {\n  :host {\n    --button-icon-opacity: 0.4;\n  }\n}\n\n/* src/components/button/css/theme/content/label-variables.css */\n@layer button.theme.content.label {\n  :host {\n    --labeled-label-font-size: var(--medium);\n    --labeled-label-align: center;\n    --labeled-label-padding: "";\n    --labeled-label-font-size: var(--relative-medium);\n    --labeled-label-border-color: var(--border-color);\n    --labeled-label-border-offset: -var(--border-box-shadow-width);\n    --labeled-tag-label-size: 1.85em;\n    --labeled-icon-margin: 0em;\n    --labeled-icon-width: 1em + calc(var(--vertical-padding) * 2);\n    --labeled-icon-background-color: rgba(0, 0, 0, 0.05);\n    --labeled-icon-padding: calc(var(--horizontal-padding) + var(--labeled-icon-width));\n    --labeled-icon-border: transparent;\n    --labeled-icon-color: "";\n    --labeled-icon-left-shadow: -1px 0px 0px 0px var(--labeled-icon-border) inset;\n    --labeled-icon-right-shadow: 1px 0px 0px 0px var(--labeled-icon-border) inset;\n  }\n}\n\n/* src/components/button/css/theme/content/or-variables.css */\n@layer button.theme.content.or {\n  :host {\n    --button-or-text: "or";\n    --button-or-gap: 0.3em;\n    --button-or-height: calc(var(--button-vertical-padding) * 2) + 1em;\n    --button-or-z-index: 3;\n    --button-or-circle-distance-to-edge: var(--button-vertical-padding);\n    --button-or-circle-size: calc(var(--button-or-height) - var(--button-or-circle-distance-to-edge));\n    --button-or-line-height: var(--button-or-circle-size);\n    --button-or-box-shadow: var(--button-border-box-shadow), var(--button-shadow-box-shadow);\n    --button-or-vertical-offset: calc(var(--button-or-circle-size) / 2 * -1);\n    --button-or-horizontal-offset: calc(var(--button-or-circle-size) / 2 * -1 );\n    --button-or-background-color: var(--white);\n    --button-or-text-shadow: var(--button-text-shadow);\n    --button-or-text-style: var(--normal);\n    --button-or-text-weight: var(--bold);\n    --button-or-text-color: var(--light-text-color);\n    --button-or-spacer-height: var(--button-vertical-padding);\n    --button-or-spacer-color: transparent;\n  }\n}\n\n/* src/components/button/css/theme/plural/buttons-variables.css */\n@layer button.theme.plural {\n  :host {\n    --button-group-box-shadow: none;\n    --button-group-button-box-shadow: var(--button-box-shadow);\n    --button-vertical-box-shadow: none;\n    --button-group-button-offset: 0px 0px 0px 0px;\n    --button-vertical-group-offset: 0px 0px 0px 0px;\n  }\n}\n\n/* src/components/button/css/theme/types/emphasis-variables.css */\n@layer button.theme.types.emphasis {\n  :host {\n    --button-primary-color: var(--primary-color);\n    --button-primary-background-image: var(--button-colored-background-image);\n    --button-primary-box-shadow: var(--button-colored-box-shadow);\n    --button-primary-text-color: var(--button-inverted-text-color);\n    --button-primary-text-shadow: var(--button-inverted-text-shadow);\n    --button-secondary-color: var(--secondary-color);\n    --button-secondary-background-image: var(--button-colored-background-image);\n    --button-secondary-box-shadow: var(--button-colored-box-shadow);\n    --button-secondary-text-color: var(--button-inverted-text-color);\n    --button-secondary-text-shadow: var(--button-inverted-text-shadow);\n    --button-primary-color-hover: oklch(from var(--button-primary-color) calc(l + var(--hover-lightness)) c h);\n    --button-secondary-color-hover: oklch(from var(--button-secondary-color) calc(l + var(--hover-lightness)) c h);\n    --button-primary-color-focus: oklch(from var(--button-primary-color) calc(l + var(--focus-lightness)) c h);\n    --button-secondary-color-focus: oklch(from var(--button-secondary-color) calc(l + var(--focus-lightness)) c h);\n    --button-primary-color-down: oklch(from var(--button-primary-color) calc(l + var(--down-lightness)) c h);\n    --button-secondary-color-down: oklch(from var(--button-secondary-color) calc(l + var(--down-lightness)) c h);\n    --button-primary-color-active: oklch(from var(--button-primary-color) calc(l + var(--active-lightness)) c h);\n    --button-secondary-color-active: oklch(from var(--button-secondary-color) calc(l + var(--active-lightness)) c h);\n    --button-light-primary-text-color: var(--button-inverted-text-color);\n    --button-light-secondary-text-color: var(--button-inverted-text-color);\n  }\n}\n\n/* src/components/button/css/theme/types/icon-variables.css */\n@layer button.theme.types.icon {\n  ui-button {\n  }\n}\n\n/* src/components/button/css/theme/types/labeled-variables.css */\n@layer button.theme.types.labeled {\n  ui-button {\n  }\n}\n\n/* src/components/button/css/theme/types/labeled-icon-variables.css */\n@layer button.theme.types.labeled-icon {\n  ui-button {\n  }\n}\n\n/* src/components/button/css/theme/types/toggle-variables.css */\n@layer button.theme.types.toggle {\n  :host {\n    --button-toggle-active-background: #CFF3D8;\n    --button-toggle-active-color: #22592D;\n    --button-toggle-active-text-shadow: var(--button-text-shadow);\n    --button-toggle-active-hover-background: #CFFFD8;\n    --button-toggle-active-hover-color: #22592D;\n  }\n}\n\n/* src/components/button/css/theme/types/animated-variables.css */\n@layer button.theme.types.animated {\n  :host {\n    --button-animated-vertical-align: middle;\n    --button-animated-z-index: 1;\n    --button-animation-duration: 0.3s;\n    --button-animation-easing: ease;\n    --button-fade-scale-high: 1.5;\n    --button-fade-scale-low: 0.75;\n  }\n}\n\n/* src/components/button/css/theme/types/transparent-variables.css */\n@layer button.theme.types.transparent {\n  :host {\n    --button-transparent-background-image: linear-gradient(rgba(255, 255, 255, 0.05), rgba(0, 0, 0, 0.08));\n    --button-transparent-background-color: rgba(0, 0, 0, 0.03);\n    --button-transparent-text-color: var(--button-text-color);\n    --button-transparent-box-shadow: var(--button-box-shadow);\n    --button-transparent-hover-background-image: linear-gradient(rgba(255, 255, 255, 0.08), rgba(0, 0, 0, 0.1));\n    --button-transparent-hover-background-color: var(--subtle-transparent-white);\n    --button-transparent-hover-text-color: var(--button-hover-color);\n    --button-transparent-hover-box-shadow: var(--button-hover-box-shadow);\n    --button-transparent-pressed-background-image: var(--button-transparent-hover-background-image);\n    --button-transparent-pressed-background-color: var(--transparent-white);\n    --button-transparent-pressed-text-color: var(--button-pressed-color);\n    --button-transparent-pressed-box-shadow: var(--button-pressed-box-shadow);\n    --button-transparent-active-background-image: var(--button-background-image);\n    --button-transparent-active-background-color: rgba(0, 0, 0, 0.02);\n    --button-transparent-active-text-color: var(--button-green);\n    --button-transparent-active-box-shadow: var(--button-box-shadow);\n    --button-transparent-inverted-background-image: linear-gradient(rgba(255, 255, 255, 0.05), rgba(0, 0, 0, 0.08));\n    --button-transparent-inverted-background-color: rgba(255, 255, 255, 0.03);\n    --button-transparent-inverted-text-color: var(--button-inverted-text-color);\n    --button-transparent-inverted-box-shadow: var(--button-box-shadow);\n    --button-transparent-inverted-hover-background-image: var(--button-hover-background-image);\n    --button-transparent-inverted-hover-background-color: var(--subtle-transparent-white);\n    --button-transparent-inverted-hover-text-color: var(--button-inverted-text-color);\n    --button-transparent-inverted-hover-box-shadow: var(--button-hover-box-shadow);\n    --button-transparent-inverted-pressed-background-image: var(--button-pressed-background-image);\n    --button-transparent-inverted-pressed-background-color: var(--transparent-white);\n    --button-transparent-inverted-pressed-text-color: var(--button-inverted-text-color);\n    --button-transparent-inverted-pressed-box-shadow: var(--button-pressed-box-shadow);\n    --button-transparent-inverted-active-background-image: var(--button-background-image);\n    --button-transparent-inverted-active-background-color: var(--subtle-transparent-white);\n    --button-transparent-inverted-active-text-color: #FFFFFF;\n    --button-transparent-inverted-active-box-shadow: var(--button-box-shadow);\n  }\n}\n\n/* src/components/button/css/theme/states/hover-variables.css */\n@layer button.theme.states.hover {\n  :host {\n    --button-hover-background-color: #FFFFFF;\n    --button-hover-background-image: var(--button-background-image);\n    --button-hover-box-shadow:\n      0 -1px 0 0 rgba(0, 0, 0, 0.05) inset,\n      0 0 0 1px rgba(0, 0, 0, 0.13) inset,\n      0 1px 3px rgba(0, 0, 0, 0.25) ;\n    --button-hover-color: var(--black-90);\n    --button-hover-icon-opacity: 0.85;\n  }\n}\n\n/* src/components/button/css/theme/states/focus-variables.css */\n@layer button.theme.states.focus {\n  :host {\n    --button-focus-background-color: var(--button-hover-background-color);\n    --button-focus-background-image: var(--button-hover-background-image);\n    --button-focus-box-shadow: var(--button-hover-box-shadow);\n    --button-focus-color: var(--button-hover-color);\n    --button-focus-icon-opacity: 0.85;\n  }\n}\n\n/* src/components/button/css/theme/states/pressed-variables.css */\n@layer button.theme.states.pressed {\n  :host {\n    --button-pressed-background-color: var(--button-background-color);\n    --button-pressed-background-image: var(--button-background-image);\n    --button-pressed-color: var(--black-90);\n    --button-pressed-shadow-box-shadow: var(--inset-shadow);\n    --button-pressed-box-shadow:\n      var(--button-sharpen-box-shadow),\n      var(--button-border-box-shadow),\n      var(--button-pressed-shadow-box-shadow) ;\n  }\n}\n\n/* src/components/button/css/theme/states/active-variables.css */\n@layer button.theme.states.active {\n  :host {\n    --button-active-background-color: #DFDFDF;\n    --button-active-background-image: var(--button-background-image);\n    --button-active-color: var(--black-90);\n    --button-active-shadow-box-shadow: var(--subtle-inset-shadow);\n    --button-active-box-shadow:\n      var(--button-sharpen-box-shadow),\n      var(--button-border-box-shadow),\n      var(--button-active-shadow-box-shadow) ;\n    --button-active-hover-background-color: #DADADA;\n    --button-active-hover-background-image: var(--button-active-background-image);\n    --button-active-hover-color: var(--button-active-color);\n    --button-active-hover-box-shadow: var(--button-active-box-shadow);\n    --button-active-down-background-color: var(--button-active-background-color);\n    --button-active-down-background-image: var(--button-active-background-image);\n    --button-active-down-color: var(--button-active-color);\n    --button-active-down-box-shadow: var(--button-active-box-shadow);\n  }\n}\n\n/* src/components/button/css/theme/states/disabled-variables.css */\n@layer button.theme.states.disabled {\n  :host {\n    --button-disabled-cursor: not-allowed;\n    --button-disabled-opacity: 0.4;\n    --button-disabled-background-color: #FFFFFF;\n    --button-disabled-background-image: var(--button-background-image);\n    --button-disabled-border-box-shadow: 0px 0px 0px var(--button-border-width) rgba(0, 0, 0, 0.1) inset;\n    --button-disabled-shadow-box-shadow: 0px 2px 3px rgba(0, 0, 0, 0.04);\n    --button-disabled-color: var(--black-20);\n    --button-disabled-box-shadow:\n      var(--button-sharpen-box-shadow),\n      var(--button-disabled-border-box-shadow),\n      var(--button-disabled-shadow-box-shadow) ;\n    --button-clickable-disabled-cursor: not-allowed;\n  }\n}\n\n/* src/components/button/css/theme/states/loading-variables.css */\n@layer button.theme.states.loading {\n  :host {\n    --button-loading-icon-duration: 2s;\n    --button-loading-opacity: 1;\n    --button-loading-transition: opacity var(--button-transition-duration) var(--button-transition-easing) ;\n  }\n}\n\n/* src/components/button/css/theme/variations/attached-variables.css */\n@layer button.theme.variations.attached {\n  :host {\n    --button-attached-offset: -1px;\n    --button-attached-border-shadow: 0px 0px 0px 1px var(--button-border-color);\n    --button-attached-box-shadow: var(--button-attached-border-shadow), var(--button-shadow-box-shadow) ;\n    --button-attached-horizontal-padding: var(--relative-12px);\n    --button-attached-z-index: 2;\n    --button-attached-pressed-box-shadow: 0 2px 2px rgba(0, 0, 0, 0.08) inset, var(--button-attached-box-shadow) ;\n  }\n}\n\n/* src/components/button/css/theme/variations/basic-variables.css */\n@layer button.theme.variations.basic {\n  :host {\n    --button-basic-border-radius: var(--button-border-radius);\n    --button-basic-border-size: 1px;\n    --button-basic-text-color: var(--button-text-color);\n    --button-basic-colored-border-size: 1px;\n    --button-basic-background: transparent none;\n    --button-basic-font-weight: var(--button-font-weight);\n    --button-basic-border: 1px solid var(--button-border-color);\n    --button-basic-box-shadow: 0px 0px 0px var(--button-basic-border-size) var(--button-border-color) inset;\n    --button-basic-loading-color: var(--button-off-white);\n    --button-basic-text-transform: none;\n    --button-basic-hover-background: #FFFFFF;\n    --button-basic-hover-text-color: var(--button-hover-color);\n    --button-basic-hover-box-shadow: 0px 0px 0px var(--button-basic-border-size) var(--selected-border-color) inset, 0px 0px 0px 0px var(--button-border-color) inset ;\n    --button-basic-focus-background: var(--button-basic-hover-background);\n    --button-basic-focus-text-color: var(--button-basic-hover-text-color);\n    --button-basic-focus-box-shadow: var(--button-basic-hover-box-shadow);\n    --button-basic-down-background: #F8F8F8;\n    --button-basic-down-text-color: var(--button-pressed-text-color);\n    --button-basic-down-box-shadow: 0px 0px 0px var(--button-basic-border-size) rgba(0, 0, 0, 0.15) inset, 0px 1px 4px 0px var(--button-border-color) inset ;\n    --button-basic-active-background: var(--button-transparent-black);\n    --button-basic-active-box-shadow: "";\n    --button-basic-active-text-color: var(--button-selected-text-color);\n    --button-basic-inverted-background: transparent;\n    --button-basic-inverted-focus-background: transparent;\n    --button-basic-inverted-down-background: var(--button-transparent-white);\n    --button-basic-inverted-active-background: var(--button-transparent-white);\n    --button-basic-inverted-box-shadow: 0px 0px 0px var(--button-inverted-border-size) rgba(255, 255, 255, 0.5) inset;\n    --button-basic-inverted-hover-box-shadow: 0px 0px 0px var(--button-inverted-border-size) rgba(255, 255, 255, 1) inset;\n    --button-basic-inverted-focus-box-shadow: 0px 0px 0px var(--button-inverted-border-size) rgba(255, 255, 255, 1) inset;\n    --button-basic-inverted-down-box-shadow: 0px 0px 0px var(--button-inverted-border-size) rgba(255, 255, 255, 0.9) inset;\n    --button-basic-inverted-active-box-shadow: 0px 0px 0px var(--button-inverted-border-size) rgba(255, 255, 255, 0.7) inset;\n    --button-basic-inverted-color: var(--button-dark-white);\n    --button-basic-inverted-hover-color: var(--button-dark-white-hover);\n    --button-basic-inverted-down-color: var(--button-dark-white-active);\n    --button-basic-inverted-active-color: var(--button-inverted-text-color);\n    --button-basic-group-border: var(--button-basic-border-size) solid var(--button-border-color);\n    --button-basic-group-box-shadow: none;\n  }\n}\n\n/* src/components/button/css/theme/variations/circular-variables.css */\n@layer button.theme.variations.circular;\n\n/* src/components/button/css/theme/variations/colored-variables.css */\n@layer button.theme.variations.colored {\n  :host {\n    --button-colored-background-image: var(--button-background-image);\n    --button-colored-box-shadow:\n      0 -1px 0 0 rgba(0, 0, 0, 0.05) inset,\n      0 0 0 1px rgba(0, 0, 0, 0.13) inset,\n      0 1px 3px rgba(0, 0, 0, 0.15) ;\n    --button-inverted-text-shadow: 1px 1px 1px rgba(0, 0, 0, 0.3);\n    --button-red: var(--red);\n    --button-orange: var(--orange);\n    --button-yellow: var(--yellow);\n    --button-olive: var(--olive);\n    --button-green: var(--green);\n    --button-teal: var(--teal);\n    --button-blue: var(--blue);\n    --button-violet: var(--violet);\n    --button-purple: var(--purple);\n    --button-pink: var(--pink);\n    --button-brown: var(--brown);\n    --button-grey: var(--grey);\n    --button-black: var(--black);\n    --button-colored-hover-lightness: 0.05;\n    --button-colored-hover-hue: 2;\n    --button-red-hover: oklch(from var(--button-red) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-orange-hover: oklch(from var(--button-orange) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-yellow-hover: oklch(from var(--button-yellow) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-olive-hover: oklch(from var(--button-olive) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-green-hover: oklch(from var(--button-green) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-teal-hover: oklch(from var(--button-teal) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-blue-hover: oklch(from var(--button-blue) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-violet-hover: oklch(from var(--button-violet) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-purple-hover: oklch(from var(--button-purple) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-pink-hover: oklch(from var(--button-pink) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-brown-hover: oklch(from var(--button-brown) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-grey-hover: oklch(from var(--button-grey) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-black-hover: oklch(from var(--button-black) calc(l - var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-colored-focus-lightness: 0.08;\n    --button-colored-focus-hue: 2;\n    --button-red-focus: oklch(from var(--button-red) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-orange-focus: oklch(from var(--button-orange) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-yellow-focus: oklch(from var(--button-yellow) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-olive-focus: oklch(from var(--button-olive) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-green-focus: oklch(from var(--button-green) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-teal-focus: oklch(from var(--button-teal) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-blue-focus: oklch(from var(--button-blue) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-violet-focus: oklch(from var(--button-violet) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-purple-focus: oklch(from var(--button-purple) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-pink-focus: oklch(from var(--button-pink) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-brown-focus: oklch(from var(--button-brown) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-grey-focus: oklch(from var(--button-grey) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-black-focus: oklch(from var(--button-black) calc(l - var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-colored-pressed-lightness: -0.02;\n    --button-colored-pressed-hue: 2;\n    --button-red-pressed: oklch(from var(--button-red) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-orange-pressed: oklch(from var(--button-orange) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-yellow-pressed: oklch(from var(--button-yellow) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-olive-pressed: oklch(from var(--button-olive) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-green-pressed: oklch(from var(--button-green) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-teal-pressed: oklch(from var(--button-teal) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-blue-pressed: oklch(from var(--button-blue) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-violet-pressed: oklch(from var(--button-violet) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-purple-pressed: oklch(from var(--button-purple) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-pink-pressed: oklch(from var(--button-pink) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-brown-pressed: oklch(from var(--button-brown) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-grey-pressed: oklch(from var(--button-grey) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-black-pressed: oklch(from var(--button-black) calc(l - var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-brown-text-color: var(--button-inverted-text-color);\n    --button-brown-text-shadow: var(--button-inverted-text-shadow);\n    --button-red-text-color: var(--button-inverted-text-color);\n    --button-red-text-shadow: var(--button-inverted-text-shadow);\n    --button-orange-text-color: var(--button-inverted-text-color);\n    --button-orange-text-shadow: var(--button-inverted-text-shadow);\n    --button-green-text-color: var(--button-inverted-text-color);\n    --button-green-text-shadow: var(--button-inverted-text-shadow);\n    --button-blue-text-color: var(--button-inverted-text-color);\n    --button-blue-text-shadow: var(--button-inverted-text-shadow);\n    --button-violet-text-color: var(--button-inverted-text-color);\n    --button-violet-text-shadow: var(--button-inverted-text-shadow);\n    --button-purple-text-color: var(--button-inverted-text-color);\n    --button-purple-text-shadow: var(--button-inverted-text-shadow);\n    --button-pink-text-color: var(--button-inverted-text-color);\n    --button-pink-text-shadow: var(--button-inverted-text-shadow);\n    --button-black-text-color: var(--button-inverted-text-color);\n    --button-black-text-shadow: var(--button-inverted-text-shadow);\n    --button-olive-text-color: var(--button-inverted-text-color);\n    --button-olive-text-shadow: var(--button-inverted-text-shadow);\n    --button-yellow-text-color: var(--button-inverted-text-color);\n    --button-yellow-text-shadow: var(--button-inverted-text-shadow);\n    --button-teal-text-color: var(--button-inverted-text-color);\n    --button-teal-text-shadow: var(--button-inverted-text-shadow);\n    --button-grey-text-color: var(--button-inverted-text-color);\n    --button-grey-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-brown-text-color: var(--button-inverted-text-color);\n    --button-light-brown-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-red-text-color: var(--button-inverted-text-color);\n    --button-light-red-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-orange-text-color: var(--button-inverted-text-color);\n    --button-light-orange-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-green-text-color: var(--button-inverted-text-color);\n    --button-light-green-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-blue-text-color: var(--button-inverted-text-color);\n    --button-light-blue-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-violet-text-color: var(--button-inverted-text-color);\n    --button-light-violet-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-purple-text-color: var(--button-inverted-text-color);\n    --button-light-purple-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-pink-text-color: var(--button-inverted-text-color);\n    --button-light-pink-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-black-text-color: var(--button-inverted-text-color);\n    --button-light-black-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-olive-text-color: var(--button-text-color);\n    --button-light-olive-text-shadow: var(--button-text-shadow);\n    --button-light-yellow-text-color: var(--button-text-color);\n    --button-light-yellow-text-shadow: var(--button-text-shadow);\n    --button-light-teal-text-color: var(--button-text-color);\n    --button-light-teal-text-shadow: var(--button-text-shadow);\n    --button-light-grey-text-color: var(--button-text-color);\n    --button-light-grey-text-shadow: var(--button-text-shadow);\n  }\n}\n\n/* src/components/button/css/theme/variations/compact-variables.css */\n@layer button.theme.variations.compact {\n  :host {\n    --button-compact-vertical-padding: var(--6px);\n    --button-compact-horizontal-padding: var(--8px);\n    --button-compact-icon-padding: var(--button-compact-vertical-padding);\n    --button-very-compact-reduction-factor: 0.4;\n    --button-very-compact-vertical-padding: var(--5px);\n    --button-very-compact-horizontal-padding: var(--5px);\n    --button-very-compact-icon-padding: var(--button-very-compact-vertical-padding);\n  }\n}\n\n/* src/components/button/css/theme/variations/floated-variables.css */\n@layer button.theme.variations.floated {\n  :host {\n    --button-floated-margin: 0.25em;\n  }\n}\n\n/* src/components/button/css/theme/variations/fluid-variables.css */\n@layer button.theme.variations.fluid {\n  ui-button {\n  }\n}\n\n/* src/components/button/css/theme/variations/negative-variables.css */\n@layer button.theme.variations.negative {\n  :host {\n    --button-negative-color: var(--negative-color);\n    --button-negative-background-image: var(--button-colored-background-image);\n    --button-negative-text-color: var(--button-inverted-text-color);\n    --button-negative-text-shadow: var(--button-inverted-text-shadow);\n    --button-negative-box-shadow: var(--button-colored-box-shadow);\n    --button-negative-color-hover: oklch(from var(--button-negative-color) calc(l + var(--hover-lightness)) c h);\n    --button-negative-color-focus: oklch(from var(--button-negative-color) calc(l + var(--focus-lightness)) c h);\n    --button-negative-color-down: oklch(from var(--button-negative-color) calc(l + var(--down-lightness)) c h);\n    --button-negative-color-active: oklch(from var(--button-negative-color) calc(l + var(--active-lightness)) c h);\n    --button-subtle-negative-color: #FFFAFA;\n    --button-subtle-negative-background-image: var(--button-colored-background-image);\n    --button-subtle-negative-text-color: rgba(145, 50, 50, 0.9);\n    --button-subtle-negative-text-shadow: var(--button-text-shadow);\n    --button-subtle-negative-box-shadow: var(--button-box-shadow);\n    --button-subtle-negative-color-hover: #FFEAEA;\n    --button-subtle-negative-color-focus: #FFEAEA;\n    --button-subtle-negative-color-down: #FFEAEA;\n    --button-subtle-negative-color-active: #F1FFF7;\n  }\n}\n\n/* src/components/button/css/theme/variations/warning-variables.css */\n@layer button.theme.variations.warning {\n  :host {\n    --button-warning-color: var(--warning-color);\n    --button-warning-background-image: var(--button-colored-background-image);\n    --button-warning-text-color: var(--button-inverted-text-color);\n    --button-warning-text-shadow: var(--button-inverted-text-shadow);\n    --button-warning-box-shadow: var(--button-colored-box-shadow);\n    --button-warning-color-hover: oklch(from var(--button-warning-color) calc(l + var(--hover-lightness)) c h);\n    --button-warning-color-focus: oklch(from var(--button-warning-color) calc(l + var(--focus-lightness)) c h);\n    --button-warning-color-down: oklch(from var(--button-warning-color) calc(l + var(--down-lightness)) c h);\n    --button-warning-color-active: oklch(from var(--button-warning-color) calc(l + var(--active-lightness)) c h);\n    --button-subtle-warning-color: #FFFDF5;\n    --button-subtle-warning-background-image: var(--button-colored-background-image);\n    --button-subtle-warning-text-color: rgba(135, 105, 23, 0.9);\n    --button-subtle-warning-text-shadow: var(--button-text-shadow);\n    --button-subtle-warning-box-shadow: var(--button-box-shadow);\n    --button-subtle-warning-color-hover: #FFF5DD;\n    --button-subtle-warning-color-focus: #FFF5DD;\n    --button-subtle-warning-color-down: #FFF5DD;\n    --button-subtle-warning-color-active: #FFFDEA;\n  }\n}\n\n/* src/components/button/css/theme/variations/info-variables.css */\n@layer button.theme.variations.info {\n  :host {\n    --button-info-color: var(--info-color);\n    --button-info-background-image: var(--button-colored-background-image);\n    --button-info-text-color: var(--button-inverted-text-color);\n    --button-info-text-shadow: var(--button-inverted-text-shadow);\n    --button-info-box-shadow: var(--button-colored-box-shadow);\n    --button-info-color-hover: oklch(from var(--button-info-color) calc(l + var(--hover-lightness)) c h);\n    --button-info-color-focus: oklch(from var(--button-info-color) calc(l + var(--focus-lightness)) c h);\n    --button-info-color-down: oklch(from var(--button-info-color) calc(l + var(--down-lightness)) c h);\n    --button-info-color-active: oklch(from var(--button-info-color) calc(l + var(--active-lightness)) c h);\n    --button-subtle-info-color: #F8FEFF;\n    --button-subtle-info-background-image: var(--button-colored-background-image);\n    --button-subtle-info-text-color: rgba(23, 94, 135, 0.9);\n    --button-subtle-info-text-shadow: var(--button-text-shadow);\n    --button-subtle-info-box-shadow: var(--button-box-shadow);\n    --button-subtle-info-color-hover: #DEFBFF;\n    --button-subtle-info-color-focus: #DEFBFF;\n    --button-subtle-info-color-down: #DEFBFF;\n    --button-subtle-info-color-active: #E4FBFF;\n  }\n}\n\n/* src/components/button/css/theme/variations/positive-variables.css */\n@layer button.theme.variations.positive {\n  :host {\n    --button-positive-color: var(--positive-color);\n    --button-positive-background-image: var(--button-colored-background-image);\n    --button-positive-text-color: var(--button-inverted-text-color);\n    --button-positive-text-shadow: var(--button-inverted-text-shadow);\n    --button-positive-box-shadow: var(--button-colored-box-shadow);\n    --button-positive-color-hover: oklch(from var(--positive-color) calc(l + var(--hover-lightness)) c h);\n    --button-positive-color-focus: oklch(from var(--positive-color) calc(l + var(--focus-lightness)) c h);\n    --button-positive-color-down: oklch(from var(--positive-color) calc(l + var(--down-lightness)) c h);\n    --button-positive-color-active: oklch(from var(--positive-color) calc(l + var(--active-lightness)) c h);\n    --button-subtle-positive-color: #F3FFF6;\n    --button-subtle-positive-background-image: var(--button-colored-background-image);\n    --button-subtle-positive-text-color: rgba(38, 127, 81, 0.9);\n    --button-subtle-positive-text-shadow: var(--button-text-shadow);\n    --button-subtle-positive-box-shadow: var(--button-box-shadow);\n    --button-subtle-positive-color-hover: #EAFFEA;\n    --button-subtle-positive-color-focus: #EAFFEA;\n    --button-subtle-positive-color-down: #EAFFEA;\n    --button-subtle-positive-color-active: #F1FFF7;\n  }\n}\n\n/* src/components/button/css/theme/variations/sizing-variables.css */\n@layer button.theme.variations.sizing {\n  :host {\n    --button-mini: var(--mini);\n    --button-tiny: var(--tiny);\n    --button-small: var(--small);\n    --button-medium: inherit;\n    --button-large: var(--large);\n    --button-big: var(--big);\n    --button-huge: var(--huge);\n    --button-massive: var(--massive);\n  }\n}\n\n/* src/components/button/css/theme/variations/social-variables.css */\n@layer button.theme.variations.social {\n  :host {\n    --button-instagram-background-image: var(--instagram-gradient);\n    --facebook-hover-color: oklch(from var(--facebook-color) calc(l - 0.05) c calc(h + 10));\n    --twitter-hover-color: oklch(from var(--twitter-color) calc(l - 0.05) c calc(h + 10));\n    --linked-in-hover-color: oklch(from var(--linked-in-color) calc(l - 0.05) c calc(h + 10));\n    --youtube-hover-color: oklch(from var(--youtube-color) calc(l - 0.05) c calc(h + 10));\n    --instagram-hover-color: oklch(from var(--instagram-color) calc(l - 0.05) c calc(h + 10));\n    --pinterest-hover-color: oklch(from var(--pinterest-color) calc(l - 0.05) c calc(h + 10));\n    --facebook-down-color: oklch(from var(--facebook-color) calc(l - 0.1) c h);\n    --twitter-down-color: oklch(from var(--twitter-color) calc(l - 0.1) c h);\n    --linked-in-down-color: oklch(from var(--linked-in-color) calc(l - 0.1) c h);\n    --youtube-down-color: oklch(from var(--youtube-color) calc(l - 0.1) c h);\n    --instagram-down-color: oklch(from var(--instagram-color) calc(l - 0.1) c h);\n    --pinterest-down-color: oklch(from var(--pinterest-color) calc(l - 0.1) c h);\n    --facebook-focus-color: oklch(from var(--facebook-color) calc(l - 0.08) c calc(h + 15));\n    --twitter-focus-color: oklch(from var(--twitter-color) calc(l - 0.08) c calc(h + 15));\n    --linked-in-focus-color: oklch(from var(--linked-in-color) calc(l - 0.08) c calc(h + 15));\n    --youtube-focus-color: oklch(from var(--youtube-color) calc(l - 0.08) c calc(h + 15));\n    --instagram-focus-color: oklch(from var(--instagram-color) calc(l - 0.08) c calc(h + 15));\n    --pinterest-focus-color: oklch(from var(--pinterest-color) calc(l - 0.08) c calc(h + 15));\n  }\n}\n\n/* src/components/button/css/theme/variations/vertical-variables.css */\n@layer button.theme.variations.vertical {\n  ui-button {\n  }\n}\n\n/* src/components/button/css/theme/button-theme.css */\n\n/* src/components/button/css/button.css */\n';

// src/components/button/button.js
var createComponent = ({ el, self, settings, data, $ }) => ({
  isIconBefore() {
    return settings.icon && !settings.iconAfter;
  },
  isIconAfter() {
    return settings.icon && settings.iconAfter;
  },
  isSubmitKey(keyCode) {
    const submitKeys = {
      13: "Space",
      32: "Enter"
    };
    return get(submitKeys, String(keyCode));
  },
  performAction() {
    const formActions = ["submit", "reset"];
    if (inArray(settings.type, formActions)) {
      const form = self.getForm();
      if (form) {
        $(form).trigger(settings.type);
      }
    }
  },
  getForm() {
    return $(el).closest("form").el();
  },
  isDisabled() {
    return settings.state == "disabled";
  }
});
var events = {
  "touchstart .button"({ event, self, $ }) {
    $(this).addClass("pressed");
  },
  "touchend .button"({ event, self, $ }) {
    $(this).removeClass("pressed");
  },
  "click .button"({ event, self, $ }) {
    self.performAction();
    $(this).blur();
  },
  "keydown .button"({ event, self, $ }) {
    let $button = $(this);
    if (self.isSubmitKey(event.keyCode)) {
      $button.addClass("pressed");
      self.performAction();
      event.preventDefault();
    }
    if (event.key == "Escape") {
      $button.blur();
    }
  },
  "keyup .button"({ event, self, $ }) {
    let $button = $(this);
    if (self.isSubmitKey(event.keyCode)) {
      $button.removeClass("pressed");
    }
  }
};
var UIButton = defineComponent({
  tagName: "ui-button",
  componentSpec: button_component_default,
  template: button_default,
  css: button_bundle_default,
  createComponent,
  events
});

// src/components/button/parts/or/button-or.js
import { defineComponent as defineComponent2 } from "https://cdn.jsdelivr.net/npm/@semantic-ui/component@0.12.4/dist/index.min.js";

// src/components/button/parts/or/button-or.css?raw
var button_or_default = "/*-------------------\n      Or Buttons\n--------------------*/\n:host {\n  align-self: center;\n}\n.or {\n  position: relative;\n  width: var(--button-or-gap);\n  height: var(--button-or-height);\n  z-index: var(--button-or-z-index);\n}\n.or .shape {\n  position: absolute;\n  text-align: center;\n  border-radius: var(--circular-radius);\n\n  top: 50%;\n  left: 50%;\n  background-color: var(--button-or-background-color);\n  text-shadow: var(--button-or-text-shadow);\n\n  margin-top: var(--button-or-vertical-offset);\n  margin-left: var(--button-or-horizontal-offset);\n\n  width: var(--button-or-circle-size);\n  height: var(--button-or-circle-size);\n\n  line-height: var(--button-or-line-height);\n  color: var(--button-or-text-color);\n\n  font-style: var(--button-or-text-style);\n  font-weight: var(--button-or-text-weight);\n\n  box-shadow: var(--button-or-box-shadow);\n}\n\n";

// src/components/button/parts/or/button-or.html?raw
var button_or_default2 = '<div class="{{ui}} or" part="or">\n  <div class="shape"><slot>or</slot></div>\n</div>\n';

// src/components/button/parts/or/button-or.js
var ButtonOr = defineComponent2({
  template: button_or_default2,
  css: button_or_default
});

// src/components/button/plural/buttons.js
import { defineComponent as defineComponent3 } from "https://cdn.jsdelivr.net/npm/@semantic-ui/component@0.12.4/dist/index.min.js";

// src/components/button/plural/buttons.html?raw
var buttons_default = '<div class="{{ui}} buttons">\n  {{>slot}}\n</div>\n';

// src/components/button/button-page.css?raw
var button_page_default = "ui-buttons ui-button::part(button) {\n  flex: 1 0 auto;\n  border-radius: 0em;\n  margin: var(--button-group-button-offset);\n}\nui-buttons > ui-button:first-child::part(button) {\n  border-left: none;\n  margin-left: 0em;\n  border-top-left-radius: var(--button-border-radius);\n  border-bottom-left-radius: var(--button-border-radius);\n}\nui-buttons > ui-button:last-child::part(button) {\n  border-top-right-radius: var(--button-border-radius);\n  border-bottom-right-radius: var(--button-border-radius);\n}\n";

// src/components/button/plural/buttons.js
var UIButtons = defineComponent3({
  tagName: "ui-buttons",
  singularTag: "ui-button",
  plural: true,
  delegateFocus: true,
  componentSpec: button_component_default,
  template: buttons_default,
  css: button_bundle_default,
  pageCSS: button_page_default
});
export {
  ButtonOr,
  UIButton,
  UIButtons
};
//# sourceMappingURL=button.js.map
