/**
 * @semantic-ui/core v0.12.4
 * Semantic empowers designers and developers by creating a shared vocabulary for UI.
 *
 * @license MIT
 * @copyright (c) 2025 Jack Lukic <jack@semantic-ui.com>
 * @homepage http://next.semantic-ui.com
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

// src/components/card/card.js
import { defineComponent } from "https://cdn.jsdelivr.net/npm/@semantic-ui/component@0.12.4/dist/index.min.js";

// src/components/card/specs/card-component.json
var card_component_default = {
  tagName: "ui-card",
  content: [
    "icon",
    "header",
    "description",
    "subheader",
    "image"
  ],
  contentAttributes: [
    "icon",
    "header",
    "description",
    "subheader",
    "image"
  ],
  variations: [
    "fluid",
    "link",
    "horizontal"
  ],
  states: [
    "hover",
    "focused",
    "disabled"
  ],
  settings: [
    "href"
  ],
  attributes: [
    "icon",
    "header",
    "description",
    "subheader",
    "image",
    "hover",
    "focused",
    "disabled",
    "fluid",
    "link",
    "horizontal",
    "href"
  ],
  optionAttributes: {
    disabled: "disabled",
    "clickable-disabled": "disabled"
  },
  propertyTypes: {
    icon: "string",
    header: "string",
    description: "string",
    subheader: "string",
    image: "string",
    hover: "boolean",
    focused: "boolean",
    disabled: "string",
    fluid: "boolean",
    link: "boolean",
    horizontal: "boolean",
    href: "string"
  },
  allowedValues: {
    disabled: [
      "disabled",
      "clickable-disabled"
    ]
  },
  attributeClasses: [
    "icon",
    "disabled"
  ]
};

// src/components/card/card.html?raw
var card_default = '{#if href}\n  <a class="{ui}card" href="{href}">\n    {> content}\n  </a>\n{else}\n  <div class="{ui}card" part="card">\n    {> content}\n  </div>\n{/if}\n\n{#snippet content}\n  {#if horizontal}\n    {>image}\n    {>icon}\n    <div class="content">\n      {>header}\n      {>subheader}\n      {>description}\n      {> slot}\n    </div>\n  {else}\n    {>image}\n    <div class="content">\n      {>icon}\n      {>header}\n      {>subheader}\n      {>description}\n      {> slot}\n    </div>\n  {/if}\n{/snippet}\n\n{#snippet icon}\n  <div class="icon" part="icon">\n    {#if icon}\n      <ui-icon icon={icon}></ui-icon>\n    {/if}\n    {> slot icon}\n  </div>\n{/snippet}\n\n{#snippet header}\n  <div class="header" part="header">\n    {header}\n    {> slot header}\n  </div>\n{/snippet}\n\n{#snippet subheader}\n  <div class="subheader" part="subheader">\n    {subheader}\n    {> slot subheader}\n  </div>\n{/snippet}\n\n{#snippet image}\n  <div class="image" part="image">\n    {#if image}\n      <img src="{image}" part="image-img">\n    {/if}\n    {> slot image}\n  </div>\n{/snippet}\n\n{#snippet description}\n  <div class="description" part="description">\n    {description}\n    {> slot description}\n  </div>\n{/snippet}\n\n{#snippet meta}\n  <div class="meta" part="meta">\n    {#each value in meta}\n      <span>{value}</span>\n    {/each}\n    {> slot meta}\n  </div>\n{/snippet}\n';

// src/components/card/card-bundle.css?raw
var card_bundle_default = '/**\n  ---DO NOT EDIT THIS FILE DIRECTLY---\n  This CSS file was concatenated from files listed in the css/ folder as part of a build process\n  This is to allow for js import with @import links which will not be followed\n**/\n\n/* src/components/card/css/definition/content/card.css */\n@layer card.definition.content.card {\n  :host {\n    display: inline-block;\n    text-align: var(--card-text-align);\n    margin: var(--card-margin);\n  }\n  .card {\n    display: flex;\n    flex-direction: var(--card-flex-direction);\n    gap: var(--card-gap);\n    text-decoration: none;\n    border-radius: var(--card-border-radius);\n    border: var(--card-border);\n    transition: var(--card-transition);\n    box-shadow: var(--card-box-shadow);\n    background: var(--card-background);\n    padding: var(--card-padding);\n    width: var(--card-width);\n  }\n  .card > :first-child {\n    border-radius: inherit;\n    border-bottom-left-radius: 0;\n    border-bottom-right-radius: 0;\n  }\n  .card > :last-child {\n    border-radius: inherit;\n    border-top-left-radius: 0;\n    border-top-right-radius: 0;\n  }\n}\n\n/* src/components/card/css/definition/content/description.css */\n@layer card.definition.content.description {\n  ::slotted(.description),\n  .description {\n    color: var(--card-description-color);\n    font-size: var(--card-description-font-size);\n    transition: var(--card-description-transition);\n    line-height: var(--card-description-line-height);\n  }\n}\n\n/* src/components/card/css/definition/content/header.css */\n@layer card.definition.content.header {\n  ::slotted(.header),\n  .header {\n    color: var(--card-header-color);\n    font-size: var(--card-header-font-size);\n    font-weight: var(--card-header-font-weight);\n    transition: var(--card-header-transition);\n  }\n}\n\n/* src/components/card/css/definition/content/subheader.css */\n@layer card.definition.content.subheader {\n  ::slotted(.subheader),\n  .subheader {\n    color: var(--card-subheader-color);\n    font-size: var(--card-subheader-font-size);\n    font-weight: var(--card-subheader-font-weight);\n    transition: var(--card-subheader-transition);\n  }\n}\n\n/* src/components/card/css/definition/content/image.css */\n@layer card.definition.content.image {\n  .image {\n    overflow: hidden;\n    margin: var(--card-reverse-padding) var(--card-reverse-padding) 1em;\n  }\n  ::slotted(.image),\n  ::slotted(ui-image),\n  .image img {\n    display: block;\n    width: var(--card-image-width);\n    max-width: var(--card-image-max-width);\n    object-fit: contain;\n  }\n}\n\n/* src/components/card/css/definition/content/icon.css */\n@layer card.definition.content.icon {\n  ::slotted(ui-icon),\n  ::slotted(.icon),\n  .icon ui-icon {\n    font-size: var(--card-icon-font-size);\n    margin: var(--card-icon-margin);\n    color: var(--card-icon-color);\n  }\n}\n\n/* src/components/card/css/definition/content/meta.css */\n@layer card.definition.content.meta {\n  ::slotted(.meta),\n  .meta {\n    margin-top: var(--card-meta-margin);\n    padding-top: var(--card-meta-spacing);\n    border-top: var(--card-meta-border);\n    display: flex;\n    gap: var(--card-meta-gap);\n  }\n  .meta > * {\n    color: var(--card-meta-text-color);\n    font-weight: bold;\n  }\n}\n\n/* src/components/card/css/definition/states/disabled.css */\n@layer card.definition.states.disabled {\n  .disabled {\n    pointer-events: none;\n    opacity: var(--disabled-opacity);\n  }\n  .clickable-disabled {\n    pointer-events: allowed;\n  }\n}\n\n/* src/components/card/css/definition/plural/cards.css */\n@layer card.definition.plural {\n  :host(ui-cards) {\n    display: block;\n    container: host / inline-size;\n    margin: var(--cards-margin);\n  }\n  .component {\n    container: component / inline-size;\n  }\n  .cards {\n    display: grid;\n    gap: var(--cards-gap);\n    grid-auto-rows: 1fr;\n    width: 100%;\n  }\n  ::slotted(ui-card) {\n    display: contents;\n    margin: 0;\n  }\n}\n\n/* src/components/card/css/definition/variations/basic.css */\n@layer card.definition.variations.basic {\n  .basic.card {\n    background: var(--card-basic-background);\n    box-shadow: var(--card-basic-box-shadow);\n    border: var(--card-basic-border);\n  }\n}\n\n/* src/components/card/css/definition/variations/count.css */\n@layer card.definition.variations.count {\n  .cards.one {\n    grid-template-columns: 1fr;\n  }\n  .cards.two {\n    grid-template-columns: repeat(2, 1fr);\n  }\n  .cards.three {\n    grid-template-columns: repeat(3, 1fr);\n  }\n  .cards.four {\n    grid-template-columns: repeat(4, 1fr);\n  }\n  .cards.five {\n    grid-template-columns: repeat(5, 1fr);\n  }\n  .cards.six {\n    grid-template-columns: repeat(6, 1fr);\n  }\n  .cards.seven {\n    grid-template-columns: repeat(7, 1fr);\n  }\n  .cards.eight {\n    grid-template-columns: repeat(8, 1fr);\n  }\n  .cards ::slotted(*) {\n    --card-width: none;\n  }\n}\n\n/* src/components/card/css/definition/variations/fluid.css */\n@layer card.definition.variations.fluid {\n  :host([fluid]),\n  .fluid.card {\n    --card-width: auto;\n    --card-image-max-width: none;\n  }\n}\n\n/* src/components/card/css/definition/variations/horizontal.css */\n@layer card.definition.variations.horizontal {\n  .horizontal {\n    flex-direction: var(--card-horizontal-flex-direction);\n    gap: var(--card-horizontal-gap);\n    text-align: left;\n  }\n  .horizontal ::slotted(.image),\n  .horizontal ::slotted(ui-image),\n  .horizontal .image {\n    margin: var(--card-reverse-padding);\n    max-width: var(--card-horizontal-image-max-width);\n  }\n  .horizontal ::slotted(ui-icon),\n  .horizontal ::slotted(.icon),\n  .horizontal .icon ui-icon {\n    font-size: var(--card-horizontal-icon-font-size);\n    margin: var(--card-horizontal-icon-margin);\n  }\n  .horizontal ::slotted(.header),\n  .horizontal .header {\n    font-size: var(--card-horizontal-header-size);\n  }\n  .horizontal :first-child {\n    border-radius: inherit;\n    border-top-right-radius: 0;\n    border-bottom-right-radius: 0;\n  }\n  .horizontal :last-child {\n    border-radius: inherit;\n    border-top-left-radius: 0;\n    border-bottom-left-radius: 0;\n  }\n}\n\n/* src/components/card/css/definition/variations/link.css */\n@layer card.definition.variations.link {\n  .link.card,\n  a.card {\n    cursor: pointer;\n    color: inherit;\n  }\n  .link.card:hover,\n  a.card:hover {\n    background: var(--card-link-hover-background);\n    box-shadow: var(--card-link-hover-box-shadow);\n    border: var(--card-link-hover-border);\n  }\n  .link.card:hover ::slotted(.header),\n  .link.card:hover .header,\n  a.card:hover ::slotted(.header),\n  a.card:hover .header {\n    color: var(--card-link-hover-header-color);\n  }\n  .link.card:hover ::slotted(ui-icon),\n  .link.card:hover ::slotted(.icon),\n  .link.card:hover .icon ui-icon,\n  a.card:hover ::slotted(ui-icon),\n  a.card:hover ::slotted(.icon),\n  a.card:hover .icon ui-icon {\n    color: var(--card-link-hover-icon-color);\n  }\n}\n\n/* src/components/card/css/definition/variations/spaced.css */\n@layer card.definition.variations.spaced {\n  .cards.spaced {\n    gap: var(--cards-spaced-gap);\n  }\n  .cards.very-spaced {\n    gap: var(--cards-very-spaced-gap);\n  }\n}\n\n/* src/components/card/css/definition/variations/doubling.css */\n@layer card.definition.variations.doubling {\n  @container component (max-width: var(--card-doubling-breakpoint)) {\n    .doubling.cards {\n    }\n  }\n}\n\n/* src/components/card/css/definition/variations/stackable.css */\n@layer card.definition.variations.stackable {\n  .component {\n    --card-stackable-comparison: max(calc(100cqi - var(--card-stackable-breakpoint)), 0px);\n    width: --card-stackable-comparison;\n  }\n  @container component style(--card-stackable-comparison: 0) {\n    .stackable.cards {\n      display: flex;\n      flex-direction: column;\n    }\n  }\n}\n\n/* src/components/card/css/definition/card-definition.css */\n\n/* src/components/card/css/theme/content/card-variables.css */\n@layer card.theme.content.card {\n  :host {\n    --card-margin: 0px 5px 5px 0px;\n    --card-text-align: center;\n    --card-padding: var(--spacing);\n    --card-reverse-padding: calc(var(--spacing) * -1);\n    --card-flex-direction: column;\n    --card-border-radius: var(--border-radius);\n    --card-transition: var(--transition);\n    --card-background: var(--ui-background-emphasis);\n    --card-box-shadow: 0px 0px 5px var(--standard-5);\n    --card-text-align: center;\n    --card-border: var(--internal-border);\n    --card-gap: 0;\n    --card-width: 290px;\n  }\n}\n\n/* src/components/card/css/theme/content/description-variables.css */\n@layer card.theme.content.description {\n  :host {\n    --card-description-font-size: var(--relative-15px);\n    --card-description-color: var(--standard-60);\n    --card-description-line-height: inherit;\n    --card-description-transition: var(--transition);\n  }\n}\n\n/* src/components/card/css/theme/content/header-variables.css */\n@layer card.theme.content.header {\n  :host {\n    --card-header-font-size: var(--relative-20px);\n    --card-header-font-weight: var(--bold);\n    --card-header-transition: var(--transition);\n    --card-header-color: var(--standard-100);\n  }\n}\n\n/* src/components/card/css/theme/content/subheader-variables.css */\n@layer card.theme.content.subheader {\n  :host {\n    --card-subheader-font-size: var(--relative-16px);\n    --card-subheader-font-weight: var(--bold);\n    --card-subheader-transition: var(--transition);\n    --card-subheader-color: var(--standard-80);\n  }\n}\n\n/* src/components/card/css/theme/content/image-variables.css */\n@layer card.theme.content.image {\n  :host {\n    --card-image-margin: -1.5em -1.5em 1.5em;\n    --card-image-width: 100%;\n    --card-image-max-width: 100%;\n  }\n}\n\n/* src/components/card/css/theme/content/icon-variables.css */\n@layer card.theme.content.icon {\n  :host {\n    --card-icon-font-size: var(--relative-32px);\n    --card-icon-color: var(--standard-40);\n    --card-icon-margin: 0 0 var(--compact-spacing) 0;\n  }\n}\n\n/* src/components/card/css/theme/content/meta-variables.css */\n@layer card.theme.content.meta {\n  :host {\n    --card-meta-margin: var(--compact-spacing) 0 0;\n    --card-meta-padding: var(--compact-spacing) 0 0;\n    --card-meta-border: var(--border);\n    --card-meta-gap: var(--compact-spacing);\n    --card-meta-text-color: var(--standard-90);\n  }\n}\n\n/* src/components/card/css/theme/plural/cards-variables.css */\n@layer card.theme.plural {\n  :host {\n    --cards-gap: var(--spacing);\n    --cards-margin: var(--vertical-spacing);\n  }\n}\n\n/* src/components/card/css/theme/variations/basic-variables.css */\n@layer card.theme.variations.basic {\n  :host {\n    --card-basic-background: transparent;\n    --card-basic-box-shadow: var(--floating-shadow);\n    --card-basic-border: var(--card-border);\n  }\n}\n\n/* src/components/card/css/theme/variations/count-variables.css */\n@layer card.theme.variations.count;\n\n/* src/components/card/css/theme/variations/fluid-variables.css */\n@layer card.theme.variations.fluid {\n  :host {\n  }\n}\n\n/* src/components/card/css/theme/variations/horizontal-variables.css */\n@layer card.theme.variations.horizontal {\n  :host {\n    --card-horizontal-flex-direction: row;\n    --card-horizontal-gap: var(--padding);\n    --card-horizontal-image-max-width: 125px;\n    --card-horizontal-icon-size: var(--massive);\n    --card-horizontal-icon-margin: 0 0 0 var(--spacing);\n    --card-horizontal-header-size: var(--large);\n    --card-horizontal-icon-font-size: var(--massive);\n  }\n}\n\n/* src/components/card/css/theme/variations/link-variables.css */\n@layer card.theme.variations.link {\n  :host {\n    --card-link-hover-background: oklch(0.98 0.01 227.13);\n    --card-link-hover-box-shadow: 0px 0px 5px var(--standard-5);\n    --card-link-hover-border: 1px solid var(--primary-text-color);\n    --card-link-hover-header-color: var(--primary-text-color);\n    --card-link-hover-icon-color: var(--primary-text-color);\n  }\n  @container style(--dark-mode: true) {\n    .card {\n      --card-link-hover-background: oklch(0.17 0.04 225.68);\n      --card-link-hover-box-shadow: oklch(0.58 0.14 233.34 / 0.25) 0px 0px 7px 2px;\n      --card-link-hover-border: 1px solid var(--primary-text-color);\n    }\n  }\n}\n\n/* src/components/card/css/theme/variations/spaced-variables.css */\n@layer card.theme.variations.spaced {\n  :host {\n    --cards-spaced-gap: 2rem;\n    --cards-very-spaced-gap: 3rem;\n  }\n}\n\n/* src/components/card/css/theme/variations/doubling-variables.css */\n@layer card.theme.variations.doubling {\n  :host {\n  }\n}\n\n/* src/components/card/css/theme/variations/stackable-variables.css */\n@layer card.theme.variations.stackable {\n  @property --card-stackable-comparison { syntax: "<length>"; inherits: true; initial-value: 1px; }\n  :host {\n    --card-stackable-breakpoint: var(--largest-mobile-screen);\n  }\n}\n\n/* src/components/card/css/theme/card-theme.css */\n\n/* src/components/card/css/card.css */\n';

// src/components/card/card-page.css?raw
var card_page_default = '/* CSS Properties must be declared in global scope */\n@property --card-stackable-comparison {\n  syntax: "<length>";\n  inherits: true;\n  initial-value: 1px;\n}\n';

// src/components/card/card.js
var createComponent = ({ $ }) => ({});
var UICard = defineComponent({
  tagName: "ui-card",
  componentSpec: card_component_default,
  template: card_default,
  css: card_bundle_default,
  pageCSS: card_page_default,
  createComponent
});

// src/components/card/plural/cards.js
import { defineComponent as defineComponent2 } from "https://cdn.jsdelivr.net/npm/@semantic-ui/component@0.12.4/dist/index.min.js";

// src/components/card/specs/cards-component.json
var cards_component_default = {
  tagName: "ui-cards",
  variations: [
    "doubling",
    "stackable",
    "spaced",
    "count"
  ],
  attributes: [
    "doubling",
    "stackable",
    "spaced",
    "count"
  ],
  optionAttributes: {
    spaced: "spaced",
    "very-spaced": "spaced",
    two: "count",
    three: "count",
    four: "count",
    five: "count",
    six: "count"
  },
  propertyTypes: {
    doubling: "boolean",
    stackable: "boolean",
    spaced: "string",
    count: "string"
  },
  allowedValues: {
    spaced: [
      "spaced",
      "very-spaced"
    ],
    count: [
      "two",
      "three",
      "four",
      "five",
      "six"
    ]
  }
};

// src/components/card/plural/cards.html?raw
var cards_default = '<div class="component">\n  <div class="{{ui}}cards" part="cards">\n    {{>slot}}\n  </div>\n</div>\n';

// src/components/card/plural/cards.js
var UICards = defineComponent2({
  tagName: "ui-cards",
  singularTag: "ui-card",
  plural: true,
  delegateFocus: true,
  componentSpec: cards_component_default,
  template: cards_default,
  css: card_bundle_default
});
export {
  UICard,
  UICards
};
//# sourceMappingURL=card.js.map
