/**
 * @semantic-ui/core v0.12.4
 * Semantic empowers designers and developers by creating a shared vocabulary for UI.
 *
 * @license MIT
 * @copyright (c) 2025 Jack Lukic <jack@semantic-ui.com>
 * @homepage http://next.semantic-ui.com
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

// src/components/label/label.js
import { defineComponent } from "https://cdn.jsdelivr.net/npm/@semantic-ui/component@0.12.4/dist/index.min.js";

// src/components/label/specs/label-component.json
var label_component_default = {
  tagName: "ui-label",
  types: [
    "emphasis"
  ],
  variations: [
    "badge",
    "size"
  ],
  attributes: [
    "emphasis",
    "badge",
    "size"
  ],
  optionAttributes: {
    secondary: "emphasis",
    outline: "emphasis",
    mini: "size",
    tiny: "size",
    small: "size",
    medium: "size",
    large: "size",
    big: "size",
    huge: "size",
    massive: "size"
  },
  propertyTypes: {
    emphasis: "string",
    badge: "boolean",
    size: "string"
  },
  allowedValues: {
    emphasis: [
      "secondary",
      "outline"
    ],
    size: [
      "mini",
      "tiny",
      "small",
      "medium",
      "large",
      "big",
      "huge",
      "massive"
    ]
  }
};

// src/components/label/label.html?raw
var label_default = '<div class="{ui}label" part="label">\n  {#if text}\n    {text}\n  {else}\n    {>slot}\n  {/if}\n  {#if detail}\n    <span class="detail">{detail}</span>\n  {/if}\n</div>\n';

// src/components/label/label-bundle.css?raw
var label_bundle_default = "/**\n  ---DO NOT EDIT THIS FILE DIRECTLY---\n  This CSS file was concatenated from files listed in the css/ folder as part of a build process\n  This is to allow for js import with @import links which will not be followed\n**/\n\n/* src/components/label/css/definition/content/label.css */\n@layer label.definition.content.label {\n  :host {\n    display: inline-flex;\n    margin: var(--label-margin);\n  }\n  :host::last-child {\n    margin-right: 0rem;\n  }\n  .label {\n    display: inline-flex;\n    padding: var(--label-padding);\n    background: var(--label-background);\n    color: var(--label-color);\n    border-radius: var(--label-border-radius);\n    font-weight: var(--label-font-weight);\n    min-width: var(--label-min-width);\n  }\n}\n\n/* src/components/label/css/definition/types/emphasis.css */\n@layer label.definition.types.emphasis {\n  .secondary.label {\n    background: var(--label-secondary-background);\n    color: var(--label-secondary-text-color);\n  }\n  .outline.label {\n    background: var(--label-outline-background);\n    outline: var(--label-outline);\n    color: var(--label-outline-text-color);\n  }\n}\n\n/* src/components/label/css/definition/types/badge.css */\n@layer label.definition.types.badge {\n  .badge.label {\n    padding: var(--label-badge-padding);\n  }\n}\n\n/* src/components/label/css/definition/variations/sizing.css */\n@layer label.definition.variations.sizing {\n  .mini.label {\n    font-size: var(--label-mini);\n  }\n  .tiny.label {\n    font-size: var(--label-tiny);\n  }\n  .small.label {\n    font-size: var(--label-small);\n  }\n  :host {\n    font-size: var(--label-medium);\n  }\n  .large.label {\n    font-size: var(--label-large);\n  }\n  .big.label {\n    font-size: var(--label-big);\n  }\n  .huge.label {\n    font-size: var(--label-huge);\n  }\n  .massive.label {\n    font-size: var(--label-massive);\n  }\n  .mini.labels {\n    --label-medium: var(--label-mini);\n  }\n  .tiny.labels {\n    --label-medium: var(--label-tiny);\n  }\n  .small.labels {\n    --label-medium: var(--label-small);\n  }\n  .large.labels {\n    --label-medium: var(--label-large);\n  }\n  .big.labels {\n    --label-medium: var(--label-big);\n  }\n  .huge.labels {\n    --label-medium: var(--label-huge);\n  }\n  .massive.labels {\n    --label-medium: var(--label-massive);\n  }\n}\n\n/* src/components/label/css/definition/variations/aligned.css */\n@layer label.definition.variations.aligned;\n\n/* src/components/label/css/definition/label-definition.css */\n\n/* src/components/label/css/theme/content/label-variables.css */\n@layer label.theme.content.label {\n  :host {\n    --label-vertical-padding: var(--relative-3px);\n    --label-horizontal-padding: var(--relative-6px);\n    --label-padding: var(--label-vertical-padding) var(--label-horizontal-padding);\n    --label-color: var(--inverted-90);\n    --label-background: var(--standard-90);\n    --label-border-radius: var(--relative-5px);\n    --label-min-width: 0px;\n    --label-font-weight: var(--bold);\n    --label-vertical-margin: calc(var(--label-vertical-padding) * -1);\n    --label-horizontal-margin: 4px;\n    --label-margin: var(--label-vertical-margin) var(--label-horizontal-margin);\n  }\n}\n\n/* src/components/label/css/theme/types/emphasis-variables.css */\n@layer label.theme.types.emphasis {\n  :host {\n    --label-secondary-background: var(--standard-10);\n    --label-secondary-text-color: var(--standard-90);\n    --label-outline-background: transparent;\n    --label-outline: var(--internal-border);\n    --label-outline-text-color: var(--standard-90);\n  }\n}\n\n/* src/components/label/css/theme/types/badge-variables.css */\n@layer label.theme.types.badge {\n  :host {\n    --label-badge-vertical-padding: var(--label-vertical-padding);\n    --label-badge-horizontal-padding: var(--relative-4px);\n    --label-badge-padding: var(--label-badge-vertical-padding) var(--label-badge-horizontal-padding);\n  }\n}\n\n/* src/components/label/css/theme/variations/sizing-variables.css */\n@layer label.theme.variations.sizing {\n  :host {\n    --label-mini: var(--9px);\n    --label-tiny: var(--10px);\n    --label-small: var(--11px);\n    --label-medium: inherit;\n    --label-large: var(--15px);\n    --label-big: var(--16px);\n    --label-huge: var(--18px);\n    --label-massive: var(--24px);\n  }\n}\n\n/* src/components/label/css/theme/variations/aligned-variables.css */\n@layer label.theme.variations.aligned {\n  :host {\n  }\n}\n\n/* src/components/label/css/theme/label-theme.css */\n\n/* src/components/label/css/label.css */\n";

// src/components/label/label.js
var createComponent = ({ $ }) => ({});
var UILabel = defineComponent({
  tagName: "ui-label",
  componentSpec: label_component_default,
  template: label_default,
  css: label_bundle_default,
  createComponent
});
export {
  UILabel
};
//# sourceMappingURL=label.js.map
