/**
 * @semantic-ui/core v0.12.4
 * Semantic empowers designers and developers by creating a shared vocabulary for UI.
 *
 * @license MIT
 * @copyright (c) 2025 Jack Lukic <jack@semantic-ui.com>
 * @homepage http://next.semantic-ui.com
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

// src/components/menu/content/item/menu-item.js
import { defineComponent } from "https://cdn.jsdelivr.net/npm/@semantic-ui/component@0.12.4/dist/index.min.js";

// src/components/menu/specs/menu-item-component.json
var menu_item_component_default = {
  tagName: "menu-item",
  content: [
    "icon",
    "label",
    "badge",
    "href",
    "value"
  ],
  contentAttributes: [
    "icon",
    "label",
    "badge",
    "href",
    "value"
  ],
  states: [
    "hover",
    "focused",
    "active",
    "disabled"
  ],
  attributes: [
    "icon",
    "label",
    "badge",
    "href",
    "value",
    "hover",
    "focused",
    "active",
    "disabled"
  ],
  propertyTypes: {
    icon: "string",
    label: "string",
    badge: "string",
    href: "string",
    value: "string",
    hover: "boolean",
    focused: "boolean",
    active: "boolean",
    disabled: "boolean"
  },
  attributeClasses: [
    "icon"
  ]
};

// src/components/menu/menu-bundle.css?raw
var menu_bundle_default = "/**\n  ---DO NOT EDIT THIS FILE DIRECTLY---\n  This CSS file was concatenated from files listed in the css/ folder as part of a build process\n  This is to allow for js import with @import links which will not be followed\n**/\n\n/* src/components/menu/css/definition/content/menu.css */\n@layer menu.definition.content.menu {\n  ui-menu {\n    display: block;\n    margin: var(--menu-margin);\n    padding: var(--menu-padding);\n    box-shadow: var(--menu-box-shadow);\n    border: var(--menu-border);\n    font-size: var(--menu-font-size);\n  }\n  .menu {\n    display: flex;\n    flex-direction: row;\n    font-weight: var(--menu-font-weight);\n    gap: var(--menu-gap);\n    background: var(--menu-background);\n    align-items: var(--menu-align-items);\n    justify-content: var(--menu-justify-content);\n  }\n}\n\n/* src/components/menu/css/definition/content/item.css */\n@layer menu.definition.content.item {\n  .item {\n    display: block;\n    cursor: pointer;\n    background: var(--menu-item-background);\n    margin: var(--menu-item-margin);\n    padding: var(--menu-item-padding);\n    border: var(--menu-item-border);\n    color: var(--menu-item-color);\n    font-weight: var(--menu-item-font-weight);\n    line-height: var(--menu-item-line-height);\n    box-shadow: var(--menu-item-box-shadow);\n    border-radius: var(--menu-item-border-radius);\n    text-align: var(--menu-item-text-align);\n    text-decoration: var(--menu-item-text-decoration);\n  }\n  .item:hover,\n  .item.hover {\n    background: var(--menu-item-hover-background);\n    margin: var(--menu-item-hover-margin);\n    padding: var(--menu-item-hover-padding);\n    border: var(--menu-item-hover-border);\n    color: var(--menu-item-hover-color);\n    box-shadow: var(--menu-item-hover-box-shadow);\n    border-radius: var(--menu-item-hover-border-radius);\n  }\n  .active.item {\n    cursor: default;\n    background: var(--menu-item-active-background);\n    margin: var(--menu-item-active-margin);\n    padding: var(--menu-item-active-padding);\n    border: var(--menu-item-active-border);\n    box-shadow: var(--menu-item-active-box-shadow);\n    font-weight: var(--menu-item-active-font-weight);\n    color: var(--menu-item-active-color);\n    border-radius: var(--menu-item-active-border-radius);\n  }\n}\n\n/* src/components/menu/css/definition/types/selection.css */\n@layer menu.definition.types.selection {\n  .selection.menu {\n    gap: var(--menu-selection-gap);\n  }\n  .selection.menu ::slotted(*),\n  .selection.menu menu-item {\n    --menu-item-padding: var(--menu-selection-item-padding);\n    --menu-item-border-radius: var(--menu-selection-item-border-radius);\n    --menu-item-color: var(--menu-selection-item-color);\n    --menu-item-hover-background: var(--menu-selection-item-hover-background);\n    --menu-item-hover-border-radius: var(--menu-selection-item-border-radius);\n    --menu-item-hover-color: var(--menu-selection-item-hover-color);\n    --menu-item-hover-box-shadow: var(--menu-selection-item-hover-box-shadow);\n    --menu-item-active-background: var(--menu-selection-item-active-background);\n    --menu-item-active-border-radius: var(--menu-selection-item-border-radius);\n    --menu-item-active-padding: var(--menu-selection-item-active-padding);\n    --menu-item-active-color: var(--menu-selection-item-active-color);\n    --menu-item-active-box-shadow: var(--menu-selection-item-active-box-shadow);\n  }\n}\n\n/* src/components/menu/css/definition/variations/evenly-spaced.css */\n@layer menu.definition.variations.equalWidth {\n  .evenly-spaced.menu {\n    display: grid;\n    grid-auto-flow: column;\n    grid-auto-columns: minmax(0, 1fr);\n    --menu-item-text-align: var(--menu-evenly-spaced-item-text-align) ;\n  }\n}\n\n/* src/components/menu/css/definition/variations/fitted.css */\n@layer menu.definition.variations.fitted {\n  :host([fitted]),\n  .fitted.menu {\n    margin: 0;\n  }\n}\n\n/* src/components/menu/css/definition/variations/inset.css */\n@layer menu.definition.variations.inset {\n  .inset.menu {\n    border: var(--menu-inset-border);\n    border-radius: var(--menu-inset-border-radius);\n    padding: var(--menu-inset-padding);\n    background: var(--menu-inset-background);\n  }\n}\n\n/* src/components/menu/css/definition/variations/vertical.css */\n@layer menu.definition.variations.vertical {\n  .vertical.menu {\n    flex-direction: column;\n    align-items: var(--menu-vertical-align-items);\n    text-align: var(--menu-vertical-text-align);\n  }\n}\n\n/* src/components/menu/css/definition/menu-definition.css */\n\n/* src/components/menu/css/theme/content/menu-variables.css */\n@layer menu.theme.content.menu {\n  :host {\n    --menu-margin: var(--vertically-spaced);\n    --menu-font-weight: var(--normal);\n    --menu-gap: var(--4px);\n    --menu-align-items: flex-start;\n    --menu-font-size: var(--medium);\n    --menu-justify-content: flex-start;\n    --menu-padding: 0;\n    --menu-box-shadow: none;\n    --menu-background: none;\n    --menu-border: none;\n  }\n}\n\n/* src/components/menu/css/theme/content/menu-item-variables.css */\n@layer menu.theme.content.menuItem {\n  :host {\n    --menu-item-background-color: transparent;\n    --menu-item-background-image: none;\n    --menu-item-background: var(--menu-item-background-color) var(--menu-item-background-image);\n    --menu-item-margin: 0;\n    --menu-item-line-height: 1;\n    --menu-item-font-weight: var(--normal);\n    --menu-item-padding: var(--7px) var(--6px);\n    --menu-item-border: none;\n    --menu-item-border-radius: none;\n    --menu-item-color: var(--standard-60);\n    --menu-item-text-align: inherit;\n    --menu-item-box-shadow: none;\n    --menu-item-text-decoration: none;\n    --menu-item-hover-background-color: var(--menu-item-background-color);\n    --menu-item-hover-background-image: var(--menu-item-background-image);\n    --menu-item-hover-background: var(--menu-item-hover-background-color) var(--menu-item-hover-background-image);\n    --menu-item-hover-margin: var(--menu-item-margin);\n    --menu-item-hover-padding: var(--menu-item-padding);\n    --menu-item-hover-color: var(--standard-100);\n    --menu-item-hover-border: var(--menu-item-border);\n    --menu-item-hover-box-shadow: var(--menu-item-box-shadow);\n    --menu-item-hover-border-radius: var(--menu-item-border-radius);\n    --menu-item-active-background-color: var(--menu-item-active-background-color);\n    --menu-item-active-background-image: var(--menu-item-active-background-image);\n    --menu-item-active-font-weight: var(--bold);\n    --menu-item-active-background: var(--menu-item-background);\n    --menu-item-active-margin: var(--menu-item-margin);\n    --menu-item-active-padding: var(--menu-item-padding);\n    --menu-item-active-color: var(--primary-text-color);\n    --menu-item-active-border: var(--menu-item-border);\n    --menu-item-active-box-shadow: var(--menu-item-box-shadow);\n    --menu-item-active-border-radius: var(--menu-item-border-radius);\n  }\n  html.dark {\n    --menu-item-color: var(--standard-30);\n    --menu-item-hover-color: var(--standard-100);\n    --menu-item-active-color: var(--primary-text-color);\n  }\n}\n\n/* src/components/menu/css/theme/types/selection-variables.css */\n@layer menu.theme.type.selection {\n  :host {\n    --menu-selection-gap: 6px;\n    --menu-selection-item-padding: 7px 6px;\n    --menu-selection-item-border-radius: var(--border-radius);\n    --menu-selection-item-color: var(--standard-30);\n    --menu-selection-item-hover-padding: var(--menu-selection-item-padding);\n    --menu-selection-item-hover-background: var(--standard-10);\n    --menu-selection-item-hover-color: #013A4F;\n    --menu-selection-item-hover-box-shadow: none;\n    --menu-selection-item-active-padding: var(--menu-selection-item-padding);\n    --menu-selection-item-active-background: #D0EBF3;\n    --menu-selection-item-active-color: var(--primary-text-color);\n    --menu-selection-item-active-box-shadow: 0px 1px 6px rgb(85 147 167 / 77%) inset;\n  }\n  @container style(--dark-mode: true) {\n    :host {\n      --menu-selection-item-hover-background: transparent;\n      --menu-selection-item-hover-color: var(--standard-90);\n      --menu-selection-item-active-background: #35B7F1;\n      --menu-selection-item-active-color: var(--black-90);\n      --menu-selection-item-active-box-shadow: 0px 0px 10px rgb(0 92 165) inset;\n    }\n  }\n}\n\n/* src/components/menu/css/theme/variations/evenly-spaced-variables.css */\n@layer menu.theme.variations.evenlySpaced {\n  :host {\n    --menu-evenly-spaced-item-text-align: center;\n  }\n}\n\n/* src/components/menu/css/theme/variations/vertical-variables.css */\n@layer menu.theme.variations.vertical {\n  :host {\n    --menu-vertical-align-items: stretch;\n    --menu-vertical-text-align: center;\n  }\n}\n\n/* src/components/menu/css/theme/variations/inset-variables.css */\n@layer menu.theme.variations.inset {\n  :host {\n    --menu-inset-padding: 3px 4px;\n    --menu-inset-border-radius: var(--border-radius);\n    --menu-inset-border: var(--internal-border);\n    --menu-inset-background: var(--inverted-15);\n  }\n}\n\n/* src/components/menu/css/theme/menu-theme.css */\n\n/* src/components/menu/css/menu.css */\n";

// src/components/menu/content/item/menu-item.html?raw
var menu_item_default = '{{#snippet content}}\n  {{#if icon}}\n    <ui-icon icon={{icon}}></ui-icon>\n  {{/if}}\n  {{>slot}}\n{{/snippet}}\n\n{{#if href}}\n  <a class="{{ui}}item" href="{{href}}" part="item">\n    {{>content}}\n  </a>\n{{else}}\n  <div class="{{ui}}item" part="item">\n    {{>content}}\n  </div>\n{{/if}}\n';

// src/components/menu/content/item/menu-item.js
var onCreated = ({ data }) => {
};
var events = {
  "touchstart .menu"({ event, tpl, $ }) {
    $(this).addClass("pressed");
  },
  "touchend .menu"({ event, tpl, $ }) {
    $(this).removeClass("pressed");
  }
};
var MenuItem = defineComponent({
  tagName: "menu-item",
  events,
  onCreated,
  componentSpec: menu_item_component_default,
  template: menu_item_default,
  css: menu_bundle_default
});

// src/components/menu/menu.js
import { defineComponent as defineComponent2 } from "https://cdn.jsdelivr.net/npm/@semantic-ui/component@0.12.4/dist/index.min.js";

// src/components/menu/specs/menu-component.json
var menu_component_default = {
  tagName: "ui-menu",
  content: [
    "item"
  ],
  types: [
    "selection"
  ],
  variations: [
    "evenly-spaced",
    "fitted",
    "vertical",
    "inset"
  ],
  settings: [
    "items",
    "value"
  ],
  attributes: [
    "item",
    "selection",
    "evenly-spaced",
    "fitted",
    "vertical",
    "inset",
    "items",
    "value"
  ],
  propertyTypes: {
    item: "string",
    selection: "boolean",
    "evenly-spaced": "boolean",
    fitted: "boolean",
    vertical: "boolean",
    inset: "boolean",
    items: "array",
    value: "string"
  },
  defaultValues: {
    items: [],
    value: ""
  }
};

// src/components/menu/menu.html?raw
var menu_default = '<div class="{ui}menu" part="menu">\n  {#each item in items}\n    <menu-item\n      active={isValueActive value item}\n      href={item.href}\n      data-value={item.value}\n      exportparts="item"\n    >\n      {item.label}\n      {#if item.badge}\n        <ui-label outline badge>{item.badge}</ui-label>\n      {/if}\n    </menu-item>\n  {else}\n    {>slot}\n  {/each}\n</div>\n';

// src/components/menu/menu-page.css?raw
var menu_page_default = "ui-menu[selection] menu-item {\n  --menu-item-padding: var(--menu-selection-item-padding);\n  --menu-item-border-radius: var(--menu-selection-item-border-radius);\n  --menu-item-color: var(--menu-selection-item-color);\n\n  --menu-item-hover-background: var(--menu-selection-item-hover-background);\n  --menu-item-hover-border-radius: var(--menu-selection-item-border-radius);\n  --menu-item-hover-color: var(--menu-selection-item-hover-color);\n  --menu-item-hover-box-shadow: var(--menu-selection-item-hover-box-shadow);\n\n  --menu-item-active-background: var(--menu-selection-item-active-background);\n  --menu-item-active-border-radius: var(--menu-selection-item-border-radius);\n  --menu-item-active-padding: var(--menu-selection-item-active-padding);\n  --menu-item-active-color: var(--menu-selection-item-active-color);\n  --menu-item-active-box-shadow: var(--menu-selection-item-active-box-shadow);\n}\n";

// src/components/menu/menu.js
var createComponent = ({ settings, self, $, dispatchEvent }) => ({
  setValue(value) {
    settings.value = value;
    dispatchEvent("change", { value });
  },
  getValue(item) {
    return item.value || item.href;
  },
  isValueActive(activeValue, item) {
    if (item.active) {
      return true;
    }
    if (activeValue !== void 0) {
      return activeValue == self.getValue(item);
    }
    return false;
  },
  selectIndex(eq) {
    const value = $("menu-item").eq(eq).attr("data-value");
    if (value !== void 0) {
      self.setValue(value);
    }
  }
});
var onCreated2 = ({ settings }) => {
};
var onRendered = function({ $ }) {
};
var events2 = {
  "click menu-item"({ self, data }) {
    self.setValue(data.value);
  }
};
var UIMenu = defineComponent2({
  tagName: "ui-menu",
  componentSpec: menu_component_default,
  template: menu_default,
  css: menu_bundle_default,
  pageCSS: menu_page_default,
  createComponent,
  events: events2,
  onCreated: onCreated2,
  onRendered
});
export {
  MenuItem,
  UIMenu
};
//# sourceMappingURL=menu.js.map
