/**
 * @semantic-ui/core v0.12.4
 * Semantic empowers designers and developers by creating a shared vocabulary for UI.
 *
 * @license MIT
 * @copyright (c) 2025 Jack Lukic <jack@semantic-ui.com>
 * @homepage http://next.semantic-ui.com
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

// src/components/modal/modal.js
import { defineComponent } from "@semantic-ui/component";

// packages/utils/src/functions.js
var noop = (v) => v;

// packages/utils/src/colors.js
var GAMMA_EXPONENT = 1 / 2.4;

// src/components/modal/specs/modal-component.json
var modal_component_default = {
  tagName: "ui-modal",
  types: [
    "glass"
  ],
  variations: [
    "aligned",
    "size"
  ],
  settings: [
    "closeable"
  ],
  attributes: [
    "glass",
    "aligned",
    "size",
    "closeable"
  ],
  optionAttributes: {
    "top-aligned": "aligned",
    tiny: "size",
    small: "size",
    medium: "size",
    large: "size",
    big: "size"
  },
  propertyTypes: {
    glass: "boolean",
    aligned: "string",
    size: "string",
    closeable: "boolean"
  },
  allowedValues: {
    aligned: [
      "top-aligned"
    ],
    size: [
      "tiny",
      "small",
      "medium",
      "large",
      "big"
    ]
  },
  defaultValues: {
    closeable: true
  }
};

// src/components/modal/modal.html?raw
var modal_default = '<dialog part="dialog">\n  {{#if not closeable}}\n    <ui-icon link x class="close"></ui-icon>\n  {{/if}}\n  <div class="{{ui}}modal" part="modal">\n    {{>slot}}\n  </div>\n</dialog>\n';

// src/components/modal/modal-bundle.css?raw
var modal_bundle_default = '/**\n  ---DO NOT EDIT THIS FILE DIRECTLY---\n  This CSS file was concatenated from files listed in the css/ folder as part of a build process\n  This is to allow for js import with @import links which will not be followed\n**/\n\n/* src/components/modal/css/definition/content/modal.css */\n@layer modal.definition.content.modal {\n  dialog {\n    position: fixed;\n    width: inherit;\n    outline: none;\n    border: none;\n    background-color: transparent;\n    overflow: visible;\n  }\n  dialog {\n    display: none;\n    flex-direction: column;\n    opacity: 0;\n    scale: 0.8;\n    transition: var(--modal-dialog-transition);\n  }\n  dialog[open] {\n    display: flex;\n    opacity: 1;\n    scale: 1;\n  }\n  @starting-style {\n    dialog[open] {\n      opacity: 0;\n      scale: 0.8;\n    }\n  }\n  dialog::backdrop {\n    background-color: rgb(0 0 0 / 0%);\n    transition: var(--modal-dimmer-transition);\n  }\n  dialog[open]::backdrop {\n    background: var(--modal-dimmer-background);\n  }\n  @starting-style {\n    dialog[open]::backdrop {\n      background: rgb(0 0 0 / 0%);\n    }\n  }\n  dialog .modal {\n    background: var(--modal-background);\n    max-width: var(--modal-max-width);\n    border-radius: var(--modal-border-radius);\n    box-shadow: 0px 0px 0px rgba(0, 0, 0, 0);\n    transition: var(--modal-transition);\n  }\n  dialog[open] .modal {\n    box-shadow: var(--modal-box-shadow);\n  }\n  @starting-style {\n    dialog[open] .modal {\n      box-shadow: 0px 0px 0px rgba(0, 0, 0, 0);\n    }\n  }\n  dialog ::slotted(.content) {\n    padding: var(--padding);\n  }\n  dialog .close {\n    cursor: pointer;\n    align-self: flex-end;\n    color: #FFF;\n    margin: 0;\n    font-size: 22px;\n    padding: 1rem;\n    opacity: 0.6;\n    transition: var(--transition);\n  }\n  dialog .close:hover {\n    opacity: 1;\n  }\n  dialog .close + .modal {\n    margin-right: 3rem;\n  }\n}\n\n/* src/components/modal/css/definition/types/glass.css */\n@layer modal.definition.types.glass {\n  .glass.modal {\n    -webkit-backdrop-filter: var(--modal-glass-backdrop-filter);\n    backdrop-filter: var(--modal-glass-backdrop-filter);\n    box-shadow: var(--modal-glass-box-shadow);\n    background: var(--modal-glass-background);\n  }\n}\n\n/* src/components/modal/css/definition/variations/aligned.css */\n@layer modal.definition.variations.aligned;\n\n/* src/components/modal/css/definition/variations/sizing.css */\n@layer modal.definition.variations.sizing {\n  :host {\n    width: var(--modal-medium);\n  }\n  :host([size="mini"]),\n  :host([mini]),\n  :host.mini {\n    width: var(--modal-mini);\n  }\n  :host([size="tiny"]),\n  :host([tiny]),\n  :host.tiny {\n    width: var(--modal-tiny);\n  }\n  :host([size="small"]),\n  :host([small]),\n  :host.small {\n    width: var(--modal-small);\n  }\n  :host([size="large"]),\n  :host([large]),\n  :host.large {\n    width: var(--modal-large);\n  }\n  :host([size="big"]),\n  :host([big]),\n  :host.big {\n    width: var(--modal-big);\n  }\n  :host([size="huge"]),\n  :host([huge]),\n  :host.huge {\n    width: var(--modal-huge);\n  }\n  :host([size="massive"]),\n  :host([massive]),\n  :host.massive {\n    width: var(--modal-massive);\n  }\n}\n\n/* src/components/modal/css/definition/modal-definition.css */\n\n/* src/components/modal/css/theme/content/modal-variables.css */\n@layer modal.theme.content.modal {\n  :host {\n    --modal-box-shadow: 2px 5px 15px rgba(0, 0, 0, 0.3);\n    --modal-border-radius: var(--border-radius);\n    --modal-background: var(--white);\n    --modal-dimmer-background: var(--black-50);\n    --modal-max-width: calc(100vw - 2rem);\n    --modal-transition: all 300ms ease 100ms;\n    --modal-dialog-transition-duration: 200ms;\n    --modal-dialog-transition:\n      opacity var(--modal-dialog-transition-duration) ease,\n      scale var(--modal-dialog-transition-duration) ease,\n      overlay var(--modal-dialog-transition-duration) ease allow-discrete,\n      display var(--modal-dialog-transition-duration) ease allow-discrete;\n    --modal-dimmer-transition-duration: 700ms;\n    --modal-dimmer-transition:\n      display var(--modal-dimmer-transition-duration) allow-discrete,\n      overlay var(--modal-dimmer-transition-duration) allow-discrete,\n      background var(--modal-dimmer-transition-duration);\n  }\n}\n\n/* src/components/modal/css/theme/types/glass-variables.css */\n@layer modal.theme.types.glass {\n  :host {\n    --modal-glass-background: none transparent;\n    --modal-glass-blur: 7px;\n    --modal-glass-backdrop-filter: blur(var(--modal-glass-blur));\n    --modal-glass-box-shadow:\n      inset -0.75px -0.5px rgba(255, 255, 255, 0.1),\n      inset +0.75px +0.5px rgba(255, 255, 255, 0.025),\n      3px 2px 10px rgba(0, 0, 0, 0.25),\n      inset 0px 0px 10px 5px rgba(255, 255, 255, 0.025),\n      inset 0px 0px 40px 5px rgba(255, 255, 255, 0.025) ;\n  }\n}\n\n/* src/components/modal/css/theme/variations/aligned-variables.css */\n@layer modal.theme.variations.aligned {\n  :host {\n  }\n}\n\n/* src/components/modal/css/theme/variations/sizing-variables.css */\n@layer modal.theme.variations.sizing {\n  :host {\n    --modal-mini: 320px;\n    --modal-tiny: 400px;\n    --modal-small: 500px;\n    --modal-medium: 700px;\n    --modal-large: 850px;\n    --modal-big: 1100px;\n    --modal-huge: 1300px;\n    --modal-massive: 1600px;\n  }\n}\n\n/* src/components/modal/css/theme/modal-theme.css */\n\n/* src/components/modal/css/modal.css */\n';

// src/components/modal/modal.js
var createComponent = ({ $, dispatchEvent }) => ({
  show(callback = noop) {
    if (callback() !== false) {
      $("dialog").get(0).showModal();
    }
    dispatchEvent("show");
  },
  hide(callback = noop) {
    if (callback() !== false) {
      $("dialog").get(0).close();
    }
    dispatchEvent("hide");
  }
});
var onCreated = ({}) => {
};
var onRendered = function({}) {
};
var events = {
  "click ui-icon.close"({ event, self }) {
    self.hide();
  },
  "click dialog"({ $, event, settings, self }) {
    if (settings.closeable && $(event.target).is("dialog")) {
      self.hide();
    }
  }
};
var UIModal = defineComponent({
  tagName: "ui-modal",
  componentSpec: modal_component_default,
  template: modal_default,
  css: modal_bundle_default,
  createComponent,
  events,
  onCreated,
  onRendered
});
export {
  UIModal
};
//# sourceMappingURL=modal.js.map
