/**
 * @semantic-ui/core v0.12.4
 * Semantic empowers designers and developers by creating a shared vocabulary for UI.
 *
 * @license MIT
 * @copyright (c) 2025 Jack Lukic <jack@semantic-ui.com>
 * @homepage http://next.semantic-ui.com
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);

// packages/utils/src/equality.js
var isEqual = (a3, b3, options = {}) => {
  if (a3 === b3) {
    return true;
  }
  if (a3 && b3 && typeof a3 == "object" && typeof b3 == "object") {
    if (a3.constructor !== b3.constructor) {
      return false;
    }
    let length, i6, keys3;
    if (Array.isArray(a3)) {
      length = a3.length;
      if (length != b3.length) {
        return false;
      }
      for (i6 = length; i6-- !== 0; ) {
        if (!isEqual(a3[i6], b3[i6])) {
          return false;
        }
      }
      return true;
    }
    if (a3 instanceof Map && b3 instanceof Map) {
      if (a3.size !== b3.size) {
        return false;
      }
      for (i6 of a3.entries()) {
        if (!b3.has(i6[0])) {
          return false;
        }
      }
      for (i6 of a3.entries()) {
        if (!isEqual(i6[1], b3.get(i6[0]))) {
          return false;
        }
      }
      return true;
    }
    if (a3 instanceof Set && b3 instanceof Set) {
      if (a3.size !== b3.size) {
        return false;
      }
      for (i6 of a3.entries()) {
        if (!b3.has(i6[0])) {
          return false;
        }
      }
      return true;
    }
    if (ArrayBuffer.isView(a3) && ArrayBuffer.isView(b3)) {
      length = a3.length;
      if (length != b3.length) {
        return false;
      }
      for (i6 = length; i6-- !== 0; ) {
        if (a3[i6] !== b3[i6]) {
          return false;
        }
      }
      return true;
    }
    if (a3.constructor === RegExp) {
      return a3.source === b3.source && a3.flags === b3.flags;
    }
    if (a3.valueOf !== Object.prototype.valueOf) {
      return a3.valueOf() === b3.valueOf();
    }
    if (a3.toString !== Object.prototype.toString) {
      return a3.toString() === b3.toString();
    }
    keys3 = Object.keys(a3);
    length = keys3.length;
    if (length !== Object.keys(b3).length) {
      return false;
    }
    for (i6 = length; i6-- !== 0; ) {
      if (!Object.prototype.hasOwnProperty.call(b3, keys3[i6])) {
        return false;
      }
    }
    for (i6 = length; i6-- !== 0; ) {
      let key = keys3[i6];
      if (!isEqual(a3[key], b3[key])) {
        return false;
      }
    }
    return true;
  }
  return a3 !== a3 && b3 !== b3;
};

// packages/utils/src/types.js
var isObject = (x2) => {
  return x2 !== null && typeof x2 == "object";
};
var isPlainObject = (x2) => {
  return isObject(x2) && x2.constructor === Object;
};
var isString = (x2) => {
  return typeof x2 == "string";
};
var isNumber = (x2) => {
  return typeof x2 == "number";
};
var isArray = (x2) => {
  return Array.isArray(x2);
};
var isFunction = (x2) => {
  return typeof x2 == "function" || false;
};
var isDOM = (element) => {
  if (typeof window === "undefined") {
    return true;
  }
  return element instanceof Element || element instanceof Document || element === window || element instanceof DocumentFragment;
};
var isEmpty = (x2) => {
  if (x2 == null) {
    return true;
  }
  if (isArray(x2) || isString(x2)) {
    return x2.length === 0;
  }
  for (let key in x2) {
    if (x2[key]) {
      return false;
    }
  }
  return true;
};
var isClassInstance = (obj) => {
  if (obj === null || typeof obj !== "object") {
    return false;
  }
  const proto = Object.getPrototypeOf(obj);
  const constructorName = proto.constructor.name;
  const builtInTypes = [
    "Object",
    "Array",
    "Date",
    "RegExp",
    "Map",
    "Set",
    "Error",
    "Uint8Array",
    "Int8Array",
    "Uint16Array",
    "Int16Array",
    "Uint32Array",
    "Int32Array",
    "Float32Array",
    "Float64Array",
    "BigInt64Array",
    "BigUint64Array",
    "NodeList"
  ];
  return !builtInTypes.includes(constructorName);
};

// packages/utils/src/looping.js
var each = (obj, func, context) => {
  if (obj === null || obj === void 0) {
    return obj;
  }
  const iteratee = context ? func.bind(context) : func;
  if (isObject(obj) || isFunction(obj)) {
    if (obj.length !== void 0 && typeof obj.length === "number") {
      obj = Array.from(obj);
    }
  }
  if (isArray(obj)) {
    for (let i6 = 0; i6 < obj.length; ++i6) {
      if (iteratee(obj[i6], i6, obj) === false) {
        break;
      }
    }
  } else {
    const keys3 = Object.keys(obj);
    for (let key of keys3) {
      if (iteratee(obj[key], key, obj) === false) {
        break;
      }
    }
  }
  return obj;
};

// packages/utils/src/crypto.js
var tokenize = (str = "") => {
  return (str || "").replace(/\s+/g, "-").replace(/[^\w-]+/g, "").replace(/_/g, "-").toLowerCase();
};
var prettifyID = (num) => {
  num = parseInt(num, 10);
  if (num === 0) {
    return "0";
  }
  let result = "";
  const chars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ";
  while (num > 0) {
    result = chars[num % chars.length] + result;
    num = Math.floor(num / chars.length);
  }
  return result;
};
function hashCode(input, { prettify = false, seed = 305419896 } = {}) {
  const prime1 = 2654435761;
  const prime2 = 2246822519;
  const prime3 = 3266489917;
  let inputData;
  if (input === null || input === void 0) {
    inputData = new TextEncoder().encode("");
  } else if (input && input.toString === Object.prototype.toString && typeof input === "object") {
    try {
      inputData = new TextEncoder().encode(JSON.stringify(input));
    } catch (error) {
      console.error("Error serializing input", error);
      return 0;
    }
  } else {
    inputData = new TextEncoder().encode(input.toString());
  }
  let hash;
  if (inputData.length <= 8) {
    hash = seed;
    for (let i6 = 0; i6 < inputData.length; i6++) {
      hash ^= inputData[i6];
      hash = Math.imul(hash, prime1);
      hash ^= hash >>> 13;
    }
  } else {
    hash = seed;
    for (let i6 = 0; i6 < inputData.length; i6++) {
      hash = Math.imul(hash ^ inputData[i6], prime1);
      hash = hash << 13 | hash >>> 19;
      hash = Math.imul(hash, prime2);
    }
    hash ^= inputData.length;
  }
  hash ^= hash >>> 16;
  hash = Math.imul(hash, prime3);
  hash ^= hash >>> 13;
  if (prettify) {
    return prettifyID(hash >>> 0);
  }
  return hash >>> 0;
}
var generateID = () => {
  const num = Math.random() * 1e15;
  return prettifyID(num);
};

// packages/utils/src/functions.js
var noop = (v3) => v3;
var wrapFunction = (x2) => {
  return isFunction(x2) ? x2 : () => x2;
};

// packages/utils/src/regexp.js
var escapeRegExp = (string) => {
  return string.replace(/([.*+?^=!:${}()|\[\]\/\\])/g, "\\$1");
};
var escapeHTML = (string) => {
  const htmlEscapes = {
    "&": "&amp",
    "<": "&lt",
    ">": "&gt",
    '"': "&quot",
    "'": "&#39"
  };
  const htmlRegExp = /[&<>"']/g;
  const hasHTML = RegExp(htmlRegExp.source);
  return string && hasHTML.test(string) ? string.replace(htmlRegExp, (chr) => htmlEscapes[chr]) : string;
};

// packages/utils/src/objects.js
var keys2 = (obj) => {
  if (isObject(obj)) {
    return Object.keys(obj);
  }
};
var filterObject = (obj, callback) => {
  return Object.fromEntries(
    Object.entries(obj).filter(([key, value]) => callback(value, key))
  );
};
var mapObject = (obj, callback) => {
  return Object.fromEntries(
    Object.entries(obj).map(([key, value]) => [key, callback(value, key)])
  );
};
var extend = (obj, ...sources) => {
  sources.forEach((source) => {
    let descriptor, prop;
    if (source) {
      for (prop in source) {
        descriptor = Object.getOwnPropertyDescriptor(source, prop);
        if (descriptor === void 0) {
          obj[prop] = source[prop];
        } else {
          Object.defineProperty(obj, prop, descriptor);
        }
      }
    }
  });
  return obj;
};
var arrayFromObject = (obj) => {
  if (isArray(obj)) {
    return obj;
  }
  let arr = [];
  each(obj, (value, key) => {
    arr.push({
      value,
      key
    });
  });
  return arr;
};
var get = function(obj, path = "") {
  if (typeof path !== "string") {
    return void 0;
  }
  function extractArrayLikeAccess(part) {
    const key = part.substring(0, part.indexOf("["));
    const index = parseInt(part.substring(part.indexOf("[") + 1, part.indexOf("]")), 10);
    return { key, index };
  }
  function getCombinedKey(path2) {
    const dotIndex = path2.indexOf(".");
    if (dotIndex !== -1) {
      const nextDotIndex = path2.indexOf(".", dotIndex + 1);
      if (nextDotIndex !== -1) {
        return path2.slice(0, nextDotIndex);
      }
    }
    return path2;
  }
  if (obj === null || !isObject(obj)) {
    return void 0;
  }
  const parts = path.split(".");
  let currentObject = obj;
  for (let i6 = 0; i6 < parts.length; i6++) {
    if (currentObject === null || !isObject(currentObject)) {
      return void 0;
    }
    let part = parts[i6];
    if (part.includes("[")) {
      const { key, index } = extractArrayLikeAccess(part);
      if (key in currentObject && isArray(currentObject[key]) && index < currentObject[key].length) {
        currentObject = currentObject[key][index];
      } else {
        return void 0;
      }
    } else {
      if (part in currentObject) {
        currentObject = currentObject[part];
      } else {
        const remainingPath = parts.slice(i6).join(".");
        if (remainingPath in currentObject) {
          currentObject = currentObject[remainingPath];
          break;
        } else {
          const combinedKey = getCombinedKey(`${part}.${parts[i6 + 1]}`);
          if (combinedKey in currentObject) {
            currentObject = currentObject[combinedKey];
            i6++;
          } else {
            return void 0;
          }
        }
      }
    }
  }
  return currentObject;
};
var reverseKeys = (obj) => {
  const newObj = {};
  const pushValue = (key, value) => {
    if (isArray(newObj[key])) {
      newObj[key].push(value);
    } else if (newObj[key]) {
      newObj[key] = [newObj[key], value];
    } else {
      newObj[key] = value;
    }
  };
  Object.keys(obj).forEach((key) => {
    if (isArray(obj[key])) {
      each(obj[key], (subKey) => {
        pushValue(subKey, key);
      });
    } else {
      pushValue(obj[key], key);
    }
  });
  return newObj;
};

// packages/utils/src/arrays.js
var unique = (arr) => {
  return Array.from(new Set(arr));
};
var last = (array = [], number = 1) => {
  const { length } = array;
  if (!length) {
    return;
  }
  if (number === 1) {
    return array[length - 1];
  } else {
    return array.slice(Math.max(length - number, 0));
  }
};
var firstMatch = (array = [], callback) => {
  let result;
  each(array, (value, index) => {
    if (callback(value, index, array)) {
      result = value;
      return false;
    }
  });
  return result;
};
var findIndex = (array = [], callback) => {
  let matchedIndex = -1;
  each(array, (value, index) => {
    if (callback(value, index, array)) {
      matchedIndex = index;
      return false;
    }
  });
  return matchedIndex;
};
var remove = (array = [], callbackOrValue) => {
  const callback = isFunction(callbackOrValue) ? callbackOrValue : (val) => isEqual(val, callbackOrValue);
  const index = findIndex(array, callback);
  if (index > -1) {
    array.splice(index, 1);
    return true;
  }
  return false;
};
var inArray = (value, array = []) => {
  return array.indexOf(value) > -1;
};
var range = (start, stop, step = 1) => {
  if (!stop) {
    stop = start;
    start = 0;
  }
  const length = stop - start;
  return Array(length).fill(void 0).map((x2, index) => {
    return index * step + start;
  });
};
var some = (collection, predicate) => {
  return (collection == null ? void 0 : collection.some) ? collection.some(predicate) : false;
};
var any = some;
var ARRAY_SIZE_THRESHOLD = 58;
var difference = (...arrays) => {
  if (arrays.length === 0) {
    return [];
  }
  if (arrays.length === 1) {
    return [...new Set(arrays[0])];
  }
  const totalSize = arrays.reduce((sum, arr) => sum + arr.length, 0);
  const useSet = totalSize >= ARRAY_SIZE_THRESHOLD;
  const [first, ...rest] = arrays;
  const firstUnique = [...new Set(first)];
  if (useSet) {
    const sets = rest.map((arr) => new Set(arr));
    return firstUnique.filter((item) => !sets.some((set) => set.has(item)));
  }
  return firstUnique.filter((item) => !rest.some((arr) => arr.includes(item)));
};

// packages/utils/src/ssr.js
var isServer = /* @__PURE__ */ (() => {
  return typeof window === "undefined";
})();
var isClient = /* @__PURE__ */ (() => {
  return typeof window !== "undefined";
})();

// packages/utils/src/browser.js
var getKeyFromEvent = (event) => {
  let pressedKey = event == null ? void 0 : event.key;
  if (!pressedKey) {
    return "";
  }
  let key = "";
  if (event.ctrlKey && pressedKey !== "Control") {
    key += "ctrl+";
  }
  if (event.altKey && pressedKey !== "Alt") {
    key += "alt+";
  }
  if (event.shiftKey && pressedKey !== "Shift") {
    key += "shift+";
  }
  if (event.metaKey && pressedKey !== "Meta") {
    key += "meta+";
  }
  const specialKeys = {
    Control: "ctrl",
    Escape: "esc",
    " ": "space"
  };
  pressedKey = pressedKey.replace("Arrow", "");
  key += specialKeys[pressedKey] || pressedKey.toLowerCase();
  return key;
};

// packages/utils/src/cloning.js
var clone = (src, seen = /* @__PURE__ */ new Map()) => {
  if (!src || typeof src !== "object") {
    return src;
  }
  if (seen.has(src)) {
    return seen.get(src);
  }
  let copy;
  if (src.nodeType && "cloneNode" in src) {
    copy = src.cloneNode(true);
    seen.set(src, copy);
  } else if (src instanceof Date) {
    copy = new Date(src.getTime());
    seen.set(src, copy);
  } else if (src instanceof RegExp) {
    copy = new RegExp(src);
    seen.set(src, copy);
  } else if (Array.isArray(src)) {
    copy = new Array(src.length);
    seen.set(src, copy);
    for (let i6 = 0; i6 < src.length; i6++) {
      copy[i6] = clone(src[i6], seen);
    }
  } else if (src instanceof Map) {
    copy = /* @__PURE__ */ new Map();
    seen.set(src, copy);
    for (const [k2, v3] of src.entries()) {
      copy.set(k2, clone(v3, seen));
    }
  } else if (src instanceof Set) {
    copy = /* @__PURE__ */ new Set();
    seen.set(src, copy);
    for (const v3 of src) {
      copy.add(clone(v3, seen));
    }
  } else if (src instanceof Object) {
    copy = {};
    seen.set(src, copy);
    for (const [k2, v3] of Object.entries(src)) {
      copy[k2] = clone(v3, seen);
    }
  }
  return copy;
};

// packages/utils/src/colors.js
var GAMMA_EXPONENT = 1 / 2.4;

// packages/utils/src/dates.js
var formatDate = function(date, format = "LLL", {
  locale = "default",
  hour12 = true,
  timezone = "UTC",
  ...additionalOptions
} = {}) {
  if (isNaN(date.getTime())) {
    return "Invalid Date";
  }
  const localDate = new Date(date.getTime());
  if (timezone === "local") {
    timezone = Intl.DateTimeFormat().resolvedOptions().timeZone;
  }
  const pad = (n5) => n5 < 10 ? `0${n5}` : n5;
  const shorthand = reverseKeys({
    // North America
    "America/New_York": ["ET"],
    "America/Chicago": ["CT"],
    "America/Denver": ["MT"],
    "America/Los_Angeles": ["PT"],
    "America/Anchorage": ["AKT"],
    "Pacific/Honolulu": ["HT"],
    "America/Halifax": ["AT"],
    // Europe
    "Europe/London": ["UK", "WET"],
    "Europe/Paris": ["CET", "ECT"],
    "Europe/Helsinki": ["EET"],
    "Europe/Dublin": ["IRST"],
    // Note disambiguation with India
    // Australia/Oceania
    "Australia/Sydney": ["AET"],
    "Australia/Adelaide": ["ACT"],
    "Australia/Perth": ["AWT"],
    "Pacific/Auckland": ["NZT"],
    // South America
    "America/Sao_Paulo": ["BRT"],
    // Asia
    "Asia/Kolkata": ["IST", "INST"],
    // Note disambiguation with Ireland
    "Asia/Tokyo": ["JST"],
    "Asia/Singapore": ["SGT"]
  });
  if (timezone && shorthand[timezone]) {
    timezone = shorthand[timezone];
  }
  const localeOptions = {
    timeZone: timezone,
    year: "numeric",
    month: "long",
    day: "numeric",
    weekday: "long",
    hour: "numeric",
    minute: "numeric",
    second: "numeric",
    hour12,
    ...additionalOptions
  };
  const formatter = new Intl.DateTimeFormat(locale, localeOptions);
  const dateParts = formatter.formatToParts(localDate).reduce((acc, part) => {
    acc[part.type] = part.value;
    return acc;
  }, {});
  let { year, month, day, weekday, hour, minute, second, dayPeriod } = dateParts;
  if (hour === "24") {
    hour = "00";
  }
  const timezoneDate = new Date(date.toLocaleString("en-US", { timeZone: timezone }));
  const dateMap = {
    YYYY: year,
    YY: year.slice(-2),
    MMMM: month,
    MMM: month.slice(0, 3),
    MM: pad(timezoneDate.getMonth() + 1),
    M: timezoneDate.getMonth() + 1,
    DD: pad(timezoneDate.getDate()),
    D: timezoneDate.getDate(),
    Do: day + ["th", "st", "nd", "rd"][day % 10 > 3 ? 0 : (day % 100 - day % 10 !== 10) * day % 10],
    dddd: weekday,
    ddd: weekday.slice(0, 3),
    HH: hour.padStart(2, "0"),
    hh: hour12 ? (hour % 12 || 12).toString().padStart(2, "0") : hour.padStart(2, "0"),
    h: hour12 ? (hour % 12 || 12).toString() : hour,
    mm: minute,
    ss: second,
    a: hour12 && dayPeriod ? dayPeriod.toLowerCase() : ""
  };
  const formatMap = {
    LT: "h:mm a",
    LTS: "h:mm:ss a",
    L: "MM/DD/YYYY",
    l: "M/D/YYYY",
    LL: "MMMM D, YYYY",
    ll: "MMM D, YYYY",
    LLL: "MMMM D, YYYY h:mm a",
    lll: "MMM D, YYYY h:mm a",
    LLLL: "dddd, MMMM D, YYYY h:mm a",
    llll: "ddd, MMM D, YYYY h:mm a"
  };
  format = format.trim();
  const expandedFormat = formatMap[format] || format;
  return expandedFormat.replace(/\b(?:YYYY|YY|MMMM|MMM|MM|M|DD|D|Do|dddd|ddd|HH|hh|h|mm|ss|a)\b/g, (match) => {
    return dateMap[match];
  }).replace(/\[(.+?)\]/g, (match, p1) => p1).trim();
};

// packages/utils/src/errors.js
var fatal = (message, {
  errorType = Error,
  metadata = {},
  onError = null,
  removeStackLines = 1
} = {}) => {
  const error = new errorType(message);
  Object.assign(error, metadata);
  if (error.stack) {
    const stackLines = error.stack.split("\n");
    stackLines.splice(1, removeStackLines);
    error.stack = stackLines.join("\n");
  }
  const throwError = () => {
    if (typeof global.onError === "function") {
      global.onError(error);
    }
    throw error;
  };
  if (typeof queueMicrotask === "function") {
    queueMicrotask(throwError);
  } else {
    setTimeout(throwError, 0);
  }
};

// packages/utils/src/strings.js
var kebabToCamel = (str = "") => {
  return str.replace(/-./g, (m3) => m3[1].toUpperCase());
};
var camelToKebab = (str = "") => {
  return str.replace(/([a-z0-9])([A-Z])/g, "$1-$2").toLowerCase();
};
var capitalize = (str = "") => {
  return str.charAt(0).toUpperCase() + str.slice(1);
};
var toTitleCase = (str = "") => {
  const stopWords = [
    "the",
    "a",
    "an",
    "and",
    "but",
    "for",
    "at",
    "by",
    "from",
    "to",
    "in",
    "on",
    "of",
    "or",
    "nor",
    "with",
    "as"
  ];
  if (!isString(str)) {
    return;
  }
  return str.toLowerCase().split(" ").map((word, index) => {
    if (index === 0 || !stopWords.includes(word)) {
      return word.charAt(0).toUpperCase() + word.slice(1);
    }
    return word;
  }).join(" ");
};
var joinWords = (words, {
  separator = ", ",
  lastSeparator = " and ",
  oxford = true,
  quotes = false,
  transform = noop
} = {}) => {
  if (!isArray(words) || words.length === 0) {
    return "";
  }
  const processedWords = words.map((word) => {
    let processed = word;
    if (isFunction(transform)) {
      processed = transform(word);
    }
    return quotes ? `"${processed}"` : processed;
  });
  if (processedWords.length === 1) {
    return processedWords[0];
  }
  if (processedWords.length === 2) {
    return processedWords.join(lastSeparator);
  }
  const lastWord = processedWords.pop();
  let result = processedWords.join(separator);
  if (oxford && separator.trim() !== lastSeparator.trim()) {
    result += separator.trim();
  }
  return result + lastSeparator + lastWord;
};

// packages/component/src/helpers/scope-styles.js
var scopeStyles = (css, scopeSelector = "") => {
  scopeSelector = scopeSelector.toLowerCase();
  const scopeRule = (rule, scopeSelector2) => {
    if (rule.type === CSSRule.STYLE_RULE) {
      return `${scopeSelector2} ${rule.selectorText} { ${rule.style.cssText} }`;
    } else if (rule.type === CSSRule.MEDIA_RULE || rule.type === CSSRule.SUPPORTS_RULE) {
      return `@${rule.type === CSSRule.MEDIA_RULE ? "media" : "supports"} ${rule.conditionText || ""} { ${scopeRule(rule.cssText, scopeSelector2)} }`;
    } else if (rule.type === CSSRule.LAYER_STATEMENT_RULE || rule.type == 0 && rule.cssRules) {
      let scopedInnerRules = [];
      each(rule.cssRules, (innerRule) => {
        scopedInnerRules.push(scopeRule(innerRule, scopeSelector2));
      });
      return `@layer ${rule.name} { ${scopedInnerRules.join(" ")} }`;
    } else {
      return rule.cssText;
    }
  };
  const styleSheet = new CSSStyleSheet();
  styleSheet.replaceSync(css);
  let modifiedRules = [];
  each(styleSheet.cssRules, (rule) => {
    modifiedRules.push(scopeRule(rule, scopeSelector));
  });
  return modifiedRules.join("\n");
};

// packages/component/src/helpers/adopt-stylesheet.js
var adoptStylesheet = (css, adoptedElement, { scopeSelector } = {}) => {
  if (isServer) {
    return;
  }
  if (!adoptedElement) {
    adoptedElement = document;
  }
  const hash = hashCode(css);
  if (!adoptedElement.cssHashes) {
    adoptedElement.cssHashes = [];
  }
  if (adoptedElement.cssHashes.includes(hash)) {
    return;
  }
  adoptedElement.cssHashes.push(hash);
  const stylesheet = new CSSStyleSheet();
  if (scopeSelector) {
    css = scopeStyles(css, scopeSelector);
  }
  stylesheet.id = hash;
  stylesheet.replaceSync(css);
  adoptedElement.adoptedStyleSheets = [
    ...adoptedElement.adoptedStyleSheets,
    stylesheet
  ];
};

// packages/templating/src/compiler/string-scanner.js
var _StringScanner = class _StringScanner {
  constructor(input) {
    this.input = input;
    this.pos = 0;
  }
  matches(regex) {
    return regex.test(this.rest());
  }
  rest() {
    return this.input.slice(this.pos);
  }
  step(step = 1) {
    if (!this.isEOF()) {
      this.pos = this.pos + step;
    }
  }
  rewind(step = 1) {
    if (this.pos !== 0) {
      this.pos = this.pos - step;
    }
  }
  isEOF() {
    return this.pos >= this.input.length;
  }
  // get character at current position
  peek() {
    return this.input.charAt(this.pos);
  }
  consume(pattern) {
    const regex = typeof pattern === "string" ? new RegExp(escapeRegExp(pattern)) : new RegExp(pattern);
    const substring = this.input.substring(this.pos);
    const match = regex.exec(substring);
    if (match && match.index === 0) {
      this.pos += match[0].length;
      return match[0];
    }
    return null;
  }
  consumeUntil(pattern) {
    const regex = typeof pattern === "string" ? new RegExp(escapeRegExp(pattern)) : new RegExp(pattern);
    const match = regex.exec(this.input.substring(this.pos));
    if (!match) {
      const consumedText2 = this.input.substr(this.pos);
      this.pos = this.input.length;
      return consumedText2;
    }
    const consumedText = this.input.substring(this.pos, this.pos + match.index);
    this.pos += match.index;
    return consumedText;
  }
  returnTo(pattern) {
    if (!pattern) {
      return;
    }
    const regex = typeof pattern === "string" ? new RegExp(escapeRegExp(pattern), "gm") : new RegExp(pattern, "gm");
    let lastMatch = null;
    let match;
    const substring = this.input.substring(0, this.pos);
    while ((match = regex.exec(substring)) !== null) {
      lastMatch = match;
    }
    if (lastMatch) {
      const consumedText = this.input.substring(0, lastMatch.index);
      this.pos = lastMatch.index;
      return consumedText;
    }
    return;
  }
  getContext() {
    let insideTag = false;
    let i6 = this.pos - 1;
    let tagPos;
    while (i6 >= 0) {
      if (this.input[i6] === ">") {
        break;
      }
      if (this.input[i6] === "<") {
        insideTag = true;
        tagPos = i6;
        break;
      }
      i6--;
    }
    if (insideTag) {
      const tagText = this.input.substring(tagPos, this.pos);
      const attrPattern = /([a-zA-Z-]+)(?=\s*=\s*[^=]*$)/;
      const attrMatch = tagText.match(attrPattern);
      const attrName = attrMatch ? attrMatch[1] : "";
      const booleanAttributes = [
        "allowfullscreen",
        "async",
        "autofocus",
        "autoplay",
        "checked",
        "controls",
        "default",
        "defer",
        "disabled",
        "formnovalidate",
        "inert",
        "ismap",
        "itemscope",
        "loop",
        "multiple",
        "muted",
        "nomodule",
        "novalidate",
        "open",
        "playsinline",
        "readonly",
        "required",
        "reversed",
        "selected"
      ];
      let booleanAttribute = false;
      if (booleanAttributes.includes(attrName)) {
        booleanAttribute = true;
      } else {
        const quotedAttrPattern = /([a-zA-Z-]+)(?=\s*=\s*(\"|\')\s*[^=]*$)/;
        const quotedAttrMatch = tagText.match(quotedAttrPattern);
        const quotedAttrName = quotedAttrMatch ? quotedAttrMatch[1] : "";
        booleanAttribute = attrName !== quotedAttrName;
      }
      if (attrName) {
        return {
          insideTag: true,
          attribute: attrName,
          booleanAttribute
        };
      }
    }
    return {
      insideTag
    };
  }
  fatal(msg) {
    msg = msg || "Parse error";
    const input = typeof this.input === "string" ? this.input : "";
    const lines = input.split("\n");
    let lineNumber = 0;
    let charCount = 0;
    for (const line of lines) {
      if (charCount + line.length + 1 > this.pos) {
        break;
      }
      charCount += line.length + 1;
      lineNumber++;
    }
    const linesBefore = 5;
    const linesAfter = 5;
    const startLine = Math.max(0, lineNumber - linesBefore);
    const endLine = Math.min(lines.length, lineNumber + linesAfter + 1);
    const contextLines = lines.slice(startLine, endLine);
    const consoleMsg = contextLines.map((line, idx) => {
      return `%c${line}`;
    }).join("\n");
    const normalStyle = "color: grey";
    const errorStyle = "color: red; font-weight: bold";
    if (_StringScanner.DEBUG_MODE) {
      if (globalThis.document) {
        let errorHTML = "";
        each(contextLines, (line, index) => {
          const style = index < linesBefore || index > linesBefore ? normalStyle : errorStyle;
          errorHTML += `<div style="${style}">${line}</div>`;
        });
        const html = `
          <div style="padding: 1rem; font-size: 14px;">
            <h2>Could not render template</h2>
            <h3>${msg}</h3>
            <code style="margin-top: 1rem; display: block; background-color: #EFEFEF; padding: 0.25rem 1rem;border-left: 3px solid #888"><pre>${errorHTML}</pre></code>
          </div>
        `;
        document.body.innerHTML = html;
      }
      console.error(
        msg + "\n" + consoleMsg,
        ...contextLines.map((_2, idx) => lineNumber - startLine === idx ? errorStyle : normalStyle)
      );
      const e6 = new Error(msg);
      throw e6;
    }
  }
};
__publicField(_StringScanner, "DEBUG_MODE", true);
var StringScanner = _StringScanner;

// packages/templating/src/compiler/template-compiler.js
var _TemplateCompiler = class _TemplateCompiler {
  constructor(templateString) {
    this.templateString = templateString || "";
    this.snippets = {};
  }
  /*
    Creates an AST representation of a template
    from a template string
  */
  compile(templateString = this.templateString) {
    templateString = _TemplateCompiler.preprocessTemplate(templateString);
    const scanner = new StringScanner(templateString);
    if (!isString(templateString)) {
      scanner.fatal("Template is not a string", templateString);
    }
    const { htmlRegExp } = _TemplateCompiler;
    const syntax = _TemplateCompiler.detectSyntax(templateString);
    const tagRegExp = syntax == "doubleBracket" ? _TemplateCompiler.doubleBracketRegExp : _TemplateCompiler.singleBracketRegExp;
    const parserRegExp = syntax == "doubleBracket" ? _TemplateCompiler.doubleBracketParserRegExp : _TemplateCompiler.singleBracketParserRegExp;
    const parseTag = (scanner2) => {
      let getTagContent = () => {
        if (scanner2.peek() == "}") {
          scanner2.consumeUntil(parserRegExp.EXPRESSION_END);
          return;
        }
        let openTags = 1;
        let content = scanner2.peek();
        while (openTags > 0 && !scanner2.isEOF()) {
          scanner2.step();
          if (scanner2.peek() == "{") {
            openTags++;
          }
          if (scanner2.peek() == "}") {
            openTags--;
          }
          if (openTags == 0) {
            scanner2.rewind();
            break;
          }
          content += scanner2.peek();
        }
        scanner2.consumeUntil(parserRegExp.EXPRESSION_END);
        scanner2.consume(parserRegExp.EXPRESSION_END);
        content = content.trim();
        return content;
      };
      for (let type in tagRegExp) {
        if (scanner2.matches(tagRegExp[type])) {
          const context = scanner2.getContext();
          scanner2.consume(tagRegExp[type]);
          const rawContent = getTagContent();
          scanner2.consume(parserRegExp.EXPRESSION_END);
          const content = this.getValue(rawContent);
          return { type, content, ...context };
        }
      }
      for (let type in htmlRegExp) {
        if (scanner2.matches(htmlRegExp[type])) {
          scanner2.consume(htmlRegExp[type]);
          const context = scanner2.getContext();
          const content = this.getValue(scanner2.consumeUntil(parserRegExp.TAG_CLOSE).trim());
          scanner2.consume(parserRegExp.TAG_CLOSE);
          return { type, content, ...context };
        }
      }
      return null;
    };
    const ast = [];
    const stack = [];
    let contentBranch = null;
    let conditionStack = [];
    let contentStack = [];
    while (!scanner.isEOF()) {
      const tag = parseTag(scanner);
      const conditionTarget = last(conditionStack);
      const contentTarget = (contentBranch == null ? void 0 : contentBranch.content) || ast;
      if (tag) {
        let newNode = {
          type: tag.type.toLowerCase()
        };
        switch (tag.type) {
          case "IF":
            newNode = {
              ...newNode,
              condition: tag.content,
              content: [],
              branches: []
            };
            contentTarget.push(newNode);
            conditionStack.push(newNode);
            contentStack.push(newNode);
            contentBranch = newNode;
            break;
          case "ELSEIF":
            newNode = {
              ...newNode,
              condition: tag.content,
              content: []
            };
            if (!conditionTarget) {
              scanner.returnTo(tagRegExp.ELSEIF);
              scanner.fatal(
                "{{elseif}} encountered without matching if condition"
              );
            }
            contentStack.pop();
            contentStack.push(newNode);
            conditionTarget.branches.push(newNode);
            contentBranch = newNode;
            break;
          case "ELSE":
            newNode = {
              ...newNode,
              content: []
            };
            if (!conditionTarget) {
              scanner.returnTo(tagRegExp.ELSE);
              scanner.fatal(
                "{{else}} encountered without matching if or each condition"
              );
              break;
            }
            if (conditionTarget.type === "if") {
              contentStack.pop();
              contentStack.push(newNode);
              conditionTarget.branches.push(newNode);
              contentBranch = newNode;
            } else if (conditionTarget.type === "each") {
              contentStack.pop();
              contentStack.push(newNode);
              conditionTarget.else = newNode;
              contentBranch = newNode;
            } else {
              scanner.returnTo(tagRegExp.ELSE);
              scanner.fatal(
                "{{else}} encountered with unknown condition type: " + conditionTarget.type
              );
            }
            break;
          case "CLOSE_IF":
            if (conditionStack.length == 0) {
              scanner.returnTo(tagRegExp.CLOSE_IF);
              scanner.fatal("{{/if}} close tag found without open if tag");
            }
            stack.pop();
            contentStack.pop();
            conditionStack.pop();
            contentBranch = last(contentStack);
            break;
          case "SNIPPET":
            newNode = {
              ...newNode,
              type: "snippet",
              name: tag.content,
              content: []
            };
            this.snippets[tag.content] = newNode;
            contentTarget.push(newNode);
            conditionStack.push(newNode);
            contentStack.push(newNode);
            contentBranch = newNode;
            break;
          case "CLOSE_SNIPPET":
            if (conditionStack.length == 0) {
              scanner.returnTo(tagRegExp.CLOSE_IF);
              scanner.fatal("{{/snippet}} close tag found without open if tag");
            }
            stack.pop();
            contentStack.pop();
            contentBranch = last(contentStack);
            break;
          case "HTML_EXPRESSION":
            newNode = {
              ...newNode,
              type: "expression",
              unsafeHTML: true,
              value: tag.content
            };
            contentTarget.push(newNode);
            scanner.consume("}");
            break;
          case "EXPRESSION":
            newNode = {
              ...newNode,
              value: tag.content
            };
            if (tag.booleanAttribute) {
              newNode.ifDefined = true;
            }
            contentTarget.push(newNode);
            break;
          case "TEMPLATE":
            const templateInfo = this.parseTemplateString(tag.content);
            newNode = {
              ...newNode,
              ...templateInfo
            };
            contentTarget.push(newNode);
            break;
          case "SLOT":
            newNode = {
              ...newNode,
              name: tag.content
            };
            contentTarget.push(newNode);
            break;
          case "EACH":
            let iterateOver;
            let iterateAs;
            let indexAs;
            const inParts = tag.content.split(" in ");
            const asParts = tag.content.split(" as ");
            if (inParts.length > 1) {
              let iteratorPart = inParts[0].trim();
              iterateOver = inParts[1].trim();
              const commaIndex = iteratorPart.indexOf(",");
              if (commaIndex !== -1) {
                iterateAs = iteratorPart.substring(0, commaIndex).trim();
                indexAs = iteratorPart.substring(commaIndex + 1).trim();
              } else {
                iterateAs = iteratorPart;
              }
            } else if (asParts.length > 1) {
              iterateOver = asParts[0].trim();
              const iteratorPart = asParts[1].trim();
              const commaIndex = iteratorPart.indexOf(",");
              if (commaIndex !== -1) {
                iterateAs = iteratorPart.substring(0, commaIndex).trim();
                indexAs = iteratorPart.substring(commaIndex + 1).trim();
              } else {
                iterateAs = iteratorPart;
              }
            } else {
              iterateOver = tag.content.trim();
            }
            newNode = {
              ...newNode,
              over: iterateOver,
              content: []
            };
            if (iterateAs) {
              newNode.as = iterateAs;
            }
            if (indexAs) {
              newNode.indexAs = indexAs;
            }
            contentStack.push(newNode);
            conditionStack.push(newNode);
            contentTarget.push(newNode);
            contentBranch = newNode;
            break;
          case "CLOSE_EACH":
            stack.pop();
            contentStack.pop();
            conditionStack.pop();
            contentBranch = last(contentStack);
            break;
          case "SVG_OPEN":
            contentTarget.push({ type: "html", html: "<svg " });
            contentTarget.push(...this.compile(tag.content));
            contentTarget.push({ type: "html", html: ">" });
            newNode = {
              type: "svg",
              content: []
            };
            contentStack.push(newNode);
            contentTarget.push(newNode);
            contentBranch = newNode;
            break;
          case "SVG_CLOSE":
            stack.pop();
            contentStack.pop();
            contentBranch = last(contentStack);
            newNode = {
              type: "html",
              html: "</svg>"
            };
            (contentTarget || ast).push(newNode);
            break;
        }
      } else {
        const html = scanner.consumeUntil(parserRegExp.NEXT_TAG);
        if (html) {
          const htmlNode = { type: "html", html };
          contentTarget.push(htmlNode);
        }
      }
    }
    const optimizedAST = _TemplateCompiler.optimizeAST(ast);
    return optimizedAST;
  }
  getValue(expression) {
    if (expression == "true") {
      return true;
    } else if (expression == "false") {
      return false;
    } else if (isString(expression) && expression.trim() !== "" && Number.isFinite(+expression)) {
      return Number(expression);
    }
    return expression;
  }
  parseTemplateString(expression = "") {
    const regExp = _TemplateCompiler.templateRegExp;
    let templateInfo = {};
    regExp.VERBOSE_KEYWORD.lastIndex = 0;
    if (regExp.VERBOSE_KEYWORD.test(expression)) {
      const matches = [...expression.matchAll(regExp.VERBOSE_PROPERTIES)];
      each(matches, (match, index) => {
        const property = match[1];
        const value = _TemplateCompiler.getObjectFromString(match[2]);
        templateInfo[property] = value;
      });
    } else {
      let data = {};
      const name = expression.split(/\b/)[0];
      templateInfo.name = `'${name}'`;
      const dataMatches = [...expression.matchAll(regExp.STANDARD)];
      each(dataMatches, (match, index) => {
        let name2 = match[1].trim();
        let value = match[2].trim();
        data[name2] = value;
      });
      templateInfo.reactiveData = data;
    }
    return templateInfo;
  }
  static getObjectFromString(objectString = "") {
    const regExp = _TemplateCompiler.templateRegExp.DATA_OBJECT;
    const obj = {};
    let match;
    let isObject2 = false;
    while ((match = regExp.exec(objectString)) !== null) {
      isObject2 = true;
      obj[match[1]] = match[2].trim();
    }
    return isObject2 ? obj : objectString.trim();
  }
  static detectSyntax(templateString = "") {
    const doubleIndex = templateString.search(/{{\s*/);
    const singleIndex = templateString.search(/{[^{]\s*/);
    if (doubleIndex !== -1 && doubleIndex < singleIndex) {
      return "doubleBracket";
    }
    return "singleBracket";
  }
  static preprocessTemplate(templateString = "") {
    templateString = templateString.trim();
    templateString = templateString.replace(
      _TemplateCompiler.preprocessRegExp.WEB_COMPONENT_SELF_CLOSING,
      (match, tagName, attributes) => {
        return `<${tagName}${attributes}></${tagName}>`;
      }
    );
    return templateString;
  }
  // joins neighboring html nodes into a single node
  static optimizeAST(ast) {
    const optimizedAST = [];
    let currentHtmlNode = null;
    const processNode = (node) => {
      if (node.type === "html") {
        if (currentHtmlNode) {
          currentHtmlNode.html += node.html;
        } else {
          currentHtmlNode = { ...node };
          optimizedAST.push(currentHtmlNode);
        }
      } else {
        if (currentHtmlNode) {
          currentHtmlNode = null;
        }
        if (Array.isArray(node.content)) {
          node.content = this.optimizeAST(node.content);
        }
        if (node.else && node.else.content) {
          node.else.content = this.optimizeAST(node.else.content);
        }
        optimizedAST.push(node);
      }
    };
    ast.forEach(processNode);
    return optimizedAST;
  }
};
__publicField(_TemplateCompiler, "singleBracketRegExp", {
  IF: /^{\s*#if\s+/,
  ELSEIF: /^{\s*else\s*if\s+/,
  ELSE: /^{\s*else\s*/,
  EACH: /^{\s*#each\s+/,
  SNIPPET: /^{\s*#snippet\s+/,
  CLOSE_IF: /^{\s*\/(if)\s*/,
  CLOSE_EACH: /^{\s*\/(each)\s*/,
  CLOSE_SNIPPET: /^{\s*\/(snippet)\s*/,
  SLOT: /^{>\s*slot\s*/,
  TEMPLATE: /^{>\s*/,
  HTML_EXPRESSION: /^{\s*#html\s*/,
  EXPRESSION: /^{\s*/
});
__publicField(_TemplateCompiler, "singleBracketParserRegExp", {
  NEXT_TAG: /(\{|\<svg|\<\/svg)/,
  // used to advance scanner to either a parseable expression or svg tag
  EXPRESSION_START: /\{/,
  EXPRESSION_END: /\}/,
  TAG_CLOSE: /\>/
});
__publicField(_TemplateCompiler, "doubleBracketRegExp", {
  IF: /^{{\s*#if\s+/,
  ELSEIF: /^{{\s*else\s*if\s+/,
  ELSE: /^{{\s*else\s*/,
  EACH: /^{{\s*#each\s+/,
  SNIPPET: /^{{\s*#snippet\s+/,
  CLOSE_IF: /^{{\s*\/(if)\s*/,
  CLOSE_EACH: /^{{\s*\/(each)\s*/,
  CLOSE_SNIPPET: /^{{\s*\/(snippet)\s*/,
  SLOT: /^{{>\s*slot\s*/,
  TEMPLATE: /^{{>\s*/,
  HTML_EXPRESSION: /^{{\s*#html\s*/,
  EXPRESSION: /^{{\s*/
});
__publicField(_TemplateCompiler, "doubleBracketParserRegExp", {
  NEXT_TAG: /(\{\{|\<svg|\<\/svg)/,
  // used to advance scanner to either a parseable expression or svg tag
  EXPRESSION_START: /\{\{/,
  EXPRESSION_END: /\}\}/,
  TAG_CLOSE: /\>/
});
__publicField(_TemplateCompiler, "htmlRegExp", {
  SVG_OPEN: /^\<svg\s*/i,
  SVG_CLOSE: /^\<\/svg\s*/i
});
__publicField(_TemplateCompiler, "preprocessRegExp", {
  WEB_COMPONENT_SELF_CLOSING: /<(\w+-\w+)([^>]*)\/>/g
});
__publicField(_TemplateCompiler, "templateRegExp", {
  VERBOSE_KEYWORD: /^(template|snippet)\W/g,
  VERBOSE_PROPERTIES: /(\w+)\s*=\s*(((?!\w+\s*=).)+)/gms,
  STANDARD: /(\w+)\s*=\s*((?:(?!\n|$|\w+\s*=).)+)/g,
  DATA_OBJECT: /(\w+)\s*:\s*([^,}]+)/g,
  // parses { one: 'two' }
  SINGLE_QUOTES: /\'/g
});
var TemplateCompiler = _TemplateCompiler;

// packages/reactivity/src/scheduler.js
var _Scheduler = class _Scheduler {
  static scheduleReaction(reaction) {
    _Scheduler.pendingReactions.add(reaction);
    _Scheduler.scheduleFlush();
  }
  static scheduleFlush() {
    if (!_Scheduler.isFlushScheduled) {
      _Scheduler.isFlushScheduled = true;
      if (typeof queueMicrotask === "function") {
        queueMicrotask(() => _Scheduler.flush());
      } else {
        Promise.resolve().then(() => _Scheduler.flush());
      }
    }
  }
  static flush() {
    _Scheduler.isFlushScheduled = false;
    _Scheduler.pendingReactions.forEach((reaction) => reaction.run());
    _Scheduler.pendingReactions.clear();
    _Scheduler.afterFlushCallbacks.forEach((callback) => callback());
    _Scheduler.afterFlushCallbacks = [];
  }
  static afterFlush(callback) {
    _Scheduler.afterFlushCallbacks.push(callback);
  }
  static getSource() {
    var _a3;
    if (!_Scheduler.current) {
      console.log("No reactive flush is currently occurring.");
      return;
    }
    const { context, dependencies } = _Scheduler.current;
    let stack = context.stack || ((_a3 = dependencies == null ? void 0 : dependencies.values().next()) == null ? void 0 : _a3.value.context.stack);
    let message;
    if (stack) {
      if (context.message) {
        message = context.message;
      } else if (context.firstRun) {
        message = `First run of new reaction created at:`;
      } else if (context.value) {
        message = `Reaction triggered by reactive update`;
      } else {
        message = `Reaction triggered at:`;
      }
      console.groupCollapsed("\u{1F501} Reaction Triggered");
      console.log(message);
      if (context.value) {
        console.log("Reactive value change was:", context.value);
      }
      console.log("Reaction was:", _Scheduler.current);
      console.error(stack);
      delete context.stack;
      console.log("Metadata:", context);
      console.groupEnd();
    } else {
      console.error("Nothing found");
      console.log(_Scheduler.current.context);
    }
    return stack;
  }
};
__publicField(_Scheduler, "current", null);
__publicField(_Scheduler, "pendingReactions", /* @__PURE__ */ new Set());
__publicField(_Scheduler, "afterFlushCallbacks", []);
__publicField(_Scheduler, "isFlushScheduled", false);
var Scheduler = _Scheduler;

// packages/reactivity/src/dependency.js
var Dependency = class {
  constructor(...metadata) {
    this.subscribers = /* @__PURE__ */ new Set();
    this.setContext(metadata);
  }
  depend() {
    if (Scheduler.current) {
      this.subscribers.add(Scheduler.current);
      Scheduler.current.dependencies.add(this);
    }
  }
  // allows metadata to be passed with dependency for debugging
  setContext(context = {}) {
    if (Error.captureStackTrace) {
      Error.captureStackTrace(context, this.setContext);
    } else {
      context.stack = new Error().stack;
    }
    this.context = context;
  }
  changed(context) {
    this.setContext(context);
    this.subscribers.forEach((subscriber) => subscriber.invalidate(this.context));
  }
  // called after flush
  cleanUp(reaction) {
    this.subscribers.delete(reaction);
  }
  // identical for now but called from stop()
  unsubscribe(reaction) {
    this.subscribers.delete(reaction);
  }
};

// packages/reactivity/src/reaction.js
var _Reaction = class _Reaction {
  static create(callback, options = {}) {
    const reaction = new _Reaction(callback, options);
    if (options.firstRun !== false) {
      reaction.boundRun();
    }
    return reaction;
  }
  constructor(callback, { context } = {}) {
    this.callback = callback;
    this.dependencies = /* @__PURE__ */ new Set();
    this.firstRun = true;
    this.active = true;
    if (context) {
      this.setContext(context);
    }
    this.boundRun = this.run.bind(this);
  }
  setContext(additionalContext = {}) {
    const defaultContext = {
      firstRun: this.firstRun
    };
    this.context = {
      ...defaultContext,
      ...additionalContext
    };
  }
  setTrace() {
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this.context, this.setTrace);
    } else {
      this.context.stack = new Error().stack;
    }
  }
  addContext(additionalContext = {}) {
    if (!this.context) {
      this.context = {};
    }
    for (const key in additionalContext) {
      this.context[key] = additionalContext[key];
    }
  }
  run() {
    if (!this.active) {
      return;
    }
    this.addContext({
      firstRun: this.firstRun
    });
    Scheduler.current = this;
    this.dependencies.forEach((dep) => dep.cleanUp(this));
    this.dependencies.clear();
    this.callback(this);
    this.firstRun = false;
    Scheduler.current = null;
    Scheduler.pendingReactions.delete(this);
  }
  invalidate(context) {
    this.active = true;
    if (context) {
      this.addContext(context);
    }
    Scheduler.scheduleReaction(this);
  }
  stop() {
    if (!this.active) {
      return;
    }
    this.active = false;
    this.dependencies.forEach((dep) => dep.unsubscribe(this));
  }
  // Static proxies for developer experience
  static get current() {
    return Scheduler.current;
  }
  static nonreactive(func) {
    const previousReaction = Scheduler.current;
    Scheduler.current = null;
    try {
      return func();
    } finally {
      Scheduler.current = previousReaction;
    }
  }
  static guard(f5, equalCheck = isEqual) {
    if (!Scheduler.current) {
      return f5();
    }
    let dep = new Dependency();
    let value, newValue;
    dep.depend();
    const comp = new _Reaction(() => {
      newValue = f5();
      if (!comp.firstRun && !equalCheck(newValue, value)) {
        dep.changed();
      }
      value = clone(newValue);
    });
    comp.run();
    return newValue;
  }
};
// DX pass throughs
__publicField(_Reaction, "flush", Scheduler.flush);
__publicField(_Reaction, "scheduleFlush", Scheduler.scheduleFlush);
__publicField(_Reaction, "afterFlush", Scheduler.afterFlush);
__publicField(_Reaction, "getSource", Scheduler.getSource);
var Reaction = _Reaction;

// packages/reactivity/src/signal.js
var _Signal = class _Signal {
  constructor(initialValue, { context, equalityFunction, allowClone = true, cloneFunction } = {}) {
    this.dependency = new Dependency({
      firstRun: true,
      value: initialValue
    });
    this.allowClone = allowClone;
    this.equalityFunction = equalityFunction ? wrapFunction(equalityFunction) : _Signal.equalityFunction;
    this.clone = cloneFunction ? wrapFunction(cloneFunction) : _Signal.cloneFunction;
    this.currentValue = this.maybeClone(initialValue);
    this.setContext(context);
  }
  // set debugging context for signal
  setContext(additionalContext = {}) {
    const defaultContext = {
      value: this.currentValue
    };
    this.context = {
      ...defaultContext,
      ...additionalContext
    };
  }
  addContext(additionalContext = {}) {
    if (!this.context) {
      this.context = {};
    }
    for (const key in additionalContext) {
      this.context[key] = additionalContext[key];
    }
  }
  // set debugging stack trace for signal
  setTrace() {
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this.context, this.setTrace);
    } else {
      this.context.stack = new Error().stack;
    }
  }
  get value() {
    this.dependency.depend();
    const value = this.currentValue;
    return Array.isArray(value) || typeof value == "object" ? this.maybeClone(value) : value;
  }
  canCloneValue(value) {
    return this.allowClone === true && !isClassInstance(value);
  }
  maybeClone(value) {
    if (!this.canCloneValue(value)) {
      return value;
    }
    if (isArray(value)) {
      return value = value.map((value2) => this.maybeClone(value2));
    }
    return this.clone(value);
  }
  set value(newValue) {
    if (!this.equalityFunction(this.currentValue, newValue)) {
      this.currentValue = this.maybeClone(newValue);
      this.setContext();
      this.setTrace();
      this.dependency.changed(this.context);
    }
  }
  get() {
    return this.value;
  }
  set(newValue) {
    if (!this.equalityFunction(this.currentValue, newValue)) {
      this.addContext({ value: newValue });
      this.value = newValue;
    }
  }
  subscribe(callback) {
    return Reaction.create((comp) => {
      callback(this.value, comp);
    });
  }
  peek() {
    return this.maybeClone(this.currentValue);
  }
  clear() {
    return this.set(void 0);
  }
  // array helpers
  push(...args) {
    const arr = this.peek();
    arr.push(...args);
    this.set(arr);
  }
  unshift(...args) {
    const arr = this.peek();
    arr.unshift(...args);
    this.set(arr);
  }
  splice(...args) {
    const arr = this.peek();
    arr.splice(...args);
    this.set(arr);
  }
  map(mapFunction) {
    const newValue = Array.prototype.map.call(this.peek(), mapFunction);
    this.set(newValue);
  }
  filter(filterFunction) {
    const newValue = Array.prototype.filter.call(this.peek(), filterFunction);
    this.set(newValue);
  }
  getIndex(index) {
    return this.get()[index];
  }
  setIndex(index, value) {
    let arr = this.peek();
    arr[index] = value;
    this.set(arr);
  }
  removeIndex(index) {
    let arr = this.peek();
    arr.splice(index, 1);
    this.set(arr);
  }
  // sets
  setArrayProperty(indexOrProperty, property, value) {
    let index;
    if (isNumber(indexOrProperty)) {
      index = indexOrProperty;
    } else {
      index = "all";
      value = property;
      property = indexOrProperty;
    }
    const newValue = this.peek().map((object, currentIndex) => {
      if (index == "all" || currentIndex == index) {
        object[property] = value;
      }
      return object;
    });
    this.set(newValue);
  }
  toggle() {
    return this.set(!this.peek());
  }
  increment(amount = 1, max) {
    let newAmount = this.peek() + amount;
    if (isNumber(max) && newAmount > max) {
      newAmount = max;
    }
    return this.set(newAmount);
  }
  decrement(amount = 1, min) {
    let newAmount = this.peek() - amount;
    if (isNumber(min) && newAmount < min) {
      newAmount = min;
    }
    return this.set(newAmount);
  }
  now() {
    return this.set(/* @__PURE__ */ new Date());
  }
  getIDs(item) {
    if (isObject(item)) {
      return unique([item == null ? void 0 : item._id, item == null ? void 0 : item.id, item == null ? void 0 : item.hash, item == null ? void 0 : item.key].filter(Boolean));
    }
    return [item];
  }
  getID(item) {
    return this.getIDs(item).filter(Boolean)[0];
  }
  hasID(item, id) {
    return this.getID(item) === id;
  }
  getItem(id) {
    return findIndex(this.currentValue, (item) => this.hasID(item, id));
  }
  setProperty(idOrProperty, property, value) {
    if (arguments.length == 3) {
      const id = idOrProperty;
      const index = this.getItem(id);
      return this.setArrayProperty(index, property, value);
    } else {
      value = property;
      property = idOrProperty;
      const obj = this.peek();
      obj[property] = value;
      this.set(obj);
    }
  }
  replaceItem(id, item) {
    return this.setIndex(this.getItem(id), item);
  }
  removeItem(id) {
    return this.removeIndex(this.getItem(id));
  }
};
__publicField(_Signal, "equalityFunction", isEqual);
__publicField(_Signal, "cloneFunction", clone);
var Signal = _Signal;

// packages/templating/src/template-helpers.js
var TemplateHelpers = {
  exists(a3) {
    return !isEmpty(a3);
  },
  isEmpty(a3) {
    return isEmpty(a3);
  },
  stringify(a3) {
    return JSON.stringify(a3);
  },
  hasAny(a3) {
    return (a3 == null ? void 0 : a3.length) > 0;
  },
  range(start, stop, step = 1) {
    return range(start, stop, step);
  },
  concat(...args) {
    return args.join("");
  },
  both(a3, b3) {
    return a3 && b3;
  },
  either(a3, b3) {
    return a3 || b3;
  },
  join(array = [], delimiter = " ", spaceAfter = false) {
    if (array.length == 0) {
      return;
    }
    const value = array.join(delimiter).trim();
    return spaceAfter ? `${value} ` : value;
  },
  classes(classes, spaceAfter = true) {
    return TemplateHelpers.join(classes, " ", true);
  },
  joinComma(array = [], oxford, quotes) {
    return joinWords(array, {
      separator: ", ",
      lastSeparator: " and ",
      oxford,
      quotes
    });
  },
  classIf(expr, trueClass = "", falseClass = "") {
    let val = expr ? trueClass : falseClass;
    return val ? `${val} ` : "";
  },
  classMap(classObj) {
    let classNames = [];
    each(classObj, (condition, className) => {
      if (condition) {
        classNames.push(className);
      }
    });
    return classNames.length ? `${classNames.join(" ")} ` : "";
  },
  maybe(expr, trueExpr, falseExpr) {
    return expr ? trueExpr : falseExpr;
  },
  activeIf(expr) {
    return TemplateHelpers.classIf(expr, "active", "");
  },
  selectedIf(expr) {
    return TemplateHelpers.classIf(expr, "selected", "");
  },
  capitalize(text = "") {
    return capitalize(text);
  },
  titleCase(text = "") {
    return toTitleCase(text);
  },
  disabledIf(expr) {
    return TemplateHelpers.classIf(expr, "disabled", "");
  },
  checkedIf(expr) {
    return TemplateHelpers.classIf(expr, "checked", "");
  },
  maybePlural(value, plural = "s") {
    return value == 1 ? "" : plural;
  },
  not(a3) {
    return !a3;
  },
  is(a3, b3) {
    return a3 == b3;
  },
  isNot(a3, b3) {
    return a3 !== b3;
  },
  notEqual(a3, b3) {
    return TemplateHelpers.isNot(a3, b3);
  },
  isExactly(a3, b3) {
    return a3 === b3;
  },
  isNotExactly(a3, b3) {
    return a3 !== b3;
  },
  greaterThan(a3, b3) {
    return a3 > b3;
  },
  lessThan(a3, b3) {
    return a3 < b3;
  },
  greaterThanEquals(a3, b3) {
    return a3 >= b3;
  },
  lessThanEquals(a3, b3) {
    return a3 <= b3;
  },
  numberFromIndex(a3) {
    return a3 + 1;
  },
  formatDate(date = /* @__PURE__ */ new Date(), format = "L", options = { timezone: "local" }) {
    return formatDate(date, format, options);
  },
  formatDateTime(date = /* @__PURE__ */ new Date(), format = "LLL", options = { timezone: "local" }) {
    return formatDate(date, format, options);
  },
  formatDateTimeSeconds(date = /* @__PURE__ */ new Date(), format = "LTS", options = { timezone: "local" }) {
    return formatDate(date, format, options);
  },
  object({ obj }) {
    return obj;
  },
  log(...args) {
    console.log(...args);
  },
  debugger() {
    debugger;
  },
  tokenize(string = "") {
    return tokenize(string);
  },
  debugReactivity() {
    Reaction.getSource();
  },
  arrayFromObject(obj) {
    return arrayFromObject(obj);
  },
  escapeHTML(string) {
    return escapeHTML(string);
  },
  guard: (value) => {
    return Reaction.guard(wrapFunction(value));
  },
  nonreactive: (value) => {
    return Reaction.nonReactive(wrapFunction(value));
  }
};

// packages/query/src/query.js
var _Query = class _Query {
  constructor(selector, { root = document, pierceShadow = false, prevObject = null } = {}) {
    let elements = [];
    if (!root) {
      return;
    }
    if (selector instanceof _Query) {
      elements = selector;
    }
    if (selector === window || selector === globalThis || inArray(selector, ["window", "globalThis"]) || selector == _Query.globalThisProxy) {
      elements = [_Query.globalThisProxy];
      this.isBrowser = isClient;
      this.isGlobal = true;
    } else if (isArray(selector) || selector instanceof NodeList || selector instanceof HTMLCollection) {
      selector = Array.from(selector);
      elements = selector;
    } else if (isString(selector)) {
      if (selector.trim().slice(0, 1) == "<") {
        const template = document.createElement("template");
        template.innerHTML = selector.trim();
        elements = Array.from(template.content.childNodes);
      } else {
        elements = pierceShadow ? this.querySelectorAllDeep(root, selector) : root.querySelectorAll(selector);
      }
    } else if (isDOM(selector)) {
      elements = [selector];
    } else if (selector instanceof NodeList) {
      elements = selector;
    }
    this.selector = selector;
    this.length = elements.length;
    this.options = { root, pierceShadow };
    this.prevObject = prevObject;
    Object.assign(this, elements);
  }
  /* Returns a copy of current DOM Object */
  chain(elements) {
    return this.isGlobal && !elements ? new _Query(globalThis, this.options) : new _Query(elements, { ...this.options, prevObject: this });
  }
  end() {
    return this.prevObject || this;
  }
  /* we will add all elements across shadow root boundaries while matching
     intermediate selectors at shadow boundaries
  */
  querySelectorAllDeep(root, selector, includeRoot = true) {
    const elements = /* @__PURE__ */ new Set();
    const domSelector = isDOM(selector);
    let domFound = false;
    let queriedRoot = false;
    if (includeRoot) {
      if (domSelector && root == selector || !domSelector && root.matches && root.matches(selector)) {
        elements.add(root);
      }
    }
    if (domSelector) {
      queriedRoot = true;
    } else if (root.querySelectorAll) {
      root.querySelectorAll(selector).forEach((el) => elements.add(el));
      queriedRoot = true;
    }
    const getRemainingSelector = (el, selector2) => {
      const parts = selector2.split(" ");
      let partialSelector;
      let remainingSelector;
      each(parts, (part, index) => {
        partialSelector = parts.slice(0, index + 1).join(" ");
        if (el.matches(partialSelector)) {
          remainingSelector = parts.slice(index + 1).join(" ");
          return;
        }
      });
      return remainingSelector || selector2;
    };
    const addElements = (node, selector2) => {
      if (domSelector && (node === selector2 || node.contains)) {
        if (node.contains(selector2)) {
          elements.add(selector2);
          domFound = true;
        }
      } else if (node.querySelectorAll) {
        node.querySelectorAll(selector2).forEach((el) => elements.add(el));
      }
    };
    const findElements = (node, selector2, query) => {
      if (domSelector && domFound) return;
      if (query === true) {
        addElements(node, selector2);
        queriedRoot = true;
      }
      if (node.nodeType === Node.ELEMENT_NODE && node.shadowRoot) {
        const newSelector = getRemainingSelector(node, selector2);
        addElements(node.shadowRoot, newSelector);
        findElements(node.shadowRoot, newSelector, !queriedRoot);
      }
      if (node.assignedNodes) {
        const newSelector = getRemainingSelector(node, selector2);
        const nodes = node.assignedNodes();
        for (let i6 = 0; i6 < nodes.length; i6++) {
          findElements(nodes[i6], newSelector, queriedRoot);
        }
      }
      if (node.childNodes && node.childNodes.length) {
        const childCount = node.childNodes.length;
        for (let i6 = 0; i6 < childCount; i6++) {
          findElements(node.childNodes[i6], selector2, queriedRoot);
        }
      }
    };
    findElements(root, selector);
    return Array.from(elements);
  }
  each(callback) {
    for (let index = 0; index < this.length; index++) {
      const el = this[index];
      const $el = this.chain(el);
      callback.call($el, el, index);
    }
    return this;
  }
  removeAllEvents() {
    _Query.eventHandlers = [];
  }
  find(selector) {
    const elements = Array.from(this).flatMap((el) => {
      if (this.options.pierceShadow) {
        return this.querySelectorAllDeep(el, selector, false);
      } else {
        return Array.from(el.querySelectorAll(selector));
      }
    });
    return this.chain(elements);
  }
  parent(selector) {
    const parents = Array.from(this).map((el) => el.parentElement).filter(Boolean);
    return selector ? this.chain(parents).filter(selector) : this.chain(parents);
  }
  children(selector) {
    const allChildren = Array.from(this).flatMap((el) => Array.from(el.children));
    const filteredChildren = selector ? allChildren.filter((child) => child.matches(selector)) : allChildren;
    return this.chain(filteredChildren);
  }
  siblings(selector) {
    const siblings = Array.from(this).flatMap((el) => {
      if (!el.parentNode) {
        return;
      }
      return Array.from(el.parentNode.children).filter((child) => child !== el);
    }).filter(Boolean);
    return selector ? this.chain(siblings).filter(selector) : this.chain(siblings);
  }
  // returns the index of element only including siblings that match a filter
  index(siblingFilter) {
    const el = this.el();
    if (!(el == null ? void 0 : el.parentNode)) {
      return -1;
    }
    const $siblings = this.chain(el.parentNode.children).filter(siblingFilter);
    const siblingEls = $siblings.get();
    const els = this.get();
    return findIndex(siblingEls, (el2) => inArray(el2, els));
  }
  // returns the index of current collection that match filter
  indexOf(filter) {
    const els = this.get();
    const el = this.filter(filter).get(0);
    return els.indexOf(el);
  }
  filter(filter) {
    if (!filter) {
      return this;
    }
    let filteredElements = [];
    if (isFunction(filter)) {
      filteredElements = Array.from(this).filter(filter);
    } else {
      filteredElements = Array.from(this).filter((el) => {
        if (isString(filter)) {
          return el.matches && el.matches(filter);
        } else if (filter instanceof _Query) {
          return filter.get().includes(el);
        } else {
          let els = isArray(filter) ? filter : [filter];
          return inArray(el, els);
        }
      });
    }
    return this.chain(filteredElements);
  }
  is(selector) {
    const filteredElements = Array.from(this).filter((el) => {
      if (typeof selector === "string") {
        return el.matches && el.matches(selector);
      } else if (this.isGlobal) {
        return inArray(selector, ["window", "globalThis"]);
      } else {
        const elements = selector instanceof _Query ? selector.get() : [selector];
        return elements.includes(el);
      }
    });
    return filteredElements.length === this.length;
  }
  not(selector) {
    const filteredElements = Array.from(this).filter((el) => {
      if (typeof selector === "string") {
        return !el.matches || el.matches && !el.matches(selector);
      } else if (this.isGlobal) {
        return !inArray(selector, ["window", "globalThis"]);
      } else {
        const elements = selector instanceof _Query ? selector.get() : [selector];
        return !elements.includes(el);
      }
    });
    return this.chain(filteredElements);
  }
  closest(selector) {
    const closest = Array.from(this).map((el) => {
      if (this.options.pierceShadow) {
        return this.closestDeep(el, selector);
      } else if (selector && (el == null ? void 0 : el.closest)) {
        return el.closest(selector);
      } else if (this.isGlobal) {
        return inArray(selector, ["window", "globalThis"]);
      }
    }).filter(Boolean);
    return this.chain(closest);
  }
  closestDeep(element, selector) {
    let currentElement = element;
    const domSelector = isDOM(selector);
    const stringSelector = isString(selector);
    while (currentElement) {
      if (domSelector && currentElement === selector || stringSelector && currentElement.matches(selector)) {
        return currentElement;
      }
      if (currentElement.parentElement) {
        currentElement = currentElement.parentElement;
      } else if (currentElement.parentNode && currentElement.parentNode.host) {
        currentElement = currentElement.parentNode.host;
      } else {
        return;
      }
    }
    return;
  }
  ready(handler) {
    if (this.is(document) && document.readyState == "loading") {
      this.on("ready", handler);
    } else {
      handler.call(document, new Event("DOMContentLoaded"));
    }
    return this;
  }
  getEventAlias(eventName) {
    const aliases = {
      ready: "DOMContentLoaded"
    };
    return aliases[eventName] || eventName;
  }
  getEventArray(eventNames) {
    return eventNames.split(" ").map((name) => this.getEventAlias(name)).filter(Boolean);
  }
  on(eventNames, targetSelectorOrHandler, handlerOrOptions, options) {
    const eventHandlers = [];
    let handler;
    let targetSelector;
    if (isObject(handlerOrOptions)) {
      options = handlerOrOptions;
      handler = targetSelectorOrHandler;
    } else if (isString(targetSelectorOrHandler)) {
      targetSelector = targetSelectorOrHandler;
      handler = handlerOrOptions;
    } else if (isFunction(targetSelectorOrHandler)) {
      handler = targetSelectorOrHandler;
    }
    const events3 = this.getEventArray(eventNames);
    events3.forEach((eventName) => {
      const abortController = (options == null ? void 0 : options.abortController) || new AbortController();
      const eventSettings = (options == null ? void 0 : options.eventSettings) || {};
      const signal = abortController.signal;
      this.each((el) => {
        let delegateHandler;
        if (targetSelector) {
          delegateHandler = (event) => {
            let target;
            if (event.composed && event.composedPath) {
              let path = event.composedPath();
              const elIndex = findIndex(path, (thisEl) => thisEl == el);
              path = path.slice(0, elIndex);
              target = path.find((el2) => el2 instanceof Element && el2.matches && el2.matches(targetSelector));
            } else {
              target = event.target.closest(targetSelector);
            }
            if (target) {
              handler.call(target, event);
            }
          };
        }
        const eventListener = delegateHandler || handler;
        const domEL = el == _Query.globalThisProxy ? globalThis : el;
        if (domEL.addEventListener) {
          domEL.addEventListener(eventName, eventListener, { signal, ...eventSettings });
        }
        const eventHandler = {
          el,
          eventName,
          eventListener,
          abortController,
          delegated: targetSelector !== void 0,
          handler,
          abort: (reason) => abortController.abort(reason)
        };
        eventHandlers.push(eventHandler);
      });
    });
    if (!_Query.eventHandlers) {
      _Query.eventHandlers = [];
    }
    _Query.eventHandlers.push(...eventHandlers);
    if (options == null ? void 0 : options.returnHandler) {
      return eventHandlers.length == 1 ? eventHandlers[0] : eventHandlers;
    }
    return this;
  }
  one(eventName, targetSelectorOrHandler, handlerOrOptions, options) {
    let handler;
    let targetSelector;
    if (isObject(handlerOrOptions)) {
      options = handlerOrOptions;
      handler = targetSelectorOrHandler;
    } else if (isString(targetSelectorOrHandler)) {
      targetSelector = targetSelectorOrHandler;
      handler = handlerOrOptions;
    } else if (isFunction(targetSelectorOrHandler)) {
      handler = targetSelectorOrHandler;
    }
    options = options || {};
    const abortController = new AbortController();
    options.abortController = abortController;
    const wrappedHandler = function(...args) {
      abortController.abort();
      handler.apply(this, args);
    };
    return targetSelector ? this.on(eventName, targetSelector, wrappedHandler, options) : this.on(eventName, wrappedHandler, options);
  }
  off(eventNames, handler) {
    const events3 = this.getEventArray(eventNames);
    _Query.eventHandlers = _Query.eventHandlers.filter((eventHandler) => {
      if ((!eventNames || inArray(eventHandler.eventName, events3)) && (!handler || (handler == null ? void 0 : handler.eventListener) == eventHandler.eventListener || eventHandler.eventListener === handler || eventHandler.handler === handler)) {
        const el = this.isGlobal ? globalThis : eventHandler.el;
        if (el.removeEventListener) {
          el.removeEventListener(eventHandler.eventName, eventHandler.eventListener);
        }
        return false;
      }
      return true;
    });
    return this;
  }
  trigger(eventName, eventParams) {
    return this.each((el) => {
      if (typeof el.dispatchEvent !== "function") {
        return;
      }
      const event = new Event(eventName, { bubbles: true, cancelable: true });
      if (eventParams) {
        Object.assign(event, eventParams);
      }
      el.dispatchEvent(event);
    });
  }
  // shorthand for most common trigger() uses
  click(eventParams) {
    return this.trigger("click", eventParams);
  }
  submit(eventParams) {
    return this.trigger("submit", eventParams);
  }
  dispatchEvent(eventName, eventData = {}, eventSettings = {}) {
    const eventOptions = {
      bubbles: true,
      cancelable: true,
      composed: true,
      detail: eventData,
      ...eventSettings
    };
    this.each((el) => {
      const event = new CustomEvent(eventName, eventOptions);
      el.dispatchEvent(event);
    });
    return this;
  }
  remove() {
    return this.each((el) => el.remove());
  }
  addClass(classNames) {
    const classesToAdd = classNames.split(" ");
    return this.each((el) => el.classList.add(...classesToAdd));
  }
  hasClass(className) {
    return Array.from(this).some((el) => el.classList.contains(className));
  }
  removeClass(classNames) {
    const classesToRemove = classNames.split(" ");
    return this.each((el) => el.classList.remove(...classesToRemove));
  }
  toggleClass(classNames) {
    const classesToToggle = classNames.split(" ");
    return this.each((el) => el.classList.toggle(...classesToToggle));
  }
  html(newHTML) {
    if (newHTML !== void 0) {
      return this.each((el) => el.innerHTML = newHTML);
    } else if (this.length > 0) {
      return this.map((el) => el.innerHTML || el.nodeValue).join("");
    }
  }
  outerHTML(newHTML) {
    if (newHTML !== void 0) {
      return this.each((el) => el.outerHTML = newHTML);
    } else if (this.length) {
      return this.map((el) => el.outerHTML).join("");
    }
  }
  getSlot(name) {
    return this.map((el) => {
      if (el.tagName.toLowerCase() == "slot" && (!name || el.name == name)) {
        const nodes = el.assignedNodes({ flatten: true });
        if (nodes) {
          return this.chain(nodes).html();
        }
      } else if (el.shadowRoot) {
        const slotSelector = name ? `slot[name="${name}"]` : "slot:not([name])";
        const slot = el.shadowRoot.querySelector(slotSelector);
        const nodes = slot.assignedNodes({ flatten: true });
        if (nodes) {
          return this.chain(nodes).html();
        }
      } else {
        const slotSelector = name ? `[slot="${name}"]` : ":not([slot])";
        return this.chain(el).find(slotSelector).html();
      }
    }).join("");
  }
  setSlot(nameOrHTML, newHTML) {
    let name;
    if (newHTML) {
      name = nameOrHTML;
    } else {
      newHTML = nameOrHTML;
    }
    return this.each((el) => {
      var _a3;
      if (el.tagName.toLowerCase() == "slot") {
        el = (_a3 = el.getRootNode().getRootNode()) == null ? void 0 : _a3.host;
      }
      const $el = this.chain(el);
      if (name) {
        const slotSelector = `[slot="${name}"]`;
        let $slottedElement = this.chain(el).find(slotSelector);
        if (!$slottedElement.exists()) {
          $el.append(`<span slot="${name}"></span>`);
          $slottedElement = this.chain(el).find(slotSelector);
        }
        $slottedElement.html(newHTML);
      } else {
        $el.html(newHTML);
      }
    });
  }
  text(newText) {
    if (newText !== void 0) {
      return this.each((el) => el.textContent = newText);
    } else {
      const childNodes = (el) => {
        return el.nodeName === "SLOT" ? el.assignedNodes({ flatten: true }) : el.childNodes;
      };
      const values2 = this.map((el) => this.getTextContentRecursive(childNodes(el)));
      return values2.length > 1 ? values2 : values2[0];
    }
  }
  // Helper function to recursively get text content
  getTextContentRecursive(nodes) {
    return Array.from(nodes).map((node) => {
      if (node.nodeType === Node.TEXT_NODE) {
        return node.nodeValue;
      } else if (node.nodeName === "SLOT") {
        const slotNodes = node.assignedNodes({ flatten: true });
        return this.getTextContentRecursive(slotNodes);
      } else {
        return this.getTextContentRecursive(node.childNodes);
      }
    }).join("").trim();
  }
  // non jquery variant to return only immediate text node
  textNode() {
    return Array.from(this).map((el) => {
      return Array.from(el.childNodes).filter((node) => node.nodeType === Node.TEXT_NODE).map((node) => node.nodeValue).join("");
    }).join("");
  }
  map(...args) {
    return Array.from(this).map(...args);
  }
  value(newValue) {
    const usesValue = (el) => {
      return el instanceof HTMLInputElement || el instanceof HTMLSelectElement || el instanceof HTMLTextAreaElement || customElements.get(el.tagName.toLowerCase());
    };
    if (newValue !== void 0) {
      return this.each((el) => {
        if (usesValue(el)) {
          el.value = newValue;
        }
      });
    } else {
      const values2 = this.map((el) => {
        if (usesValue(el)) {
          return el.value;
        }
        return void 0;
      });
      return values2.length > 1 ? values2 : values2[0];
    }
  }
  // alias
  val(...args) {
    return this.value(...args);
  }
  focus() {
    if (this.length) {
      this[0].focus();
    }
    return this;
  }
  blur() {
    if (this.length) {
      this[0].blur();
    }
    return this;
  }
  css(property, value = null, settings = { includeComputed: false }) {
    const elements = Array.from(this);
    if (isPlainObject(property) || value !== null) {
      if (isPlainObject(property)) {
        Object.entries(property).forEach(([prop, val]) => {
          elements.forEach((el) => el.style.setProperty(camelToKebab(prop), val));
        });
      } else {
        elements.forEach((el) => el.style.setProperty(camelToKebab(property), value));
      }
      return this;
    } else {
      if (elements == null ? void 0 : elements.length) {
        const styles = elements.map((el) => {
          const inlineStyle = el.style[property];
          if (settings.includeComputed) {
            return window.getComputedStyle(el).getPropertyValue(property);
          }
          if (inlineStyle) {
            return inlineStyle;
          }
          return void 0;
        });
        return elements.length === 1 ? styles[0] : styles;
      }
    }
  }
  computedStyle(property) {
    return this.css(property, null, { includeComputed: true });
  }
  cssVar(variable, value) {
    return this.css(`--${variable}`, value, { includeComputed: true });
  }
  attr(attribute, value) {
    if (isPlainObject(attribute)) {
      Object.entries(attribute).forEach(([attr, val]) => {
        this.each((el) => el.setAttribute(attr, val));
      });
    } else if (value !== void 0) {
      this.each((el) => el.setAttribute(attribute, value));
    } else if (this.length) {
      const attributes = this.map((el) => el.getAttribute(attribute));
      return attributes.length > 1 ? attributes : attributes[0];
    }
    return;
  }
  removeAttr(attributeName) {
    return this.each((el) => el.removeAttribute(attributeName));
  }
  el() {
    return this.get(0);
  }
  get(index) {
    if (index !== void 0) {
      return this[index];
    } else {
      return Array.from(this);
    }
  }
  eq(index) {
    return this.chain(this[index]);
  }
  first() {
    return this.eq(0);
  }
  last() {
    return this.eq(this.length - 1);
  }
  prop(name, value) {
    if (value !== void 0) {
      return this.each((el) => {
        el[name] = value;
      });
    } else {
      if (this.length == 0) {
        return void 0;
      } else if (this.length === 1) {
        return this[0][name];
      } else {
        return this.map((el) => el[name]);
      }
    }
  }
  next(selector) {
    const nextSiblings = this.map((el) => {
      let nextSibling = el.nextElementSibling;
      while (nextSibling) {
        if (!selector || nextSibling.matches(selector)) {
          return nextSibling;
        }
        nextSibling = nextSibling.nextElementSibling;
      }
      return null;
    }).filter(Boolean);
    return this.chain(nextSiblings);
  }
  prev(selector) {
    const prevSiblings = this.map((el) => {
      let prevSibling = el.previousElementSibling;
      while (prevSibling) {
        if (!selector || prevSibling.matches(selector)) {
          return prevSibling;
        }
        prevSibling = prevSibling.previousElementSibling;
      }
      return null;
    }).filter(Boolean);
    return this.chain(prevSiblings);
  }
  height(value) {
    return this.prop("innerHeight", value) || this.prop("clientHeight", value);
  }
  width(value) {
    return this.prop("innerWidth", value) || this.prop("clientWidth", value);
  }
  scrollHeight(value) {
    const el = this.isGlobal && this.isBrowser ? this.chain(document.documentElement) : this;
    return el.prop("scrollHeight", value);
  }
  scrollWidth(value) {
    const el = this.isGlobal && this.isBrowser ? this.chain(document.documentElement) : this;
    return el.prop("scrollWidth", value);
  }
  scrollLeft(value) {
    const el = this.isGlobal && this.isBrowser ? this.chain(document.documentElement) : this;
    return el.prop("scrollLeft", value);
  }
  scrollTop(value) {
    const el = this.isGlobal && this.isBrowser ? this.chain(document.documentElement) : this;
    return el.prop("scrollTop", value);
  }
  clone() {
    const fragment = document.createDocumentFragment();
    this.each((el) => {
      fragment.appendChild(el.cloneNode(true));
    });
    return this.chain(fragment.childNodes);
  }
  reverse() {
    const els = this.get().reverse();
    return this.chain(els);
  }
  insertContent(target, content, position) {
    const $content = this.chain(content);
    $content.each((el) => {
      var _a3, _b;
      if (target.insertAdjacentElement) {
        target.insertAdjacentElement(position, el);
      } else {
        switch (position) {
          case "beforebegin":
            (_a3 = target.parentNode) == null ? void 0 : _a3.insertBefore(el, target);
            break;
          case "afterbegin":
            target.insertBefore(el, target.firstChild);
            break;
          case "beforeend":
            target.appendChild(el);
            break;
          case "afterend":
            (_b = target.parentNode) == null ? void 0 : _b.insertBefore(el, target.nextSibling);
            break;
        }
      }
    });
  }
  prepend(...allContent) {
    return this.each((el) => {
      each(allContent, (content) => {
        this.insertContent(el, content, "afterbegin");
      });
    });
  }
  append(...allContent) {
    return this.each((el) => {
      each(allContent, (content) => {
        this.insertContent(el, content, "beforeend");
      });
    });
  }
  insertBefore(selector) {
    return this.chain(selector).each((el) => {
      this.insertContent(el, this.selector, "beforebegin");
    });
  }
  insertAfter(selector) {
    return this.chain(selector).each((el) => {
      this.insertContent(el, this.selector, "afterend");
    });
  }
  detach() {
    return this.each((el) => {
      if (el.parentNode) {
        el.parentNode.removeChild(el);
      }
    });
  }
  naturalWidth() {
    const widths = this.map((el) => {
      const $clone = $(el).clone();
      $clone.insertAfter(el).css({
        position: "absolute",
        display: "block",
        transform: "translate(-9999px, -9999px)",
        zIndex: "-1"
      });
      const naturalWidth = $clone.width();
      $clone.remove();
      return naturalWidth;
    });
    return widths.length > 1 ? widths : widths[0];
  }
  naturalHeight() {
    const height = this.map((el) => {
      const $clone = $(el).clone();
      $clone.insertAfter(el).css({
        position: "absolute",
        display: "block",
        transform: "translate(-9999px, -9999px)",
        zIndex: "-1"
      });
      const naturalHeight = $clone.height();
      $clone.remove();
      return naturalHeight;
    });
    return height.length > 1 ? height : height[0];
  }
  // offsetParent does not return the true offset parent
  // in cases where there is a parent node with a transform context
  // so we need to get that manually where finding the true offset parent is essential
  // for instance when calculating position
  offsetParent({ calculate = true } = {}) {
    return Array.from(this).map((el) => {
      if (!calculate) {
        return el.offsetParent;
      }
      let $el, isPositioned, isTransformed, isBody;
      let parentNode = el == null ? void 0 : el.parentNode;
      while (parentNode && !isPositioned && !isTransformed && !isBody) {
        parentNode = parentNode == null ? void 0 : parentNode.parentNode;
        if (parentNode) {
          $el = $(parentNode);
          isPositioned = $el.computedStyle("position") !== "static";
          isTransformed = $el.computedStyle("transform") !== "none";
          isBody = $el.is("body");
        }
      }
      return parentNode;
    });
  }
  // alias
  count() {
    return this.length;
  }
  exists() {
    return this.length > 0;
  }
  // adds properties to an element after dom loads
  initialize(settings) {
    document.addEventListener("DOMContentLoaded", () => {
      this.settings(settings);
    });
  }
  settings(settings) {
    return this.each((el) => {
      each(settings, (value, setting) => {
        el[setting] = value;
      });
    });
  }
  setting(setting, value) {
    return this.each((el) => {
      el[setting] = value;
    });
  }
  // special helper for SUI components
  component() {
    const components = this.map((el) => el.component).filter(Boolean);
    return components.length > 1 ? components : components[0];
  }
  dataContext() {
    const contexts = this.map((el) => el.dataContext).filter(Boolean);
    return contexts.length > 1 ? contexts : contexts[0];
  }
};
/*
  This avoids keeping a copy of window/globalThis in
  memory when an element references the global object
  reducing memory footprint
*/
__publicField(_Query, "globalThisProxy", new Proxy({}, {
  get(target, prop) {
    return globalThis[prop];
  },
  set(target, prop, value) {
    globalThis[prop] = value;
    return true;
  }
}));
/*
  We keep an array of event handlers for teardown
*/
__publicField(_Query, "eventHandlers", []);
var Query = _Query;

// packages/query/src/index.js
var $2 = function(selector, args = {}) {
  const isClient2 = typeof window !== "undefined";
  if (!(args == null ? void 0 : args.root) && isClient2) {
    args.root = document;
  }
  return new Query(selector, args);
};

// node_modules/@lit/reactive-element/css-tag.js
var t = globalThis;
var e = t.ShadowRoot && (void 0 === t.ShadyCSS || t.ShadyCSS.nativeShadow) && "adoptedStyleSheets" in Document.prototype && "replace" in CSSStyleSheet.prototype;
var s = Symbol();
var o = /* @__PURE__ */ new WeakMap();
var n = class {
  constructor(t5, e6, o7) {
    if (this._$cssResult$ = true, o7 !== s) throw Error("CSSResult is not constructable. Use `unsafeCSS` or `css` instead.");
    this.cssText = t5, this.t = e6;
  }
  get styleSheet() {
    let t5 = this.o;
    const s5 = this.t;
    if (e && void 0 === t5) {
      const e6 = void 0 !== s5 && 1 === s5.length;
      e6 && (t5 = o.get(s5)), void 0 === t5 && ((this.o = t5 = new CSSStyleSheet()).replaceSync(this.cssText), e6 && o.set(s5, t5));
    }
    return t5;
  }
  toString() {
    return this.cssText;
  }
};
var r = (t5) => new n("string" == typeof t5 ? t5 : t5 + "", void 0, s);
var S = (s5, o7) => {
  if (e) s5.adoptedStyleSheets = o7.map((t5) => t5 instanceof CSSStyleSheet ? t5 : t5.styleSheet);
  else for (const e6 of o7) {
    const o8 = document.createElement("style"), n5 = t.litNonce;
    void 0 !== n5 && o8.setAttribute("nonce", n5), o8.textContent = e6.cssText, s5.appendChild(o8);
  }
};
var c = e ? (t5) => t5 : (t5) => t5 instanceof CSSStyleSheet ? ((t6) => {
  let e6 = "";
  for (const s5 of t6.cssRules) e6 += s5.cssText;
  return r(e6);
})(t5) : t5;

// node_modules/@lit/reactive-element/reactive-element.js
var { is: i2, defineProperty: e2, getOwnPropertyDescriptor: r2, getOwnPropertyNames: h, getOwnPropertySymbols: o2, getPrototypeOf: n2 } = Object;
var a = globalThis;
var c2 = a.trustedTypes;
var l = c2 ? c2.emptyScript : "";
var p = a.reactiveElementPolyfillSupport;
var d = (t5, s5) => t5;
var u = { toAttribute(t5, s5) {
  switch (s5) {
    case Boolean:
      t5 = t5 ? l : null;
      break;
    case Object:
    case Array:
      t5 = null == t5 ? t5 : JSON.stringify(t5);
  }
  return t5;
}, fromAttribute(t5, s5) {
  let i6 = t5;
  switch (s5) {
    case Boolean:
      i6 = null !== t5;
      break;
    case Number:
      i6 = null === t5 ? null : Number(t5);
      break;
    case Object:
    case Array:
      try {
        i6 = JSON.parse(t5);
      } catch (t6) {
        i6 = null;
      }
  }
  return i6;
} };
var f = (t5, s5) => !i2(t5, s5);
var y = { attribute: true, type: String, converter: u, reflect: false, hasChanged: f };
Symbol.metadata ?? (Symbol.metadata = Symbol("metadata")), a.litPropertyMetadata ?? (a.litPropertyMetadata = /* @__PURE__ */ new WeakMap());
var b = class extends HTMLElement {
  static addInitializer(t5) {
    this._$Ei(), (this.l ?? (this.l = [])).push(t5);
  }
  static get observedAttributes() {
    return this.finalize(), this._$Eh && [...this._$Eh.keys()];
  }
  static createProperty(t5, s5 = y) {
    if (s5.state && (s5.attribute = false), this._$Ei(), this.elementProperties.set(t5, s5), !s5.noAccessor) {
      const i6 = Symbol(), r7 = this.getPropertyDescriptor(t5, i6, s5);
      void 0 !== r7 && e2(this.prototype, t5, r7);
    }
  }
  static getPropertyDescriptor(t5, s5, i6) {
    const { get: e6, set: h4 } = r2(this.prototype, t5) ?? { get() {
      return this[s5];
    }, set(t6) {
      this[s5] = t6;
    } };
    return { get() {
      return e6 == null ? void 0 : e6.call(this);
    }, set(s6) {
      const r7 = e6 == null ? void 0 : e6.call(this);
      h4.call(this, s6), this.requestUpdate(t5, r7, i6);
    }, configurable: true, enumerable: true };
  }
  static getPropertyOptions(t5) {
    return this.elementProperties.get(t5) ?? y;
  }
  static _$Ei() {
    if (this.hasOwnProperty(d("elementProperties"))) return;
    const t5 = n2(this);
    t5.finalize(), void 0 !== t5.l && (this.l = [...t5.l]), this.elementProperties = new Map(t5.elementProperties);
  }
  static finalize() {
    if (this.hasOwnProperty(d("finalized"))) return;
    if (this.finalized = true, this._$Ei(), this.hasOwnProperty(d("properties"))) {
      const t6 = this.properties, s5 = [...h(t6), ...o2(t6)];
      for (const i6 of s5) this.createProperty(i6, t6[i6]);
    }
    const t5 = this[Symbol.metadata];
    if (null !== t5) {
      const s5 = litPropertyMetadata.get(t5);
      if (void 0 !== s5) for (const [t6, i6] of s5) this.elementProperties.set(t6, i6);
    }
    this._$Eh = /* @__PURE__ */ new Map();
    for (const [t6, s5] of this.elementProperties) {
      const i6 = this._$Eu(t6, s5);
      void 0 !== i6 && this._$Eh.set(i6, t6);
    }
    this.elementStyles = this.finalizeStyles(this.styles);
  }
  static finalizeStyles(s5) {
    const i6 = [];
    if (Array.isArray(s5)) {
      const e6 = new Set(s5.flat(1 / 0).reverse());
      for (const s6 of e6) i6.unshift(c(s6));
    } else void 0 !== s5 && i6.push(c(s5));
    return i6;
  }
  static _$Eu(t5, s5) {
    const i6 = s5.attribute;
    return false === i6 ? void 0 : "string" == typeof i6 ? i6 : "string" == typeof t5 ? t5.toLowerCase() : void 0;
  }
  constructor() {
    super(), this._$Ep = void 0, this.isUpdatePending = false, this.hasUpdated = false, this._$Em = null, this._$Ev();
  }
  _$Ev() {
    var _a3;
    this._$ES = new Promise((t5) => this.enableUpdating = t5), this._$AL = /* @__PURE__ */ new Map(), this._$E_(), this.requestUpdate(), (_a3 = this.constructor.l) == null ? void 0 : _a3.forEach((t5) => t5(this));
  }
  addController(t5) {
    var _a3;
    (this._$EO ?? (this._$EO = /* @__PURE__ */ new Set())).add(t5), void 0 !== this.renderRoot && this.isConnected && ((_a3 = t5.hostConnected) == null ? void 0 : _a3.call(t5));
  }
  removeController(t5) {
    var _a3;
    (_a3 = this._$EO) == null ? void 0 : _a3.delete(t5);
  }
  _$E_() {
    const t5 = /* @__PURE__ */ new Map(), s5 = this.constructor.elementProperties;
    for (const i6 of s5.keys()) this.hasOwnProperty(i6) && (t5.set(i6, this[i6]), delete this[i6]);
    t5.size > 0 && (this._$Ep = t5);
  }
  createRenderRoot() {
    const t5 = this.shadowRoot ?? this.attachShadow(this.constructor.shadowRootOptions);
    return S(t5, this.constructor.elementStyles), t5;
  }
  connectedCallback() {
    var _a3;
    this.renderRoot ?? (this.renderRoot = this.createRenderRoot()), this.enableUpdating(true), (_a3 = this._$EO) == null ? void 0 : _a3.forEach((t5) => {
      var _a4;
      return (_a4 = t5.hostConnected) == null ? void 0 : _a4.call(t5);
    });
  }
  enableUpdating(t5) {
  }
  disconnectedCallback() {
    var _a3;
    (_a3 = this._$EO) == null ? void 0 : _a3.forEach((t5) => {
      var _a4;
      return (_a4 = t5.hostDisconnected) == null ? void 0 : _a4.call(t5);
    });
  }
  attributeChangedCallback(t5, s5, i6) {
    this._$AK(t5, i6);
  }
  _$EC(t5, s5) {
    var _a3;
    const i6 = this.constructor.elementProperties.get(t5), e6 = this.constructor._$Eu(t5, i6);
    if (void 0 !== e6 && true === i6.reflect) {
      const r7 = (void 0 !== ((_a3 = i6.converter) == null ? void 0 : _a3.toAttribute) ? i6.converter : u).toAttribute(s5, i6.type);
      this._$Em = t5, null == r7 ? this.removeAttribute(e6) : this.setAttribute(e6, r7), this._$Em = null;
    }
  }
  _$AK(t5, s5) {
    var _a3;
    const i6 = this.constructor, e6 = i6._$Eh.get(t5);
    if (void 0 !== e6 && this._$Em !== e6) {
      const t6 = i6.getPropertyOptions(e6), r7 = "function" == typeof t6.converter ? { fromAttribute: t6.converter } : void 0 !== ((_a3 = t6.converter) == null ? void 0 : _a3.fromAttribute) ? t6.converter : u;
      this._$Em = e6, this[e6] = r7.fromAttribute(s5, t6.type), this._$Em = null;
    }
  }
  requestUpdate(t5, s5, i6) {
    if (void 0 !== t5) {
      if (i6 ?? (i6 = this.constructor.getPropertyOptions(t5)), !(i6.hasChanged ?? f)(this[t5], s5)) return;
      this.P(t5, s5, i6);
    }
    false === this.isUpdatePending && (this._$ES = this._$ET());
  }
  P(t5, s5, i6) {
    this._$AL.has(t5) || this._$AL.set(t5, s5), true === i6.reflect && this._$Em !== t5 && (this._$Ej ?? (this._$Ej = /* @__PURE__ */ new Set())).add(t5);
  }
  async _$ET() {
    this.isUpdatePending = true;
    try {
      await this._$ES;
    } catch (t6) {
      Promise.reject(t6);
    }
    const t5 = this.scheduleUpdate();
    return null != t5 && await t5, !this.isUpdatePending;
  }
  scheduleUpdate() {
    return this.performUpdate();
  }
  performUpdate() {
    var _a3;
    if (!this.isUpdatePending) return;
    if (!this.hasUpdated) {
      if (this.renderRoot ?? (this.renderRoot = this.createRenderRoot()), this._$Ep) {
        for (const [t7, s6] of this._$Ep) this[t7] = s6;
        this._$Ep = void 0;
      }
      const t6 = this.constructor.elementProperties;
      if (t6.size > 0) for (const [s6, i6] of t6) true !== i6.wrapped || this._$AL.has(s6) || void 0 === this[s6] || this.P(s6, this[s6], i6);
    }
    let t5 = false;
    const s5 = this._$AL;
    try {
      t5 = this.shouldUpdate(s5), t5 ? (this.willUpdate(s5), (_a3 = this._$EO) == null ? void 0 : _a3.forEach((t6) => {
        var _a4;
        return (_a4 = t6.hostUpdate) == null ? void 0 : _a4.call(t6);
      }), this.update(s5)) : this._$EU();
    } catch (s6) {
      throw t5 = false, this._$EU(), s6;
    }
    t5 && this._$AE(s5);
  }
  willUpdate(t5) {
  }
  _$AE(t5) {
    var _a3;
    (_a3 = this._$EO) == null ? void 0 : _a3.forEach((t6) => {
      var _a4;
      return (_a4 = t6.hostUpdated) == null ? void 0 : _a4.call(t6);
    }), this.hasUpdated || (this.hasUpdated = true, this.firstUpdated(t5)), this.updated(t5);
  }
  _$EU() {
    this._$AL = /* @__PURE__ */ new Map(), this.isUpdatePending = false;
  }
  get updateComplete() {
    return this.getUpdateComplete();
  }
  getUpdateComplete() {
    return this._$ES;
  }
  shouldUpdate(t5) {
    return true;
  }
  update(t5) {
    this._$Ej && (this._$Ej = this._$Ej.forEach((t6) => this._$EC(t6, this[t6]))), this._$EU();
  }
  updated(t5) {
  }
  firstUpdated(t5) {
  }
};
b.elementStyles = [], b.shadowRootOptions = { mode: "open" }, b[d("elementProperties")] = /* @__PURE__ */ new Map(), b[d("finalized")] = /* @__PURE__ */ new Map(), p == null ? void 0 : p({ ReactiveElement: b }), (a.reactiveElementVersions ?? (a.reactiveElementVersions = [])).push("2.0.4");

// node_modules/lit-html/lit-html.js
var t2 = globalThis;
var i3 = t2.trustedTypes;
var s2 = i3 ? i3.createPolicy("lit-html", { createHTML: (t5) => t5 }) : void 0;
var e3 = "$lit$";
var h2 = `lit$${Math.random().toFixed(9).slice(2)}$`;
var o3 = "?" + h2;
var n3 = `<${o3}>`;
var r3 = document;
var l2 = () => r3.createComment("");
var c3 = (t5) => null === t5 || "object" != typeof t5 && "function" != typeof t5;
var a2 = Array.isArray;
var u2 = (t5) => a2(t5) || "function" == typeof (t5 == null ? void 0 : t5[Symbol.iterator]);
var d2 = "[ 	\n\f\r]";
var f2 = /<(?:(!--|\/[^a-zA-Z])|(\/?[a-zA-Z][^>\s]*)|(\/?$))/g;
var v = /-->/g;
var _ = />/g;
var m = RegExp(`>|${d2}(?:([^\\s"'>=/]+)(${d2}*=${d2}*(?:[^ 	
\f\r"'\`<>=]|("|')|))|$)`, "g");
var p2 = /'/g;
var g = /"/g;
var $3 = /^(?:script|style|textarea|title)$/i;
var y2 = (t5) => (i6, ...s5) => ({ _$litType$: t5, strings: i6, values: s5 });
var x = y2(1);
var b2 = y2(2);
var w = y2(3);
var T = Symbol.for("lit-noChange");
var E = Symbol.for("lit-nothing");
var A = /* @__PURE__ */ new WeakMap();
var C = r3.createTreeWalker(r3, 129);
function P(t5, i6) {
  if (!a2(t5) || !t5.hasOwnProperty("raw")) throw Error("invalid template strings array");
  return void 0 !== s2 ? s2.createHTML(i6) : i6;
}
var V = (t5, i6) => {
  const s5 = t5.length - 1, o7 = [];
  let r7, l3 = 2 === i6 ? "<svg>" : 3 === i6 ? "<math>" : "", c6 = f2;
  for (let i7 = 0; i7 < s5; i7++) {
    const s6 = t5[i7];
    let a3, u5, d3 = -1, y3 = 0;
    for (; y3 < s6.length && (c6.lastIndex = y3, u5 = c6.exec(s6), null !== u5); ) y3 = c6.lastIndex, c6 === f2 ? "!--" === u5[1] ? c6 = v : void 0 !== u5[1] ? c6 = _ : void 0 !== u5[2] ? ($3.test(u5[2]) && (r7 = RegExp("</" + u5[2], "g")), c6 = m) : void 0 !== u5[3] && (c6 = m) : c6 === m ? ">" === u5[0] ? (c6 = r7 ?? f2, d3 = -1) : void 0 === u5[1] ? d3 = -2 : (d3 = c6.lastIndex - u5[2].length, a3 = u5[1], c6 = void 0 === u5[3] ? m : '"' === u5[3] ? g : p2) : c6 === g || c6 === p2 ? c6 = m : c6 === v || c6 === _ ? c6 = f2 : (c6 = m, r7 = void 0);
    const x2 = c6 === m && t5[i7 + 1].startsWith("/>") ? " " : "";
    l3 += c6 === f2 ? s6 + n3 : d3 >= 0 ? (o7.push(a3), s6.slice(0, d3) + e3 + s6.slice(d3) + h2 + x2) : s6 + h2 + (-2 === d3 ? i7 : x2);
  }
  return [P(t5, l3 + (t5[s5] || "<?>") + (2 === i6 ? "</svg>" : 3 === i6 ? "</math>" : "")), o7];
};
var N = class _N {
  constructor({ strings: t5, _$litType$: s5 }, n5) {
    let r7;
    this.parts = [];
    let c6 = 0, a3 = 0;
    const u5 = t5.length - 1, d3 = this.parts, [f5, v3] = V(t5, s5);
    if (this.el = _N.createElement(f5, n5), C.currentNode = this.el.content, 2 === s5 || 3 === s5) {
      const t6 = this.el.content.firstChild;
      t6.replaceWith(...t6.childNodes);
    }
    for (; null !== (r7 = C.nextNode()) && d3.length < u5; ) {
      if (1 === r7.nodeType) {
        if (r7.hasAttributes()) for (const t6 of r7.getAttributeNames()) if (t6.endsWith(e3)) {
          const i6 = v3[a3++], s6 = r7.getAttribute(t6).split(h2), e6 = /([.?@])?(.*)/.exec(i6);
          d3.push({ type: 1, index: c6, name: e6[2], strings: s6, ctor: "." === e6[1] ? H : "?" === e6[1] ? I : "@" === e6[1] ? L : k }), r7.removeAttribute(t6);
        } else t6.startsWith(h2) && (d3.push({ type: 6, index: c6 }), r7.removeAttribute(t6));
        if ($3.test(r7.tagName)) {
          const t6 = r7.textContent.split(h2), s6 = t6.length - 1;
          if (s6 > 0) {
            r7.textContent = i3 ? i3.emptyScript : "";
            for (let i6 = 0; i6 < s6; i6++) r7.append(t6[i6], l2()), C.nextNode(), d3.push({ type: 2, index: ++c6 });
            r7.append(t6[s6], l2());
          }
        }
      } else if (8 === r7.nodeType) if (r7.data === o3) d3.push({ type: 2, index: c6 });
      else {
        let t6 = -1;
        for (; -1 !== (t6 = r7.data.indexOf(h2, t6 + 1)); ) d3.push({ type: 7, index: c6 }), t6 += h2.length - 1;
      }
      c6++;
    }
  }
  static createElement(t5, i6) {
    const s5 = r3.createElement("template");
    return s5.innerHTML = t5, s5;
  }
};
function S2(t5, i6, s5 = t5, e6) {
  var _a3, _b;
  if (i6 === T) return i6;
  let h4 = void 0 !== e6 ? (_a3 = s5._$Co) == null ? void 0 : _a3[e6] : s5._$Cl;
  const o7 = c3(i6) ? void 0 : i6._$litDirective$;
  return (h4 == null ? void 0 : h4.constructor) !== o7 && ((_b = h4 == null ? void 0 : h4._$AO) == null ? void 0 : _b.call(h4, false), void 0 === o7 ? h4 = void 0 : (h4 = new o7(t5), h4._$AT(t5, s5, e6)), void 0 !== e6 ? (s5._$Co ?? (s5._$Co = []))[e6] = h4 : s5._$Cl = h4), void 0 !== h4 && (i6 = S2(t5, h4._$AS(t5, i6.values), h4, e6)), i6;
}
var M = class {
  constructor(t5, i6) {
    this._$AV = [], this._$AN = void 0, this._$AD = t5, this._$AM = i6;
  }
  get parentNode() {
    return this._$AM.parentNode;
  }
  get _$AU() {
    return this._$AM._$AU;
  }
  u(t5) {
    const { el: { content: i6 }, parts: s5 } = this._$AD, e6 = ((t5 == null ? void 0 : t5.creationScope) ?? r3).importNode(i6, true);
    C.currentNode = e6;
    let h4 = C.nextNode(), o7 = 0, n5 = 0, l3 = s5[0];
    for (; void 0 !== l3; ) {
      if (o7 === l3.index) {
        let i7;
        2 === l3.type ? i7 = new R(h4, h4.nextSibling, this, t5) : 1 === l3.type ? i7 = new l3.ctor(h4, l3.name, l3.strings, this, t5) : 6 === l3.type && (i7 = new z(h4, this, t5)), this._$AV.push(i7), l3 = s5[++n5];
      }
      o7 !== (l3 == null ? void 0 : l3.index) && (h4 = C.nextNode(), o7++);
    }
    return C.currentNode = r3, e6;
  }
  p(t5) {
    let i6 = 0;
    for (const s5 of this._$AV) void 0 !== s5 && (void 0 !== s5.strings ? (s5._$AI(t5, s5, i6), i6 += s5.strings.length - 2) : s5._$AI(t5[i6])), i6++;
  }
};
var R = class _R {
  get _$AU() {
    var _a3;
    return ((_a3 = this._$AM) == null ? void 0 : _a3._$AU) ?? this._$Cv;
  }
  constructor(t5, i6, s5, e6) {
    this.type = 2, this._$AH = E, this._$AN = void 0, this._$AA = t5, this._$AB = i6, this._$AM = s5, this.options = e6, this._$Cv = (e6 == null ? void 0 : e6.isConnected) ?? true;
  }
  get parentNode() {
    let t5 = this._$AA.parentNode;
    const i6 = this._$AM;
    return void 0 !== i6 && 11 === (t5 == null ? void 0 : t5.nodeType) && (t5 = i6.parentNode), t5;
  }
  get startNode() {
    return this._$AA;
  }
  get endNode() {
    return this._$AB;
  }
  _$AI(t5, i6 = this) {
    t5 = S2(this, t5, i6), c3(t5) ? t5 === E || null == t5 || "" === t5 ? (this._$AH !== E && this._$AR(), this._$AH = E) : t5 !== this._$AH && t5 !== T && this._(t5) : void 0 !== t5._$litType$ ? this.$(t5) : void 0 !== t5.nodeType ? this.T(t5) : u2(t5) ? this.k(t5) : this._(t5);
  }
  O(t5) {
    return this._$AA.parentNode.insertBefore(t5, this._$AB);
  }
  T(t5) {
    this._$AH !== t5 && (this._$AR(), this._$AH = this.O(t5));
  }
  _(t5) {
    this._$AH !== E && c3(this._$AH) ? this._$AA.nextSibling.data = t5 : this.T(r3.createTextNode(t5)), this._$AH = t5;
  }
  $(t5) {
    var _a3;
    const { values: i6, _$litType$: s5 } = t5, e6 = "number" == typeof s5 ? this._$AC(t5) : (void 0 === s5.el && (s5.el = N.createElement(P(s5.h, s5.h[0]), this.options)), s5);
    if (((_a3 = this._$AH) == null ? void 0 : _a3._$AD) === e6) this._$AH.p(i6);
    else {
      const t6 = new M(e6, this), s6 = t6.u(this.options);
      t6.p(i6), this.T(s6), this._$AH = t6;
    }
  }
  _$AC(t5) {
    let i6 = A.get(t5.strings);
    return void 0 === i6 && A.set(t5.strings, i6 = new N(t5)), i6;
  }
  k(t5) {
    a2(this._$AH) || (this._$AH = [], this._$AR());
    const i6 = this._$AH;
    let s5, e6 = 0;
    for (const h4 of t5) e6 === i6.length ? i6.push(s5 = new _R(this.O(l2()), this.O(l2()), this, this.options)) : s5 = i6[e6], s5._$AI(h4), e6++;
    e6 < i6.length && (this._$AR(s5 && s5._$AB.nextSibling, e6), i6.length = e6);
  }
  _$AR(t5 = this._$AA.nextSibling, i6) {
    var _a3;
    for ((_a3 = this._$AP) == null ? void 0 : _a3.call(this, false, true, i6); t5 && t5 !== this._$AB; ) {
      const i7 = t5.nextSibling;
      t5.remove(), t5 = i7;
    }
  }
  setConnected(t5) {
    var _a3;
    void 0 === this._$AM && (this._$Cv = t5, (_a3 = this._$AP) == null ? void 0 : _a3.call(this, t5));
  }
};
var k = class {
  get tagName() {
    return this.element.tagName;
  }
  get _$AU() {
    return this._$AM._$AU;
  }
  constructor(t5, i6, s5, e6, h4) {
    this.type = 1, this._$AH = E, this._$AN = void 0, this.element = t5, this.name = i6, this._$AM = e6, this.options = h4, s5.length > 2 || "" !== s5[0] || "" !== s5[1] ? (this._$AH = Array(s5.length - 1).fill(new String()), this.strings = s5) : this._$AH = E;
  }
  _$AI(t5, i6 = this, s5, e6) {
    const h4 = this.strings;
    let o7 = false;
    if (void 0 === h4) t5 = S2(this, t5, i6, 0), o7 = !c3(t5) || t5 !== this._$AH && t5 !== T, o7 && (this._$AH = t5);
    else {
      const e7 = t5;
      let n5, r7;
      for (t5 = h4[0], n5 = 0; n5 < h4.length - 1; n5++) r7 = S2(this, e7[s5 + n5], i6, n5), r7 === T && (r7 = this._$AH[n5]), o7 || (o7 = !c3(r7) || r7 !== this._$AH[n5]), r7 === E ? t5 = E : t5 !== E && (t5 += (r7 ?? "") + h4[n5 + 1]), this._$AH[n5] = r7;
    }
    o7 && !e6 && this.j(t5);
  }
  j(t5) {
    t5 === E ? this.element.removeAttribute(this.name) : this.element.setAttribute(this.name, t5 ?? "");
  }
};
var H = class extends k {
  constructor() {
    super(...arguments), this.type = 3;
  }
  j(t5) {
    this.element[this.name] = t5 === E ? void 0 : t5;
  }
};
var I = class extends k {
  constructor() {
    super(...arguments), this.type = 4;
  }
  j(t5) {
    this.element.toggleAttribute(this.name, !!t5 && t5 !== E);
  }
};
var L = class extends k {
  constructor(t5, i6, s5, e6, h4) {
    super(t5, i6, s5, e6, h4), this.type = 5;
  }
  _$AI(t5, i6 = this) {
    if ((t5 = S2(this, t5, i6, 0) ?? E) === T) return;
    const s5 = this._$AH, e6 = t5 === E && s5 !== E || t5.capture !== s5.capture || t5.once !== s5.once || t5.passive !== s5.passive, h4 = t5 !== E && (s5 === E || e6);
    e6 && this.element.removeEventListener(this.name, this, s5), h4 && this.element.addEventListener(this.name, this, t5), this._$AH = t5;
  }
  handleEvent(t5) {
    var _a3;
    "function" == typeof this._$AH ? this._$AH.call(((_a3 = this.options) == null ? void 0 : _a3.host) ?? this.element, t5) : this._$AH.handleEvent(t5);
  }
};
var z = class {
  constructor(t5, i6, s5) {
    this.element = t5, this.type = 6, this._$AN = void 0, this._$AM = i6, this.options = s5;
  }
  get _$AU() {
    return this._$AM._$AU;
  }
  _$AI(t5) {
    S2(this, t5);
  }
};
var Z = { M: e3, P: h2, A: o3, C: 1, L: V, R: M, D: u2, V: S2, I: R, H: k, N: I, U: L, B: H, F: z };
var j = t2.litHtmlPolyfillSupport;
j == null ? void 0 : j(N, R), (t2.litHtmlVersions ?? (t2.litHtmlVersions = [])).push("3.2.1");
var B = (t5, i6, s5) => {
  const e6 = (s5 == null ? void 0 : s5.renderBefore) ?? i6;
  let h4 = e6._$litPart$;
  if (void 0 === h4) {
    const t6 = (s5 == null ? void 0 : s5.renderBefore) ?? null;
    e6._$litPart$ = h4 = new R(i6.insertBefore(l2(), t6), t6, void 0, s5 ?? {});
  }
  return h4._$AI(t5), h4;
};

// node_modules/lit-element/lit-element.js
var r4 = class extends b {
  constructor() {
    super(...arguments), this.renderOptions = { host: this }, this._$Do = void 0;
  }
  createRenderRoot() {
    var _a3;
    const t5 = super.createRenderRoot();
    return (_a3 = this.renderOptions).renderBefore ?? (_a3.renderBefore = t5.firstChild), t5;
  }
  update(t5) {
    const s5 = this.render();
    this.hasUpdated || (this.renderOptions.isConnected = this.isConnected), super.update(t5), this._$Do = B(s5, this.renderRoot, this.renderOptions);
  }
  connectedCallback() {
    var _a3;
    super.connectedCallback(), (_a3 = this._$Do) == null ? void 0 : _a3.setConnected(true);
  }
  disconnectedCallback() {
    var _a3;
    super.disconnectedCallback(), (_a3 = this._$Do) == null ? void 0 : _a3.setConnected(false);
  }
  render() {
    return T;
  }
};
var _a;
r4._$litElement$ = true, r4["finalized"] = true, (_a = globalThis.litElementHydrateSupport) == null ? void 0 : _a.call(globalThis, { LitElement: r4 });
var i4 = globalThis.litElementPolyfillSupport;
i4 == null ? void 0 : i4({ LitElement: r4 });
(globalThis.litElementVersions ?? (globalThis.litElementVersions = [])).push("4.1.1");

// node_modules/lit-html/directive-helpers.js
var { I: t3 } = Z;
var f3 = (o7) => void 0 === o7.strings;
var s3 = () => document.createComment("");
var r5 = (o7, i6, n5) => {
  var _a3;
  const e6 = o7._$AA.parentNode, l3 = void 0 === i6 ? o7._$AB : i6._$AA;
  if (void 0 === n5) {
    const i7 = e6.insertBefore(s3(), l3), c6 = e6.insertBefore(s3(), l3);
    n5 = new t3(i7, c6, o7, o7.options);
  } else {
    const t5 = n5._$AB.nextSibling, i7 = n5._$AM, c6 = i7 !== o7;
    if (c6) {
      let t6;
      (_a3 = n5._$AQ) == null ? void 0 : _a3.call(n5, o7), n5._$AM = o7, void 0 !== n5._$AP && (t6 = o7._$AU) !== i7._$AU && n5._$AP(t6);
    }
    if (t5 !== l3 || c6) {
      let o8 = n5._$AA;
      for (; o8 !== t5; ) {
        const t6 = o8.nextSibling;
        e6.insertBefore(o8, l3), o8 = t6;
      }
    }
  }
  return n5;
};
var v2 = (o7, t5, i6 = o7) => (o7._$AI(t5, i6), o7);
var u3 = {};
var m2 = (o7, t5 = u3) => o7._$AH = t5;
var p3 = (o7) => o7._$AH;
var M2 = (o7) => {
  var _a3;
  (_a3 = o7._$AP) == null ? void 0 : _a3.call(o7, false, true);
  let t5 = o7._$AA;
  const i6 = o7._$AB.nextSibling;
  for (; t5 !== i6; ) {
    const o8 = t5.nextSibling;
    t5.remove(), t5 = o8;
  }
};

// node_modules/lit-html/directive.js
var t4 = { ATTRIBUTE: 1, CHILD: 2, PROPERTY: 3, BOOLEAN_ATTRIBUTE: 4, EVENT: 5, ELEMENT: 6 };
var e4 = (t5) => (...e6) => ({ _$litDirective$: t5, values: e6 });
var i5 = class {
  constructor(t5) {
  }
  get _$AU() {
    return this._$AM._$AU;
  }
  _$AT(t5, e6, i6) {
    this._$Ct = t5, this._$AM = e6, this._$Ci = i6;
  }
  _$AS(t5, e6) {
    return this.update(t5, e6);
  }
  update(t5, e6) {
    return this.render(...e6);
  }
};

// node_modules/lit-html/async-directive.js
var s4 = (i6, t5) => {
  var _a3;
  const e6 = i6._$AN;
  if (void 0 === e6) return false;
  for (const i7 of e6) (_a3 = i7._$AO) == null ? void 0 : _a3.call(i7, t5, false), s4(i7, t5);
  return true;
};
var o4 = (i6) => {
  let t5, e6;
  do {
    if (void 0 === (t5 = i6._$AM)) break;
    e6 = t5._$AN, e6.delete(i6), i6 = t5;
  } while (0 === (e6 == null ? void 0 : e6.size));
};
var r6 = (i6) => {
  for (let t5; t5 = i6._$AM; i6 = t5) {
    let e6 = t5._$AN;
    if (void 0 === e6) t5._$AN = e6 = /* @__PURE__ */ new Set();
    else if (e6.has(i6)) break;
    e6.add(i6), c4(t5);
  }
};
function h3(i6) {
  void 0 !== this._$AN ? (o4(this), this._$AM = i6, r6(this)) : this._$AM = i6;
}
function n4(i6, t5 = false, e6 = 0) {
  const r7 = this._$AH, h4 = this._$AN;
  if (void 0 !== h4 && 0 !== h4.size) if (t5) if (Array.isArray(r7)) for (let i7 = e6; i7 < r7.length; i7++) s4(r7[i7], false), o4(r7[i7]);
  else null != r7 && (s4(r7, false), o4(r7));
  else s4(this, i6);
}
var c4 = (i6) => {
  i6.type == t4.CHILD && (i6._$AP ?? (i6._$AP = n4), i6._$AQ ?? (i6._$AQ = h3));
};
var f4 = class extends i5 {
  constructor() {
    super(...arguments), this._$AN = void 0;
  }
  _$AT(i6, t5, e6) {
    super._$AT(i6, t5, e6), r6(this), this.isConnected = i6._$AU;
  }
  _$AO(i6, t5 = true) {
    var _a3, _b;
    i6 !== this.isConnected && (this.isConnected = i6, i6 ? (_a3 = this.reconnected) == null ? void 0 : _a3.call(this) : (_b = this.disconnected) == null ? void 0 : _b.call(this)), t5 && (s4(this, i6), o4(this));
  }
  setValue(t5) {
    if (f3(this._$Ct)) this._$Ct._$AI(t5, this);
    else {
      const i6 = [...this._$Ct._$AH];
      i6[this._$Ci] = t5, this._$Ct._$AI(i6, this, 0);
    }
  }
  disconnected() {
  }
  reconnected() {
  }
};

// packages/renderer/src/lit/directives/reactive-conditional.js
var ReactiveConditionalDirective = class extends f4 {
  constructor(partInfo) {
    super(partInfo);
    this.reaction = null;
  }
  render(conditional) {
    let matchIndex = -1;
    if (this.reaction) {
      this.reaction.stop();
    }
    let html = E;
    let context = {
      message: `if/else statement: {#if ${conditional.expression}}`,
      conditional
    };
    this.reaction = Reaction.create((comp) => {
      var _a3;
      if (!this.isConnected) {
        comp.stop();
        return;
      }
      let matchIndex2 = -1;
      if (conditional.condition()) {
        html = conditional.content();
        matchIndex2 = 1e3;
      } else if ((_a3 = conditional.branches) == null ? void 0 : _a3.length) {
        each(conditional.branches, (branch, index) => {
          if (matchIndex2 === -1) {
            if (branch.type == "elseif" && branch.condition()) {
              matchIndex2 = index;
              html = branch.content();
            } else if (branch.type == "else") {
              matchIndex2 = index;
              html = branch.content();
            }
          }
        });
      } else {
        html = E;
        delete this.matchIndex;
      }
      if (!html) {
        html = E;
        delete this.matchIndex;
      }
      if (!comp.firstRun && this.matchIndex !== matchIndex2) {
        this.matchIndex = matchIndex2;
        this.setValue(html);
      }
      return html;
    }, { context });
    return html;
  }
  disconnected() {
    if (this.reaction) {
      this.reaction.stop();
      this.reaction = null;
    }
  }
  reconnected() {
  }
};
var reactiveConditional = e4(ReactiveConditionalDirective);

// node_modules/lit-html/directives/if-defined.js
var o5 = (o7) => o7 ?? E;

// node_modules/lit-html/directives/unsafe-html.js
var e5 = class extends i5 {
  constructor(i6) {
    if (super(i6), this.it = E, i6.type !== t4.CHILD) throw Error(this.constructor.directiveName + "() can only be used in child bindings");
  }
  render(r7) {
    if (r7 === E || null == r7) return this._t = void 0, this.it = r7;
    if (r7 === T) return r7;
    if ("string" != typeof r7) throw Error(this.constructor.directiveName + "() called with a non-string value");
    if (r7 === this.it) return this._t;
    this.it = r7;
    const s5 = [r7];
    return s5.raw = s5, this._t = { _$litType$: this.constructor.resultType, strings: s5, values: [] };
  }
};
e5.directiveName = "unsafeHTML", e5.resultType = 1;
var o6 = e4(e5);

// packages/renderer/src/lit/directives/reactive-data.js
var ReactiveDataDirective = class extends f4 {
  constructor(partInfo) {
    super(partInfo);
    this.partInfo = partInfo;
    this.reaction = null;
  }
  render(expression, settings = {}) {
    this.expression = expression;
    this.settings = settings;
    if (expression.expression == "debugReactivity") {
      return this.expression.value();
    }
    if (this.reaction) {
      return this.getReactiveValue();
    } else {
      let value;
      const context = {
        message: `expression: {${expression.expression}}`,
        expression: expression.expression
      };
      this.reaction = Reaction.create((computation) => {
        if (!this.isConnected) {
          computation.stop();
          return;
        }
        value = this.getReactiveValue();
        if (this.settings.unsafeHTML) {
          value = o6(value);
        }
        if (!computation.firstRun) {
          this.setValue(value);
        }
      }, { context });
      return value;
    }
  }
  getReactiveValue() {
    let reactiveValue = this.expression.value();
    if (this.settings.ifDefined) {
      if (inArray(reactiveValue, ["", void 0, null, false, 0])) {
        return o5(void 0);
      }
    }
    if (isArray(reactiveValue) || isObject(reactiveValue)) {
      reactiveValue = JSON.stringify(reactiveValue);
    }
    return reactiveValue;
  }
  disconnected() {
    if (this.reaction) {
      this.reaction.stop();
      this.reaction = null;
    }
  }
  reconnected() {
  }
};
var reactiveData = e4(ReactiveDataDirective);

// node_modules/lit-html/directives/repeat.js
var u4 = (e6, s5, t5) => {
  const r7 = /* @__PURE__ */ new Map();
  for (let l3 = s5; l3 <= t5; l3++) r7.set(e6[l3], l3);
  return r7;
};
var c5 = e4(class extends i5 {
  constructor(e6) {
    if (super(e6), e6.type !== t4.CHILD) throw Error("repeat() can only be used in text expressions");
  }
  dt(e6, s5, t5) {
    let r7;
    void 0 === t5 ? t5 = s5 : void 0 !== s5 && (r7 = s5);
    const l3 = [], o7 = [];
    let i6 = 0;
    for (const s6 of e6) l3[i6] = r7 ? r7(s6, i6) : i6, o7[i6] = t5(s6, i6), i6++;
    return { values: o7, keys: l3 };
  }
  render(e6, s5, t5) {
    return this.dt(e6, s5, t5).values;
  }
  update(s5, [t5, r7, c6]) {
    const d3 = p3(s5), { values: p4, keys: a3 } = this.dt(t5, r7, c6);
    if (!Array.isArray(d3)) return this.ut = a3, p4;
    const h4 = this.ut ?? (this.ut = []), v3 = [];
    let m3, y3, x2 = 0, j2 = d3.length - 1, k2 = 0, w2 = p4.length - 1;
    for (; x2 <= j2 && k2 <= w2; ) if (null === d3[x2]) x2++;
    else if (null === d3[j2]) j2--;
    else if (h4[x2] === a3[k2]) v3[k2] = v2(d3[x2], p4[k2]), x2++, k2++;
    else if (h4[j2] === a3[w2]) v3[w2] = v2(d3[j2], p4[w2]), j2--, w2--;
    else if (h4[x2] === a3[w2]) v3[w2] = v2(d3[x2], p4[w2]), r5(s5, v3[w2 + 1], d3[x2]), x2++, w2--;
    else if (h4[j2] === a3[k2]) v3[k2] = v2(d3[j2], p4[k2]), r5(s5, d3[x2], d3[j2]), j2--, k2++;
    else if (void 0 === m3 && (m3 = u4(a3, k2, w2), y3 = u4(h4, x2, j2)), m3.has(h4[x2])) if (m3.has(h4[j2])) {
      const e6 = y3.get(a3[k2]), t6 = void 0 !== e6 ? d3[e6] : null;
      if (null === t6) {
        const e7 = r5(s5, d3[x2]);
        v2(e7, p4[k2]), v3[k2] = e7;
      } else v3[k2] = v2(t6, p4[k2]), r5(s5, d3[x2], t6), d3[e6] = null;
      k2++;
    } else M2(d3[j2]), j2--;
    else M2(d3[x2]), x2++;
    for (; k2 <= w2; ) {
      const e6 = r5(s5, v3[w2 + 1]);
      v2(e6, p4[k2]), v3[k2++] = e6;
    }
    for (; x2 <= j2; ) {
      const e6 = d3[x2++];
      null !== e6 && M2(e6);
    }
    return this.ut = a3, m2(s5, v3), T;
  }
});

// packages/renderer/src/lit/directives/reactive-each.js
var ReactiveEachDirective = class extends f4 {
  constructor(partInfo) {
    super(partInfo);
    this.reaction = null;
    this.items = [];
    this.eachCondition = null;
  }
  render(eachCondition, settings = {}) {
    this.eachCondition = eachCondition;
    if (this.reaction) {
      this.reaction.stop();
      this.reaction = null;
    }
    let context;
    if (eachCondition.node) {
      let { as, over } = eachCondition.node;
      let context2 = {
        message: `reactive each: {#each ${as} in ${over}}`,
        each: eachCondition.node
      };
    }
    this.reaction = Reaction.create((computation) => {
      if (!this.isConnected) {
        computation.stop();
        return;
      }
      this.items = this.getItems(this.eachCondition);
      if (!computation.firstRun) {
        const rendered = this.renderItems();
        this.setValue(rendered);
      }
    }, { context });
    return this.renderItems();
  }
  renderItems() {
    let items = this.getItems(this.eachCondition);
    if (!(items == null ? void 0 : items.length) > 0 && this.eachCondition.else) {
      return c5(
        [1],
        () => "else-case",
        () => this.eachCondition.else()
      );
    }
    const collectionType = this.getCollectionType(items);
    if (collectionType == "object") {
      items = arrayFromObject(items);
    }
    return c5(
      items,
      (item, indexOrKey) => this.getItemID(item, indexOrKey, collectionType),
      (item, indexOrKey) => this.getTemplate(item, indexOrKey, collectionType)
    );
  }
  getCollectionType(items) {
    if (isArray(items)) {
      return "array";
    }
    return "object";
  }
  getItems() {
    return this.eachCondition.over() || [];
  }
  getTemplate(item, indexOrKey, collectionType) {
    const templateData = this.getEachData(item, indexOrKey, collectionType, this.eachCondition);
    return this.eachCondition.content(templateData);
  }
  getItemID(item, indexOrKey, collectionType) {
    if (isPlainObject(item)) {
      const key = collectionType == "object" ? indexOrKey : void 0;
      return key || item._id || item.id || item.key || item.hash || item._hash || item.value || indexOrKey;
    }
    if (isString(item)) {
      return item;
    }
    return indexOrKey;
  }
  getEachData(item, indexOrKey, collectionType, eachCondition) {
    let { as, indexAs } = eachCondition;
    if (!indexAs) {
      indexAs = collectionType == "array" ? "index" : "key";
    }
    if (collectionType == "object") {
      indexOrKey = item.key;
      item = item.value;
    }
    return as ? { [as]: item, [indexAs]: indexOrKey } : { ...item, this: item, [indexAs]: indexOrKey };
  }
  disconnected() {
    if (this.reaction) {
      this.reaction.stop();
      this.reaction = null;
    }
  }
  reconnected() {
  }
};
var reactiveEach = e4(ReactiveEachDirective);

// packages/renderer/src/lit/directives/render-template.js
var RenderTemplateDirective = class extends f4 {
  constructor(partInfo) {
    var _a3, _b;
    super(partInfo);
    this.renderRoot = (_b = (_a3 = partInfo.options) == null ? void 0 : _a3.host) == null ? void 0 : _b.renderRoot;
    this.template = null;
    this.part = null;
  }
  render({ getTemplate, templateName, subTemplates, data, parentTemplate }) {
    var _a3;
    this.parentTemplate = parentTemplate;
    this.getTemplate = getTemplate;
    this.subTemplates = subTemplates;
    this.data = data;
    this.ast = null;
    this.reaction = Reaction.create((reaction) => {
      this.maybeCreateTemplate();
      const dataContext = this.unpackData(this.data);
      if (!this.isConnected) {
        reaction.stop();
        return;
      }
      if (reaction.firstRun) {
        return;
      }
      const template = this.template;
      if (!template || (template == null ? void 0 : template.ast.length) == 0) {
        return;
      }
      reaction.addContext({
        message: `template ${template == null ? void 0 : template.templateName} data context`,
        dataContext,
        template
      });
      const html = this.renderTemplate(dataContext);
      this.setValue(html);
    });
    this.maybeCreateTemplate();
    if (!this.template || ((_a3 = this.template) == null ? void 0 : _a3.ast.length) == 0) {
      return E;
    }
    return this.renderTemplate();
  }
  renderTemplate(dataContext) {
    this.attachTemplate();
    if (!dataContext) {
      dataContext = this.unpackData(this.data);
    }
    this.template.setDataContext(dataContext);
    return this.template.render();
  }
  maybeCreateTemplate() {
    let templateName;
    let template;
    const templateOrName = this.getTemplate();
    if (isString(templateOrName)) {
      templateName = templateOrName;
      template = this.subTemplates[templateName];
    } else if (templateOrName instanceof Template) {
      template = templateOrName;
      templateName = template.templateName;
    }
    if (!template) {
      return false;
    }
    this.templateID = template.id;
    this.template = template.clone({
      templateName,
      subTemplates: this.subTemplates,
      data: this.unpackData(this.data)
    });
  }
  attachTemplate() {
    var _a3, _b;
    const { parentNode, startNode, endNode } = this.part || {};
    const element = (_b = (_a3 = this.part) == null ? void 0 : _a3.options) == null ? void 0 : _b.host;
    const renderRoot = element == null ? void 0 : element.renderRoot;
    this.template.setElement(element);
    this.template.attach(renderRoot, {
      element,
      parentNode,
      startNode,
      endNode
    });
    if (this.parentTemplate) {
      this.template.setParent(this.parentTemplate);
    }
  }
  unpackData(dataObj) {
    return mapObject(dataObj, (val) => val());
  }
  update(part, settings) {
    this.part = part;
    return this.render.apply(this, settings);
  }
  reconnected() {
  }
  disconnected() {
    if (this.template) {
      this.template.onDestroyed();
    }
  }
};
var renderTemplate = e4(RenderTemplateDirective);

// packages/renderer/src/lit/renderer.js
var _LitRenderer = class _LitRenderer {
  // experimental
  static getID({ ast, data, isSVG } = {}) {
    return hashCode({ ast });
  }
  constructor({ ast, data, template, subTemplates, snippets, helpers, isSVG }) {
    this.ast = ast || "";
    this.data = data;
    this.renderTrees = {};
    this.treeIDs = [];
    this.template = template;
    this.subTemplates = subTemplates;
    this.resetHTML();
    this.snippets = snippets || {};
    this.helpers = helpers || {};
    this.isSVG = isSVG;
    this.id = _LitRenderer.getID({ ast, data, isSVG });
  }
  resetHTML() {
    this.html = [];
    this.html.raw = [];
    this.expressions = [];
  }
  /*
    Creates an AST representation of a template
    this can be cached on the web component class
  */
  render({ ast = this.ast, data = this.data } = {}) {
    this.resetHTML();
    this.readAST({ ast, data });
    this.clearTemp();
    const renderer = this.isSVG ? b2 : x;
    this.litTemplate = renderer.apply(this, [this.html, ...this.expressions]);
    return this.litTemplate;
  }
  cachedRender(data) {
    if (data) {
      this.updateData(data);
    }
    return this.litTemplate;
  }
  readAST({ ast = this.ast, data = this.data } = {}) {
    each(ast, (node) => {
      switch (node.type) {
        case "html":
          this.addHTML(node.html);
          break;
        case "svg":
          this.addValue(this.evaluateSVG(node.content, data));
          break;
        case "expression":
          const value = this.evaluateExpression(node.value, data, {
            unsafeHTML: node.unsafeHTML,
            ifDefined: node.ifDefined,
            asDirective: true
          });
          this.addValue(value);
          break;
        case "if":
          this.addValue(this.evaluateConditional(node, data));
          break;
        case "each":
          this.addValue(this.evaluateEach(node, data));
          break;
        case "template":
          this.addValue(this.evaluateTemplate(node, data));
          break;
        case "snippet":
          this.snippets[node.name] = node;
          break;
        case "slot":
          if (node.name) {
            this.addHTML(`<slot name="${node.name}"></slot>`);
          } else {
            this.addHTML(`<slot></slot>`);
          }
          break;
      }
    });
  }
  /*
    The conditional directive takes an if condition and branches
    but does not have access to LitRenderer and evaluateExpression
    so we have to pass through functions that do this
  */
  evaluateConditional(node, data) {
    const directiveMap = (value, key) => {
      if (key == "branches") {
        return value.map((branch) => {
          if (branch.condition) {
            branch.expression = branch.condition;
          }
          return mapObject(branch, directiveMap);
        });
      }
      if (key == "condition") {
        return () => this.evaluateExpression(value, data);
      }
      if (key == "content") {
        return () => this.renderContent({ ast: value, data });
      }
      return value;
    };
    node.expression = node.condition;
    let conditionalArguments = mapObject(node, directiveMap);
    return reactiveConditional(conditionalArguments);
  }
  /*
    The conditional directive takes an each conditions
    with over() and content(). it needs to
    return reactive values from renderer
  */
  evaluateEach(node, data) {
    const directiveMap = (value, key) => {
      if (key == "over") {
        return (expressionString) => {
          const computedValue = this.evaluateExpression(value, data);
          return computedValue;
        };
      }
      if (key == "content") {
        return (eachData) => {
          data = { ...this.data, ...eachData };
          return this.renderContent({
            ast: value,
            data
          });
        };
      }
      if (key == "else") {
        return (data2) => {
          return this.renderContent({
            ast: value.content,
            data: this.data
          });
        };
      }
      return value;
    };
    let eachArguments = mapObject(node, directiveMap);
    return reactiveEach(eachArguments, data);
  }
  evaluateTemplate(node, data = {}) {
    const templateName = this.lookupExpressionValue(node.name, data);
    if (this.snippets[templateName]) {
      return this.evaluateSnippet(node, data);
    } else {
      return this.evaluateSubTemplate(node, data);
    }
  }
  evaluateSVG(svg, data) {
    return this.renderContent({
      isSVG: true,
      ast: svg,
      data
    });
  }
  // returns a function that returns the value in the current data context
  getPackedValue = (expression, data, { reactive = false } = {}) => {
    const getValue = (expressionString) => {
      const value = this.evaluateExpression(expressionString, data);
      return value;
    };
    return reactive ? () => getValue(expression) : () => Reaction.nonreactive(() => getValue(expression));
  };
  getPackedNodeData(node, data, { inheritParent = false } = {}) {
    const getPackedData = (unpackedData, options = {}) => {
      let packedData = {};
      if (isString(unpackedData)) {
        const expression = unpackedData;
        unpackedData = this.evaluateExpression(expression, data, options);
        packedData = mapObject(unpackedData, wrapFunction);
      } else if (isPlainObject(unpackedData)) {
        packedData = mapObject(unpackedData, (expression) => this.getPackedValue(expression, data, options));
      }
      return packedData;
    };
    const packedStaticData = getPackedData(node.data);
    const packedReactiveData = getPackedData(node.reactiveData, { reactive: true });
    data = {
      ...inheritParent ? this.data : {},
      ...packedStaticData,
      ...packedReactiveData
    };
    return data;
  }
  evaluateSnippet(node, data = {}) {
    const snippetName = this.lookupExpressionValue(node.name, data);
    const snippet = this.snippets[snippetName];
    if (!snippet) {
      fatal(`Snippet "${snippetName}" not found`);
    }
    const snippetData = this.getPackedNodeData(node, data, { inheritParent: true });
    return this.renderContent({
      ast: snippet.content,
      data: snippetData
    });
  }
  evaluateSubTemplate(node, data = {}) {
    const templateData = this.getPackedNodeData(node, data);
    return renderTemplate({
      subTemplates: this.subTemplates,
      templateName: node.name,
      getTemplate: () => this.evaluateExpression(node.name, data),
      // template can be dynamic
      data: templateData,
      parentTemplate: this.template
    });
  }
  // i.e foo.baz = { foo: { baz: 'value' } }
  evaluateExpression(expression, data = this.data, { asDirective = false, ifDefined = false, unsafeHTML = false } = {}) {
    if (typeof expression === "string") {
      if (asDirective) {
        const dataArguments = {
          expression,
          value: () => this.lookupExpressionValue(expression, this.data)
        };
        return reactiveData(dataArguments, { ifDefined, unsafeHTML });
      } else {
        return this.lookupExpressionValue(expression, data);
      }
    }
    return expression;
  }
  // parses an expression like 'maybe (isEven number)' to ['maybe, ['isEven', 'number']]
  // parse parensed expression like `outerFunc (innerJS ? trueCond : falseCond)` -> [outerFunc, jsExpr]
  getExpressionArray(expr) {
    const groups = [];
    const processedExpr = expr.replace(_LitRenderer.PARENS_REGEXP, (match) => {
      const placeholder = `__GROUP${groups.length}__`;
      groups.push(match.slice(1, -1));
      return placeholder;
    });
    const tokens = processedExpr.match(_LitRenderer.TOKEN_REGEXP) || [];
    const getValue = (token) => {
      const match = token.match(/__GROUP(\d+)__/);
      return match ? groups[parseInt(match[1], 10)] : token;
    };
    const parse = (tokens2) => {
      const result = [];
      while (tokens2.length > 0) {
        const token = tokens2.shift();
        if (token === "(") {
          result.push(parse(tokens2));
        } else if (token === ")") {
          return result;
        } else {
          result.push(getValue(token));
        }
      }
      return result;
    };
    const expressions = parse(tokens);
    return expressions;
  }
  // evaluate javascript expressions
  evaluateJavascript(code, context = {}, { includeHelpers = true } = {}) {
    let result;
    if (includeHelpers) {
      context = {
        ...this.helpers,
        ...context
      };
      context = filterObject(context, (value, name) => {
        const reservedWords = ["debugger"];
        return !reservedWords.includes(name) && _LitRenderer.VAR_NAME_REGEXP.test(name);
      });
    }
    try {
      const proxyHandler = {
        has(target, key) {
          if (key in target) {
            return true;
          }
          return false;
        },
        get(target, prop) {
          const value = target[prop];
          if (value instanceof Signal) {
            return value.get();
          }
          if (isFunction(value)) {
            return new Proxy(value, {
              apply(targetFn, thisArg, args) {
                return targetFn.apply(thisArg, args);
              }
            });
          }
          return value;
        }
      };
      const proxiedContext = new Proxy({ ...context }, proxyHandler);
      result = new Function("ctx", `
        with (ctx) {
          return ${code};
        }
      `)(proxiedContext);
      result = new Function(...keys, `return ${code}`)(...values);
    } catch (e6) {
    }
    return result;
  }
  // this evaluates an expression from right determining if something is an argument or a function
  // then looking up the value
  lookupExpressionValue(expression = "", data = {}, visited = /* @__PURE__ */ new Set()) {
    if (visited.has(expression)) {
      return void 0;
    }
    visited.add(expression);
    if (isString(expression)) {
      const value = this.lookupTokenValue(expression, data);
      if (value !== void 0) {
        visited.delete(expression);
        if (visited.size > 0) {
          return value;
        }
        return wrapFunction(value)();
      }
    }
    let expressionArray;
    if (!isArray(expression)) {
      expression = this.addParensToExpression(expression);
      expressionArray = this.getExpressionArray(expression);
    } else {
      expressionArray = expression;
    }
    let funcArguments = [];
    let result;
    let index = expressionArray.length;
    while (index--) {
      const token = expressionArray[index];
      if (isArray(token)) {
        result = this.lookupExpressionValue(token.join(" "), data, visited);
        funcArguments.unshift(result);
      } else {
        const tokenValue = this.lookupExpressionValue(token, data, visited);
        result = isFunction(tokenValue) ? tokenValue(...funcArguments) : tokenValue;
        funcArguments.unshift(result);
      }
    }
    visited.delete(expression);
    return result;
  }
  lookupTokenValue(token = "", data) {
    if (isArray(token)) {
      return this.lookupExpressionValue(token, data);
    }
    const literalValue = this.getLiteralValue(token);
    if (literalValue !== void 0) {
      return literalValue;
    }
    let dataValue = this.getDeepDataValue(data, token);
    let value = this.accessTokenValue(dataValue, token, data);
    if (value !== void 0) {
      return value;
    }
    const jsValue = this.evaluateJavascript(token, data);
    if (jsValue !== void 0) {
      return this.accessTokenValue(jsValue, token, data);
    }
    const helper = this.helpers[token];
    if (isFunction(helper)) {
      return helper;
    }
  }
  getDeepDataValue(obj, path) {
    return path.split(".").reduce((acc, part) => {
      if (acc === void 0) {
        return void 0;
      }
      const current = acc instanceof Signal ? acc.get() : wrapFunction(acc)();
      if (current == void 0) {
        return void 0;
      }
      return current[part];
    }, obj);
  }
  // retrieve token value accessing getter for reactive vars
  accessTokenValue(tokenValue, token, data) {
    const getThisContext = (token2, data2) => {
      const path = token2.split(".").slice(0, -1).join(".");
      return this.getDeepDataValue(data2, path);
    };
    if (isFunction(tokenValue) && token.search(".") !== -1) {
      const thisContext = getThisContext(token, data);
      tokenValue = tokenValue.bind(thisContext);
    }
    if (tokenValue !== void 0) {
      return tokenValue instanceof Signal ? tokenValue.value : tokenValue;
    }
    return void 0;
  }
  addParensToExpression(expression = "") {
    return String(expression).replace(_LitRenderer.WRAPPED_EXPRESSION, (match, before, brackets, after) => {
      return `${before}(${brackets})${after}`;
    });
  }
  getLiteralValue(token) {
    if (token.length > 1 && (token[0] === "'" || token[0] === '"') && token[0] === token[token.length - 1]) {
      return token.slice(1, -1).replace(/\\(['"])/g, "$1");
    }
    const boolString = { true: true, false: false };
    if (boolString[token] !== void 0) {
      return boolString[token];
    }
    if (Number.isFinite(+token)) {
      return Number(token);
    }
  }
  addHTML(html) {
    if (this.lastHTML) {
      const lastHTML = this.html.pop();
      html = `${lastHTML}${html}`;
    }
    this.html.push(html);
    this.html.raw.push(String.raw({ raw: html }));
    this.lastHTML = true;
  }
  addHTMLSpacer() {
    this.addHTML("");
  }
  addValue(expression) {
    this.addHTMLSpacer();
    this.expressions.push(expression);
    this.lastHTML = false;
    this.addHTMLSpacer();
  }
  // subtrees are rendered as separate contexts stored as weakrefs for gc
  renderContent({ ast, data, isSVG = this.isSVG } = {}) {
    const contentID = _LitRenderer.getID({ ast, data, isSVG });
    const treeRef = this.renderTrees[contentID];
    const existingTree = treeRef ? treeRef.deref() : void 0;
    if (_LitRenderer.useSubtreeCache && existingTree) {
      return existingTree.cachedRender(data);
    }
    const tree = new _LitRenderer({
      ast,
      data,
      isSVG,
      subTemplates: this.subTemplates,
      snippets: this.snippets,
      helpers: this.helpers,
      template: this.template
    });
    this.treeIDs.push(contentID);
    this.renderTrees[contentID] = new WeakRef(tree);
    return tree.render();
  }
  cleanup() {
    this.renderTrees = [];
  }
  setData(newData) {
    this.updateData(newData);
    this.updateSubtreeData(newData);
  }
  // yeah we're going there, weakrefs
  updateSubtreeData(newData) {
    each(this.renderTrees, (ref, contentID) => {
      const tree = ref.deref();
      if (tree) {
        tree.updateData(newData);
      }
    });
  }
  /*
    Note this is important to preserve the object reference vs clobbering
    const a = { foo: 'baz' }; const b = a.foo; a.foo = 'bar';
  */
  updateData(newData) {
    each(this.data, (value, name) => {
      delete this.data[name];
    });
    each(newData, (value, name) => {
      if (this.data[name] !== value) {
        this.data[name] = value;
      }
    });
  }
  clearTemp() {
    delete this.lastHTML;
  }
};
__publicField(_LitRenderer, "html", x);
__publicField(_LitRenderer, "PARENS_REGEXP", /\((?:[^()]*|\((?:[^()]*|\([^()]*\))*\))*\)/g);
// match `(one () )` and [`(one)`, `(two)`]
__publicField(_LitRenderer, "TOKEN_REGEXP", /('[^']*'|"[^"]*"|\(|\)|[^\s()]+)/g);
// match "" '', \b for token groups in Lisp style expr
__publicField(_LitRenderer, "WRAPPED_EXPRESSION", /(\s|^)([\[{].*?[\]}])(\s|$)/g);
__publicField(_LitRenderer, "VAR_NAME_REGEXP", /^[a-zA-Z_$][0-9a-zA-Z_$]*$/);
__publicField(_LitRenderer, "useSubtreeCache", false);
var LitRenderer = _LitRenderer;

// packages/templating/src/template.js
var _a2;
var Template = (_a2 = class {
  rendered = false;
  destroyed = false;
  constructor({
    templateName,
    ast,
    template,
    data,
    element,
    renderRoot,
    css,
    events: events3,
    keys: keys3,
    defaultState,
    subTemplates,
    createComponent: createComponent2,
    parentTemplate,
    // the parent template when nested
    renderingEngine = "lit",
    isPrototype = false,
    attachStyles = false,
    // whether to construct css stylesheet and attach to renderRoot
    onCreated: onCreated3 = noop,
    onRendered: onRendered2 = noop,
    onUpdated = noop,
    onDestroyed = noop,
    onThemeChanged = noop
  } = {}) {
    if (!ast) {
      const compiler = new TemplateCompiler(template);
      ast = compiler.compile();
    }
    this.events = events3;
    this.observers = [];
    this.keys = keys3 || {};
    this.ast = ast;
    this.css = css;
    this.data = data || {};
    this.reactions = [];
    this.defaultState = defaultState;
    this.state = this.createReactiveState(defaultState, data) || {};
    this.templateName = templateName || this.getGenericTemplateName();
    this.subTemplates = subTemplates;
    this.createComponent = createComponent2;
    this.onCreated = noop;
    this.onDestroyed = noop;
    this.onRendered = noop;
    this.onRenderedCallback = onRendered2;
    this.onDestroyedCallback = onDestroyed;
    this.onCreatedCallback = onCreated3;
    this.onThemeChangedCallback = onThemeChanged;
    this.id = generateID();
    this.isPrototype = isPrototype;
    this.parentTemplate = parentTemplate;
    this.attachStyles = attachStyles;
    this.element = element;
    this.renderingEngine = renderingEngine;
    if (renderRoot) {
      this.attach(renderRoot);
    }
  }
  createReactiveState(defaultState, data) {
    let reactiveState = {};
    let getInitialValue = (config, name) => {
      const dataValue = get(data, name);
      if (dataValue) {
        return dataValue;
      }
      return (config == null ? void 0 : config.value) || config;
    };
    each(defaultState, (config, name) => {
      const initialValue = getInitialValue(config, name);
      if (config == null ? void 0 : config.options) {
        reactiveState[name] = new Signal(initialValue, config.options);
      } else {
        reactiveState[name] = new Signal(initialValue);
      }
    });
    return reactiveState;
  }
  setDataContext(data, { rerender = true } = {}) {
    this.data = data;
    if (rerender) {
      this.rendered = false;
    }
  }
  // when rendered as a partial/subtemplate
  setParent(parentTemplate) {
    if (!parentTemplate._childTemplates) {
      parentTemplate._childTemplates = [];
    }
    parentTemplate._childTemplates.push(this);
    this.parentTemplate = parentTemplate;
  }
  removeParent() {
    var _a3;
    if (!((_a3 = this.parentTemplate) == null ? void 0 : _a3._childTemplates)) {
      return;
    }
    this.parentTemplate._childTemplates = this.parentTemplate._childTemplates.filter((template) => {
      return template.id !== this.id;
    });
  }
  setElement(element) {
    this.element = element;
  }
  getGenericTemplateName() {
    _a2.templateCount++;
    return `Anonymous #${_a2.templateCount}`;
  }
  initialize() {
    let template = this;
    let instance;
    this.instance = {};
    if (isFunction(this.createComponent)) {
      instance = this.call(this.createComponent) || {};
      extend(template.instance, instance);
    }
    if (isFunction(template.instance.initialize)) {
      this.call(template.instance.initialize.bind(template));
    }
    template.instance.templateName = this.templateName;
    this.onCreated = () => {
      this.call(this.onCreatedCallback);
      _a2.addTemplate(this);
      this.dispatchEvent("created", { component: this.instance }, {}, { triggerCallback: false });
    };
    this.onRendered = () => {
      this.call(this.onRenderedCallback);
      if (isFunction(this.onRenderOnce)) {
        this.onRenderOnce();
        delete this.onRenderOnce;
      }
      this.dispatchEvent("rendered", { component: this.instance }, {}, { triggerCallback: false });
    };
    this.onUpdated = () => {
      this.dispatchEvent("updated", { component: this.instance }, {}, { triggerCallback: false });
    };
    this.onThemeChanged = (...args) => {
      this.call(this.onThemeChangedCallback, ...args);
    };
    this.onDestroyed = () => {
      _a2.removeTemplate(this);
      this.rendered = false;
      this.destroyed = true;
      this.clearReactions();
      this.removeEvents();
      this.removeObservers();
      this.removeParent();
      this.call(this.onDestroyedCallback);
      this.dispatchEvent("destroyed", { component: this.instance }, {}, { triggerCallback: false });
    };
    this.initialized = true;
    if (this.renderingEngine == "lit") {
      this.renderer = new LitRenderer({
        ast: this.ast,
        data: this.getDataContext(),
        template: this,
        subTemplates: this.subTemplates,
        helpers: TemplateHelpers
      });
    } else {
      fatal("Unknown renderer specified", this.renderingEngine);
    }
    this.onCreated();
  }
  async attach(renderRoot, { parentNode = renderRoot, startNode, endNode } = {}) {
    if (!this.initialized) {
      this.initialize();
    }
    if (this.renderRoot == renderRoot) {
      return;
    }
    this.renderRoot = renderRoot;
    this.parentNode = parentNode;
    this.startNode = startNode;
    this.endNode = endNode;
    this.attachEvents();
    this.bindKeys();
    if (this.attachStyles) {
      await this.adoptStylesheet();
    }
  }
  getDataContext() {
    return {
      ...this.data,
      ...this.state,
      ...this.instance
    };
  }
  async adoptStylesheet() {
    if (!this.css) {
      return;
    }
    if (!this.renderRoot || !this.renderRoot.adoptedStyleSheets) {
      return;
    }
    const cssString = this.css;
    if (!this.stylesheet) {
      this.stylesheet = new CSSStyleSheet();
      await this.stylesheet.replace(cssString);
    }
    let styles = Array.from(this.renderRoot.adoptedStyleSheets);
    let hasStyles = styles.some((style) => isEqual(style.cssRules, this.stylesheet.cssRules));
    if (!hasStyles) {
      this.renderRoot.adoptedStyleSheets = [
        ...this.renderRoot.adoptedStyleSheets,
        this.stylesheet
      ];
    }
  }
  clone(settings) {
    const defaultSettings = {
      templateName: this.templateName,
      element: this.element,
      ast: this.ast,
      css: this.css,
      defaultState: this.defaultState,
      events: this.events,
      keys: this.keys,
      renderingEngine: this.renderingEngine,
      subTemplates: this.subTemplates,
      onCreated: this.onCreatedCallback,
      onThemeChanged: this.onThemeChangedCallback,
      onRendered: this.onRenderedCallback,
      parentTemplate: this.parentTemplate,
      onDestroyed: this.onDestroyedCallback,
      createComponent: this.createComponent
    };
    const templateSettings = {
      ...defaultSettings,
      ...settings
    };
    return new _a2(templateSettings);
  }
  parseEventString(eventString) {
    let eventType = "delegate";
    let keywords = ["deep", "global", "bind"];
    each(keywords, (keyword) => {
      if (eventString.startsWith(keyword)) {
        eventString = eventString.replace(keyword, "");
        eventType = keyword;
      }
    });
    eventString = eventString.trim();
    const getBubbledEvent = (eventName) => {
      const bubbleMap = {
        blur: "focusout",
        focus: "focusin",
        load: "DOMContentLoaded",
        unload: "beforeunload",
        mouseenter: "mouseover",
        mouseleave: "mouseout"
      };
      if (bubbleMap[eventName]) {
        eventName = bubbleMap[eventName];
      }
      return eventName;
    };
    let events3 = [];
    let parts = eventString.split(/\s+/);
    let addedEvents = false;
    let addedSelectors = false;
    const eventNames = [];
    const selectors = [];
    each(parts, (part, index) => {
      const value = part.replace(/(\,|\W)+$/, "").trim();
      const hasComma = part.includes(",");
      if (!addedEvents) {
        eventNames.push(getBubbledEvent(value));
        addedEvents = !hasComma;
      } else if (!addedSelectors) {
        const selectorParts = parts.slice(index).join(" ").split(",");
        each(selectorParts, (value2) => {
          selectors.push(value2.trim());
        });
        addedSelectors = true;
      }
    });
    each(eventNames, (eventName) => {
      if (!selectors.length) {
        selectors.push("");
      }
      each(selectors, (selector) => {
        events3.push({ eventName, eventType, selector });
      });
    });
    return events3;
  }
  attachEvents(events3 = this.events) {
    if (!this.parentNode || !this.renderRoot) {
      fatal("You must set a parent before attaching events");
    }
    this.removeEvents();
    this.eventController = new AbortController();
    if (!_a2.isServer && this.onThemeChangedCallback !== noop) {
      const observer = new MutationObserver(this.onThemeChanged);
      observer.observe(document.documentElement, {
        attributes: true,
        attributeFilter: ["class"]
      });
      this.observers.push(observer);
      $2("html").on("themechange", (event) => {
        this.onThemeChanged({
          additionalData: {
            event,
            ...event.detail
          }
        });
      }, { abortController: this.eventController });
    }
    each(events3, (userHandler, eventString) => {
      const subEvents = this.parseEventString(eventString);
      const template = this;
      each(subEvents, (event) => {
        const { eventName, selector, eventType } = event;
        if (selector) {
          $2(selector, { root: this.renderRoot }).on(eventName, noop, { abortController: this.eventController });
        }
        const eventHandler = function(event2) {
          var _a3, _b;
          if (eventType !== "global" && !template.isNodeInTemplate(event2.target)) {
            return;
          }
          const isDeep = selector && $2(event2.target).closest(selector).length == 0;
          if (!inArray(eventType, ["deep", "global"]) && isDeep) {
            return;
          }
          if (inArray(eventName, ["mouseover", "mouseout"]) && event2.relatedTarget && event2.target.contains(event2.relatedTarget)) {
            return;
          }
          const targetElement = this;
          const boundEvent = userHandler.bind(targetElement);
          const eventData = (event2 == null ? void 0 : event2.detail) || {};
          const elData = mapObject({ ...targetElement == null ? void 0 : targetElement.dataset }, (stringValue) => {
            let value;
            try {
              value = JSON.parse(stringValue);
            } catch (e6) {
              value = stringValue;
            }
            return value;
          });
          const elValue = (targetElement == null ? void 0 : targetElement.value) || ((_a3 = event2.target) == null ? void 0 : _a3.value) || ((_b = event2 == null ? void 0 : event2.detail) == null ? void 0 : _b.value);
          template.call(boundEvent, {
            additionalData: {
              event: event2,
              isDeep,
              target: targetElement,
              value: elValue,
              data: {
                ...elData,
                ...eventData
              }
            }
          });
        };
        const eventSettings = { abortController: this.eventController };
        if (eventType == "global") {
          $2(selector).on(eventName, eventHandler, eventSettings);
        } else if (eventType == "bind") {
          this.onRenderOnce = () => {
            this.$(selector).on(eventName, eventHandler, eventSettings);
            wrapFunction(this.onRenderOnce);
          };
        } else {
          $2(this.renderRoot).on(eventName, selector, eventHandler, eventSettings);
        }
      });
    });
  }
  removeEvents() {
    if (this.eventController) {
      this.eventController.abort("Template destroyed");
    }
  }
  removeObservers() {
    each(this.observers, (observer) => {
      observer.disconnect();
    });
  }
  bindKeys(keys3 = this.keys) {
    if (isServer) {
      return;
    }
    if (Object.keys(keys3).length == 0) {
      return;
    }
    const sequenceTimeout = 500;
    const eventSettings = { abortController: this.eventController };
    this.currentSequence = "";
    $2(document).on("keydown", (event) => {
      const key = getKeyFromEvent(event);
      let repeatedKey = key == this.currentKey;
      this.currentKey = key;
      this.currentSequence += key;
      each(this.keys, (handler, keySequence) => {
        keySequence = keySequence.replace(/\s*\+\s*/g, "+");
        const keySequences = keySequence.split(",");
        if (any(keySequences, (sequence) => this.currentSequence.endsWith(sequence))) {
          const inputFocused = document.activeElement && (["input", "select", "textarea"].includes(document.activeElement.tagName.toLowerCase()) || document.activeElement.isContentEditable);
          const eventResult = this.call(handler, {
            additionalData: {
              event,
              inputFocused,
              repeatedKey
            }
          });
          if (eventResult !== true) {
            event.preventDefault();
          }
        }
      });
      this.currentSequence += " ";
      clearTimeout(this.resetSequence);
      this.resetSequence = setTimeout(() => {
        this.currentSequence = "";
      }, sequenceTimeout);
    }, eventSettings).on("keyup", (event) => {
      this.currentKey = "";
    }, eventSettings);
  }
  bindKey(key, callback) {
    if (!key || !callback) {
      return;
    }
    const needsInit = Object.keys(this.keys).length == 0;
    this.keys[key] = callback;
    if (needsInit) {
      this.bindKeys();
    }
  }
  unbindKey(key) {
    delete this.keys[key];
  }
  // Find the direct child of the renderRoot that is an ancestor of the event.target
  // then confirm position
  isNodeInTemplate(node) {
    const getRootChild = (node2) => {
      while (node2 && node2.parentNode !== this.parentNode) {
        if (node2.parentNode === null && node2.host) {
          node2 = node2.host;
        } else {
          node2 = node2.parentNode;
        }
      }
      return node2;
    };
    const isNodeInRange = (node2, startNode = this.startNode, endNode = this.endNode) => {
      if (!startNode || !endNode) {
        return true;
      }
      if (node2 === null) {
        return false;
      }
      const startComparison = startNode.compareDocumentPosition(node2);
      const endComparison = endNode.compareDocumentPosition(node2);
      const isAfterStart = (startComparison & Node.DOCUMENT_POSITION_FOLLOWING) !== 0;
      const isBeforeEnd = (endComparison & Node.DOCUMENT_POSITION_PRECEDING) !== 0;
      return isAfterStart && isBeforeEnd;
    };
    return isNodeInRange(getRootChild(node));
  }
  render(additionalData = {}) {
    if (!this.initialized) {
      this.initialize();
    }
    const dataContext = {
      ...this.getDataContext(),
      ...additionalData
    };
    this.setDataContext(dataContext, { rerender: false });
    this.renderer.setData(dataContext);
    if (!this.rendered) {
      this.html = this.renderer.render();
      setTimeout(this.onRendered, 0);
    }
    this.rendered = true;
    this.destroyed = false;
    setTimeout(this.onUpdated, 0);
    return this.html;
  }
  /*******************************
             DOM Helpers
  *******************************/
  // Rendered DOM (either shadow or regular)
  $(selector, { root = this.renderRoot, filterTemplate = true, ...otherArgs } = {}) {
    if (!_a2.isServer && inArray(selector, ["body", "document", "html"])) {
      root = document;
    }
    if (!root) {
      root = globalThis;
    }
    if (root == this.renderRoot) {
      const $results = $2(selector, { root, ...otherArgs });
      return filterTemplate ? $results.filter((node) => this.isNodeInTemplate(node)) : $results;
    } else {
      return $2(selector, { root, ...otherArgs });
    }
  }
  $$(selector, args) {
    return this.$(selector, { root: this.renderRoot, pierceShadow: true, filterTemplate: true, ...args });
  }
  // calls callback if defined with consistent params and this context
  call(func, { params, additionalData = {}, firstArg, additionalArgs } = {}) {
    var _a3;
    const args = [];
    if (this.isPrototype) {
      return;
    }
    if (!params) {
      const element = this.element;
      params = {
        el: this.element,
        // provide 3 options for referring to self
        tpl: this.instance,
        self: this.instance,
        component: this.instance,
        $: this.$.bind(this),
        $$: this.$$.bind(this),
        reaction: this.reaction.bind(this),
        signal: this.signal.bind(this),
        afterFlush: Reaction.afterFlush,
        nonreactive: Reaction.nonreactive,
        flush: Reaction.flush,
        data: this.data,
        settings: (_a3 = this.element) == null ? void 0 : _a3.settings,
        state: this.state,
        isRendered: () => this.rendered,
        isServer: _a2.isServer,
        isClient: !_a2.isServer,
        dispatchEvent: this.dispatchEvent.bind(this),
        attachEvent: this.attachEvent.bind(this),
        bindKey: this.bindKey.bind(this),
        unbindKey: this.unbindKey.bind(this),
        abortController: this.eventController,
        helpers: TemplateHelpers,
        template: this,
        templateName: this.templateName,
        templates: _a2.renderedTemplates,
        findTemplate: this.findTemplate,
        findParent: this.findParent.bind(this),
        findChild: this.findChild.bind(this),
        findChildren: this.findChildren.bind(this),
        // not yet implemented
        content: this.instance.content,
        // on demand since forces recalculateStyle on body
        get darkMode() {
          return element.isDarkMode();
        },
        ...additionalData
      };
      args.push(params);
    }
    if (additionalArgs) {
      args.push(...additionalArgs);
    }
    if (isFunction(func)) {
      return func.apply(this.element, args);
    }
  }
  // attaches an external event handler making sure to remove the event when the component is destroyed
  attachEvent(selector, eventName, eventHandler, { eventSettings = {}, querySettings = { pierceShadow: true } } = {}) {
    return $2(selector, document, querySettings).on(eventName, eventHandler, {
      abortController: this.eventController,
      returnHandler: true,
      ...eventSettings
    });
  }
  // dispatches an event from this template
  dispatchEvent(eventName, eventData, eventSettings, { triggerCallback = true } = {}) {
    if (_a2.isServer) {
      return;
    }
    if (triggerCallback) {
      const callbackName = `on${capitalize(eventName)}`;
      const callback = this.element[callbackName];
      wrapFunction(callback).call(this.element, eventData);
    }
    return $2(this.element).dispatchEvent(eventName, eventData, eventSettings);
  }
  /*******************************
          Reactive Helpers
  *******************************/
  // reactions bound with this.reaction will be scoped to template
  // and be removed when the template is destroyed
  reaction(reaction) {
    this.reactions.push(Reaction.create(reaction));
  }
  signal(value, options) {
    return new Signal(value, options);
  }
  clearReactions() {
    each(this.reactions || [], (comp) => comp.stop());
  }
  /*******************************
          Template Helpers
  *******************************/
  findTemplate = (templateName) => _a2.findTemplate(templateName);
  findParent = (templateName) => _a2.findParentTemplate(this, templateName);
  findChild = (templateName) => _a2.findChildTemplate(this, templateName);
  findChildren = (templateName) => _a2.findChildTemplates(this, templateName);
  static addTemplate(template) {
    if (template.isPrototype) {
      return;
    }
    let templates = _a2.renderedTemplates.get(template.templateName) || [];
    templates.push(template);
    _a2.renderedTemplates.set(template.templateName, templates);
  }
  static removeTemplate(template) {
    if (template.isPrototype) {
      return;
    }
    let templates = _a2.renderedTemplates.get(template.templateName) || [];
    remove(templates, (thisTemplate) => thisTemplate.id == template.id);
    _a2.renderedTemplates.set(templates);
  }
  static getTemplates(templateName) {
    return _a2.renderedTemplates.get(templateName) || [];
  }
  static findTemplate(templateName) {
    return _a2.getTemplates(templateName)[0];
  }
  static findParentTemplate(template, templateName) {
    var _a3;
    let match;
    const isMatch = (component) => {
      if (match || !(component == null ? void 0 : component.templateName)) {
        return false;
      }
      if (templateName && (component == null ? void 0 : component.templateName) !== templateName) {
        return false;
      }
      return true;
    };
    if (!match) {
      let parentNode = (_a3 = template.element) == null ? void 0 : _a3.parentNode;
      while (parentNode) {
        if (isMatch(parentNode.component)) {
          match = {
            ...parentNode.component,
            ...parentNode.dataContext
          };
          break;
        }
        parentNode = parentNode.parentNode;
      }
    }
    while (template) {
      template = template.parentTemplate;
      if (isMatch(template)) {
        match = {
          ...template.instance,
          ...template.data
        };
        break;
      }
    }
    return match;
  }
  static findChildTemplates(template, templateName) {
    let result = [];
    function search(template2, templateName2) {
      if (!templateName2 || template2.templateName === templateName2) {
        result.push({
          ...template2.instance,
          ...template2.data
        });
      }
      if (template2._childTemplates) {
        template2._childTemplates.forEach((childTemplate) => {
          search(childTemplate, templateName2);
        });
      }
    }
    search(template, templateName);
    return result;
  }
  static findChildTemplate(template, templateName) {
    return _a2.findChildTemplates(template, templateName)[0];
  }
}, __publicField(_a2, "templateCount", 0), __publicField(_a2, "isServer", isServer), __publicField(_a2, "renderedTemplates", /* @__PURE__ */ new Map()), _a2);

// packages/component/src/helpers/adjust-property-from-attribute.js
var SPACE_REGEX = /\s+/mg;
var SPECIAL_ATTRIBUTES = ["disabled", "value"];
var reverseDashes = (string) => {
  if (isString(string)) {
    return string.split("-").reverse().join("-");
  }
  return string;
};
var tokenizeSpaces = (string) => {
  if (isString(string)) {
    return string.replaceAll(SPACE_REGEX, "-");
  }
  return string;
};
var adjustPropertyFromAttribute = ({ el, attribute, attributeValue, properties, componentSpec, oldValue }) => {
  var _a3;
  const checkSpecForAllowedValue = ({ attribute: attribute2, optionValue, optionAttributeValue }) => {
    optionValue = tokenizeSpaces(optionValue);
    let optionsToCheck = [optionValue];
    if (attribute2 && optionValue) {
      optionsToCheck.push(`${attribute2}-${attributeValue}`);
      optionsToCheck.push(`${attributeValue}-${attribute2}`);
    }
    optionsToCheck.push(reverseDashes(optionValue));
    optionsToCheck = unique(optionsToCheck);
    const matchingValue = firstMatch(
      optionsToCheck,
      (currentValue) => get(componentSpec.optionAttributes, currentValue)
    );
    if (!matchingValue) {
      return { matchingAttribute: void 0, matchingValue: void 0 };
    }
    if (inArray(attributeValue == null ? void 0 : attributeValue.constructor, [Object, Array, Function])) {
      return { matchingAttribute: void 0, matchingValue: void 0 };
    }
    const matchingAttribute = get(componentSpec.optionAttributes, matchingValue);
    return { matchingAttribute, matchingValue };
  };
  const setProperty = (attribute2, value) => {
    const property = kebabToCamel(attribute2);
    if (value !== void 0) {
      el[property] = value;
    }
    if (inArray(attribute2, SPECIAL_ATTRIBUTES)) {
      el.requestUpdate();
    }
  };
  const removeProperty = (attribute2) => {
    const property = kebabToCamel(attribute2);
    el[property] = null;
    if (inArray(attribute2, SPECIAL_ATTRIBUTES)) {
      el.requestUpdate();
    }
  };
  const isBooleanValue = (attribute2, attributeValue2) => {
    var _a4;
    const isBooleanType = componentSpec.propertyTypes[attribute2] == Boolean;
    const isIdentityBoolean = ((_a4 = componentSpec.optionAttributes) == null ? void 0 : _a4[attribute2]) == attribute2;
    const isAttributeClass = inArray(attribute2, componentSpec.attributeClasses);
    return (isBooleanType || isAttributeClass || isIdentityBoolean) && inArray(attributeValue2, ["", true, attribute2]);
  };
  if (componentSpec) {
    if (attribute == "class" && attributeValue) {
      const previousClasses = isString(oldValue) ? oldValue.split(" ") : [];
      const currentClasses = attributeValue.split(" ");
      const classesToRemove = difference(previousClasses, currentClasses);
      const classesToAdd = difference(currentClasses, previousClasses);
      each(classesToRemove, (className) => {
        adjustPropertyFromAttribute({
          el,
          attribute: className,
          attributeValue: null,
          componentSpec
        });
      });
      each(classesToAdd, (className) => {
        adjustPropertyFromAttribute({
          el,
          attribute: className,
          attributeValue: true,
          componentSpec
        });
      });
    } else if (inArray(attribute, componentSpec.attributes)) {
      if (isBooleanValue(attribute, attributeValue)) {
        attributeValue = true;
        setProperty(attribute, attributeValue);
        return;
      }
      if (attributeValue === null) {
        removeProperty(attribute);
        return;
      }
      const { matchingValue } = checkSpecForAllowedValue({
        attribute,
        optionValue: attributeValue
      });
      if (matchingValue) {
        setProperty(attribute, matchingValue);
      }
    } else if (attributeValue !== void 0) {
      const { matchingAttribute, matchingValue } = checkSpecForAllowedValue({
        optionValue: attribute,
        optionAttributeValue: attributeValue
      });
      if (matchingAttribute && attributeValue === null) {
        if (el[matchingAttribute] == attribute) {
          removeProperty(matchingAttribute);
        }
        return;
      }
      if (matchingAttribute && matchingValue) {
        setProperty(matchingAttribute, matchingValue);
      }
    }
  } else if (properties && attributeValue !== void 0 && attribute.includes("-")) {
    const propertyName = kebabToCamel(attribute);
    const attributeSettings = properties[attribute];
    if (propertyName !== attribute && (attributeSettings == null ? void 0 : attributeSettings.alias)) {
      const convertFunc = (_a3 = attributeSettings == null ? void 0 : attributeSettings.converter) == null ? void 0 : _a3.fromAttribute;
      let propertyValue = convertFunc ? convertFunc(attributeValue) : attributeValue;
      if (propertyValue) {
        setProperty(propertyName, propertyValue);
      }
      return;
    }
  }
};

// packages/component/src/web-component.js
var _WebComponentBase = class _WebComponentBase extends r4 {
  constructor() {
    super();
    this.renderCallbacks = [];
  }
  updated() {
    super.updated();
    each(this.renderCallbacks, (callback) => callback());
  }
  addRenderCallback(callback) {
    this.renderCallbacks.push(callback);
  }
  /*******************************
           Lit Properties
  *******************************/
  static getProperties({ properties = {}, defaultSettings, componentSpec }) {
    if (keys2(properties).length) {
      return properties;
    }
    if (componentSpec) {
      properties.class = { type: String, noAccessor: true, alias: true };
      each(componentSpec.attributes, (attributeName) => {
        const propertyType = componentSpec.propertyTypes[attributeName];
        const propertyName = kebabToCamel(attributeName);
        properties[propertyName] = _WebComponentBase.getPropertySettings({
          name: attributeName,
          type: propertyType
        });
      });
      each(componentSpec.properties, (attributeName) => {
        const propertyType = componentSpec.propertyTypes[attributeName];
        const propertyName = kebabToCamel(attributeName);
        properties[propertyName] = _WebComponentBase.getPropertySettings({
          name: attributeName,
          type: propertyType
        });
      });
      each(componentSpec.optionAttributes, (attributeValues, attributeName) => {
        const propertyName = kebabToCamel(attributeName);
        properties[propertyName] = { type: String, noAccessor: true, alias: true, attribute: attributeName };
      });
    }
    if (defaultSettings) {
      each(defaultSettings, (defaultValue, propertyName) => {
        properties[propertyName] = (defaultValue == null ? void 0 : defaultValue.type) ? defaultSettings : _WebComponentBase.getPropertySettings({
          name: propertyName,
          type: defaultValue == null ? void 0 : defaultValue.constructor,
          propertyOnly: isClassInstance(defaultValue)
          // cant serialize custom classes
        });
      });
    }
    each(properties, (propertySettings, propertyName) => {
      const attributeName = camelToKebab(propertyName);
      if (attributeName !== propertyName && !properties[attributeName] && properties[propertyName]) {
        properties[attributeName] = {
          ...properties[propertyName],
          noAccessor: true,
          alias: true
        };
      }
    });
    const specialAttrs = ["value", "checked"];
    each(specialAttrs, (attr) => {
      if (properties[attr]) {
      }
    });
    return properties;
  }
  static getPropertySettings({ name, type = String, propertyOnly = false } = {}) {
    if (isString(type)) {
      const types = {
        string: String,
        number: Number,
        boolean: Boolean,
        object: Object,
        array: Array,
        function: Function
      };
      type = types[type] || String;
    }
    let property = {
      type,
      attribute: true,
      hasChanged: (a3, b3) => {
        return !isEqual(a3, b3);
      }
    };
    if (propertyOnly || type == Function) {
      property.attribute = false;
      property.hasChanged = (newVal, oldVal) => {
        return true;
      };
    } else if (type == Boolean) {
      property.converter = {
        fromAttribute: (value, type2) => {
          if (inArray(value, ["false", "0", "null", "undefined"])) {
            return false;
          }
          if (inArray(value, ["", true, "true"])) {
            return true;
          }
          return Boolean(value);
        },
        toAttribute: (value, type2) => {
          return String(value);
        }
      };
    }
    return property;
  }
  /*******************************
      Settings / Template Data
  *******************************/
  /*
    This sets default settings for a component
  */
  setDefaultSettings({ defaultSettings = {}, componentSpec }) {
    this.defaultSettings = defaultSettings;
    each(defaultSettings, (setting, name) => {
      if ((setting == null ? void 0 : setting.default) !== void 0) {
        this.defaultSettings[name] = setting.default;
      } else {
        this.defaultSettings[name] = setting;
      }
    });
    if (componentSpec == null ? void 0 : componentSpec.defaultValues) {
      this.defaultSettings = {
        ...componentSpec.defaultValues,
        ...this.defaultSettings
      };
    }
  }
  /*
    This returns a list of settings which may include both attributes and properties
    as specified in the spec for the component. It will extend them from default settings
  */
  getSettingsFromConfig({ componentSpec, properties }) {
    let settings = {};
    each(properties, (propSettings, propertyName) => {
      if (propSettings.alias === true) {
        return;
      }
      const elementProp = this[propertyName];
      const setting = elementProp ?? this.defaultSettings[propertyName] ?? ((componentSpec == null ? void 0 : componentSpec.defaultSettings) || {})[propertyName];
      if (setting !== void 0) {
        settings[propertyName] = setting;
      }
      if (componentSpec && settings[elementProp] !== void 0) {
        settings[propertyName] = true;
      }
    });
    return settings;
  }
  /* Create a proxy object which returns the current setting
     we need this over a getter/setter because settings are
     destructured in function arguments which locks their value in time
     i.e. onCreated({settings}) { }
  */
  createSettingsProxy({ componentSpec, properties }) {
    let component = this;
    component.settingsVars = /* @__PURE__ */ new Map();
    return new Proxy({}, {
      get: (target, property) => {
        const settings = component.getSettings({
          componentSpec,
          properties
        });
        const setting = get(settings, property);
        let signal = component.settingsVars.get(property);
        if (signal) {
          signal.get();
        } else {
          signal = new Signal(setting);
          component.settingsVars.set(property, signal);
        }
        return setting;
      },
      set: (target, property, value, receiver) => {
        component.setSetting(property, value);
        let signal = component.settingsVars.get(property);
        if (signal) {
          signal.set(value);
        } else {
          signal = new Signal(value);
          component.settingsVars.set(property, signal);
        }
        return true;
      }
    });
  }
  /*
    This returns a list of styling classes to pass through to
    the template data context for the component based off
    component attributes
  */
  getUIClasses({ componentSpec, properties }) {
    if (!componentSpec) {
      return;
    }
    const classes = [];
    each(componentSpec.attributes, (attribute) => {
      var _a3, _b;
      const property = kebabToCamel(attribute);
      const value = this[property] || this[attribute];
      if (value) {
        const allowedValues = (_a3 = componentSpec.allowedValues) == null ? void 0 : _a3[attribute];
        const propertyType = (_b = componentSpec.propertyTypes) == null ? void 0 : _b[attribute];
        if (propertyType == "boolean") {
          classes.push(attribute);
        } else if (value == attribute && allowedValues && inArray(value, allowedValues)) {
          classes.push(attribute);
        } else if (allowedValues && inArray(value, allowedValues)) {
          classes.push(value);
        }
        if ((componentSpec.attributeClasses || []).includes(attribute)) {
          classes.push(attribute);
        }
      }
    });
    let classString = unique(classes).join(" ");
    if (classString) {
      classString += " ";
    }
    return classString;
  }
  isDarkMode() {
    return isServer ? void 0 : $2(this).cssVar("dark-mode") == "true" || $2("html").hasClass("dark");
  }
  /*******************************
            DOM Helpers
  *******************************/
  // Rendered DOM (either shadow or regular)
  $(selector, { root = (this == null ? void 0 : this.renderRoot) || this.shadowRoot } = {}) {
    if (!root) {
      console.error("Cannot query DOM until element has rendered.");
    }
    return $2(selector, { root });
  }
  // Original DOM (used for pulling slotted text)
  $$(selector) {
    return $2(selector, { root: this.originalDOM.content });
  }
  // calls callback if defined with consistent params and this context
  call(func, { firstArg, additionalArgs, args = [this.component, this.$.bind(this)] } = {}) {
    if (firstArg) {
      args.unshift(firstArg);
    }
    if (additionalArgs) {
      args.push(...additionalArgs);
    }
    if (isFunction(func)) {
      return func.apply(this, args);
    }
  }
};
__publicField(_WebComponentBase, "shadowRootOptions", { ...r4.shadowRootOptions, delegatesFocus: false });
// for use with light dom rendering
__publicField(_WebComponentBase, "scopedStyleSheet", null);
var WebComponentBase = _WebComponentBase;

// packages/component/src/define-component.js
var defineComponent = ({
  template = "",
  ast,
  css = "",
  pageCSS = "",
  tagName,
  delegatesFocus = false,
  templateName = kebabToCamel(tagName),
  createComponent: createComponent2 = noop,
  events: events3 = {},
  // event bindings
  keys: keys3 = {},
  // key bindings
  onCreated: onCreated3 = noop,
  onRendered: onRendered2 = noop,
  onDestroyed = noop,
  onThemeChanged = noop,
  onAttributeChanged = noop,
  defaultSettings = {},
  defaultState = {},
  subTemplates = {},
  renderingEngine,
  properties,
  // allow overriding web component properties
  // only used by components that provide a spec
  componentSpec = false,
  plural = false,
  singularTag
} = {}) => {
  var _a3;
  if (!ast) {
    const compiler = new TemplateCompiler(template);
    ast = compiler.compile();
  }
  each(subTemplates, (template2) => {
    if (template2.css) {
      css += template2.css;
    }
  });
  if (pageCSS) {
    adoptStylesheet(pageCSS);
  }
  let litTemplate = new Template({
    templateName,
    isPrototype: true,
    renderingEngine,
    ast,
    css,
    events: events3,
    keys: keys3,
    defaultState,
    subTemplates,
    onCreated: onCreated3,
    onRendered: onRendered2,
    onDestroyed,
    onThemeChanged,
    createComponent: createComponent2
  });
  let webComponent;
  if (tagName) {
    webComponent = (_a3 = class extends WebComponentBase {
      static get styles() {
        return r(css);
      }
      defaultSettings = {};
      constructor() {
        super();
        this.css = css;
        this.componentSpec = componentSpec;
        this.settings = this.createSettingsProxy({ componentSpec, properties: webComponent.properties });
        this.setDefaultSettings({ defaultSettings, componentSpec });
      }
      // callback when added to dom
      connectedCallback() {
        super.connectedCallback();
      }
      triggerAttributeChange() {
        each(webComponent.properties, (propSettings, property) => {
          const attribute = camelToKebab(property);
          let newValue = this[property];
          if (!propSettings.alias && attribute && newValue === true) {
            this.setAttribute(attribute, "");
          }
          adjustPropertyFromAttribute({
            el: this,
            attribute,
            properties: webComponent.properties,
            attributeValue: newValue,
            componentSpec
          });
        });
      }
      willUpdate() {
        if (isServer) {
          this.triggerAttributeChange();
        }
        if (!this.template) {
          this.template = litTemplate.clone({
            data: this.getData(),
            element: this,
            renderRoot: this.renderRoot
          });
          if (!this.template.initialized) {
            this.template.initialize();
          }
          this.component = this.template.instance;
          this.dataContext = this.template.data;
        }
        super.willUpdate();
      }
      firstUpdated() {
        super.firstUpdated();
      }
      updated() {
        super.updated();
      }
      // callback if removed from dom
      disconnectedCallback() {
        super.disconnectedCallback();
        if (this.template) {
          this.template.onDestroyed();
        }
        litTemplate.onDestroyed();
      }
      // callback if moves doc
      adoptedCallback() {
        super.adoptedCallback();
        this.call(onMoved);
      }
      attributeChangedCallback(attribute, oldValue, newValue) {
        super.attributeChangedCallback(attribute, oldValue, newValue);
        adjustPropertyFromAttribute({
          el: this,
          attribute,
          attributeValue: newValue,
          properties: webComponent.properties,
          oldValue,
          componentSpec
        });
        this.call(onAttributeChanged, { args: [attribute, oldValue, newValue] });
      }
      /*******************************
                  Settings
      *******************************/
      getSettings() {
        return this.getSettingsFromConfig({ componentSpec, properties: webComponent.properties });
      }
      setSetting(name, value) {
        this[name] = value;
      }
      getData() {
        let settings = this.getSettings();
        let data = {
          ...settings
        };
        if (!isServer) {
          data.darkMode = this.isDarkMode();
        }
        if (componentSpec) {
          data.ui = this.getUIClasses({ componentSpec, properties: webComponent.properties });
        }
        if (plural === true) {
          data.plural = true;
        }
        return data;
      }
      render() {
        const data = {
          ...this.getData(),
          ...this.tpl
        };
        const html = this.template.render(data);
        return html;
      }
    }, __publicField(_a3, "template", litTemplate), __publicField(_a3, "properties", WebComponentBase.getProperties({
      properties,
      componentSpec,
      defaultSettings
    })), _a3);
    if (isClient && customElements.get(tagName)) {
      return webComponent;
    }
    customElements.define(tagName, webComponent);
  }
  return tagName ? webComponent : litTemplate;
};

// src/components/menu/specs/menu-item-component.json
var menu_item_component_default = {
  tagName: "menu-item",
  content: [
    "icon",
    "label",
    "badge",
    "href",
    "value"
  ],
  contentAttributes: [
    "icon",
    "label",
    "badge",
    "href",
    "value"
  ],
  states: [
    "hover",
    "focused",
    "active",
    "disabled"
  ],
  attributes: [
    "icon",
    "label",
    "badge",
    "href",
    "value",
    "hover",
    "focused",
    "active",
    "disabled"
  ],
  propertyTypes: {
    icon: "string",
    label: "string",
    badge: "string",
    href: "string",
    value: "string",
    hover: "boolean",
    focused: "boolean",
    active: "boolean",
    disabled: "boolean"
  },
  attributeClasses: [
    "icon"
  ]
};

// src/components/menu/menu-bundle.css?raw
var menu_bundle_default = "/**\n  ---DO NOT EDIT THIS FILE DIRECTLY---\n  This CSS file was concatenated from files listed in the css/ folder as part of a build process\n  This is to allow for js import with @import links which will not be followed\n**/\n\n/* src/components/menu/css/definition/content/menu.css */\n@layer menu.definition.content.menu {\n  ui-menu {\n    display: block;\n    margin: var(--menu-margin);\n    padding: var(--menu-padding);\n    box-shadow: var(--menu-box-shadow);\n    border: var(--menu-border);\n    font-size: var(--menu-font-size);\n  }\n  .menu {\n    display: flex;\n    flex-direction: row;\n    font-weight: var(--menu-font-weight);\n    gap: var(--menu-gap);\n    background: var(--menu-background);\n    align-items: var(--menu-align-items);\n    justify-content: var(--menu-justify-content);\n  }\n}\n\n/* src/components/menu/css/definition/content/item.css */\n@layer menu.definition.content.item {\n  .item {\n    display: block;\n    cursor: pointer;\n    background: var(--menu-item-background);\n    margin: var(--menu-item-margin);\n    padding: var(--menu-item-padding);\n    border: var(--menu-item-border);\n    color: var(--menu-item-color);\n    font-weight: var(--menu-item-font-weight);\n    line-height: var(--menu-item-line-height);\n    box-shadow: var(--menu-item-box-shadow);\n    border-radius: var(--menu-item-border-radius);\n    text-align: var(--menu-item-text-align);\n    text-decoration: var(--menu-item-text-decoration);\n  }\n  .item:hover,\n  .item.hover {\n    background: var(--menu-item-hover-background);\n    margin: var(--menu-item-hover-margin);\n    padding: var(--menu-item-hover-padding);\n    border: var(--menu-item-hover-border);\n    color: var(--menu-item-hover-color);\n    box-shadow: var(--menu-item-hover-box-shadow);\n    border-radius: var(--menu-item-hover-border-radius);\n  }\n  .active.item {\n    cursor: default;\n    background: var(--menu-item-active-background);\n    margin: var(--menu-item-active-margin);\n    padding: var(--menu-item-active-padding);\n    border: var(--menu-item-active-border);\n    box-shadow: var(--menu-item-active-box-shadow);\n    font-weight: var(--menu-item-active-font-weight);\n    color: var(--menu-item-active-color);\n    border-radius: var(--menu-item-active-border-radius);\n  }\n}\n\n/* src/components/menu/css/definition/types/selection.css */\n@layer menu.definition.types.selection {\n  .selection.menu {\n    gap: var(--menu-selection-gap);\n  }\n  .selection.menu ::slotted(*),\n  .selection.menu menu-item {\n    --menu-item-padding: var(--menu-selection-item-padding);\n    --menu-item-border-radius: var(--menu-selection-item-border-radius);\n    --menu-item-color: var(--menu-selection-item-color);\n    --menu-item-hover-background: var(--menu-selection-item-hover-background);\n    --menu-item-hover-border-radius: var(--menu-selection-item-border-radius);\n    --menu-item-hover-color: var(--menu-selection-item-hover-color);\n    --menu-item-hover-box-shadow: var(--menu-selection-item-hover-box-shadow);\n    --menu-item-active-background: var(--menu-selection-item-active-background);\n    --menu-item-active-border-radius: var(--menu-selection-item-border-radius);\n    --menu-item-active-padding: var(--menu-selection-item-active-padding);\n    --menu-item-active-color: var(--menu-selection-item-active-color);\n    --menu-item-active-box-shadow: var(--menu-selection-item-active-box-shadow);\n  }\n}\n\n/* src/components/menu/css/definition/variations/evenly-spaced.css */\n@layer menu.definition.variations.equalWidth {\n  .evenly-spaced.menu {\n    display: grid;\n    grid-auto-flow: column;\n    grid-auto-columns: minmax(0, 1fr);\n    --menu-item-text-align: var(--menu-evenly-spaced-item-text-align) ;\n  }\n}\n\n/* src/components/menu/css/definition/variations/fitted.css */\n@layer menu.definition.variations.fitted {\n  :host([fitted]),\n  .fitted.menu {\n    margin: 0;\n  }\n}\n\n/* src/components/menu/css/definition/variations/inset.css */\n@layer menu.definition.variations.inset {\n  .inset.menu {\n    border: var(--menu-inset-border);\n    border-radius: var(--menu-inset-border-radius);\n    padding: var(--menu-inset-padding);\n    background: var(--menu-inset-background);\n  }\n}\n\n/* src/components/menu/css/definition/variations/vertical.css */\n@layer menu.definition.variations.vertical {\n  .vertical.menu {\n    flex-direction: column;\n    align-items: var(--menu-vertical-align-items);\n    text-align: var(--menu-vertical-text-align);\n  }\n}\n\n/* src/components/menu/css/definition/menu-definition.css */\n\n/* src/components/menu/css/theme/content/menu-variables.css */\n@layer menu.theme.content.menu {\n  :host {\n    --menu-margin: var(--vertically-spaced);\n    --menu-font-weight: var(--normal);\n    --menu-gap: var(--4px);\n    --menu-align-items: flex-start;\n    --menu-font-size: var(--medium);\n    --menu-justify-content: flex-start;\n    --menu-padding: 0;\n    --menu-box-shadow: none;\n    --menu-background: none;\n    --menu-border: none;\n  }\n}\n\n/* src/components/menu/css/theme/content/menu-item-variables.css */\n@layer menu.theme.content.menuItem {\n  :host {\n    --menu-item-background-color: transparent;\n    --menu-item-background-image: none;\n    --menu-item-background: var(--menu-item-background-color) var(--menu-item-background-image);\n    --menu-item-margin: 0;\n    --menu-item-line-height: 1;\n    --menu-item-font-weight: var(--normal);\n    --menu-item-padding: var(--7px) var(--6px);\n    --menu-item-border: none;\n    --menu-item-border-radius: none;\n    --menu-item-color: var(--standard-60);\n    --menu-item-text-align: inherit;\n    --menu-item-box-shadow: none;\n    --menu-item-text-decoration: none;\n    --menu-item-hover-background-color: var(--menu-item-background-color);\n    --menu-item-hover-background-image: var(--menu-item-background-image);\n    --menu-item-hover-background: var(--menu-item-hover-background-color) var(--menu-item-hover-background-image);\n    --menu-item-hover-margin: var(--menu-item-margin);\n    --menu-item-hover-padding: var(--menu-item-padding);\n    --menu-item-hover-color: var(--standard-100);\n    --menu-item-hover-border: var(--menu-item-border);\n    --menu-item-hover-box-shadow: var(--menu-item-box-shadow);\n    --menu-item-hover-border-radius: var(--menu-item-border-radius);\n    --menu-item-active-background-color: var(--menu-item-active-background-color);\n    --menu-item-active-background-image: var(--menu-item-active-background-image);\n    --menu-item-active-font-weight: var(--bold);\n    --menu-item-active-background: var(--menu-item-background);\n    --menu-item-active-margin: var(--menu-item-margin);\n    --menu-item-active-padding: var(--menu-item-padding);\n    --menu-item-active-color: var(--primary-text-color);\n    --menu-item-active-border: var(--menu-item-border);\n    --menu-item-active-box-shadow: var(--menu-item-box-shadow);\n    --menu-item-active-border-radius: var(--menu-item-border-radius);\n  }\n  html.dark {\n    --menu-item-color: var(--standard-30);\n    --menu-item-hover-color: var(--standard-100);\n    --menu-item-active-color: var(--primary-text-color);\n  }\n}\n\n/* src/components/menu/css/theme/types/selection-variables.css */\n@layer menu.theme.type.selection {\n  :host {\n    --menu-selection-gap: 6px;\n    --menu-selection-item-padding: 7px 6px;\n    --menu-selection-item-border-radius: var(--border-radius);\n    --menu-selection-item-color: var(--standard-30);\n    --menu-selection-item-hover-padding: var(--menu-selection-item-padding);\n    --menu-selection-item-hover-background: var(--standard-10);\n    --menu-selection-item-hover-color: #013A4F;\n    --menu-selection-item-hover-box-shadow: none;\n    --menu-selection-item-active-padding: var(--menu-selection-item-padding);\n    --menu-selection-item-active-background: #D0EBF3;\n    --menu-selection-item-active-color: var(--primary-text-color);\n    --menu-selection-item-active-box-shadow: 0px 1px 6px rgb(85 147 167 / 77%) inset;\n  }\n  @container style(--dark-mode: true) {\n    :host {\n      --menu-selection-item-hover-background: transparent;\n      --menu-selection-item-hover-color: var(--standard-90);\n      --menu-selection-item-active-background: #35B7F1;\n      --menu-selection-item-active-color: var(--black-90);\n      --menu-selection-item-active-box-shadow: 0px 0px 10px rgb(0 92 165) inset;\n    }\n  }\n}\n\n/* src/components/menu/css/theme/variations/evenly-spaced-variables.css */\n@layer menu.theme.variations.evenlySpaced {\n  :host {\n    --menu-evenly-spaced-item-text-align: center;\n  }\n}\n\n/* src/components/menu/css/theme/variations/vertical-variables.css */\n@layer menu.theme.variations.vertical {\n  :host {\n    --menu-vertical-align-items: stretch;\n    --menu-vertical-text-align: center;\n  }\n}\n\n/* src/components/menu/css/theme/variations/inset-variables.css */\n@layer menu.theme.variations.inset {\n  :host {\n    --menu-inset-padding: 3px 4px;\n    --menu-inset-border-radius: var(--border-radius);\n    --menu-inset-border: var(--internal-border);\n    --menu-inset-background: var(--inverted-15);\n  }\n}\n\n/* src/components/menu/css/theme/menu-theme.css */\n\n/* src/components/menu/css/menu.css */\n";

// src/components/menu/content/item/menu-item.html?raw
var menu_item_default = '{{#snippet content}}\n  {{#if icon}}\n    <ui-icon icon={{icon}}></ui-icon>\n  {{/if}}\n  {{>slot}}\n{{/snippet}}\n\n{{#if href}}\n  <a class="{{ui}}item" href="{{href}}" part="item">\n    {{>content}}\n  </a>\n{{else}}\n  <div class="{{ui}}item" part="item">\n    {{>content}}\n  </div>\n{{/if}}\n';

// src/components/menu/content/item/menu-item.js
var onCreated = ({ data }) => {
};
var events = {
  "touchstart .menu"({ event, tpl, $: $4 }) {
    $4(this).addClass("pressed");
  },
  "touchend .menu"({ event, tpl, $: $4 }) {
    $4(this).removeClass("pressed");
  }
};
var MenuItem = defineComponent({
  tagName: "menu-item",
  events,
  onCreated,
  componentSpec: menu_item_component_default,
  template: menu_item_default,
  css: menu_bundle_default
});

// src/components/menu/specs/menu-component.json
var menu_component_default = {
  tagName: "ui-menu",
  content: [
    "item"
  ],
  types: [
    "selection"
  ],
  variations: [
    "evenly-spaced",
    "fitted",
    "vertical",
    "inset"
  ],
  settings: [
    "items",
    "value"
  ],
  attributes: [
    "item",
    "selection",
    "evenly-spaced",
    "fitted",
    "vertical",
    "inset",
    "items",
    "value"
  ],
  propertyTypes: {
    item: "string",
    selection: "boolean",
    "evenly-spaced": "boolean",
    fitted: "boolean",
    vertical: "boolean",
    inset: "boolean",
    items: "array",
    value: "string"
  },
  defaultValues: {
    items: [],
    value: ""
  }
};

// src/components/menu/menu.html?raw
var menu_default = '<div class="{ui}menu" part="menu">\n  {#each item in items}\n    <menu-item\n      active={isValueActive value item}\n      href={item.href}\n      data-value={item.value}\n      exportparts="item"\n    >\n      {item.label}\n      {#if item.badge}\n        <ui-label outline badge>{item.badge}</ui-label>\n      {/if}\n    </menu-item>\n  {else}\n    {>slot}\n  {/each}\n</div>\n';

// src/components/menu/menu-page.css?raw
var menu_page_default = "ui-menu[selection] menu-item {\n  --menu-item-padding: var(--menu-selection-item-padding);\n  --menu-item-border-radius: var(--menu-selection-item-border-radius);\n  --menu-item-color: var(--menu-selection-item-color);\n\n  --menu-item-hover-background: var(--menu-selection-item-hover-background);\n  --menu-item-hover-border-radius: var(--menu-selection-item-border-radius);\n  --menu-item-hover-color: var(--menu-selection-item-hover-color);\n  --menu-item-hover-box-shadow: var(--menu-selection-item-hover-box-shadow);\n\n  --menu-item-active-background: var(--menu-selection-item-active-background);\n  --menu-item-active-border-radius: var(--menu-selection-item-border-radius);\n  --menu-item-active-padding: var(--menu-selection-item-active-padding);\n  --menu-item-active-color: var(--menu-selection-item-active-color);\n  --menu-item-active-box-shadow: var(--menu-selection-item-active-box-shadow);\n}\n";

// src/components/menu/menu.js
var createComponent = ({ settings, self, $: $4, dispatchEvent }) => ({
  setValue(value) {
    settings.value = value;
    dispatchEvent("change", { value });
  },
  getValue(item) {
    return item.value || item.href;
  },
  isValueActive(activeValue, item) {
    if (item.active) {
      return true;
    }
    if (activeValue !== void 0) {
      return activeValue == self.getValue(item);
    }
    return false;
  },
  selectIndex(eq) {
    const value = $4("menu-item").eq(eq).attr("data-value");
    if (value !== void 0) {
      self.setValue(value);
    }
  }
});
var onCreated2 = ({ settings }) => {
};
var onRendered = function({ $: $4 }) {
};
var events2 = {
  "click menu-item"({ self, data }) {
    self.setValue(data.value);
  }
};
var UIMenu = defineComponent({
  tagName: "ui-menu",
  componentSpec: menu_component_default,
  template: menu_default,
  css: menu_bundle_default,
  pageCSS: menu_page_default,
  createComponent,
  events: events2,
  onCreated: onCreated2,
  onRendered
});
export {
  MenuItem,
  UIMenu
};
/*! Bundled license information:

@lit/reactive-element/css-tag.js:
  (**
   * @license
   * Copyright 2019 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/reactive-element.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-html/lit-html.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-element/lit-element.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-html/is-server.js:
  (**
   * @license
   * Copyright 2022 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-html/directive-helpers.js:
  (**
   * @license
   * Copyright 2020 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-html/directive.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-html/async-directive.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-html/directives/if-defined.js:
  (**
   * @license
   * Copyright 2018 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-html/directives/unsafe-html.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-html/directives/repeat.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)
*/
//# sourceMappingURL=menu.js.map
