/**
 * @semantic-ui/core v0.12.4
 * Semantic empowers designers and developers by creating a shared vocabulary for UI.
 *
 * @license MIT
 * @copyright (c) 2025 Jack Lukic <jack@semantic-ui.com>
 * @homepage http://next.semantic-ui.com
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);

// packages/utils/src/equality.js
var isEqual = (a3, b3, options = {}) => {
  if (a3 === b3) {
    return true;
  }
  if (a3 && b3 && typeof a3 == "object" && typeof b3 == "object") {
    if (a3.constructor !== b3.constructor) {
      return false;
    }
    let length, i6, keys3;
    if (Array.isArray(a3)) {
      length = a3.length;
      if (length != b3.length) {
        return false;
      }
      for (i6 = length; i6-- !== 0; ) {
        if (!isEqual(a3[i6], b3[i6])) {
          return false;
        }
      }
      return true;
    }
    if (a3 instanceof Map && b3 instanceof Map) {
      if (a3.size !== b3.size) {
        return false;
      }
      for (i6 of a3.entries()) {
        if (!b3.has(i6[0])) {
          return false;
        }
      }
      for (i6 of a3.entries()) {
        if (!isEqual(i6[1], b3.get(i6[0]))) {
          return false;
        }
      }
      return true;
    }
    if (a3 instanceof Set && b3 instanceof Set) {
      if (a3.size !== b3.size) {
        return false;
      }
      for (i6 of a3.entries()) {
        if (!b3.has(i6[0])) {
          return false;
        }
      }
      return true;
    }
    if (ArrayBuffer.isView(a3) && ArrayBuffer.isView(b3)) {
      length = a3.length;
      if (length != b3.length) {
        return false;
      }
      for (i6 = length; i6-- !== 0; ) {
        if (a3[i6] !== b3[i6]) {
          return false;
        }
      }
      return true;
    }
    if (a3.constructor === RegExp) {
      return a3.source === b3.source && a3.flags === b3.flags;
    }
    if (a3.valueOf !== Object.prototype.valueOf) {
      return a3.valueOf() === b3.valueOf();
    }
    if (a3.toString !== Object.prototype.toString) {
      return a3.toString() === b3.toString();
    }
    keys3 = Object.keys(a3);
    length = keys3.length;
    if (length !== Object.keys(b3).length) {
      return false;
    }
    for (i6 = length; i6-- !== 0; ) {
      if (!Object.prototype.hasOwnProperty.call(b3, keys3[i6])) {
        return false;
      }
    }
    for (i6 = length; i6-- !== 0; ) {
      let key = keys3[i6];
      if (!isEqual(a3[key], b3[key])) {
        return false;
      }
    }
    return true;
  }
  return a3 !== a3 && b3 !== b3;
};

// packages/utils/src/types.js
var isObject = (x2) => {
  return x2 !== null && typeof x2 == "object";
};
var isPlainObject = (x2) => {
  return isObject(x2) && x2.constructor === Object;
};
var isString = (x2) => {
  return typeof x2 == "string";
};
var isNumber = (x2) => {
  return typeof x2 == "number";
};
var isArray = (x2) => {
  return Array.isArray(x2);
};
var isFunction = (x2) => {
  return typeof x2 == "function" || false;
};
var isDOM = (element) => {
  if (typeof window === "undefined") {
    return true;
  }
  return element instanceof Element || element instanceof Document || element === window || element instanceof DocumentFragment;
};
var isEmpty = (x2) => {
  if (x2 == null) {
    return true;
  }
  if (isArray(x2) || isString(x2)) {
    return x2.length === 0;
  }
  for (let key in x2) {
    if (x2[key]) {
      return false;
    }
  }
  return true;
};
var isClassInstance = (obj) => {
  if (obj === null || typeof obj !== "object") {
    return false;
  }
  const proto = Object.getPrototypeOf(obj);
  const constructorName = proto.constructor.name;
  const builtInTypes = [
    "Object",
    "Array",
    "Date",
    "RegExp",
    "Map",
    "Set",
    "Error",
    "Uint8Array",
    "Int8Array",
    "Uint16Array",
    "Int16Array",
    "Uint32Array",
    "Int32Array",
    "Float32Array",
    "Float64Array",
    "BigInt64Array",
    "BigUint64Array",
    "NodeList"
  ];
  return !builtInTypes.includes(constructorName);
};

// packages/utils/src/looping.js
var each = (obj, func, context) => {
  if (obj === null || obj === void 0) {
    return obj;
  }
  const iteratee = context ? func.bind(context) : func;
  if (isObject(obj) || isFunction(obj)) {
    if (obj.length !== void 0 && typeof obj.length === "number") {
      obj = Array.from(obj);
    }
  }
  if (isArray(obj)) {
    for (let i6 = 0; i6 < obj.length; ++i6) {
      if (iteratee(obj[i6], i6, obj) === false) {
        break;
      }
    }
  } else {
    const keys3 = Object.keys(obj);
    for (let key of keys3) {
      if (iteratee(obj[key], key, obj) === false) {
        break;
      }
    }
  }
  return obj;
};

// packages/utils/src/crypto.js
var tokenize = (str = "") => {
  return (str || "").replace(/\s+/g, "-").replace(/[^\w-]+/g, "").replace(/_/g, "-").toLowerCase();
};
var prettifyID = (num) => {
  num = parseInt(num, 10);
  if (num === 0) {
    return "0";
  }
  let result = "";
  const chars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ";
  while (num > 0) {
    result = chars[num % chars.length] + result;
    num = Math.floor(num / chars.length);
  }
  return result;
};
function hashCode(input, { prettify = false, seed = 305419896 } = {}) {
  const prime1 = 2654435761;
  const prime2 = 2246822519;
  const prime3 = 3266489917;
  let inputData;
  if (input === null || input === void 0) {
    inputData = new TextEncoder().encode("");
  } else if (input && input.toString === Object.prototype.toString && typeof input === "object") {
    try {
      inputData = new TextEncoder().encode(JSON.stringify(input));
    } catch (error) {
      console.error("Error serializing input", error);
      return 0;
    }
  } else {
    inputData = new TextEncoder().encode(input.toString());
  }
  let hash;
  if (inputData.length <= 8) {
    hash = seed;
    for (let i6 = 0; i6 < inputData.length; i6++) {
      hash ^= inputData[i6];
      hash = Math.imul(hash, prime1);
      hash ^= hash >>> 13;
    }
  } else {
    hash = seed;
    for (let i6 = 0; i6 < inputData.length; i6++) {
      hash = Math.imul(hash ^ inputData[i6], prime1);
      hash = hash << 13 | hash >>> 19;
      hash = Math.imul(hash, prime2);
    }
    hash ^= inputData.length;
  }
  hash ^= hash >>> 16;
  hash = Math.imul(hash, prime3);
  hash ^= hash >>> 13;
  if (prettify) {
    return prettifyID(hash >>> 0);
  }
  return hash >>> 0;
}
var generateID = () => {
  const num = Math.random() * 1e15;
  return prettifyID(num);
};

// packages/utils/src/functions.js
var noop = (v3) => v3;
var wrapFunction = (x2) => {
  return isFunction(x2) ? x2 : () => x2;
};
var debounce = (fn, options) => {
  if (typeof options == "number") {
    options = { delay: options };
  }
  const {
    delay = 200,
    immediate = false
  } = options;
  let timeout;
  let callbackCalled = false;
  function debounced(...args) {
    const later = () => {
      timeout = null;
      if (!immediate) {
        fn.apply(this, args);
      }
      callbackCalled = false;
    };
    const callNow = immediate && !timeout;
    clearTimeout(timeout);
    timeout = setTimeout(later, delay);
    if (callNow && !callbackCalled) {
      callbackCalled = true;
      fn.apply(this, args);
    }
  }
  debounced.cancel = () => {
    clearTimeout(timeout);
    timeout = null;
    callbackCalled = false;
  };
  return debounced;
};

// packages/utils/src/regexp.js
var escapeRegExp = (string) => {
  return string.replace(/([.*+?^=!:${}()|\[\]\/\\])/g, "\\$1");
};
var escapeHTML = (string) => {
  const htmlEscapes = {
    "&": "&amp",
    "<": "&lt",
    ">": "&gt",
    '"': "&quot",
    "'": "&#39"
  };
  const htmlRegExp = /[&<>"']/g;
  const hasHTML = RegExp(htmlRegExp.source);
  return string && hasHTML.test(string) ? string.replace(htmlRegExp, (chr) => htmlEscapes[chr]) : string;
};

// packages/utils/src/objects.js
var keys2 = (obj) => {
  if (isObject(obj)) {
    return Object.keys(obj);
  }
};
var filterObject = (obj, callback) => {
  return Object.fromEntries(
    Object.entries(obj).filter(([key, value]) => callback(value, key))
  );
};
var mapObject = (obj, callback) => {
  return Object.fromEntries(
    Object.entries(obj).map(([key, value]) => [key, callback(value, key)])
  );
};
var extend = (obj, ...sources) => {
  sources.forEach((source) => {
    let descriptor, prop;
    if (source) {
      for (prop in source) {
        descriptor = Object.getOwnPropertyDescriptor(source, prop);
        if (descriptor === void 0) {
          obj[prop] = source[prop];
        } else {
          Object.defineProperty(obj, prop, descriptor);
        }
      }
    }
  });
  return obj;
};
var arrayFromObject = (obj) => {
  if (isArray(obj)) {
    return obj;
  }
  let arr = [];
  each(obj, (value, key) => {
    arr.push({
      value,
      key
    });
  });
  return arr;
};
var get = function(obj, path = "") {
  if (typeof path !== "string") {
    return void 0;
  }
  function extractArrayLikeAccess(part) {
    const key = part.substring(0, part.indexOf("["));
    const index = parseInt(part.substring(part.indexOf("[") + 1, part.indexOf("]")), 10);
    return { key, index };
  }
  function getCombinedKey(path2) {
    const dotIndex = path2.indexOf(".");
    if (dotIndex !== -1) {
      const nextDotIndex = path2.indexOf(".", dotIndex + 1);
      if (nextDotIndex !== -1) {
        return path2.slice(0, nextDotIndex);
      }
    }
    return path2;
  }
  if (obj === null || !isObject(obj)) {
    return void 0;
  }
  const parts = path.split(".");
  let currentObject = obj;
  for (let i6 = 0; i6 < parts.length; i6++) {
    if (currentObject === null || !isObject(currentObject)) {
      return void 0;
    }
    let part = parts[i6];
    if (part.includes("[")) {
      const { key, index } = extractArrayLikeAccess(part);
      if (key in currentObject && isArray(currentObject[key]) && index < currentObject[key].length) {
        currentObject = currentObject[key][index];
      } else {
        return void 0;
      }
    } else {
      if (part in currentObject) {
        currentObject = currentObject[part];
      } else {
        const remainingPath = parts.slice(i6).join(".");
        if (remainingPath in currentObject) {
          currentObject = currentObject[remainingPath];
          break;
        } else {
          const combinedKey = getCombinedKey(`${part}.${parts[i6 + 1]}`);
          if (combinedKey in currentObject) {
            currentObject = currentObject[combinedKey];
            i6++;
          } else {
            return void 0;
          }
        }
      }
    }
  }
  return currentObject;
};
var reverseKeys = (obj) => {
  const newObj = {};
  const pushValue = (key, value) => {
    if (isArray(newObj[key])) {
      newObj[key].push(value);
    } else if (newObj[key]) {
      newObj[key] = [newObj[key], value];
    } else {
      newObj[key] = value;
    }
  };
  Object.keys(obj).forEach((key) => {
    if (isArray(obj[key])) {
      each(obj[key], (subKey) => {
        pushValue(subKey, key);
      });
    } else {
      pushValue(obj[key], key);
    }
  });
  return newObj;
};

// packages/utils/src/arrays.js
var unique = (arr) => {
  return Array.from(new Set(arr));
};
var last = (array = [], number = 1) => {
  const { length } = array;
  if (!length) {
    return;
  }
  if (number === 1) {
    return array[length - 1];
  } else {
    return array.slice(Math.max(length - number, 0));
  }
};
var firstMatch = (array = [], callback) => {
  let result;
  each(array, (value, index) => {
    if (callback(value, index, array)) {
      result = value;
      return false;
    }
  });
  return result;
};
var findIndex = (array = [], callback) => {
  let matchedIndex = -1;
  each(array, (value, index) => {
    if (callback(value, index, array)) {
      matchedIndex = index;
      return false;
    }
  });
  return matchedIndex;
};
var remove = (array = [], callbackOrValue) => {
  const callback = isFunction(callbackOrValue) ? callbackOrValue : (val) => isEqual(val, callbackOrValue);
  const index = findIndex(array, callback);
  if (index > -1) {
    array.splice(index, 1);
    return true;
  }
  return false;
};
var inArray = (value, array = []) => {
  return array.indexOf(value) > -1;
};
var range = (start, stop, step = 1) => {
  if (!stop) {
    stop = start;
    start = 0;
  }
  const length = stop - start;
  return Array(length).fill(void 0).map((x2, index) => {
    return index * step + start;
  });
};
var some = (collection, predicate) => {
  return (collection == null ? void 0 : collection.some) ? collection.some(predicate) : false;
};
var any = some;
var ARRAY_SIZE_THRESHOLD = 58;
var difference = (...arrays) => {
  if (arrays.length === 0) {
    return [];
  }
  if (arrays.length === 1) {
    return [...new Set(arrays[0])];
  }
  const totalSize = arrays.reduce((sum, arr) => sum + arr.length, 0);
  const useSet = totalSize >= ARRAY_SIZE_THRESHOLD;
  const [first, ...rest] = arrays;
  const firstUnique = [...new Set(first)];
  if (useSet) {
    const sets = rest.map((arr) => new Set(arr));
    return firstUnique.filter((item) => !sets.some((set) => set.has(item)));
  }
  return firstUnique.filter((item) => !rest.some((arr) => arr.includes(item)));
};

// packages/utils/src/ssr.js
var isServer = /* @__PURE__ */ (() => {
  return typeof window === "undefined";
})();
var isClient = /* @__PURE__ */ (() => {
  return typeof window !== "undefined";
})();

// packages/utils/src/browser.js
var getKeyFromEvent = (event) => {
  let pressedKey = event == null ? void 0 : event.key;
  if (!pressedKey) {
    return "";
  }
  let key = "";
  if (event.ctrlKey && pressedKey !== "Control") {
    key += "ctrl+";
  }
  if (event.altKey && pressedKey !== "Alt") {
    key += "alt+";
  }
  if (event.shiftKey && pressedKey !== "Shift") {
    key += "shift+";
  }
  if (event.metaKey && pressedKey !== "Meta") {
    key += "meta+";
  }
  const specialKeys = {
    Control: "ctrl",
    Escape: "esc",
    " ": "space"
  };
  pressedKey = pressedKey.replace("Arrow", "");
  key += specialKeys[pressedKey] || pressedKey.toLowerCase();
  return key;
};

// packages/utils/src/cloning.js
var clone = (src, seen = /* @__PURE__ */ new Map()) => {
  if (!src || typeof src !== "object") {
    return src;
  }
  if (seen.has(src)) {
    return seen.get(src);
  }
  let copy;
  if (src.nodeType && "cloneNode" in src) {
    copy = src.cloneNode(true);
    seen.set(src, copy);
  } else if (src instanceof Date) {
    copy = new Date(src.getTime());
    seen.set(src, copy);
  } else if (src instanceof RegExp) {
    copy = new RegExp(src);
    seen.set(src, copy);
  } else if (Array.isArray(src)) {
    copy = new Array(src.length);
    seen.set(src, copy);
    for (let i6 = 0; i6 < src.length; i6++) {
      copy[i6] = clone(src[i6], seen);
    }
  } else if (src instanceof Map) {
    copy = /* @__PURE__ */ new Map();
    seen.set(src, copy);
    for (const [k2, v3] of src.entries()) {
      copy.set(k2, clone(v3, seen));
    }
  } else if (src instanceof Set) {
    copy = /* @__PURE__ */ new Set();
    seen.set(src, copy);
    for (const v3 of src) {
      copy.add(clone(v3, seen));
    }
  } else if (src instanceof Object) {
    copy = {};
    seen.set(src, copy);
    for (const [k2, v3] of Object.entries(src)) {
      copy[k2] = clone(v3, seen);
    }
  }
  return copy;
};

// packages/utils/src/colors.js
var GAMMA_EXPONENT = 1 / 2.4;

// packages/utils/src/dates.js
var formatDate = function(date, format = "LLL", {
  locale = "default",
  hour12 = true,
  timezone = "UTC",
  ...additionalOptions
} = {}) {
  if (isNaN(date.getTime())) {
    return "Invalid Date";
  }
  const localDate = new Date(date.getTime());
  if (timezone === "local") {
    timezone = Intl.DateTimeFormat().resolvedOptions().timeZone;
  }
  const pad = (n5) => n5 < 10 ? `0${n5}` : n5;
  const shorthand = reverseKeys({
    // North America
    "America/New_York": ["ET"],
    "America/Chicago": ["CT"],
    "America/Denver": ["MT"],
    "America/Los_Angeles": ["PT"],
    "America/Anchorage": ["AKT"],
    "Pacific/Honolulu": ["HT"],
    "America/Halifax": ["AT"],
    // Europe
    "Europe/London": ["UK", "WET"],
    "Europe/Paris": ["CET", "ECT"],
    "Europe/Helsinki": ["EET"],
    "Europe/Dublin": ["IRST"],
    // Note disambiguation with India
    // Australia/Oceania
    "Australia/Sydney": ["AET"],
    "Australia/Adelaide": ["ACT"],
    "Australia/Perth": ["AWT"],
    "Pacific/Auckland": ["NZT"],
    // South America
    "America/Sao_Paulo": ["BRT"],
    // Asia
    "Asia/Kolkata": ["IST", "INST"],
    // Note disambiguation with Ireland
    "Asia/Tokyo": ["JST"],
    "Asia/Singapore": ["SGT"]
  });
  if (timezone && shorthand[timezone]) {
    timezone = shorthand[timezone];
  }
  const localeOptions = {
    timeZone: timezone,
    year: "numeric",
    month: "long",
    day: "numeric",
    weekday: "long",
    hour: "numeric",
    minute: "numeric",
    second: "numeric",
    hour12,
    ...additionalOptions
  };
  const formatter = new Intl.DateTimeFormat(locale, localeOptions);
  const dateParts = formatter.formatToParts(localDate).reduce((acc, part) => {
    acc[part.type] = part.value;
    return acc;
  }, {});
  let { year, month, day, weekday, hour, minute, second, dayPeriod } = dateParts;
  if (hour === "24") {
    hour = "00";
  }
  const timezoneDate = new Date(date.toLocaleString("en-US", { timeZone: timezone }));
  const dateMap = {
    YYYY: year,
    YY: year.slice(-2),
    MMMM: month,
    MMM: month.slice(0, 3),
    MM: pad(timezoneDate.getMonth() + 1),
    M: timezoneDate.getMonth() + 1,
    DD: pad(timezoneDate.getDate()),
    D: timezoneDate.getDate(),
    Do: day + ["th", "st", "nd", "rd"][day % 10 > 3 ? 0 : (day % 100 - day % 10 !== 10) * day % 10],
    dddd: weekday,
    ddd: weekday.slice(0, 3),
    HH: hour.padStart(2, "0"),
    hh: hour12 ? (hour % 12 || 12).toString().padStart(2, "0") : hour.padStart(2, "0"),
    h: hour12 ? (hour % 12 || 12).toString() : hour,
    mm: minute,
    ss: second,
    a: hour12 && dayPeriod ? dayPeriod.toLowerCase() : ""
  };
  const formatMap = {
    LT: "h:mm a",
    LTS: "h:mm:ss a",
    L: "MM/DD/YYYY",
    l: "M/D/YYYY",
    LL: "MMMM D, YYYY",
    ll: "MMM D, YYYY",
    LLL: "MMMM D, YYYY h:mm a",
    lll: "MMM D, YYYY h:mm a",
    LLLL: "dddd, MMMM D, YYYY h:mm a",
    llll: "ddd, MMM D, YYYY h:mm a"
  };
  format = format.trim();
  const expandedFormat = formatMap[format] || format;
  return expandedFormat.replace(/\b(?:YYYY|YY|MMMM|MMM|MM|M|DD|D|Do|dddd|ddd|HH|hh|h|mm|ss|a)\b/g, (match) => {
    return dateMap[match];
  }).replace(/\[(.+?)\]/g, (match, p1) => p1).trim();
};

// packages/utils/src/errors.js
var fatal = (message, {
  errorType = Error,
  metadata = {},
  onError = null,
  removeStackLines = 1
} = {}) => {
  const error = new errorType(message);
  Object.assign(error, metadata);
  if (error.stack) {
    const stackLines = error.stack.split("\n");
    stackLines.splice(1, removeStackLines);
    error.stack = stackLines.join("\n");
  }
  const throwError = () => {
    if (typeof global.onError === "function") {
      global.onError(error);
    }
    throw error;
  };
  if (typeof queueMicrotask === "function") {
    queueMicrotask(throwError);
  } else {
    setTimeout(throwError, 0);
  }
};

// packages/utils/src/strings.js
var kebabToCamel = (str = "") => {
  return str.replace(/-./g, (m3) => m3[1].toUpperCase());
};
var camelToKebab = (str = "") => {
  return str.replace(/([a-z0-9])([A-Z])/g, "$1-$2").toLowerCase();
};
var capitalize = (str = "") => {
  return str.charAt(0).toUpperCase() + str.slice(1);
};
var toTitleCase = (str = "") => {
  const stopWords = [
    "the",
    "a",
    "an",
    "and",
    "but",
    "for",
    "at",
    "by",
    "from",
    "to",
    "in",
    "on",
    "of",
    "or",
    "nor",
    "with",
    "as"
  ];
  if (!isString(str)) {
    return;
  }
  return str.toLowerCase().split(" ").map((word, index) => {
    if (index === 0 || !stopWords.includes(word)) {
      return word.charAt(0).toUpperCase() + word.slice(1);
    }
    return word;
  }).join(" ");
};
var joinWords = (words, {
  separator = ", ",
  lastSeparator = " and ",
  oxford = true,
  quotes = false,
  transform = noop
} = {}) => {
  if (!isArray(words) || words.length === 0) {
    return "";
  }
  const processedWords = words.map((word) => {
    let processed = word;
    if (isFunction(transform)) {
      processed = transform(word);
    }
    return quotes ? `"${processed}"` : processed;
  });
  if (processedWords.length === 1) {
    return processedWords[0];
  }
  if (processedWords.length === 2) {
    return processedWords.join(lastSeparator);
  }
  const lastWord = processedWords.pop();
  let result = processedWords.join(separator);
  if (oxford && separator.trim() !== lastSeparator.trim()) {
    result += separator.trim();
  }
  return result + lastSeparator + lastWord;
};

// packages/component/src/helpers/scope-styles.js
var scopeStyles = (css, scopeSelector = "") => {
  scopeSelector = scopeSelector.toLowerCase();
  const scopeRule = (rule, scopeSelector2) => {
    if (rule.type === CSSRule.STYLE_RULE) {
      return `${scopeSelector2} ${rule.selectorText} { ${rule.style.cssText} }`;
    } else if (rule.type === CSSRule.MEDIA_RULE || rule.type === CSSRule.SUPPORTS_RULE) {
      return `@${rule.type === CSSRule.MEDIA_RULE ? "media" : "supports"} ${rule.conditionText || ""} { ${scopeRule(rule.cssText, scopeSelector2)} }`;
    } else if (rule.type === CSSRule.LAYER_STATEMENT_RULE || rule.type == 0 && rule.cssRules) {
      let scopedInnerRules = [];
      each(rule.cssRules, (innerRule) => {
        scopedInnerRules.push(scopeRule(innerRule, scopeSelector2));
      });
      return `@layer ${rule.name} { ${scopedInnerRules.join(" ")} }`;
    } else {
      return rule.cssText;
    }
  };
  const styleSheet = new CSSStyleSheet();
  styleSheet.replaceSync(css);
  let modifiedRules = [];
  each(styleSheet.cssRules, (rule) => {
    modifiedRules.push(scopeRule(rule, scopeSelector));
  });
  return modifiedRules.join("\n");
};

// packages/component/src/helpers/adopt-stylesheet.js
var adoptStylesheet = (css, adoptedElement, { scopeSelector } = {}) => {
  if (isServer) {
    return;
  }
  if (!adoptedElement) {
    adoptedElement = document;
  }
  const hash = hashCode(css);
  if (!adoptedElement.cssHashes) {
    adoptedElement.cssHashes = [];
  }
  if (adoptedElement.cssHashes.includes(hash)) {
    return;
  }
  adoptedElement.cssHashes.push(hash);
  const stylesheet = new CSSStyleSheet();
  if (scopeSelector) {
    css = scopeStyles(css, scopeSelector);
  }
  stylesheet.id = hash;
  stylesheet.replaceSync(css);
  adoptedElement.adoptedStyleSheets = [
    ...adoptedElement.adoptedStyleSheets,
    stylesheet
  ];
};

// packages/templating/src/compiler/string-scanner.js
var _StringScanner = class _StringScanner {
  constructor(input) {
    this.input = input;
    this.pos = 0;
  }
  matches(regex) {
    return regex.test(this.rest());
  }
  rest() {
    return this.input.slice(this.pos);
  }
  step(step = 1) {
    if (!this.isEOF()) {
      this.pos = this.pos + step;
    }
  }
  rewind(step = 1) {
    if (this.pos !== 0) {
      this.pos = this.pos - step;
    }
  }
  isEOF() {
    return this.pos >= this.input.length;
  }
  // get character at current position
  peek() {
    return this.input.charAt(this.pos);
  }
  consume(pattern) {
    const regex = typeof pattern === "string" ? new RegExp(escapeRegExp(pattern)) : new RegExp(pattern);
    const substring = this.input.substring(this.pos);
    const match = regex.exec(substring);
    if (match && match.index === 0) {
      this.pos += match[0].length;
      return match[0];
    }
    return null;
  }
  consumeUntil(pattern) {
    const regex = typeof pattern === "string" ? new RegExp(escapeRegExp(pattern)) : new RegExp(pattern);
    const match = regex.exec(this.input.substring(this.pos));
    if (!match) {
      const consumedText2 = this.input.substr(this.pos);
      this.pos = this.input.length;
      return consumedText2;
    }
    const consumedText = this.input.substring(this.pos, this.pos + match.index);
    this.pos += match.index;
    return consumedText;
  }
  returnTo(pattern) {
    if (!pattern) {
      return;
    }
    const regex = typeof pattern === "string" ? new RegExp(escapeRegExp(pattern), "gm") : new RegExp(pattern, "gm");
    let lastMatch = null;
    let match;
    const substring = this.input.substring(0, this.pos);
    while ((match = regex.exec(substring)) !== null) {
      lastMatch = match;
    }
    if (lastMatch) {
      const consumedText = this.input.substring(0, lastMatch.index);
      this.pos = lastMatch.index;
      return consumedText;
    }
    return;
  }
  getContext() {
    let insideTag = false;
    let i6 = this.pos - 1;
    let tagPos;
    while (i6 >= 0) {
      if (this.input[i6] === ">") {
        break;
      }
      if (this.input[i6] === "<") {
        insideTag = true;
        tagPos = i6;
        break;
      }
      i6--;
    }
    if (insideTag) {
      const tagText = this.input.substring(tagPos, this.pos);
      const attrPattern = /([a-zA-Z-]+)(?=\s*=\s*[^=]*$)/;
      const attrMatch = tagText.match(attrPattern);
      const attrName = attrMatch ? attrMatch[1] : "";
      const booleanAttributes = [
        "allowfullscreen",
        "async",
        "autofocus",
        "autoplay",
        "checked",
        "controls",
        "default",
        "defer",
        "disabled",
        "formnovalidate",
        "inert",
        "ismap",
        "itemscope",
        "loop",
        "multiple",
        "muted",
        "nomodule",
        "novalidate",
        "open",
        "playsinline",
        "readonly",
        "required",
        "reversed",
        "selected"
      ];
      let booleanAttribute = false;
      if (booleanAttributes.includes(attrName)) {
        booleanAttribute = true;
      } else {
        const quotedAttrPattern = /([a-zA-Z-]+)(?=\s*=\s*(\"|\')\s*[^=]*$)/;
        const quotedAttrMatch = tagText.match(quotedAttrPattern);
        const quotedAttrName = quotedAttrMatch ? quotedAttrMatch[1] : "";
        booleanAttribute = attrName !== quotedAttrName;
      }
      if (attrName) {
        return {
          insideTag: true,
          attribute: attrName,
          booleanAttribute
        };
      }
    }
    return {
      insideTag
    };
  }
  fatal(msg) {
    msg = msg || "Parse error";
    const input = typeof this.input === "string" ? this.input : "";
    const lines = input.split("\n");
    let lineNumber = 0;
    let charCount = 0;
    for (const line of lines) {
      if (charCount + line.length + 1 > this.pos) {
        break;
      }
      charCount += line.length + 1;
      lineNumber++;
    }
    const linesBefore = 5;
    const linesAfter = 5;
    const startLine = Math.max(0, lineNumber - linesBefore);
    const endLine = Math.min(lines.length, lineNumber + linesAfter + 1);
    const contextLines = lines.slice(startLine, endLine);
    const consoleMsg = contextLines.map((line, idx) => {
      return `%c${line}`;
    }).join("\n");
    const normalStyle = "color: grey";
    const errorStyle = "color: red; font-weight: bold";
    if (_StringScanner.DEBUG_MODE) {
      if (globalThis.document) {
        let errorHTML = "";
        each(contextLines, (line, index) => {
          const style = index < linesBefore || index > linesBefore ? normalStyle : errorStyle;
          errorHTML += `<div style="${style}">${line}</div>`;
        });
        const html = `
          <div style="padding: 1rem; font-size: 14px;">
            <h2>Could not render template</h2>
            <h3>${msg}</h3>
            <code style="margin-top: 1rem; display: block; background-color: #EFEFEF; padding: 0.25rem 1rem;border-left: 3px solid #888"><pre>${errorHTML}</pre></code>
          </div>
        `;
        document.body.innerHTML = html;
      }
      console.error(
        msg + "\n" + consoleMsg,
        ...contextLines.map((_2, idx) => lineNumber - startLine === idx ? errorStyle : normalStyle)
      );
      const e6 = new Error(msg);
      throw e6;
    }
  }
};
__publicField(_StringScanner, "DEBUG_MODE", true);
var StringScanner = _StringScanner;

// packages/templating/src/compiler/template-compiler.js
var _TemplateCompiler = class _TemplateCompiler {
  constructor(templateString) {
    this.templateString = templateString || "";
    this.snippets = {};
  }
  /*
    Creates an AST representation of a template
    from a template string
  */
  compile(templateString = this.templateString) {
    templateString = _TemplateCompiler.preprocessTemplate(templateString);
    const scanner = new StringScanner(templateString);
    if (!isString(templateString)) {
      scanner.fatal("Template is not a string", templateString);
    }
    const { htmlRegExp } = _TemplateCompiler;
    const syntax = _TemplateCompiler.detectSyntax(templateString);
    const tagRegExp = syntax == "doubleBracket" ? _TemplateCompiler.doubleBracketRegExp : _TemplateCompiler.singleBracketRegExp;
    const parserRegExp = syntax == "doubleBracket" ? _TemplateCompiler.doubleBracketParserRegExp : _TemplateCompiler.singleBracketParserRegExp;
    const parseTag = (scanner2) => {
      let getTagContent = () => {
        if (scanner2.peek() == "}") {
          scanner2.consumeUntil(parserRegExp.EXPRESSION_END);
          return;
        }
        let openTags = 1;
        let content = scanner2.peek();
        while (openTags > 0 && !scanner2.isEOF()) {
          scanner2.step();
          if (scanner2.peek() == "{") {
            openTags++;
          }
          if (scanner2.peek() == "}") {
            openTags--;
          }
          if (openTags == 0) {
            scanner2.rewind();
            break;
          }
          content += scanner2.peek();
        }
        scanner2.consumeUntil(parserRegExp.EXPRESSION_END);
        scanner2.consume(parserRegExp.EXPRESSION_END);
        content = content.trim();
        return content;
      };
      for (let type in tagRegExp) {
        if (scanner2.matches(tagRegExp[type])) {
          const context = scanner2.getContext();
          scanner2.consume(tagRegExp[type]);
          const rawContent = getTagContent();
          scanner2.consume(parserRegExp.EXPRESSION_END);
          const content = this.getValue(rawContent);
          return { type, content, ...context };
        }
      }
      for (let type in htmlRegExp) {
        if (scanner2.matches(htmlRegExp[type])) {
          scanner2.consume(htmlRegExp[type]);
          const context = scanner2.getContext();
          const content = this.getValue(scanner2.consumeUntil(parserRegExp.TAG_CLOSE).trim());
          scanner2.consume(parserRegExp.TAG_CLOSE);
          return { type, content, ...context };
        }
      }
      return null;
    };
    const ast = [];
    const stack = [];
    let contentBranch = null;
    let conditionStack = [];
    let contentStack = [];
    while (!scanner.isEOF()) {
      const tag = parseTag(scanner);
      const conditionTarget = last(conditionStack);
      const contentTarget = (contentBranch == null ? void 0 : contentBranch.content) || ast;
      if (tag) {
        let newNode = {
          type: tag.type.toLowerCase()
        };
        switch (tag.type) {
          case "IF":
            newNode = {
              ...newNode,
              condition: tag.content,
              content: [],
              branches: []
            };
            contentTarget.push(newNode);
            conditionStack.push(newNode);
            contentStack.push(newNode);
            contentBranch = newNode;
            break;
          case "ELSEIF":
            newNode = {
              ...newNode,
              condition: tag.content,
              content: []
            };
            if (!conditionTarget) {
              scanner.returnTo(tagRegExp.ELSEIF);
              scanner.fatal(
                "{{elseif}} encountered without matching if condition"
              );
            }
            contentStack.pop();
            contentStack.push(newNode);
            conditionTarget.branches.push(newNode);
            contentBranch = newNode;
            break;
          case "ELSE":
            newNode = {
              ...newNode,
              content: []
            };
            if (!conditionTarget) {
              scanner.returnTo(tagRegExp.ELSE);
              scanner.fatal(
                "{{else}} encountered without matching if or each condition"
              );
              break;
            }
            if (conditionTarget.type === "if") {
              contentStack.pop();
              contentStack.push(newNode);
              conditionTarget.branches.push(newNode);
              contentBranch = newNode;
            } else if (conditionTarget.type === "each") {
              contentStack.pop();
              contentStack.push(newNode);
              conditionTarget.else = newNode;
              contentBranch = newNode;
            } else {
              scanner.returnTo(tagRegExp.ELSE);
              scanner.fatal(
                "{{else}} encountered with unknown condition type: " + conditionTarget.type
              );
            }
            break;
          case "CLOSE_IF":
            if (conditionStack.length == 0) {
              scanner.returnTo(tagRegExp.CLOSE_IF);
              scanner.fatal("{{/if}} close tag found without open if tag");
            }
            stack.pop();
            contentStack.pop();
            conditionStack.pop();
            contentBranch = last(contentStack);
            break;
          case "SNIPPET":
            newNode = {
              ...newNode,
              type: "snippet",
              name: tag.content,
              content: []
            };
            this.snippets[tag.content] = newNode;
            contentTarget.push(newNode);
            conditionStack.push(newNode);
            contentStack.push(newNode);
            contentBranch = newNode;
            break;
          case "CLOSE_SNIPPET":
            if (conditionStack.length == 0) {
              scanner.returnTo(tagRegExp.CLOSE_IF);
              scanner.fatal("{{/snippet}} close tag found without open if tag");
            }
            stack.pop();
            contentStack.pop();
            contentBranch = last(contentStack);
            break;
          case "HTML_EXPRESSION":
            newNode = {
              ...newNode,
              type: "expression",
              unsafeHTML: true,
              value: tag.content
            };
            contentTarget.push(newNode);
            scanner.consume("}");
            break;
          case "EXPRESSION":
            newNode = {
              ...newNode,
              value: tag.content
            };
            if (tag.booleanAttribute) {
              newNode.ifDefined = true;
            }
            contentTarget.push(newNode);
            break;
          case "TEMPLATE":
            const templateInfo = this.parseTemplateString(tag.content);
            newNode = {
              ...newNode,
              ...templateInfo
            };
            contentTarget.push(newNode);
            break;
          case "SLOT":
            newNode = {
              ...newNode,
              name: tag.content
            };
            contentTarget.push(newNode);
            break;
          case "EACH":
            let iterateOver;
            let iterateAs;
            let indexAs;
            const inParts = tag.content.split(" in ");
            const asParts = tag.content.split(" as ");
            if (inParts.length > 1) {
              let iteratorPart = inParts[0].trim();
              iterateOver = inParts[1].trim();
              const commaIndex = iteratorPart.indexOf(",");
              if (commaIndex !== -1) {
                iterateAs = iteratorPart.substring(0, commaIndex).trim();
                indexAs = iteratorPart.substring(commaIndex + 1).trim();
              } else {
                iterateAs = iteratorPart;
              }
            } else if (asParts.length > 1) {
              iterateOver = asParts[0].trim();
              const iteratorPart = asParts[1].trim();
              const commaIndex = iteratorPart.indexOf(",");
              if (commaIndex !== -1) {
                iterateAs = iteratorPart.substring(0, commaIndex).trim();
                indexAs = iteratorPart.substring(commaIndex + 1).trim();
              } else {
                iterateAs = iteratorPart;
              }
            } else {
              iterateOver = tag.content.trim();
            }
            newNode = {
              ...newNode,
              over: iterateOver,
              content: []
            };
            if (iterateAs) {
              newNode.as = iterateAs;
            }
            if (indexAs) {
              newNode.indexAs = indexAs;
            }
            contentStack.push(newNode);
            conditionStack.push(newNode);
            contentTarget.push(newNode);
            contentBranch = newNode;
            break;
          case "CLOSE_EACH":
            stack.pop();
            contentStack.pop();
            conditionStack.pop();
            contentBranch = last(contentStack);
            break;
          case "SVG_OPEN":
            contentTarget.push({ type: "html", html: "<svg " });
            contentTarget.push(...this.compile(tag.content));
            contentTarget.push({ type: "html", html: ">" });
            newNode = {
              type: "svg",
              content: []
            };
            contentStack.push(newNode);
            contentTarget.push(newNode);
            contentBranch = newNode;
            break;
          case "SVG_CLOSE":
            stack.pop();
            contentStack.pop();
            contentBranch = last(contentStack);
            newNode = {
              type: "html",
              html: "</svg>"
            };
            (contentTarget || ast).push(newNode);
            break;
        }
      } else {
        const html = scanner.consumeUntil(parserRegExp.NEXT_TAG);
        if (html) {
          const htmlNode = { type: "html", html };
          contentTarget.push(htmlNode);
        }
      }
    }
    const optimizedAST = _TemplateCompiler.optimizeAST(ast);
    return optimizedAST;
  }
  getValue(expression) {
    if (expression == "true") {
      return true;
    } else if (expression == "false") {
      return false;
    } else if (isString(expression) && expression.trim() !== "" && Number.isFinite(+expression)) {
      return Number(expression);
    }
    return expression;
  }
  parseTemplateString(expression = "") {
    const regExp = _TemplateCompiler.templateRegExp;
    let templateInfo = {};
    regExp.VERBOSE_KEYWORD.lastIndex = 0;
    if (regExp.VERBOSE_KEYWORD.test(expression)) {
      const matches = [...expression.matchAll(regExp.VERBOSE_PROPERTIES)];
      each(matches, (match, index) => {
        const property = match[1];
        const value = _TemplateCompiler.getObjectFromString(match[2]);
        templateInfo[property] = value;
      });
    } else {
      let data = {};
      const name = expression.split(/\b/)[0];
      templateInfo.name = `'${name}'`;
      const dataMatches = [...expression.matchAll(regExp.STANDARD)];
      each(dataMatches, (match, index) => {
        let name2 = match[1].trim();
        let value = match[2].trim();
        data[name2] = value;
      });
      templateInfo.reactiveData = data;
    }
    return templateInfo;
  }
  static getObjectFromString(objectString = "") {
    const regExp = _TemplateCompiler.templateRegExp.DATA_OBJECT;
    const obj = {};
    let match;
    let isObject2 = false;
    while ((match = regExp.exec(objectString)) !== null) {
      isObject2 = true;
      obj[match[1]] = match[2].trim();
    }
    return isObject2 ? obj : objectString.trim();
  }
  static detectSyntax(templateString = "") {
    const doubleIndex = templateString.search(/{{\s*/);
    const singleIndex = templateString.search(/{[^{]\s*/);
    if (doubleIndex !== -1 && doubleIndex < singleIndex) {
      return "doubleBracket";
    }
    return "singleBracket";
  }
  static preprocessTemplate(templateString = "") {
    templateString = templateString.trim();
    templateString = templateString.replace(
      _TemplateCompiler.preprocessRegExp.WEB_COMPONENT_SELF_CLOSING,
      (match, tagName, attributes) => {
        return `<${tagName}${attributes}></${tagName}>`;
      }
    );
    return templateString;
  }
  // joins neighboring html nodes into a single node
  static optimizeAST(ast) {
    const optimizedAST = [];
    let currentHtmlNode = null;
    const processNode = (node) => {
      if (node.type === "html") {
        if (currentHtmlNode) {
          currentHtmlNode.html += node.html;
        } else {
          currentHtmlNode = { ...node };
          optimizedAST.push(currentHtmlNode);
        }
      } else {
        if (currentHtmlNode) {
          currentHtmlNode = null;
        }
        if (Array.isArray(node.content)) {
          node.content = this.optimizeAST(node.content);
        }
        if (node.else && node.else.content) {
          node.else.content = this.optimizeAST(node.else.content);
        }
        optimizedAST.push(node);
      }
    };
    ast.forEach(processNode);
    return optimizedAST;
  }
};
__publicField(_TemplateCompiler, "singleBracketRegExp", {
  IF: /^{\s*#if\s+/,
  ELSEIF: /^{\s*else\s*if\s+/,
  ELSE: /^{\s*else\s*/,
  EACH: /^{\s*#each\s+/,
  SNIPPET: /^{\s*#snippet\s+/,
  CLOSE_IF: /^{\s*\/(if)\s*/,
  CLOSE_EACH: /^{\s*\/(each)\s*/,
  CLOSE_SNIPPET: /^{\s*\/(snippet)\s*/,
  SLOT: /^{>\s*slot\s*/,
  TEMPLATE: /^{>\s*/,
  HTML_EXPRESSION: /^{\s*#html\s*/,
  EXPRESSION: /^{\s*/
});
__publicField(_TemplateCompiler, "singleBracketParserRegExp", {
  NEXT_TAG: /(\{|\<svg|\<\/svg)/,
  // used to advance scanner to either a parseable expression or svg tag
  EXPRESSION_START: /\{/,
  EXPRESSION_END: /\}/,
  TAG_CLOSE: /\>/
});
__publicField(_TemplateCompiler, "doubleBracketRegExp", {
  IF: /^{{\s*#if\s+/,
  ELSEIF: /^{{\s*else\s*if\s+/,
  ELSE: /^{{\s*else\s*/,
  EACH: /^{{\s*#each\s+/,
  SNIPPET: /^{{\s*#snippet\s+/,
  CLOSE_IF: /^{{\s*\/(if)\s*/,
  CLOSE_EACH: /^{{\s*\/(each)\s*/,
  CLOSE_SNIPPET: /^{{\s*\/(snippet)\s*/,
  SLOT: /^{{>\s*slot\s*/,
  TEMPLATE: /^{{>\s*/,
  HTML_EXPRESSION: /^{{\s*#html\s*/,
  EXPRESSION: /^{{\s*/
});
__publicField(_TemplateCompiler, "doubleBracketParserRegExp", {
  NEXT_TAG: /(\{\{|\<svg|\<\/svg)/,
  // used to advance scanner to either a parseable expression or svg tag
  EXPRESSION_START: /\{\{/,
  EXPRESSION_END: /\}\}/,
  TAG_CLOSE: /\>/
});
__publicField(_TemplateCompiler, "htmlRegExp", {
  SVG_OPEN: /^\<svg\s*/i,
  SVG_CLOSE: /^\<\/svg\s*/i
});
__publicField(_TemplateCompiler, "preprocessRegExp", {
  WEB_COMPONENT_SELF_CLOSING: /<(\w+-\w+)([^>]*)\/>/g
});
__publicField(_TemplateCompiler, "templateRegExp", {
  VERBOSE_KEYWORD: /^(template|snippet)\W/g,
  VERBOSE_PROPERTIES: /(\w+)\s*=\s*(((?!\w+\s*=).)+)/gms,
  STANDARD: /(\w+)\s*=\s*((?:(?!\n|$|\w+\s*=).)+)/g,
  DATA_OBJECT: /(\w+)\s*:\s*([^,}]+)/g,
  // parses { one: 'two' }
  SINGLE_QUOTES: /\'/g
});
var TemplateCompiler = _TemplateCompiler;

// packages/reactivity/src/scheduler.js
var _Scheduler = class _Scheduler {
  static scheduleReaction(reaction) {
    _Scheduler.pendingReactions.add(reaction);
    _Scheduler.scheduleFlush();
  }
  static scheduleFlush() {
    if (!_Scheduler.isFlushScheduled) {
      _Scheduler.isFlushScheduled = true;
      if (typeof queueMicrotask === "function") {
        queueMicrotask(() => _Scheduler.flush());
      } else {
        Promise.resolve().then(() => _Scheduler.flush());
      }
    }
  }
  static flush() {
    _Scheduler.isFlushScheduled = false;
    _Scheduler.pendingReactions.forEach((reaction) => reaction.run());
    _Scheduler.pendingReactions.clear();
    _Scheduler.afterFlushCallbacks.forEach((callback) => callback());
    _Scheduler.afterFlushCallbacks = [];
  }
  static afterFlush(callback) {
    _Scheduler.afterFlushCallbacks.push(callback);
  }
  static getSource() {
    var _a3;
    if (!_Scheduler.current) {
      console.log("No reactive flush is currently occurring.");
      return;
    }
    const { context, dependencies } = _Scheduler.current;
    let stack = context.stack || ((_a3 = dependencies == null ? void 0 : dependencies.values().next()) == null ? void 0 : _a3.value.context.stack);
    let message;
    if (stack) {
      if (context.message) {
        message = context.message;
      } else if (context.firstRun) {
        message = `First run of new reaction created at:`;
      } else if (context.value) {
        message = `Reaction triggered by reactive update`;
      } else {
        message = `Reaction triggered at:`;
      }
      console.groupCollapsed("\u{1F501} Reaction Triggered");
      console.log(message);
      if (context.value) {
        console.log("Reactive value change was:", context.value);
      }
      console.log("Reaction was:", _Scheduler.current);
      console.error(stack);
      delete context.stack;
      console.log("Metadata:", context);
      console.groupEnd();
    } else {
      console.error("Nothing found");
      console.log(_Scheduler.current.context);
    }
    return stack;
  }
};
__publicField(_Scheduler, "current", null);
__publicField(_Scheduler, "pendingReactions", /* @__PURE__ */ new Set());
__publicField(_Scheduler, "afterFlushCallbacks", []);
__publicField(_Scheduler, "isFlushScheduled", false);
var Scheduler = _Scheduler;

// packages/reactivity/src/dependency.js
var Dependency = class {
  constructor(...metadata) {
    this.subscribers = /* @__PURE__ */ new Set();
    this.setContext(metadata);
  }
  depend() {
    if (Scheduler.current) {
      this.subscribers.add(Scheduler.current);
      Scheduler.current.dependencies.add(this);
    }
  }
  // allows metadata to be passed with dependency for debugging
  setContext(context = {}) {
    if (Error.captureStackTrace) {
      Error.captureStackTrace(context, this.setContext);
    } else {
      context.stack = new Error().stack;
    }
    this.context = context;
  }
  changed(context) {
    this.setContext(context);
    this.subscribers.forEach((subscriber) => subscriber.invalidate(this.context));
  }
  // called after flush
  cleanUp(reaction) {
    this.subscribers.delete(reaction);
  }
  // identical for now but called from stop()
  unsubscribe(reaction) {
    this.subscribers.delete(reaction);
  }
};

// packages/reactivity/src/reaction.js
var _Reaction = class _Reaction {
  static create(callback, options = {}) {
    const reaction = new _Reaction(callback, options);
    if (options.firstRun !== false) {
      reaction.boundRun();
    }
    return reaction;
  }
  constructor(callback, { context } = {}) {
    this.callback = callback;
    this.dependencies = /* @__PURE__ */ new Set();
    this.firstRun = true;
    this.active = true;
    if (context) {
      this.setContext(context);
    }
    this.boundRun = this.run.bind(this);
  }
  setContext(additionalContext = {}) {
    const defaultContext = {
      firstRun: this.firstRun
    };
    this.context = {
      ...defaultContext,
      ...additionalContext
    };
  }
  setTrace() {
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this.context, this.setTrace);
    } else {
      this.context.stack = new Error().stack;
    }
  }
  addContext(additionalContext = {}) {
    if (!this.context) {
      this.context = {};
    }
    for (const key in additionalContext) {
      this.context[key] = additionalContext[key];
    }
  }
  run() {
    if (!this.active) {
      return;
    }
    this.addContext({
      firstRun: this.firstRun
    });
    Scheduler.current = this;
    this.dependencies.forEach((dep) => dep.cleanUp(this));
    this.dependencies.clear();
    this.callback(this);
    this.firstRun = false;
    Scheduler.current = null;
    Scheduler.pendingReactions.delete(this);
  }
  invalidate(context) {
    this.active = true;
    if (context) {
      this.addContext(context);
    }
    Scheduler.scheduleReaction(this);
  }
  stop() {
    if (!this.active) {
      return;
    }
    this.active = false;
    this.dependencies.forEach((dep) => dep.unsubscribe(this));
  }
  // Static proxies for developer experience
  static get current() {
    return Scheduler.current;
  }
  static nonreactive(func) {
    const previousReaction = Scheduler.current;
    Scheduler.current = null;
    try {
      return func();
    } finally {
      Scheduler.current = previousReaction;
    }
  }
  static guard(f5, equalCheck = isEqual) {
    if (!Scheduler.current) {
      return f5();
    }
    let dep = new Dependency();
    let value, newValue;
    dep.depend();
    const comp = new _Reaction(() => {
      newValue = f5();
      if (!comp.firstRun && !equalCheck(newValue, value)) {
        dep.changed();
      }
      value = clone(newValue);
    });
    comp.run();
    return newValue;
  }
};
// DX pass throughs
__publicField(_Reaction, "flush", Scheduler.flush);
__publicField(_Reaction, "scheduleFlush", Scheduler.scheduleFlush);
__publicField(_Reaction, "afterFlush", Scheduler.afterFlush);
__publicField(_Reaction, "getSource", Scheduler.getSource);
var Reaction = _Reaction;

// packages/reactivity/src/signal.js
var _Signal = class _Signal {
  constructor(initialValue, { context, equalityFunction, allowClone = true, cloneFunction } = {}) {
    this.dependency = new Dependency({
      firstRun: true,
      value: initialValue
    });
    this.allowClone = allowClone;
    this.equalityFunction = equalityFunction ? wrapFunction(equalityFunction) : _Signal.equalityFunction;
    this.clone = cloneFunction ? wrapFunction(cloneFunction) : _Signal.cloneFunction;
    this.currentValue = this.maybeClone(initialValue);
    this.setContext(context);
  }
  // set debugging context for signal
  setContext(additionalContext = {}) {
    const defaultContext = {
      value: this.currentValue
    };
    this.context = {
      ...defaultContext,
      ...additionalContext
    };
  }
  addContext(additionalContext = {}) {
    if (!this.context) {
      this.context = {};
    }
    for (const key in additionalContext) {
      this.context[key] = additionalContext[key];
    }
  }
  // set debugging stack trace for signal
  setTrace() {
    if (Error.captureStackTrace) {
      Error.captureStackTrace(this.context, this.setTrace);
    } else {
      this.context.stack = new Error().stack;
    }
  }
  get value() {
    this.dependency.depend();
    const value = this.currentValue;
    return Array.isArray(value) || typeof value == "object" ? this.maybeClone(value) : value;
  }
  canCloneValue(value) {
    return this.allowClone === true && !isClassInstance(value);
  }
  maybeClone(value) {
    if (!this.canCloneValue(value)) {
      return value;
    }
    if (isArray(value)) {
      return value = value.map((value2) => this.maybeClone(value2));
    }
    return this.clone(value);
  }
  set value(newValue) {
    if (!this.equalityFunction(this.currentValue, newValue)) {
      this.currentValue = this.maybeClone(newValue);
      this.setContext();
      this.setTrace();
      this.dependency.changed(this.context);
    }
  }
  get() {
    return this.value;
  }
  set(newValue) {
    if (!this.equalityFunction(this.currentValue, newValue)) {
      this.addContext({ value: newValue });
      this.value = newValue;
    }
  }
  subscribe(callback) {
    return Reaction.create((comp) => {
      callback(this.value, comp);
    });
  }
  peek() {
    return this.maybeClone(this.currentValue);
  }
  clear() {
    return this.set(void 0);
  }
  // array helpers
  push(...args) {
    const arr = this.peek();
    arr.push(...args);
    this.set(arr);
  }
  unshift(...args) {
    const arr = this.peek();
    arr.unshift(...args);
    this.set(arr);
  }
  splice(...args) {
    const arr = this.peek();
    arr.splice(...args);
    this.set(arr);
  }
  map(mapFunction) {
    const newValue = Array.prototype.map.call(this.peek(), mapFunction);
    this.set(newValue);
  }
  filter(filterFunction) {
    const newValue = Array.prototype.filter.call(this.peek(), filterFunction);
    this.set(newValue);
  }
  getIndex(index) {
    return this.get()[index];
  }
  setIndex(index, value) {
    let arr = this.peek();
    arr[index] = value;
    this.set(arr);
  }
  removeIndex(index) {
    let arr = this.peek();
    arr.splice(index, 1);
    this.set(arr);
  }
  // sets
  setArrayProperty(indexOrProperty, property, value) {
    let index;
    if (isNumber(indexOrProperty)) {
      index = indexOrProperty;
    } else {
      index = "all";
      value = property;
      property = indexOrProperty;
    }
    const newValue = this.peek().map((object, currentIndex) => {
      if (index == "all" || currentIndex == index) {
        object[property] = value;
      }
      return object;
    });
    this.set(newValue);
  }
  toggle() {
    return this.set(!this.peek());
  }
  increment(amount = 1, max) {
    let newAmount = this.peek() + amount;
    if (isNumber(max) && newAmount > max) {
      newAmount = max;
    }
    return this.set(newAmount);
  }
  decrement(amount = 1, min) {
    let newAmount = this.peek() - amount;
    if (isNumber(min) && newAmount < min) {
      newAmount = min;
    }
    return this.set(newAmount);
  }
  now() {
    return this.set(/* @__PURE__ */ new Date());
  }
  getIDs(item) {
    if (isObject(item)) {
      return unique([item == null ? void 0 : item._id, item == null ? void 0 : item.id, item == null ? void 0 : item.hash, item == null ? void 0 : item.key].filter(Boolean));
    }
    return [item];
  }
  getID(item) {
    return this.getIDs(item).filter(Boolean)[0];
  }
  hasID(item, id) {
    return this.getID(item) === id;
  }
  getItem(id) {
    return findIndex(this.currentValue, (item) => this.hasID(item, id));
  }
  setProperty(idOrProperty, property, value) {
    if (arguments.length == 3) {
      const id = idOrProperty;
      const index = this.getItem(id);
      return this.setArrayProperty(index, property, value);
    } else {
      value = property;
      property = idOrProperty;
      const obj = this.peek();
      obj[property] = value;
      this.set(obj);
    }
  }
  replaceItem(id, item) {
    return this.setIndex(this.getItem(id), item);
  }
  removeItem(id) {
    return this.removeIndex(this.getItem(id));
  }
};
__publicField(_Signal, "equalityFunction", isEqual);
__publicField(_Signal, "cloneFunction", clone);
var Signal = _Signal;

// packages/templating/src/template-helpers.js
var TemplateHelpers = {
  exists(a3) {
    return !isEmpty(a3);
  },
  isEmpty(a3) {
    return isEmpty(a3);
  },
  stringify(a3) {
    return JSON.stringify(a3);
  },
  hasAny(a3) {
    return (a3 == null ? void 0 : a3.length) > 0;
  },
  range(start, stop, step = 1) {
    return range(start, stop, step);
  },
  concat(...args) {
    return args.join("");
  },
  both(a3, b3) {
    return a3 && b3;
  },
  either(a3, b3) {
    return a3 || b3;
  },
  join(array = [], delimiter = " ", spaceAfter = false) {
    if (array.length == 0) {
      return;
    }
    const value = array.join(delimiter).trim();
    return spaceAfter ? `${value} ` : value;
  },
  classes(classes, spaceAfter = true) {
    return TemplateHelpers.join(classes, " ", true);
  },
  joinComma(array = [], oxford, quotes) {
    return joinWords(array, {
      separator: ", ",
      lastSeparator: " and ",
      oxford,
      quotes
    });
  },
  classIf(expr, trueClass = "", falseClass = "") {
    let val = expr ? trueClass : falseClass;
    return val ? `${val} ` : "";
  },
  classMap(classObj) {
    let classNames = [];
    each(classObj, (condition, className) => {
      if (condition) {
        classNames.push(className);
      }
    });
    return classNames.length ? `${classNames.join(" ")} ` : "";
  },
  maybe(expr, trueExpr, falseExpr) {
    return expr ? trueExpr : falseExpr;
  },
  activeIf(expr) {
    return TemplateHelpers.classIf(expr, "active", "");
  },
  selectedIf(expr) {
    return TemplateHelpers.classIf(expr, "selected", "");
  },
  capitalize(text = "") {
    return capitalize(text);
  },
  titleCase(text = "") {
    return toTitleCase(text);
  },
  disabledIf(expr) {
    return TemplateHelpers.classIf(expr, "disabled", "");
  },
  checkedIf(expr) {
    return TemplateHelpers.classIf(expr, "checked", "");
  },
  maybePlural(value, plural = "s") {
    return value == 1 ? "" : plural;
  },
  not(a3) {
    return !a3;
  },
  is(a3, b3) {
    return a3 == b3;
  },
  isNot(a3, b3) {
    return a3 !== b3;
  },
  notEqual(a3, b3) {
    return TemplateHelpers.isNot(a3, b3);
  },
  isExactly(a3, b3) {
    return a3 === b3;
  },
  isNotExactly(a3, b3) {
    return a3 !== b3;
  },
  greaterThan(a3, b3) {
    return a3 > b3;
  },
  lessThan(a3, b3) {
    return a3 < b3;
  },
  greaterThanEquals(a3, b3) {
    return a3 >= b3;
  },
  lessThanEquals(a3, b3) {
    return a3 <= b3;
  },
  numberFromIndex(a3) {
    return a3 + 1;
  },
  formatDate(date = /* @__PURE__ */ new Date(), format = "L", options = { timezone: "local" }) {
    return formatDate(date, format, options);
  },
  formatDateTime(date = /* @__PURE__ */ new Date(), format = "LLL", options = { timezone: "local" }) {
    return formatDate(date, format, options);
  },
  formatDateTimeSeconds(date = /* @__PURE__ */ new Date(), format = "LTS", options = { timezone: "local" }) {
    return formatDate(date, format, options);
  },
  object({ obj }) {
    return obj;
  },
  log(...args) {
    console.log(...args);
  },
  debugger() {
    debugger;
  },
  tokenize(string = "") {
    return tokenize(string);
  },
  debugReactivity() {
    Reaction.getSource();
  },
  arrayFromObject(obj) {
    return arrayFromObject(obj);
  },
  escapeHTML(string) {
    return escapeHTML(string);
  },
  guard: (value) => {
    return Reaction.guard(wrapFunction(value));
  },
  nonreactive: (value) => {
    return Reaction.nonReactive(wrapFunction(value));
  }
};

// packages/query/src/query.js
var _Query = class _Query {
  constructor(selector, { root = document, pierceShadow = false, prevObject = null } = {}) {
    let elements = [];
    if (!root) {
      return;
    }
    if (selector instanceof _Query) {
      elements = selector;
    }
    if (selector === window || selector === globalThis || inArray(selector, ["window", "globalThis"]) || selector == _Query.globalThisProxy) {
      elements = [_Query.globalThisProxy];
      this.isBrowser = isClient;
      this.isGlobal = true;
    } else if (isArray(selector) || selector instanceof NodeList || selector instanceof HTMLCollection) {
      selector = Array.from(selector);
      elements = selector;
    } else if (isString(selector)) {
      if (selector.trim().slice(0, 1) == "<") {
        const template = document.createElement("template");
        template.innerHTML = selector.trim();
        elements = Array.from(template.content.childNodes);
      } else {
        elements = pierceShadow ? this.querySelectorAllDeep(root, selector) : root.querySelectorAll(selector);
      }
    } else if (isDOM(selector)) {
      elements = [selector];
    } else if (selector instanceof NodeList) {
      elements = selector;
    }
    this.selector = selector;
    this.length = elements.length;
    this.options = { root, pierceShadow };
    this.prevObject = prevObject;
    Object.assign(this, elements);
  }
  /* Returns a copy of current DOM Object */
  chain(elements) {
    return this.isGlobal && !elements ? new _Query(globalThis, this.options) : new _Query(elements, { ...this.options, prevObject: this });
  }
  end() {
    return this.prevObject || this;
  }
  /* we will add all elements across shadow root boundaries while matching
     intermediate selectors at shadow boundaries
  */
  querySelectorAllDeep(root, selector, includeRoot = true) {
    const elements = /* @__PURE__ */ new Set();
    const domSelector = isDOM(selector);
    let domFound = false;
    let queriedRoot = false;
    if (includeRoot) {
      if (domSelector && root == selector || !domSelector && root.matches && root.matches(selector)) {
        elements.add(root);
      }
    }
    if (domSelector) {
      queriedRoot = true;
    } else if (root.querySelectorAll) {
      root.querySelectorAll(selector).forEach((el) => elements.add(el));
      queriedRoot = true;
    }
    const getRemainingSelector = (el, selector2) => {
      const parts = selector2.split(" ");
      let partialSelector;
      let remainingSelector;
      each(parts, (part, index) => {
        partialSelector = parts.slice(0, index + 1).join(" ");
        if (el.matches(partialSelector)) {
          remainingSelector = parts.slice(index + 1).join(" ");
          return;
        }
      });
      return remainingSelector || selector2;
    };
    const addElements = (node, selector2) => {
      if (domSelector && (node === selector2 || node.contains)) {
        if (node.contains(selector2)) {
          elements.add(selector2);
          domFound = true;
        }
      } else if (node.querySelectorAll) {
        node.querySelectorAll(selector2).forEach((el) => elements.add(el));
      }
    };
    const findElements = (node, selector2, query) => {
      if (domSelector && domFound) return;
      if (query === true) {
        addElements(node, selector2);
        queriedRoot = true;
      }
      if (node.nodeType === Node.ELEMENT_NODE && node.shadowRoot) {
        const newSelector = getRemainingSelector(node, selector2);
        addElements(node.shadowRoot, newSelector);
        findElements(node.shadowRoot, newSelector, !queriedRoot);
      }
      if (node.assignedNodes) {
        const newSelector = getRemainingSelector(node, selector2);
        const nodes = node.assignedNodes();
        for (let i6 = 0; i6 < nodes.length; i6++) {
          findElements(nodes[i6], newSelector, queriedRoot);
        }
      }
      if (node.childNodes && node.childNodes.length) {
        const childCount = node.childNodes.length;
        for (let i6 = 0; i6 < childCount; i6++) {
          findElements(node.childNodes[i6], selector2, queriedRoot);
        }
      }
    };
    findElements(root, selector);
    return Array.from(elements);
  }
  each(callback) {
    for (let index = 0; index < this.length; index++) {
      const el = this[index];
      const $el = this.chain(el);
      callback.call($el, el, index);
    }
    return this;
  }
  removeAllEvents() {
    _Query.eventHandlers = [];
  }
  find(selector) {
    const elements = Array.from(this).flatMap((el) => {
      if (this.options.pierceShadow) {
        return this.querySelectorAllDeep(el, selector, false);
      } else {
        return Array.from(el.querySelectorAll(selector));
      }
    });
    return this.chain(elements);
  }
  parent(selector) {
    const parents = Array.from(this).map((el) => el.parentElement).filter(Boolean);
    return selector ? this.chain(parents).filter(selector) : this.chain(parents);
  }
  children(selector) {
    const allChildren = Array.from(this).flatMap((el) => Array.from(el.children));
    const filteredChildren = selector ? allChildren.filter((child) => child.matches(selector)) : allChildren;
    return this.chain(filteredChildren);
  }
  siblings(selector) {
    const siblings = Array.from(this).flatMap((el) => {
      if (!el.parentNode) {
        return;
      }
      return Array.from(el.parentNode.children).filter((child) => child !== el);
    }).filter(Boolean);
    return selector ? this.chain(siblings).filter(selector) : this.chain(siblings);
  }
  // returns the index of element only including siblings that match a filter
  index(siblingFilter) {
    const el = this.el();
    if (!(el == null ? void 0 : el.parentNode)) {
      return -1;
    }
    const $siblings = this.chain(el.parentNode.children).filter(siblingFilter);
    const siblingEls = $siblings.get();
    const els = this.get();
    return findIndex(siblingEls, (el2) => inArray(el2, els));
  }
  // returns the index of current collection that match filter
  indexOf(filter) {
    const els = this.get();
    const el = this.filter(filter).get(0);
    return els.indexOf(el);
  }
  filter(filter) {
    if (!filter) {
      return this;
    }
    let filteredElements = [];
    if (isFunction(filter)) {
      filteredElements = Array.from(this).filter(filter);
    } else {
      filteredElements = Array.from(this).filter((el) => {
        if (isString(filter)) {
          return el.matches && el.matches(filter);
        } else if (filter instanceof _Query) {
          return filter.get().includes(el);
        } else {
          let els = isArray(filter) ? filter : [filter];
          return inArray(el, els);
        }
      });
    }
    return this.chain(filteredElements);
  }
  is(selector) {
    const filteredElements = Array.from(this).filter((el) => {
      if (typeof selector === "string") {
        return el.matches && el.matches(selector);
      } else if (this.isGlobal) {
        return inArray(selector, ["window", "globalThis"]);
      } else {
        const elements = selector instanceof _Query ? selector.get() : [selector];
        return elements.includes(el);
      }
    });
    return filteredElements.length === this.length;
  }
  not(selector) {
    const filteredElements = Array.from(this).filter((el) => {
      if (typeof selector === "string") {
        return !el.matches || el.matches && !el.matches(selector);
      } else if (this.isGlobal) {
        return !inArray(selector, ["window", "globalThis"]);
      } else {
        const elements = selector instanceof _Query ? selector.get() : [selector];
        return !elements.includes(el);
      }
    });
    return this.chain(filteredElements);
  }
  closest(selector) {
    const closest = Array.from(this).map((el) => {
      if (this.options.pierceShadow) {
        return this.closestDeep(el, selector);
      } else if (selector && (el == null ? void 0 : el.closest)) {
        return el.closest(selector);
      } else if (this.isGlobal) {
        return inArray(selector, ["window", "globalThis"]);
      }
    }).filter(Boolean);
    return this.chain(closest);
  }
  closestDeep(element, selector) {
    let currentElement = element;
    const domSelector = isDOM(selector);
    const stringSelector = isString(selector);
    while (currentElement) {
      if (domSelector && currentElement === selector || stringSelector && currentElement.matches(selector)) {
        return currentElement;
      }
      if (currentElement.parentElement) {
        currentElement = currentElement.parentElement;
      } else if (currentElement.parentNode && currentElement.parentNode.host) {
        currentElement = currentElement.parentNode.host;
      } else {
        return;
      }
    }
    return;
  }
  ready(handler) {
    if (this.is(document) && document.readyState == "loading") {
      this.on("ready", handler);
    } else {
      handler.call(document, new Event("DOMContentLoaded"));
    }
    return this;
  }
  getEventAlias(eventName) {
    const aliases = {
      ready: "DOMContentLoaded"
    };
    return aliases[eventName] || eventName;
  }
  getEventArray(eventNames) {
    return eventNames.split(" ").map((name) => this.getEventAlias(name)).filter(Boolean);
  }
  on(eventNames, targetSelectorOrHandler, handlerOrOptions, options) {
    const eventHandlers = [];
    let handler;
    let targetSelector;
    if (isObject(handlerOrOptions)) {
      options = handlerOrOptions;
      handler = targetSelectorOrHandler;
    } else if (isString(targetSelectorOrHandler)) {
      targetSelector = targetSelectorOrHandler;
      handler = handlerOrOptions;
    } else if (isFunction(targetSelectorOrHandler)) {
      handler = targetSelectorOrHandler;
    }
    const events6 = this.getEventArray(eventNames);
    events6.forEach((eventName) => {
      const abortController = (options == null ? void 0 : options.abortController) || new AbortController();
      const eventSettings = (options == null ? void 0 : options.eventSettings) || {};
      const signal = abortController.signal;
      this.each((el) => {
        let delegateHandler;
        if (targetSelector) {
          delegateHandler = (event) => {
            let target;
            if (event.composed && event.composedPath) {
              let path = event.composedPath();
              const elIndex = findIndex(path, (thisEl) => thisEl == el);
              path = path.slice(0, elIndex);
              target = path.find((el2) => el2 instanceof Element && el2.matches && el2.matches(targetSelector));
            } else {
              target = event.target.closest(targetSelector);
            }
            if (target) {
              handler.call(target, event);
            }
          };
        }
        const eventListener = delegateHandler || handler;
        const domEL = el == _Query.globalThisProxy ? globalThis : el;
        if (domEL.addEventListener) {
          domEL.addEventListener(eventName, eventListener, { signal, ...eventSettings });
        }
        const eventHandler = {
          el,
          eventName,
          eventListener,
          abortController,
          delegated: targetSelector !== void 0,
          handler,
          abort: (reason) => abortController.abort(reason)
        };
        eventHandlers.push(eventHandler);
      });
    });
    if (!_Query.eventHandlers) {
      _Query.eventHandlers = [];
    }
    _Query.eventHandlers.push(...eventHandlers);
    if (options == null ? void 0 : options.returnHandler) {
      return eventHandlers.length == 1 ? eventHandlers[0] : eventHandlers;
    }
    return this;
  }
  one(eventName, targetSelectorOrHandler, handlerOrOptions, options) {
    let handler;
    let targetSelector;
    if (isObject(handlerOrOptions)) {
      options = handlerOrOptions;
      handler = targetSelectorOrHandler;
    } else if (isString(targetSelectorOrHandler)) {
      targetSelector = targetSelectorOrHandler;
      handler = handlerOrOptions;
    } else if (isFunction(targetSelectorOrHandler)) {
      handler = targetSelectorOrHandler;
    }
    options = options || {};
    const abortController = new AbortController();
    options.abortController = abortController;
    const wrappedHandler = function(...args) {
      abortController.abort();
      handler.apply(this, args);
    };
    return targetSelector ? this.on(eventName, targetSelector, wrappedHandler, options) : this.on(eventName, wrappedHandler, options);
  }
  off(eventNames, handler) {
    const events6 = this.getEventArray(eventNames);
    _Query.eventHandlers = _Query.eventHandlers.filter((eventHandler) => {
      if ((!eventNames || inArray(eventHandler.eventName, events6)) && (!handler || (handler == null ? void 0 : handler.eventListener) == eventHandler.eventListener || eventHandler.eventListener === handler || eventHandler.handler === handler)) {
        const el = this.isGlobal ? globalThis : eventHandler.el;
        if (el.removeEventListener) {
          el.removeEventListener(eventHandler.eventName, eventHandler.eventListener);
        }
        return false;
      }
      return true;
    });
    return this;
  }
  trigger(eventName, eventParams) {
    return this.each((el) => {
      if (typeof el.dispatchEvent !== "function") {
        return;
      }
      const event = new Event(eventName, { bubbles: true, cancelable: true });
      if (eventParams) {
        Object.assign(event, eventParams);
      }
      el.dispatchEvent(event);
    });
  }
  // shorthand for most common trigger() uses
  click(eventParams) {
    return this.trigger("click", eventParams);
  }
  submit(eventParams) {
    return this.trigger("submit", eventParams);
  }
  dispatchEvent(eventName, eventData = {}, eventSettings = {}) {
    const eventOptions = {
      bubbles: true,
      cancelable: true,
      composed: true,
      detail: eventData,
      ...eventSettings
    };
    this.each((el) => {
      const event = new CustomEvent(eventName, eventOptions);
      el.dispatchEvent(event);
    });
    return this;
  }
  remove() {
    return this.each((el) => el.remove());
  }
  addClass(classNames) {
    const classesToAdd = classNames.split(" ");
    return this.each((el) => el.classList.add(...classesToAdd));
  }
  hasClass(className) {
    return Array.from(this).some((el) => el.classList.contains(className));
  }
  removeClass(classNames) {
    const classesToRemove = classNames.split(" ");
    return this.each((el) => el.classList.remove(...classesToRemove));
  }
  toggleClass(classNames) {
    const classesToToggle = classNames.split(" ");
    return this.each((el) => el.classList.toggle(...classesToToggle));
  }
  html(newHTML) {
    if (newHTML !== void 0) {
      return this.each((el) => el.innerHTML = newHTML);
    } else if (this.length > 0) {
      return this.map((el) => el.innerHTML || el.nodeValue).join("");
    }
  }
  outerHTML(newHTML) {
    if (newHTML !== void 0) {
      return this.each((el) => el.outerHTML = newHTML);
    } else if (this.length) {
      return this.map((el) => el.outerHTML).join("");
    }
  }
  getSlot(name) {
    return this.map((el) => {
      if (el.tagName.toLowerCase() == "slot" && (!name || el.name == name)) {
        const nodes = el.assignedNodes({ flatten: true });
        if (nodes) {
          return this.chain(nodes).html();
        }
      } else if (el.shadowRoot) {
        const slotSelector = name ? `slot[name="${name}"]` : "slot:not([name])";
        const slot = el.shadowRoot.querySelector(slotSelector);
        const nodes = slot.assignedNodes({ flatten: true });
        if (nodes) {
          return this.chain(nodes).html();
        }
      } else {
        const slotSelector = name ? `[slot="${name}"]` : ":not([slot])";
        return this.chain(el).find(slotSelector).html();
      }
    }).join("");
  }
  setSlot(nameOrHTML, newHTML) {
    let name;
    if (newHTML) {
      name = nameOrHTML;
    } else {
      newHTML = nameOrHTML;
    }
    return this.each((el) => {
      var _a3;
      if (el.tagName.toLowerCase() == "slot") {
        el = (_a3 = el.getRootNode().getRootNode()) == null ? void 0 : _a3.host;
      }
      const $el = this.chain(el);
      if (name) {
        const slotSelector = `[slot="${name}"]`;
        let $slottedElement = this.chain(el).find(slotSelector);
        if (!$slottedElement.exists()) {
          $el.append(`<span slot="${name}"></span>`);
          $slottedElement = this.chain(el).find(slotSelector);
        }
        $slottedElement.html(newHTML);
      } else {
        $el.html(newHTML);
      }
    });
  }
  text(newText) {
    if (newText !== void 0) {
      return this.each((el) => el.textContent = newText);
    } else {
      const childNodes = (el) => {
        return el.nodeName === "SLOT" ? el.assignedNodes({ flatten: true }) : el.childNodes;
      };
      const values2 = this.map((el) => this.getTextContentRecursive(childNodes(el)));
      return values2.length > 1 ? values2 : values2[0];
    }
  }
  // Helper function to recursively get text content
  getTextContentRecursive(nodes) {
    return Array.from(nodes).map((node) => {
      if (node.nodeType === Node.TEXT_NODE) {
        return node.nodeValue;
      } else if (node.nodeName === "SLOT") {
        const slotNodes = node.assignedNodes({ flatten: true });
        return this.getTextContentRecursive(slotNodes);
      } else {
        return this.getTextContentRecursive(node.childNodes);
      }
    }).join("").trim();
  }
  // non jquery variant to return only immediate text node
  textNode() {
    return Array.from(this).map((el) => {
      return Array.from(el.childNodes).filter((node) => node.nodeType === Node.TEXT_NODE).map((node) => node.nodeValue).join("");
    }).join("");
  }
  map(...args) {
    return Array.from(this).map(...args);
  }
  value(newValue) {
    const usesValue = (el) => {
      return el instanceof HTMLInputElement || el instanceof HTMLSelectElement || el instanceof HTMLTextAreaElement || customElements.get(el.tagName.toLowerCase());
    };
    if (newValue !== void 0) {
      return this.each((el) => {
        if (usesValue(el)) {
          el.value = newValue;
        }
      });
    } else {
      const values2 = this.map((el) => {
        if (usesValue(el)) {
          return el.value;
        }
        return void 0;
      });
      return values2.length > 1 ? values2 : values2[0];
    }
  }
  // alias
  val(...args) {
    return this.value(...args);
  }
  focus() {
    if (this.length) {
      this[0].focus();
    }
    return this;
  }
  blur() {
    if (this.length) {
      this[0].blur();
    }
    return this;
  }
  css(property, value = null, settings = { includeComputed: false }) {
    const elements = Array.from(this);
    if (isPlainObject(property) || value !== null) {
      if (isPlainObject(property)) {
        Object.entries(property).forEach(([prop, val]) => {
          elements.forEach((el) => el.style.setProperty(camelToKebab(prop), val));
        });
      } else {
        elements.forEach((el) => el.style.setProperty(camelToKebab(property), value));
      }
      return this;
    } else {
      if (elements == null ? void 0 : elements.length) {
        const styles = elements.map((el) => {
          const inlineStyle = el.style[property];
          if (settings.includeComputed) {
            return window.getComputedStyle(el).getPropertyValue(property);
          }
          if (inlineStyle) {
            return inlineStyle;
          }
          return void 0;
        });
        return elements.length === 1 ? styles[0] : styles;
      }
    }
  }
  computedStyle(property) {
    return this.css(property, null, { includeComputed: true });
  }
  cssVar(variable, value) {
    return this.css(`--${variable}`, value, { includeComputed: true });
  }
  attr(attribute, value) {
    if (isPlainObject(attribute)) {
      Object.entries(attribute).forEach(([attr, val]) => {
        this.each((el) => el.setAttribute(attr, val));
      });
    } else if (value !== void 0) {
      this.each((el) => el.setAttribute(attribute, value));
    } else if (this.length) {
      const attributes = this.map((el) => el.getAttribute(attribute));
      return attributes.length > 1 ? attributes : attributes[0];
    }
    return;
  }
  removeAttr(attributeName) {
    return this.each((el) => el.removeAttribute(attributeName));
  }
  el() {
    return this.get(0);
  }
  get(index) {
    if (index !== void 0) {
      return this[index];
    } else {
      return Array.from(this);
    }
  }
  eq(index) {
    return this.chain(this[index]);
  }
  first() {
    return this.eq(0);
  }
  last() {
    return this.eq(this.length - 1);
  }
  prop(name, value) {
    if (value !== void 0) {
      return this.each((el) => {
        el[name] = value;
      });
    } else {
      if (this.length == 0) {
        return void 0;
      } else if (this.length === 1) {
        return this[0][name];
      } else {
        return this.map((el) => el[name]);
      }
    }
  }
  next(selector) {
    const nextSiblings = this.map((el) => {
      let nextSibling = el.nextElementSibling;
      while (nextSibling) {
        if (!selector || nextSibling.matches(selector)) {
          return nextSibling;
        }
        nextSibling = nextSibling.nextElementSibling;
      }
      return null;
    }).filter(Boolean);
    return this.chain(nextSiblings);
  }
  prev(selector) {
    const prevSiblings = this.map((el) => {
      let prevSibling = el.previousElementSibling;
      while (prevSibling) {
        if (!selector || prevSibling.matches(selector)) {
          return prevSibling;
        }
        prevSibling = prevSibling.previousElementSibling;
      }
      return null;
    }).filter(Boolean);
    return this.chain(prevSiblings);
  }
  height(value) {
    return this.prop("innerHeight", value) || this.prop("clientHeight", value);
  }
  width(value) {
    return this.prop("innerWidth", value) || this.prop("clientWidth", value);
  }
  scrollHeight(value) {
    const el = this.isGlobal && this.isBrowser ? this.chain(document.documentElement) : this;
    return el.prop("scrollHeight", value);
  }
  scrollWidth(value) {
    const el = this.isGlobal && this.isBrowser ? this.chain(document.documentElement) : this;
    return el.prop("scrollWidth", value);
  }
  scrollLeft(value) {
    const el = this.isGlobal && this.isBrowser ? this.chain(document.documentElement) : this;
    return el.prop("scrollLeft", value);
  }
  scrollTop(value) {
    const el = this.isGlobal && this.isBrowser ? this.chain(document.documentElement) : this;
    return el.prop("scrollTop", value);
  }
  clone() {
    const fragment = document.createDocumentFragment();
    this.each((el) => {
      fragment.appendChild(el.cloneNode(true));
    });
    return this.chain(fragment.childNodes);
  }
  reverse() {
    const els = this.get().reverse();
    return this.chain(els);
  }
  insertContent(target, content, position) {
    const $content = this.chain(content);
    $content.each((el) => {
      var _a3, _b;
      if (target.insertAdjacentElement) {
        target.insertAdjacentElement(position, el);
      } else {
        switch (position) {
          case "beforebegin":
            (_a3 = target.parentNode) == null ? void 0 : _a3.insertBefore(el, target);
            break;
          case "afterbegin":
            target.insertBefore(el, target.firstChild);
            break;
          case "beforeend":
            target.appendChild(el);
            break;
          case "afterend":
            (_b = target.parentNode) == null ? void 0 : _b.insertBefore(el, target.nextSibling);
            break;
        }
      }
    });
  }
  prepend(...allContent) {
    return this.each((el) => {
      each(allContent, (content) => {
        this.insertContent(el, content, "afterbegin");
      });
    });
  }
  append(...allContent) {
    return this.each((el) => {
      each(allContent, (content) => {
        this.insertContent(el, content, "beforeend");
      });
    });
  }
  insertBefore(selector) {
    return this.chain(selector).each((el) => {
      this.insertContent(el, this.selector, "beforebegin");
    });
  }
  insertAfter(selector) {
    return this.chain(selector).each((el) => {
      this.insertContent(el, this.selector, "afterend");
    });
  }
  detach() {
    return this.each((el) => {
      if (el.parentNode) {
        el.parentNode.removeChild(el);
      }
    });
  }
  naturalWidth() {
    const widths = this.map((el) => {
      const $clone = $(el).clone();
      $clone.insertAfter(el).css({
        position: "absolute",
        display: "block",
        transform: "translate(-9999px, -9999px)",
        zIndex: "-1"
      });
      const naturalWidth = $clone.width();
      $clone.remove();
      return naturalWidth;
    });
    return widths.length > 1 ? widths : widths[0];
  }
  naturalHeight() {
    const height = this.map((el) => {
      const $clone = $(el).clone();
      $clone.insertAfter(el).css({
        position: "absolute",
        display: "block",
        transform: "translate(-9999px, -9999px)",
        zIndex: "-1"
      });
      const naturalHeight = $clone.height();
      $clone.remove();
      return naturalHeight;
    });
    return height.length > 1 ? height : height[0];
  }
  // offsetParent does not return the true offset parent
  // in cases where there is a parent node with a transform context
  // so we need to get that manually where finding the true offset parent is essential
  // for instance when calculating position
  offsetParent({ calculate = true } = {}) {
    return Array.from(this).map((el) => {
      if (!calculate) {
        return el.offsetParent;
      }
      let $el, isPositioned, isTransformed, isBody;
      let parentNode = el == null ? void 0 : el.parentNode;
      while (parentNode && !isPositioned && !isTransformed && !isBody) {
        parentNode = parentNode == null ? void 0 : parentNode.parentNode;
        if (parentNode) {
          $el = $(parentNode);
          isPositioned = $el.computedStyle("position") !== "static";
          isTransformed = $el.computedStyle("transform") !== "none";
          isBody = $el.is("body");
        }
      }
      return parentNode;
    });
  }
  // alias
  count() {
    return this.length;
  }
  exists() {
    return this.length > 0;
  }
  // adds properties to an element after dom loads
  initialize(settings) {
    document.addEventListener("DOMContentLoaded", () => {
      this.settings(settings);
    });
  }
  settings(settings) {
    return this.each((el) => {
      each(settings, (value, setting) => {
        el[setting] = value;
      });
    });
  }
  setting(setting, value) {
    return this.each((el) => {
      el[setting] = value;
    });
  }
  // special helper for SUI components
  component() {
    const components = this.map((el) => el.component).filter(Boolean);
    return components.length > 1 ? components : components[0];
  }
  dataContext() {
    const contexts = this.map((el) => el.dataContext).filter(Boolean);
    return contexts.length > 1 ? contexts : contexts[0];
  }
};
/*
  This avoids keeping a copy of window/globalThis in
  memory when an element references the global object
  reducing memory footprint
*/
__publicField(_Query, "globalThisProxy", new Proxy({}, {
  get(target, prop) {
    return globalThis[prop];
  },
  set(target, prop, value) {
    globalThis[prop] = value;
    return true;
  }
}));
/*
  We keep an array of event handlers for teardown
*/
__publicField(_Query, "eventHandlers", []);
var Query = _Query;

// packages/query/src/index.js
var $2 = function(selector, args = {}) {
  const isClient2 = typeof window !== "undefined";
  if (!(args == null ? void 0 : args.root) && isClient2) {
    args.root = document;
  }
  return new Query(selector, args);
};

// node_modules/@lit/reactive-element/css-tag.js
var t = globalThis;
var e = t.ShadowRoot && (void 0 === t.ShadyCSS || t.ShadyCSS.nativeShadow) && "adoptedStyleSheets" in Document.prototype && "replace" in CSSStyleSheet.prototype;
var s = Symbol();
var o = /* @__PURE__ */ new WeakMap();
var n = class {
  constructor(t5, e6, o7) {
    if (this._$cssResult$ = true, o7 !== s) throw Error("CSSResult is not constructable. Use `unsafeCSS` or `css` instead.");
    this.cssText = t5, this.t = e6;
  }
  get styleSheet() {
    let t5 = this.o;
    const s5 = this.t;
    if (e && void 0 === t5) {
      const e6 = void 0 !== s5 && 1 === s5.length;
      e6 && (t5 = o.get(s5)), void 0 === t5 && ((this.o = t5 = new CSSStyleSheet()).replaceSync(this.cssText), e6 && o.set(s5, t5));
    }
    return t5;
  }
  toString() {
    return this.cssText;
  }
};
var r = (t5) => new n("string" == typeof t5 ? t5 : t5 + "", void 0, s);
var S = (s5, o7) => {
  if (e) s5.adoptedStyleSheets = o7.map((t5) => t5 instanceof CSSStyleSheet ? t5 : t5.styleSheet);
  else for (const e6 of o7) {
    const o8 = document.createElement("style"), n5 = t.litNonce;
    void 0 !== n5 && o8.setAttribute("nonce", n5), o8.textContent = e6.cssText, s5.appendChild(o8);
  }
};
var c = e ? (t5) => t5 : (t5) => t5 instanceof CSSStyleSheet ? ((t6) => {
  let e6 = "";
  for (const s5 of t6.cssRules) e6 += s5.cssText;
  return r(e6);
})(t5) : t5;

// node_modules/@lit/reactive-element/reactive-element.js
var { is: i2, defineProperty: e2, getOwnPropertyDescriptor: r2, getOwnPropertyNames: h, getOwnPropertySymbols: o2, getPrototypeOf: n2 } = Object;
var a = globalThis;
var c2 = a.trustedTypes;
var l = c2 ? c2.emptyScript : "";
var p = a.reactiveElementPolyfillSupport;
var d = (t5, s5) => t5;
var u = { toAttribute(t5, s5) {
  switch (s5) {
    case Boolean:
      t5 = t5 ? l : null;
      break;
    case Object:
    case Array:
      t5 = null == t5 ? t5 : JSON.stringify(t5);
  }
  return t5;
}, fromAttribute(t5, s5) {
  let i6 = t5;
  switch (s5) {
    case Boolean:
      i6 = null !== t5;
      break;
    case Number:
      i6 = null === t5 ? null : Number(t5);
      break;
    case Object:
    case Array:
      try {
        i6 = JSON.parse(t5);
      } catch (t6) {
        i6 = null;
      }
  }
  return i6;
} };
var f = (t5, s5) => !i2(t5, s5);
var y = { attribute: true, type: String, converter: u, reflect: false, hasChanged: f };
Symbol.metadata ?? (Symbol.metadata = Symbol("metadata")), a.litPropertyMetadata ?? (a.litPropertyMetadata = /* @__PURE__ */ new WeakMap());
var b = class extends HTMLElement {
  static addInitializer(t5) {
    this._$Ei(), (this.l ?? (this.l = [])).push(t5);
  }
  static get observedAttributes() {
    return this.finalize(), this._$Eh && [...this._$Eh.keys()];
  }
  static createProperty(t5, s5 = y) {
    if (s5.state && (s5.attribute = false), this._$Ei(), this.elementProperties.set(t5, s5), !s5.noAccessor) {
      const i6 = Symbol(), r7 = this.getPropertyDescriptor(t5, i6, s5);
      void 0 !== r7 && e2(this.prototype, t5, r7);
    }
  }
  static getPropertyDescriptor(t5, s5, i6) {
    const { get: e6, set: h4 } = r2(this.prototype, t5) ?? { get() {
      return this[s5];
    }, set(t6) {
      this[s5] = t6;
    } };
    return { get() {
      return e6 == null ? void 0 : e6.call(this);
    }, set(s6) {
      const r7 = e6 == null ? void 0 : e6.call(this);
      h4.call(this, s6), this.requestUpdate(t5, r7, i6);
    }, configurable: true, enumerable: true };
  }
  static getPropertyOptions(t5) {
    return this.elementProperties.get(t5) ?? y;
  }
  static _$Ei() {
    if (this.hasOwnProperty(d("elementProperties"))) return;
    const t5 = n2(this);
    t5.finalize(), void 0 !== t5.l && (this.l = [...t5.l]), this.elementProperties = new Map(t5.elementProperties);
  }
  static finalize() {
    if (this.hasOwnProperty(d("finalized"))) return;
    if (this.finalized = true, this._$Ei(), this.hasOwnProperty(d("properties"))) {
      const t6 = this.properties, s5 = [...h(t6), ...o2(t6)];
      for (const i6 of s5) this.createProperty(i6, t6[i6]);
    }
    const t5 = this[Symbol.metadata];
    if (null !== t5) {
      const s5 = litPropertyMetadata.get(t5);
      if (void 0 !== s5) for (const [t6, i6] of s5) this.elementProperties.set(t6, i6);
    }
    this._$Eh = /* @__PURE__ */ new Map();
    for (const [t6, s5] of this.elementProperties) {
      const i6 = this._$Eu(t6, s5);
      void 0 !== i6 && this._$Eh.set(i6, t6);
    }
    this.elementStyles = this.finalizeStyles(this.styles);
  }
  static finalizeStyles(s5) {
    const i6 = [];
    if (Array.isArray(s5)) {
      const e6 = new Set(s5.flat(1 / 0).reverse());
      for (const s6 of e6) i6.unshift(c(s6));
    } else void 0 !== s5 && i6.push(c(s5));
    return i6;
  }
  static _$Eu(t5, s5) {
    const i6 = s5.attribute;
    return false === i6 ? void 0 : "string" == typeof i6 ? i6 : "string" == typeof t5 ? t5.toLowerCase() : void 0;
  }
  constructor() {
    super(), this._$Ep = void 0, this.isUpdatePending = false, this.hasUpdated = false, this._$Em = null, this._$Ev();
  }
  _$Ev() {
    var _a3;
    this._$ES = new Promise((t5) => this.enableUpdating = t5), this._$AL = /* @__PURE__ */ new Map(), this._$E_(), this.requestUpdate(), (_a3 = this.constructor.l) == null ? void 0 : _a3.forEach((t5) => t5(this));
  }
  addController(t5) {
    var _a3;
    (this._$EO ?? (this._$EO = /* @__PURE__ */ new Set())).add(t5), void 0 !== this.renderRoot && this.isConnected && ((_a3 = t5.hostConnected) == null ? void 0 : _a3.call(t5));
  }
  removeController(t5) {
    var _a3;
    (_a3 = this._$EO) == null ? void 0 : _a3.delete(t5);
  }
  _$E_() {
    const t5 = /* @__PURE__ */ new Map(), s5 = this.constructor.elementProperties;
    for (const i6 of s5.keys()) this.hasOwnProperty(i6) && (t5.set(i6, this[i6]), delete this[i6]);
    t5.size > 0 && (this._$Ep = t5);
  }
  createRenderRoot() {
    const t5 = this.shadowRoot ?? this.attachShadow(this.constructor.shadowRootOptions);
    return S(t5, this.constructor.elementStyles), t5;
  }
  connectedCallback() {
    var _a3;
    this.renderRoot ?? (this.renderRoot = this.createRenderRoot()), this.enableUpdating(true), (_a3 = this._$EO) == null ? void 0 : _a3.forEach((t5) => {
      var _a4;
      return (_a4 = t5.hostConnected) == null ? void 0 : _a4.call(t5);
    });
  }
  enableUpdating(t5) {
  }
  disconnectedCallback() {
    var _a3;
    (_a3 = this._$EO) == null ? void 0 : _a3.forEach((t5) => {
      var _a4;
      return (_a4 = t5.hostDisconnected) == null ? void 0 : _a4.call(t5);
    });
  }
  attributeChangedCallback(t5, s5, i6) {
    this._$AK(t5, i6);
  }
  _$EC(t5, s5) {
    var _a3;
    const i6 = this.constructor.elementProperties.get(t5), e6 = this.constructor._$Eu(t5, i6);
    if (void 0 !== e6 && true === i6.reflect) {
      const r7 = (void 0 !== ((_a3 = i6.converter) == null ? void 0 : _a3.toAttribute) ? i6.converter : u).toAttribute(s5, i6.type);
      this._$Em = t5, null == r7 ? this.removeAttribute(e6) : this.setAttribute(e6, r7), this._$Em = null;
    }
  }
  _$AK(t5, s5) {
    var _a3;
    const i6 = this.constructor, e6 = i6._$Eh.get(t5);
    if (void 0 !== e6 && this._$Em !== e6) {
      const t6 = i6.getPropertyOptions(e6), r7 = "function" == typeof t6.converter ? { fromAttribute: t6.converter } : void 0 !== ((_a3 = t6.converter) == null ? void 0 : _a3.fromAttribute) ? t6.converter : u;
      this._$Em = e6, this[e6] = r7.fromAttribute(s5, t6.type), this._$Em = null;
    }
  }
  requestUpdate(t5, s5, i6) {
    if (void 0 !== t5) {
      if (i6 ?? (i6 = this.constructor.getPropertyOptions(t5)), !(i6.hasChanged ?? f)(this[t5], s5)) return;
      this.P(t5, s5, i6);
    }
    false === this.isUpdatePending && (this._$ES = this._$ET());
  }
  P(t5, s5, i6) {
    this._$AL.has(t5) || this._$AL.set(t5, s5), true === i6.reflect && this._$Em !== t5 && (this._$Ej ?? (this._$Ej = /* @__PURE__ */ new Set())).add(t5);
  }
  async _$ET() {
    this.isUpdatePending = true;
    try {
      await this._$ES;
    } catch (t6) {
      Promise.reject(t6);
    }
    const t5 = this.scheduleUpdate();
    return null != t5 && await t5, !this.isUpdatePending;
  }
  scheduleUpdate() {
    return this.performUpdate();
  }
  performUpdate() {
    var _a3;
    if (!this.isUpdatePending) return;
    if (!this.hasUpdated) {
      if (this.renderRoot ?? (this.renderRoot = this.createRenderRoot()), this._$Ep) {
        for (const [t7, s6] of this._$Ep) this[t7] = s6;
        this._$Ep = void 0;
      }
      const t6 = this.constructor.elementProperties;
      if (t6.size > 0) for (const [s6, i6] of t6) true !== i6.wrapped || this._$AL.has(s6) || void 0 === this[s6] || this.P(s6, this[s6], i6);
    }
    let t5 = false;
    const s5 = this._$AL;
    try {
      t5 = this.shouldUpdate(s5), t5 ? (this.willUpdate(s5), (_a3 = this._$EO) == null ? void 0 : _a3.forEach((t6) => {
        var _a4;
        return (_a4 = t6.hostUpdate) == null ? void 0 : _a4.call(t6);
      }), this.update(s5)) : this._$EU();
    } catch (s6) {
      throw t5 = false, this._$EU(), s6;
    }
    t5 && this._$AE(s5);
  }
  willUpdate(t5) {
  }
  _$AE(t5) {
    var _a3;
    (_a3 = this._$EO) == null ? void 0 : _a3.forEach((t6) => {
      var _a4;
      return (_a4 = t6.hostUpdated) == null ? void 0 : _a4.call(t6);
    }), this.hasUpdated || (this.hasUpdated = true, this.firstUpdated(t5)), this.updated(t5);
  }
  _$EU() {
    this._$AL = /* @__PURE__ */ new Map(), this.isUpdatePending = false;
  }
  get updateComplete() {
    return this.getUpdateComplete();
  }
  getUpdateComplete() {
    return this._$ES;
  }
  shouldUpdate(t5) {
    return true;
  }
  update(t5) {
    this._$Ej && (this._$Ej = this._$Ej.forEach((t6) => this._$EC(t6, this[t6]))), this._$EU();
  }
  updated(t5) {
  }
  firstUpdated(t5) {
  }
};
b.elementStyles = [], b.shadowRootOptions = { mode: "open" }, b[d("elementProperties")] = /* @__PURE__ */ new Map(), b[d("finalized")] = /* @__PURE__ */ new Map(), p == null ? void 0 : p({ ReactiveElement: b }), (a.reactiveElementVersions ?? (a.reactiveElementVersions = [])).push("2.0.4");

// node_modules/lit-html/lit-html.js
var t2 = globalThis;
var i3 = t2.trustedTypes;
var s2 = i3 ? i3.createPolicy("lit-html", { createHTML: (t5) => t5 }) : void 0;
var e3 = "$lit$";
var h2 = `lit$${Math.random().toFixed(9).slice(2)}$`;
var o3 = "?" + h2;
var n3 = `<${o3}>`;
var r3 = document;
var l2 = () => r3.createComment("");
var c3 = (t5) => null === t5 || "object" != typeof t5 && "function" != typeof t5;
var a2 = Array.isArray;
var u2 = (t5) => a2(t5) || "function" == typeof (t5 == null ? void 0 : t5[Symbol.iterator]);
var d2 = "[ 	\n\f\r]";
var f2 = /<(?:(!--|\/[^a-zA-Z])|(\/?[a-zA-Z][^>\s]*)|(\/?$))/g;
var v = /-->/g;
var _ = />/g;
var m = RegExp(`>|${d2}(?:([^\\s"'>=/]+)(${d2}*=${d2}*(?:[^ 	
\f\r"'\`<>=]|("|')|))|$)`, "g");
var p2 = /'/g;
var g = /"/g;
var $3 = /^(?:script|style|textarea|title)$/i;
var y2 = (t5) => (i6, ...s5) => ({ _$litType$: t5, strings: i6, values: s5 });
var x = y2(1);
var b2 = y2(2);
var w = y2(3);
var T = Symbol.for("lit-noChange");
var E = Symbol.for("lit-nothing");
var A = /* @__PURE__ */ new WeakMap();
var C = r3.createTreeWalker(r3, 129);
function P(t5, i6) {
  if (!a2(t5) || !t5.hasOwnProperty("raw")) throw Error("invalid template strings array");
  return void 0 !== s2 ? s2.createHTML(i6) : i6;
}
var V = (t5, i6) => {
  const s5 = t5.length - 1, o7 = [];
  let r7, l3 = 2 === i6 ? "<svg>" : 3 === i6 ? "<math>" : "", c6 = f2;
  for (let i7 = 0; i7 < s5; i7++) {
    const s6 = t5[i7];
    let a3, u5, d3 = -1, y3 = 0;
    for (; y3 < s6.length && (c6.lastIndex = y3, u5 = c6.exec(s6), null !== u5); ) y3 = c6.lastIndex, c6 === f2 ? "!--" === u5[1] ? c6 = v : void 0 !== u5[1] ? c6 = _ : void 0 !== u5[2] ? ($3.test(u5[2]) && (r7 = RegExp("</" + u5[2], "g")), c6 = m) : void 0 !== u5[3] && (c6 = m) : c6 === m ? ">" === u5[0] ? (c6 = r7 ?? f2, d3 = -1) : void 0 === u5[1] ? d3 = -2 : (d3 = c6.lastIndex - u5[2].length, a3 = u5[1], c6 = void 0 === u5[3] ? m : '"' === u5[3] ? g : p2) : c6 === g || c6 === p2 ? c6 = m : c6 === v || c6 === _ ? c6 = f2 : (c6 = m, r7 = void 0);
    const x2 = c6 === m && t5[i7 + 1].startsWith("/>") ? " " : "";
    l3 += c6 === f2 ? s6 + n3 : d3 >= 0 ? (o7.push(a3), s6.slice(0, d3) + e3 + s6.slice(d3) + h2 + x2) : s6 + h2 + (-2 === d3 ? i7 : x2);
  }
  return [P(t5, l3 + (t5[s5] || "<?>") + (2 === i6 ? "</svg>" : 3 === i6 ? "</math>" : "")), o7];
};
var N = class _N {
  constructor({ strings: t5, _$litType$: s5 }, n5) {
    let r7;
    this.parts = [];
    let c6 = 0, a3 = 0;
    const u5 = t5.length - 1, d3 = this.parts, [f5, v3] = V(t5, s5);
    if (this.el = _N.createElement(f5, n5), C.currentNode = this.el.content, 2 === s5 || 3 === s5) {
      const t6 = this.el.content.firstChild;
      t6.replaceWith(...t6.childNodes);
    }
    for (; null !== (r7 = C.nextNode()) && d3.length < u5; ) {
      if (1 === r7.nodeType) {
        if (r7.hasAttributes()) for (const t6 of r7.getAttributeNames()) if (t6.endsWith(e3)) {
          const i6 = v3[a3++], s6 = r7.getAttribute(t6).split(h2), e6 = /([.?@])?(.*)/.exec(i6);
          d3.push({ type: 1, index: c6, name: e6[2], strings: s6, ctor: "." === e6[1] ? H : "?" === e6[1] ? I : "@" === e6[1] ? L : k }), r7.removeAttribute(t6);
        } else t6.startsWith(h2) && (d3.push({ type: 6, index: c6 }), r7.removeAttribute(t6));
        if ($3.test(r7.tagName)) {
          const t6 = r7.textContent.split(h2), s6 = t6.length - 1;
          if (s6 > 0) {
            r7.textContent = i3 ? i3.emptyScript : "";
            for (let i6 = 0; i6 < s6; i6++) r7.append(t6[i6], l2()), C.nextNode(), d3.push({ type: 2, index: ++c6 });
            r7.append(t6[s6], l2());
          }
        }
      } else if (8 === r7.nodeType) if (r7.data === o3) d3.push({ type: 2, index: c6 });
      else {
        let t6 = -1;
        for (; -1 !== (t6 = r7.data.indexOf(h2, t6 + 1)); ) d3.push({ type: 7, index: c6 }), t6 += h2.length - 1;
      }
      c6++;
    }
  }
  static createElement(t5, i6) {
    const s5 = r3.createElement("template");
    return s5.innerHTML = t5, s5;
  }
};
function S2(t5, i6, s5 = t5, e6) {
  var _a3, _b;
  if (i6 === T) return i6;
  let h4 = void 0 !== e6 ? (_a3 = s5._$Co) == null ? void 0 : _a3[e6] : s5._$Cl;
  const o7 = c3(i6) ? void 0 : i6._$litDirective$;
  return (h4 == null ? void 0 : h4.constructor) !== o7 && ((_b = h4 == null ? void 0 : h4._$AO) == null ? void 0 : _b.call(h4, false), void 0 === o7 ? h4 = void 0 : (h4 = new o7(t5), h4._$AT(t5, s5, e6)), void 0 !== e6 ? (s5._$Co ?? (s5._$Co = []))[e6] = h4 : s5._$Cl = h4), void 0 !== h4 && (i6 = S2(t5, h4._$AS(t5, i6.values), h4, e6)), i6;
}
var M = class {
  constructor(t5, i6) {
    this._$AV = [], this._$AN = void 0, this._$AD = t5, this._$AM = i6;
  }
  get parentNode() {
    return this._$AM.parentNode;
  }
  get _$AU() {
    return this._$AM._$AU;
  }
  u(t5) {
    const { el: { content: i6 }, parts: s5 } = this._$AD, e6 = ((t5 == null ? void 0 : t5.creationScope) ?? r3).importNode(i6, true);
    C.currentNode = e6;
    let h4 = C.nextNode(), o7 = 0, n5 = 0, l3 = s5[0];
    for (; void 0 !== l3; ) {
      if (o7 === l3.index) {
        let i7;
        2 === l3.type ? i7 = new R(h4, h4.nextSibling, this, t5) : 1 === l3.type ? i7 = new l3.ctor(h4, l3.name, l3.strings, this, t5) : 6 === l3.type && (i7 = new z(h4, this, t5)), this._$AV.push(i7), l3 = s5[++n5];
      }
      o7 !== (l3 == null ? void 0 : l3.index) && (h4 = C.nextNode(), o7++);
    }
    return C.currentNode = r3, e6;
  }
  p(t5) {
    let i6 = 0;
    for (const s5 of this._$AV) void 0 !== s5 && (void 0 !== s5.strings ? (s5._$AI(t5, s5, i6), i6 += s5.strings.length - 2) : s5._$AI(t5[i6])), i6++;
  }
};
var R = class _R {
  get _$AU() {
    var _a3;
    return ((_a3 = this._$AM) == null ? void 0 : _a3._$AU) ?? this._$Cv;
  }
  constructor(t5, i6, s5, e6) {
    this.type = 2, this._$AH = E, this._$AN = void 0, this._$AA = t5, this._$AB = i6, this._$AM = s5, this.options = e6, this._$Cv = (e6 == null ? void 0 : e6.isConnected) ?? true;
  }
  get parentNode() {
    let t5 = this._$AA.parentNode;
    const i6 = this._$AM;
    return void 0 !== i6 && 11 === (t5 == null ? void 0 : t5.nodeType) && (t5 = i6.parentNode), t5;
  }
  get startNode() {
    return this._$AA;
  }
  get endNode() {
    return this._$AB;
  }
  _$AI(t5, i6 = this) {
    t5 = S2(this, t5, i6), c3(t5) ? t5 === E || null == t5 || "" === t5 ? (this._$AH !== E && this._$AR(), this._$AH = E) : t5 !== this._$AH && t5 !== T && this._(t5) : void 0 !== t5._$litType$ ? this.$(t5) : void 0 !== t5.nodeType ? this.T(t5) : u2(t5) ? this.k(t5) : this._(t5);
  }
  O(t5) {
    return this._$AA.parentNode.insertBefore(t5, this._$AB);
  }
  T(t5) {
    this._$AH !== t5 && (this._$AR(), this._$AH = this.O(t5));
  }
  _(t5) {
    this._$AH !== E && c3(this._$AH) ? this._$AA.nextSibling.data = t5 : this.T(r3.createTextNode(t5)), this._$AH = t5;
  }
  $(t5) {
    var _a3;
    const { values: i6, _$litType$: s5 } = t5, e6 = "number" == typeof s5 ? this._$AC(t5) : (void 0 === s5.el && (s5.el = N.createElement(P(s5.h, s5.h[0]), this.options)), s5);
    if (((_a3 = this._$AH) == null ? void 0 : _a3._$AD) === e6) this._$AH.p(i6);
    else {
      const t6 = new M(e6, this), s6 = t6.u(this.options);
      t6.p(i6), this.T(s6), this._$AH = t6;
    }
  }
  _$AC(t5) {
    let i6 = A.get(t5.strings);
    return void 0 === i6 && A.set(t5.strings, i6 = new N(t5)), i6;
  }
  k(t5) {
    a2(this._$AH) || (this._$AH = [], this._$AR());
    const i6 = this._$AH;
    let s5, e6 = 0;
    for (const h4 of t5) e6 === i6.length ? i6.push(s5 = new _R(this.O(l2()), this.O(l2()), this, this.options)) : s5 = i6[e6], s5._$AI(h4), e6++;
    e6 < i6.length && (this._$AR(s5 && s5._$AB.nextSibling, e6), i6.length = e6);
  }
  _$AR(t5 = this._$AA.nextSibling, i6) {
    var _a3;
    for ((_a3 = this._$AP) == null ? void 0 : _a3.call(this, false, true, i6); t5 && t5 !== this._$AB; ) {
      const i7 = t5.nextSibling;
      t5.remove(), t5 = i7;
    }
  }
  setConnected(t5) {
    var _a3;
    void 0 === this._$AM && (this._$Cv = t5, (_a3 = this._$AP) == null ? void 0 : _a3.call(this, t5));
  }
};
var k = class {
  get tagName() {
    return this.element.tagName;
  }
  get _$AU() {
    return this._$AM._$AU;
  }
  constructor(t5, i6, s5, e6, h4) {
    this.type = 1, this._$AH = E, this._$AN = void 0, this.element = t5, this.name = i6, this._$AM = e6, this.options = h4, s5.length > 2 || "" !== s5[0] || "" !== s5[1] ? (this._$AH = Array(s5.length - 1).fill(new String()), this.strings = s5) : this._$AH = E;
  }
  _$AI(t5, i6 = this, s5, e6) {
    const h4 = this.strings;
    let o7 = false;
    if (void 0 === h4) t5 = S2(this, t5, i6, 0), o7 = !c3(t5) || t5 !== this._$AH && t5 !== T, o7 && (this._$AH = t5);
    else {
      const e7 = t5;
      let n5, r7;
      for (t5 = h4[0], n5 = 0; n5 < h4.length - 1; n5++) r7 = S2(this, e7[s5 + n5], i6, n5), r7 === T && (r7 = this._$AH[n5]), o7 || (o7 = !c3(r7) || r7 !== this._$AH[n5]), r7 === E ? t5 = E : t5 !== E && (t5 += (r7 ?? "") + h4[n5 + 1]), this._$AH[n5] = r7;
    }
    o7 && !e6 && this.j(t5);
  }
  j(t5) {
    t5 === E ? this.element.removeAttribute(this.name) : this.element.setAttribute(this.name, t5 ?? "");
  }
};
var H = class extends k {
  constructor() {
    super(...arguments), this.type = 3;
  }
  j(t5) {
    this.element[this.name] = t5 === E ? void 0 : t5;
  }
};
var I = class extends k {
  constructor() {
    super(...arguments), this.type = 4;
  }
  j(t5) {
    this.element.toggleAttribute(this.name, !!t5 && t5 !== E);
  }
};
var L = class extends k {
  constructor(t5, i6, s5, e6, h4) {
    super(t5, i6, s5, e6, h4), this.type = 5;
  }
  _$AI(t5, i6 = this) {
    if ((t5 = S2(this, t5, i6, 0) ?? E) === T) return;
    const s5 = this._$AH, e6 = t5 === E && s5 !== E || t5.capture !== s5.capture || t5.once !== s5.once || t5.passive !== s5.passive, h4 = t5 !== E && (s5 === E || e6);
    e6 && this.element.removeEventListener(this.name, this, s5), h4 && this.element.addEventListener(this.name, this, t5), this._$AH = t5;
  }
  handleEvent(t5) {
    var _a3;
    "function" == typeof this._$AH ? this._$AH.call(((_a3 = this.options) == null ? void 0 : _a3.host) ?? this.element, t5) : this._$AH.handleEvent(t5);
  }
};
var z = class {
  constructor(t5, i6, s5) {
    this.element = t5, this.type = 6, this._$AN = void 0, this._$AM = i6, this.options = s5;
  }
  get _$AU() {
    return this._$AM._$AU;
  }
  _$AI(t5) {
    S2(this, t5);
  }
};
var Z = { M: e3, P: h2, A: o3, C: 1, L: V, R: M, D: u2, V: S2, I: R, H: k, N: I, U: L, B: H, F: z };
var j = t2.litHtmlPolyfillSupport;
j == null ? void 0 : j(N, R), (t2.litHtmlVersions ?? (t2.litHtmlVersions = [])).push("3.2.1");
var B = (t5, i6, s5) => {
  const e6 = (s5 == null ? void 0 : s5.renderBefore) ?? i6;
  let h4 = e6._$litPart$;
  if (void 0 === h4) {
    const t6 = (s5 == null ? void 0 : s5.renderBefore) ?? null;
    e6._$litPart$ = h4 = new R(i6.insertBefore(l2(), t6), t6, void 0, s5 ?? {});
  }
  return h4._$AI(t5), h4;
};

// node_modules/lit-element/lit-element.js
var r4 = class extends b {
  constructor() {
    super(...arguments), this.renderOptions = { host: this }, this._$Do = void 0;
  }
  createRenderRoot() {
    var _a3;
    const t5 = super.createRenderRoot();
    return (_a3 = this.renderOptions).renderBefore ?? (_a3.renderBefore = t5.firstChild), t5;
  }
  update(t5) {
    const s5 = this.render();
    this.hasUpdated || (this.renderOptions.isConnected = this.isConnected), super.update(t5), this._$Do = B(s5, this.renderRoot, this.renderOptions);
  }
  connectedCallback() {
    var _a3;
    super.connectedCallback(), (_a3 = this._$Do) == null ? void 0 : _a3.setConnected(true);
  }
  disconnectedCallback() {
    var _a3;
    super.disconnectedCallback(), (_a3 = this._$Do) == null ? void 0 : _a3.setConnected(false);
  }
  render() {
    return T;
  }
};
var _a;
r4._$litElement$ = true, r4["finalized"] = true, (_a = globalThis.litElementHydrateSupport) == null ? void 0 : _a.call(globalThis, { LitElement: r4 });
var i4 = globalThis.litElementPolyfillSupport;
i4 == null ? void 0 : i4({ LitElement: r4 });
(globalThis.litElementVersions ?? (globalThis.litElementVersions = [])).push("4.1.1");

// node_modules/lit-html/directive-helpers.js
var { I: t3 } = Z;
var f3 = (o7) => void 0 === o7.strings;
var s3 = () => document.createComment("");
var r5 = (o7, i6, n5) => {
  var _a3;
  const e6 = o7._$AA.parentNode, l3 = void 0 === i6 ? o7._$AB : i6._$AA;
  if (void 0 === n5) {
    const i7 = e6.insertBefore(s3(), l3), c6 = e6.insertBefore(s3(), l3);
    n5 = new t3(i7, c6, o7, o7.options);
  } else {
    const t5 = n5._$AB.nextSibling, i7 = n5._$AM, c6 = i7 !== o7;
    if (c6) {
      let t6;
      (_a3 = n5._$AQ) == null ? void 0 : _a3.call(n5, o7), n5._$AM = o7, void 0 !== n5._$AP && (t6 = o7._$AU) !== i7._$AU && n5._$AP(t6);
    }
    if (t5 !== l3 || c6) {
      let o8 = n5._$AA;
      for (; o8 !== t5; ) {
        const t6 = o8.nextSibling;
        e6.insertBefore(o8, l3), o8 = t6;
      }
    }
  }
  return n5;
};
var v2 = (o7, t5, i6 = o7) => (o7._$AI(t5, i6), o7);
var u3 = {};
var m2 = (o7, t5 = u3) => o7._$AH = t5;
var p3 = (o7) => o7._$AH;
var M2 = (o7) => {
  var _a3;
  (_a3 = o7._$AP) == null ? void 0 : _a3.call(o7, false, true);
  let t5 = o7._$AA;
  const i6 = o7._$AB.nextSibling;
  for (; t5 !== i6; ) {
    const o8 = t5.nextSibling;
    t5.remove(), t5 = o8;
  }
};

// node_modules/lit-html/directive.js
var t4 = { ATTRIBUTE: 1, CHILD: 2, PROPERTY: 3, BOOLEAN_ATTRIBUTE: 4, EVENT: 5, ELEMENT: 6 };
var e4 = (t5) => (...e6) => ({ _$litDirective$: t5, values: e6 });
var i5 = class {
  constructor(t5) {
  }
  get _$AU() {
    return this._$AM._$AU;
  }
  _$AT(t5, e6, i6) {
    this._$Ct = t5, this._$AM = e6, this._$Ci = i6;
  }
  _$AS(t5, e6) {
    return this.update(t5, e6);
  }
  update(t5, e6) {
    return this.render(...e6);
  }
};

// node_modules/lit-html/async-directive.js
var s4 = (i6, t5) => {
  var _a3;
  const e6 = i6._$AN;
  if (void 0 === e6) return false;
  for (const i7 of e6) (_a3 = i7._$AO) == null ? void 0 : _a3.call(i7, t5, false), s4(i7, t5);
  return true;
};
var o4 = (i6) => {
  let t5, e6;
  do {
    if (void 0 === (t5 = i6._$AM)) break;
    e6 = t5._$AN, e6.delete(i6), i6 = t5;
  } while (0 === (e6 == null ? void 0 : e6.size));
};
var r6 = (i6) => {
  for (let t5; t5 = i6._$AM; i6 = t5) {
    let e6 = t5._$AN;
    if (void 0 === e6) t5._$AN = e6 = /* @__PURE__ */ new Set();
    else if (e6.has(i6)) break;
    e6.add(i6), c4(t5);
  }
};
function h3(i6) {
  void 0 !== this._$AN ? (o4(this), this._$AM = i6, r6(this)) : this._$AM = i6;
}
function n4(i6, t5 = false, e6 = 0) {
  const r7 = this._$AH, h4 = this._$AN;
  if (void 0 !== h4 && 0 !== h4.size) if (t5) if (Array.isArray(r7)) for (let i7 = e6; i7 < r7.length; i7++) s4(r7[i7], false), o4(r7[i7]);
  else null != r7 && (s4(r7, false), o4(r7));
  else s4(this, i6);
}
var c4 = (i6) => {
  i6.type == t4.CHILD && (i6._$AP ?? (i6._$AP = n4), i6._$AQ ?? (i6._$AQ = h3));
};
var f4 = class extends i5 {
  constructor() {
    super(...arguments), this._$AN = void 0;
  }
  _$AT(i6, t5, e6) {
    super._$AT(i6, t5, e6), r6(this), this.isConnected = i6._$AU;
  }
  _$AO(i6, t5 = true) {
    var _a3, _b;
    i6 !== this.isConnected && (this.isConnected = i6, i6 ? (_a3 = this.reconnected) == null ? void 0 : _a3.call(this) : (_b = this.disconnected) == null ? void 0 : _b.call(this)), t5 && (s4(this, i6), o4(this));
  }
  setValue(t5) {
    if (f3(this._$Ct)) this._$Ct._$AI(t5, this);
    else {
      const i6 = [...this._$Ct._$AH];
      i6[this._$Ci] = t5, this._$Ct._$AI(i6, this, 0);
    }
  }
  disconnected() {
  }
  reconnected() {
  }
};

// packages/renderer/src/lit/directives/reactive-conditional.js
var ReactiveConditionalDirective = class extends f4 {
  constructor(partInfo) {
    super(partInfo);
    this.reaction = null;
  }
  render(conditional) {
    let matchIndex = -1;
    if (this.reaction) {
      this.reaction.stop();
    }
    let html = E;
    let context = {
      message: `if/else statement: {#if ${conditional.expression}}`,
      conditional
    };
    this.reaction = Reaction.create((comp) => {
      var _a3;
      if (!this.isConnected) {
        comp.stop();
        return;
      }
      let matchIndex2 = -1;
      if (conditional.condition()) {
        html = conditional.content();
        matchIndex2 = 1e3;
      } else if ((_a3 = conditional.branches) == null ? void 0 : _a3.length) {
        each(conditional.branches, (branch, index) => {
          if (matchIndex2 === -1) {
            if (branch.type == "elseif" && branch.condition()) {
              matchIndex2 = index;
              html = branch.content();
            } else if (branch.type == "else") {
              matchIndex2 = index;
              html = branch.content();
            }
          }
        });
      } else {
        html = E;
        delete this.matchIndex;
      }
      if (!html) {
        html = E;
        delete this.matchIndex;
      }
      if (!comp.firstRun && this.matchIndex !== matchIndex2) {
        this.matchIndex = matchIndex2;
        this.setValue(html);
      }
      return html;
    }, { context });
    return html;
  }
  disconnected() {
    if (this.reaction) {
      this.reaction.stop();
      this.reaction = null;
    }
  }
  reconnected() {
  }
};
var reactiveConditional = e4(ReactiveConditionalDirective);

// node_modules/lit-html/directives/if-defined.js
var o5 = (o7) => o7 ?? E;

// node_modules/lit-html/directives/unsafe-html.js
var e5 = class extends i5 {
  constructor(i6) {
    if (super(i6), this.it = E, i6.type !== t4.CHILD) throw Error(this.constructor.directiveName + "() can only be used in child bindings");
  }
  render(r7) {
    if (r7 === E || null == r7) return this._t = void 0, this.it = r7;
    if (r7 === T) return r7;
    if ("string" != typeof r7) throw Error(this.constructor.directiveName + "() called with a non-string value");
    if (r7 === this.it) return this._t;
    this.it = r7;
    const s5 = [r7];
    return s5.raw = s5, this._t = { _$litType$: this.constructor.resultType, strings: s5, values: [] };
  }
};
e5.directiveName = "unsafeHTML", e5.resultType = 1;
var o6 = e4(e5);

// packages/renderer/src/lit/directives/reactive-data.js
var ReactiveDataDirective = class extends f4 {
  constructor(partInfo) {
    super(partInfo);
    this.partInfo = partInfo;
    this.reaction = null;
  }
  render(expression, settings = {}) {
    this.expression = expression;
    this.settings = settings;
    if (expression.expression == "debugReactivity") {
      return this.expression.value();
    }
    if (this.reaction) {
      return this.getReactiveValue();
    } else {
      let value;
      const context = {
        message: `expression: {${expression.expression}}`,
        expression: expression.expression
      };
      this.reaction = Reaction.create((computation) => {
        if (!this.isConnected) {
          computation.stop();
          return;
        }
        value = this.getReactiveValue();
        if (this.settings.unsafeHTML) {
          value = o6(value);
        }
        if (!computation.firstRun) {
          this.setValue(value);
        }
      }, { context });
      return value;
    }
  }
  getReactiveValue() {
    let reactiveValue = this.expression.value();
    if (this.settings.ifDefined) {
      if (inArray(reactiveValue, ["", void 0, null, false, 0])) {
        return o5(void 0);
      }
    }
    if (isArray(reactiveValue) || isObject(reactiveValue)) {
      reactiveValue = JSON.stringify(reactiveValue);
    }
    return reactiveValue;
  }
  disconnected() {
    if (this.reaction) {
      this.reaction.stop();
      this.reaction = null;
    }
  }
  reconnected() {
  }
};
var reactiveData = e4(ReactiveDataDirective);

// node_modules/lit-html/directives/repeat.js
var u4 = (e6, s5, t5) => {
  const r7 = /* @__PURE__ */ new Map();
  for (let l3 = s5; l3 <= t5; l3++) r7.set(e6[l3], l3);
  return r7;
};
var c5 = e4(class extends i5 {
  constructor(e6) {
    if (super(e6), e6.type !== t4.CHILD) throw Error("repeat() can only be used in text expressions");
  }
  dt(e6, s5, t5) {
    let r7;
    void 0 === t5 ? t5 = s5 : void 0 !== s5 && (r7 = s5);
    const l3 = [], o7 = [];
    let i6 = 0;
    for (const s6 of e6) l3[i6] = r7 ? r7(s6, i6) : i6, o7[i6] = t5(s6, i6), i6++;
    return { values: o7, keys: l3 };
  }
  render(e6, s5, t5) {
    return this.dt(e6, s5, t5).values;
  }
  update(s5, [t5, r7, c6]) {
    const d3 = p3(s5), { values: p4, keys: a3 } = this.dt(t5, r7, c6);
    if (!Array.isArray(d3)) return this.ut = a3, p4;
    const h4 = this.ut ?? (this.ut = []), v3 = [];
    let m3, y3, x2 = 0, j2 = d3.length - 1, k2 = 0, w2 = p4.length - 1;
    for (; x2 <= j2 && k2 <= w2; ) if (null === d3[x2]) x2++;
    else if (null === d3[j2]) j2--;
    else if (h4[x2] === a3[k2]) v3[k2] = v2(d3[x2], p4[k2]), x2++, k2++;
    else if (h4[j2] === a3[w2]) v3[w2] = v2(d3[j2], p4[w2]), j2--, w2--;
    else if (h4[x2] === a3[w2]) v3[w2] = v2(d3[x2], p4[w2]), r5(s5, v3[w2 + 1], d3[x2]), x2++, w2--;
    else if (h4[j2] === a3[k2]) v3[k2] = v2(d3[j2], p4[k2]), r5(s5, d3[x2], d3[j2]), j2--, k2++;
    else if (void 0 === m3 && (m3 = u4(a3, k2, w2), y3 = u4(h4, x2, j2)), m3.has(h4[x2])) if (m3.has(h4[j2])) {
      const e6 = y3.get(a3[k2]), t6 = void 0 !== e6 ? d3[e6] : null;
      if (null === t6) {
        const e7 = r5(s5, d3[x2]);
        v2(e7, p4[k2]), v3[k2] = e7;
      } else v3[k2] = v2(t6, p4[k2]), r5(s5, d3[x2], t6), d3[e6] = null;
      k2++;
    } else M2(d3[j2]), j2--;
    else M2(d3[x2]), x2++;
    for (; k2 <= w2; ) {
      const e6 = r5(s5, v3[w2 + 1]);
      v2(e6, p4[k2]), v3[k2++] = e6;
    }
    for (; x2 <= j2; ) {
      const e6 = d3[x2++];
      null !== e6 && M2(e6);
    }
    return this.ut = a3, m2(s5, v3), T;
  }
});

// packages/renderer/src/lit/directives/reactive-each.js
var ReactiveEachDirective = class extends f4 {
  constructor(partInfo) {
    super(partInfo);
    this.reaction = null;
    this.items = [];
    this.eachCondition = null;
  }
  render(eachCondition, settings = {}) {
    this.eachCondition = eachCondition;
    if (this.reaction) {
      this.reaction.stop();
      this.reaction = null;
    }
    let context;
    if (eachCondition.node) {
      let { as, over } = eachCondition.node;
      let context2 = {
        message: `reactive each: {#each ${as} in ${over}}`,
        each: eachCondition.node
      };
    }
    this.reaction = Reaction.create((computation) => {
      if (!this.isConnected) {
        computation.stop();
        return;
      }
      this.items = this.getItems(this.eachCondition);
      if (!computation.firstRun) {
        const rendered = this.renderItems();
        this.setValue(rendered);
      }
    }, { context });
    return this.renderItems();
  }
  renderItems() {
    let items = this.getItems(this.eachCondition);
    if (!(items == null ? void 0 : items.length) > 0 && this.eachCondition.else) {
      return c5(
        [1],
        () => "else-case",
        () => this.eachCondition.else()
      );
    }
    const collectionType = this.getCollectionType(items);
    if (collectionType == "object") {
      items = arrayFromObject(items);
    }
    return c5(
      items,
      (item, indexOrKey) => this.getItemID(item, indexOrKey, collectionType),
      (item, indexOrKey) => this.getTemplate(item, indexOrKey, collectionType)
    );
  }
  getCollectionType(items) {
    if (isArray(items)) {
      return "array";
    }
    return "object";
  }
  getItems() {
    return this.eachCondition.over() || [];
  }
  getTemplate(item, indexOrKey, collectionType) {
    const templateData = this.getEachData(item, indexOrKey, collectionType, this.eachCondition);
    return this.eachCondition.content(templateData);
  }
  getItemID(item, indexOrKey, collectionType) {
    if (isPlainObject(item)) {
      const key = collectionType == "object" ? indexOrKey : void 0;
      return key || item._id || item.id || item.key || item.hash || item._hash || item.value || indexOrKey;
    }
    if (isString(item)) {
      return item;
    }
    return indexOrKey;
  }
  getEachData(item, indexOrKey, collectionType, eachCondition) {
    let { as, indexAs } = eachCondition;
    if (!indexAs) {
      indexAs = collectionType == "array" ? "index" : "key";
    }
    if (collectionType == "object") {
      indexOrKey = item.key;
      item = item.value;
    }
    return as ? { [as]: item, [indexAs]: indexOrKey } : { ...item, this: item, [indexAs]: indexOrKey };
  }
  disconnected() {
    if (this.reaction) {
      this.reaction.stop();
      this.reaction = null;
    }
  }
  reconnected() {
  }
};
var reactiveEach = e4(ReactiveEachDirective);

// packages/renderer/src/lit/directives/render-template.js
var RenderTemplateDirective = class extends f4 {
  constructor(partInfo) {
    var _a3, _b;
    super(partInfo);
    this.renderRoot = (_b = (_a3 = partInfo.options) == null ? void 0 : _a3.host) == null ? void 0 : _b.renderRoot;
    this.template = null;
    this.part = null;
  }
  render({ getTemplate, templateName, subTemplates, data, parentTemplate }) {
    var _a3;
    this.parentTemplate = parentTemplate;
    this.getTemplate = getTemplate;
    this.subTemplates = subTemplates;
    this.data = data;
    this.ast = null;
    this.reaction = Reaction.create((reaction) => {
      this.maybeCreateTemplate();
      const dataContext = this.unpackData(this.data);
      if (!this.isConnected) {
        reaction.stop();
        return;
      }
      if (reaction.firstRun) {
        return;
      }
      const template = this.template;
      if (!template || (template == null ? void 0 : template.ast.length) == 0) {
        return;
      }
      reaction.addContext({
        message: `template ${template == null ? void 0 : template.templateName} data context`,
        dataContext,
        template
      });
      const html = this.renderTemplate(dataContext);
      this.setValue(html);
    });
    this.maybeCreateTemplate();
    if (!this.template || ((_a3 = this.template) == null ? void 0 : _a3.ast.length) == 0) {
      return E;
    }
    return this.renderTemplate();
  }
  renderTemplate(dataContext) {
    this.attachTemplate();
    if (!dataContext) {
      dataContext = this.unpackData(this.data);
    }
    this.template.setDataContext(dataContext);
    return this.template.render();
  }
  maybeCreateTemplate() {
    let templateName;
    let template;
    const templateOrName = this.getTemplate();
    if (isString(templateOrName)) {
      templateName = templateOrName;
      template = this.subTemplates[templateName];
    } else if (templateOrName instanceof Template) {
      template = templateOrName;
      templateName = template.templateName;
    }
    if (!template) {
      return false;
    }
    this.templateID = template.id;
    this.template = template.clone({
      templateName,
      subTemplates: this.subTemplates,
      data: this.unpackData(this.data)
    });
  }
  attachTemplate() {
    var _a3, _b;
    const { parentNode, startNode, endNode } = this.part || {};
    const element = (_b = (_a3 = this.part) == null ? void 0 : _a3.options) == null ? void 0 : _b.host;
    const renderRoot = element == null ? void 0 : element.renderRoot;
    this.template.setElement(element);
    this.template.attach(renderRoot, {
      element,
      parentNode,
      startNode,
      endNode
    });
    if (this.parentTemplate) {
      this.template.setParent(this.parentTemplate);
    }
  }
  unpackData(dataObj) {
    return mapObject(dataObj, (val) => val());
  }
  update(part, settings) {
    this.part = part;
    return this.render.apply(this, settings);
  }
  reconnected() {
  }
  disconnected() {
    if (this.template) {
      this.template.onDestroyed();
    }
  }
};
var renderTemplate = e4(RenderTemplateDirective);

// packages/renderer/src/lit/renderer.js
var _LitRenderer = class _LitRenderer {
  // experimental
  static getID({ ast, data, isSVG } = {}) {
    return hashCode({ ast });
  }
  constructor({ ast, data, template, subTemplates, snippets, helpers, isSVG }) {
    this.ast = ast || "";
    this.data = data;
    this.renderTrees = {};
    this.treeIDs = [];
    this.template = template;
    this.subTemplates = subTemplates;
    this.resetHTML();
    this.snippets = snippets || {};
    this.helpers = helpers || {};
    this.isSVG = isSVG;
    this.id = _LitRenderer.getID({ ast, data, isSVG });
  }
  resetHTML() {
    this.html = [];
    this.html.raw = [];
    this.expressions = [];
  }
  /*
    Creates an AST representation of a template
    this can be cached on the web component class
  */
  render({ ast = this.ast, data = this.data } = {}) {
    this.resetHTML();
    this.readAST({ ast, data });
    this.clearTemp();
    const renderer = this.isSVG ? b2 : x;
    this.litTemplate = renderer.apply(this, [this.html, ...this.expressions]);
    return this.litTemplate;
  }
  cachedRender(data) {
    if (data) {
      this.updateData(data);
    }
    return this.litTemplate;
  }
  readAST({ ast = this.ast, data = this.data } = {}) {
    each(ast, (node) => {
      switch (node.type) {
        case "html":
          this.addHTML(node.html);
          break;
        case "svg":
          this.addValue(this.evaluateSVG(node.content, data));
          break;
        case "expression":
          const value = this.evaluateExpression(node.value, data, {
            unsafeHTML: node.unsafeHTML,
            ifDefined: node.ifDefined,
            asDirective: true
          });
          this.addValue(value);
          break;
        case "if":
          this.addValue(this.evaluateConditional(node, data));
          break;
        case "each":
          this.addValue(this.evaluateEach(node, data));
          break;
        case "template":
          this.addValue(this.evaluateTemplate(node, data));
          break;
        case "snippet":
          this.snippets[node.name] = node;
          break;
        case "slot":
          if (node.name) {
            this.addHTML(`<slot name="${node.name}"></slot>`);
          } else {
            this.addHTML(`<slot></slot>`);
          }
          break;
      }
    });
  }
  /*
    The conditional directive takes an if condition and branches
    but does not have access to LitRenderer and evaluateExpression
    so we have to pass through functions that do this
  */
  evaluateConditional(node, data) {
    const directiveMap = (value, key) => {
      if (key == "branches") {
        return value.map((branch) => {
          if (branch.condition) {
            branch.expression = branch.condition;
          }
          return mapObject(branch, directiveMap);
        });
      }
      if (key == "condition") {
        return () => this.evaluateExpression(value, data);
      }
      if (key == "content") {
        return () => this.renderContent({ ast: value, data });
      }
      return value;
    };
    node.expression = node.condition;
    let conditionalArguments = mapObject(node, directiveMap);
    return reactiveConditional(conditionalArguments);
  }
  /*
    The conditional directive takes an each conditions
    with over() and content(). it needs to
    return reactive values from renderer
  */
  evaluateEach(node, data) {
    const directiveMap = (value, key) => {
      if (key == "over") {
        return (expressionString) => {
          const computedValue = this.evaluateExpression(value, data);
          return computedValue;
        };
      }
      if (key == "content") {
        return (eachData) => {
          data = { ...this.data, ...eachData };
          return this.renderContent({
            ast: value,
            data
          });
        };
      }
      if (key == "else") {
        return (data2) => {
          return this.renderContent({
            ast: value.content,
            data: this.data
          });
        };
      }
      return value;
    };
    let eachArguments = mapObject(node, directiveMap);
    return reactiveEach(eachArguments, data);
  }
  evaluateTemplate(node, data = {}) {
    const templateName = this.lookupExpressionValue(node.name, data);
    if (this.snippets[templateName]) {
      return this.evaluateSnippet(node, data);
    } else {
      return this.evaluateSubTemplate(node, data);
    }
  }
  evaluateSVG(svg, data) {
    return this.renderContent({
      isSVG: true,
      ast: svg,
      data
    });
  }
  // returns a function that returns the value in the current data context
  getPackedValue = (expression, data, { reactive = false } = {}) => {
    const getValue = (expressionString) => {
      const value = this.evaluateExpression(expressionString, data);
      return value;
    };
    return reactive ? () => getValue(expression) : () => Reaction.nonreactive(() => getValue(expression));
  };
  getPackedNodeData(node, data, { inheritParent = false } = {}) {
    const getPackedData = (unpackedData, options = {}) => {
      let packedData = {};
      if (isString(unpackedData)) {
        const expression = unpackedData;
        unpackedData = this.evaluateExpression(expression, data, options);
        packedData = mapObject(unpackedData, wrapFunction);
      } else if (isPlainObject(unpackedData)) {
        packedData = mapObject(unpackedData, (expression) => this.getPackedValue(expression, data, options));
      }
      return packedData;
    };
    const packedStaticData = getPackedData(node.data);
    const packedReactiveData = getPackedData(node.reactiveData, { reactive: true });
    data = {
      ...inheritParent ? this.data : {},
      ...packedStaticData,
      ...packedReactiveData
    };
    return data;
  }
  evaluateSnippet(node, data = {}) {
    const snippetName = this.lookupExpressionValue(node.name, data);
    const snippet = this.snippets[snippetName];
    if (!snippet) {
      fatal(`Snippet "${snippetName}" not found`);
    }
    const snippetData = this.getPackedNodeData(node, data, { inheritParent: true });
    return this.renderContent({
      ast: snippet.content,
      data: snippetData
    });
  }
  evaluateSubTemplate(node, data = {}) {
    const templateData = this.getPackedNodeData(node, data);
    return renderTemplate({
      subTemplates: this.subTemplates,
      templateName: node.name,
      getTemplate: () => this.evaluateExpression(node.name, data),
      // template can be dynamic
      data: templateData,
      parentTemplate: this.template
    });
  }
  // i.e foo.baz = { foo: { baz: 'value' } }
  evaluateExpression(expression, data = this.data, { asDirective = false, ifDefined = false, unsafeHTML = false } = {}) {
    if (typeof expression === "string") {
      if (asDirective) {
        const dataArguments = {
          expression,
          value: () => this.lookupExpressionValue(expression, this.data)
        };
        return reactiveData(dataArguments, { ifDefined, unsafeHTML });
      } else {
        return this.lookupExpressionValue(expression, data);
      }
    }
    return expression;
  }
  // parses an expression like 'maybe (isEven number)' to ['maybe, ['isEven', 'number']]
  // parse parensed expression like `outerFunc (innerJS ? trueCond : falseCond)` -> [outerFunc, jsExpr]
  getExpressionArray(expr) {
    const groups = [];
    const processedExpr = expr.replace(_LitRenderer.PARENS_REGEXP, (match) => {
      const placeholder = `__GROUP${groups.length}__`;
      groups.push(match.slice(1, -1));
      return placeholder;
    });
    const tokens = processedExpr.match(_LitRenderer.TOKEN_REGEXP) || [];
    const getValue = (token) => {
      const match = token.match(/__GROUP(\d+)__/);
      return match ? groups[parseInt(match[1], 10)] : token;
    };
    const parse = (tokens2) => {
      const result = [];
      while (tokens2.length > 0) {
        const token = tokens2.shift();
        if (token === "(") {
          result.push(parse(tokens2));
        } else if (token === ")") {
          return result;
        } else {
          result.push(getValue(token));
        }
      }
      return result;
    };
    const expressions = parse(tokens);
    return expressions;
  }
  // evaluate javascript expressions
  evaluateJavascript(code, context = {}, { includeHelpers = true } = {}) {
    let result;
    if (includeHelpers) {
      context = {
        ...this.helpers,
        ...context
      };
      context = filterObject(context, (value, name) => {
        const reservedWords = ["debugger"];
        return !reservedWords.includes(name) && _LitRenderer.VAR_NAME_REGEXP.test(name);
      });
    }
    try {
      const proxyHandler = {
        has(target, key) {
          if (key in target) {
            return true;
          }
          return false;
        },
        get(target, prop) {
          const value = target[prop];
          if (value instanceof Signal) {
            return value.get();
          }
          if (isFunction(value)) {
            return new Proxy(value, {
              apply(targetFn, thisArg, args) {
                return targetFn.apply(thisArg, args);
              }
            });
          }
          return value;
        }
      };
      const proxiedContext = new Proxy({ ...context }, proxyHandler);
      result = new Function("ctx", `
        with (ctx) {
          return ${code};
        }
      `)(proxiedContext);
      result = new Function(...keys, `return ${code}`)(...values);
    } catch (e6) {
    }
    return result;
  }
  // this evaluates an expression from right determining if something is an argument or a function
  // then looking up the value
  lookupExpressionValue(expression = "", data = {}, visited = /* @__PURE__ */ new Set()) {
    if (visited.has(expression)) {
      return void 0;
    }
    visited.add(expression);
    if (isString(expression)) {
      const value = this.lookupTokenValue(expression, data);
      if (value !== void 0) {
        visited.delete(expression);
        if (visited.size > 0) {
          return value;
        }
        return wrapFunction(value)();
      }
    }
    let expressionArray;
    if (!isArray(expression)) {
      expression = this.addParensToExpression(expression);
      expressionArray = this.getExpressionArray(expression);
    } else {
      expressionArray = expression;
    }
    let funcArguments = [];
    let result;
    let index = expressionArray.length;
    while (index--) {
      const token = expressionArray[index];
      if (isArray(token)) {
        result = this.lookupExpressionValue(token.join(" "), data, visited);
        funcArguments.unshift(result);
      } else {
        const tokenValue = this.lookupExpressionValue(token, data, visited);
        result = isFunction(tokenValue) ? tokenValue(...funcArguments) : tokenValue;
        funcArguments.unshift(result);
      }
    }
    visited.delete(expression);
    return result;
  }
  lookupTokenValue(token = "", data) {
    if (isArray(token)) {
      return this.lookupExpressionValue(token, data);
    }
    const literalValue = this.getLiteralValue(token);
    if (literalValue !== void 0) {
      return literalValue;
    }
    let dataValue = this.getDeepDataValue(data, token);
    let value = this.accessTokenValue(dataValue, token, data);
    if (value !== void 0) {
      return value;
    }
    const jsValue = this.evaluateJavascript(token, data);
    if (jsValue !== void 0) {
      return this.accessTokenValue(jsValue, token, data);
    }
    const helper = this.helpers[token];
    if (isFunction(helper)) {
      return helper;
    }
  }
  getDeepDataValue(obj, path) {
    return path.split(".").reduce((acc, part) => {
      if (acc === void 0) {
        return void 0;
      }
      const current = acc instanceof Signal ? acc.get() : wrapFunction(acc)();
      if (current == void 0) {
        return void 0;
      }
      return current[part];
    }, obj);
  }
  // retrieve token value accessing getter for reactive vars
  accessTokenValue(tokenValue, token, data) {
    const getThisContext = (token2, data2) => {
      const path = token2.split(".").slice(0, -1).join(".");
      return this.getDeepDataValue(data2, path);
    };
    if (isFunction(tokenValue) && token.search(".") !== -1) {
      const thisContext = getThisContext(token, data);
      tokenValue = tokenValue.bind(thisContext);
    }
    if (tokenValue !== void 0) {
      return tokenValue instanceof Signal ? tokenValue.value : tokenValue;
    }
    return void 0;
  }
  addParensToExpression(expression = "") {
    return String(expression).replace(_LitRenderer.WRAPPED_EXPRESSION, (match, before, brackets, after) => {
      return `${before}(${brackets})${after}`;
    });
  }
  getLiteralValue(token) {
    if (token.length > 1 && (token[0] === "'" || token[0] === '"') && token[0] === token[token.length - 1]) {
      return token.slice(1, -1).replace(/\\(['"])/g, "$1");
    }
    const boolString = { true: true, false: false };
    if (boolString[token] !== void 0) {
      return boolString[token];
    }
    if (Number.isFinite(+token)) {
      return Number(token);
    }
  }
  addHTML(html) {
    if (this.lastHTML) {
      const lastHTML = this.html.pop();
      html = `${lastHTML}${html}`;
    }
    this.html.push(html);
    this.html.raw.push(String.raw({ raw: html }));
    this.lastHTML = true;
  }
  addHTMLSpacer() {
    this.addHTML("");
  }
  addValue(expression) {
    this.addHTMLSpacer();
    this.expressions.push(expression);
    this.lastHTML = false;
    this.addHTMLSpacer();
  }
  // subtrees are rendered as separate contexts stored as weakrefs for gc
  renderContent({ ast, data, isSVG = this.isSVG } = {}) {
    const contentID = _LitRenderer.getID({ ast, data, isSVG });
    const treeRef = this.renderTrees[contentID];
    const existingTree = treeRef ? treeRef.deref() : void 0;
    if (_LitRenderer.useSubtreeCache && existingTree) {
      return existingTree.cachedRender(data);
    }
    const tree = new _LitRenderer({
      ast,
      data,
      isSVG,
      subTemplates: this.subTemplates,
      snippets: this.snippets,
      helpers: this.helpers,
      template: this.template
    });
    this.treeIDs.push(contentID);
    this.renderTrees[contentID] = new WeakRef(tree);
    return tree.render();
  }
  cleanup() {
    this.renderTrees = [];
  }
  setData(newData) {
    this.updateData(newData);
    this.updateSubtreeData(newData);
  }
  // yeah we're going there, weakrefs
  updateSubtreeData(newData) {
    each(this.renderTrees, (ref, contentID) => {
      const tree = ref.deref();
      if (tree) {
        tree.updateData(newData);
      }
    });
  }
  /*
    Note this is important to preserve the object reference vs clobbering
    const a = { foo: 'baz' }; const b = a.foo; a.foo = 'bar';
  */
  updateData(newData) {
    each(this.data, (value, name) => {
      delete this.data[name];
    });
    each(newData, (value, name) => {
      if (this.data[name] !== value) {
        this.data[name] = value;
      }
    });
  }
  clearTemp() {
    delete this.lastHTML;
  }
};
__publicField(_LitRenderer, "html", x);
__publicField(_LitRenderer, "PARENS_REGEXP", /\((?:[^()]*|\((?:[^()]*|\([^()]*\))*\))*\)/g);
// match `(one () )` and [`(one)`, `(two)`]
__publicField(_LitRenderer, "TOKEN_REGEXP", /('[^']*'|"[^"]*"|\(|\)|[^\s()]+)/g);
// match "" '', \b for token groups in Lisp style expr
__publicField(_LitRenderer, "WRAPPED_EXPRESSION", /(\s|^)([\[{].*?[\]}])(\s|$)/g);
__publicField(_LitRenderer, "VAR_NAME_REGEXP", /^[a-zA-Z_$][0-9a-zA-Z_$]*$/);
__publicField(_LitRenderer, "useSubtreeCache", false);
var LitRenderer = _LitRenderer;

// packages/templating/src/template.js
var _a2;
var Template = (_a2 = class {
  rendered = false;
  destroyed = false;
  constructor({
    templateName,
    ast,
    template,
    data,
    element,
    renderRoot,
    css,
    events: events6,
    keys: keys3,
    defaultState: defaultState2,
    subTemplates,
    createComponent: createComponent11,
    parentTemplate,
    // the parent template when nested
    renderingEngine = "lit",
    isPrototype = false,
    attachStyles = false,
    // whether to construct css stylesheet and attach to renderRoot
    onCreated: onCreated4 = noop,
    onRendered: onRendered3 = noop,
    onUpdated = noop,
    onDestroyed = noop,
    onThemeChanged = noop
  } = {}) {
    if (!ast) {
      const compiler = new TemplateCompiler(template);
      ast = compiler.compile();
    }
    this.events = events6;
    this.observers = [];
    this.keys = keys3 || {};
    this.ast = ast;
    this.css = css;
    this.data = data || {};
    this.reactions = [];
    this.defaultState = defaultState2;
    this.state = this.createReactiveState(defaultState2, data) || {};
    this.templateName = templateName || this.getGenericTemplateName();
    this.subTemplates = subTemplates;
    this.createComponent = createComponent11;
    this.onCreated = noop;
    this.onDestroyed = noop;
    this.onRendered = noop;
    this.onRenderedCallback = onRendered3;
    this.onDestroyedCallback = onDestroyed;
    this.onCreatedCallback = onCreated4;
    this.onThemeChangedCallback = onThemeChanged;
    this.id = generateID();
    this.isPrototype = isPrototype;
    this.parentTemplate = parentTemplate;
    this.attachStyles = attachStyles;
    this.element = element;
    this.renderingEngine = renderingEngine;
    if (renderRoot) {
      this.attach(renderRoot);
    }
  }
  createReactiveState(defaultState2, data) {
    let reactiveState = {};
    let getInitialValue = (config, name) => {
      const dataValue = get(data, name);
      if (dataValue) {
        return dataValue;
      }
      return (config == null ? void 0 : config.value) || config;
    };
    each(defaultState2, (config, name) => {
      const initialValue = getInitialValue(config, name);
      if (config == null ? void 0 : config.options) {
        reactiveState[name] = new Signal(initialValue, config.options);
      } else {
        reactiveState[name] = new Signal(initialValue);
      }
    });
    return reactiveState;
  }
  setDataContext(data, { rerender = true } = {}) {
    this.data = data;
    if (rerender) {
      this.rendered = false;
    }
  }
  // when rendered as a partial/subtemplate
  setParent(parentTemplate) {
    if (!parentTemplate._childTemplates) {
      parentTemplate._childTemplates = [];
    }
    parentTemplate._childTemplates.push(this);
    this.parentTemplate = parentTemplate;
  }
  removeParent() {
    var _a3;
    if (!((_a3 = this.parentTemplate) == null ? void 0 : _a3._childTemplates)) {
      return;
    }
    this.parentTemplate._childTemplates = this.parentTemplate._childTemplates.filter((template) => {
      return template.id !== this.id;
    });
  }
  setElement(element) {
    this.element = element;
  }
  getGenericTemplateName() {
    _a2.templateCount++;
    return `Anonymous #${_a2.templateCount}`;
  }
  initialize() {
    let template = this;
    let instance;
    this.instance = {};
    if (isFunction(this.createComponent)) {
      instance = this.call(this.createComponent) || {};
      extend(template.instance, instance);
    }
    if (isFunction(template.instance.initialize)) {
      this.call(template.instance.initialize.bind(template));
    }
    template.instance.templateName = this.templateName;
    this.onCreated = () => {
      this.call(this.onCreatedCallback);
      _a2.addTemplate(this);
      this.dispatchEvent("created", { component: this.instance }, {}, { triggerCallback: false });
    };
    this.onRendered = () => {
      this.call(this.onRenderedCallback);
      if (isFunction(this.onRenderOnce)) {
        this.onRenderOnce();
        delete this.onRenderOnce;
      }
      this.dispatchEvent("rendered", { component: this.instance }, {}, { triggerCallback: false });
    };
    this.onUpdated = () => {
      this.dispatchEvent("updated", { component: this.instance }, {}, { triggerCallback: false });
    };
    this.onThemeChanged = (...args) => {
      this.call(this.onThemeChangedCallback, ...args);
    };
    this.onDestroyed = () => {
      _a2.removeTemplate(this);
      this.rendered = false;
      this.destroyed = true;
      this.clearReactions();
      this.removeEvents();
      this.removeObservers();
      this.removeParent();
      this.call(this.onDestroyedCallback);
      this.dispatchEvent("destroyed", { component: this.instance }, {}, { triggerCallback: false });
    };
    this.initialized = true;
    if (this.renderingEngine == "lit") {
      this.renderer = new LitRenderer({
        ast: this.ast,
        data: this.getDataContext(),
        template: this,
        subTemplates: this.subTemplates,
        helpers: TemplateHelpers
      });
    } else {
      fatal("Unknown renderer specified", this.renderingEngine);
    }
    this.onCreated();
  }
  async attach(renderRoot, { parentNode = renderRoot, startNode, endNode } = {}) {
    if (!this.initialized) {
      this.initialize();
    }
    if (this.renderRoot == renderRoot) {
      return;
    }
    this.renderRoot = renderRoot;
    this.parentNode = parentNode;
    this.startNode = startNode;
    this.endNode = endNode;
    this.attachEvents();
    this.bindKeys();
    if (this.attachStyles) {
      await this.adoptStylesheet();
    }
  }
  getDataContext() {
    return {
      ...this.data,
      ...this.state,
      ...this.instance
    };
  }
  async adoptStylesheet() {
    if (!this.css) {
      return;
    }
    if (!this.renderRoot || !this.renderRoot.adoptedStyleSheets) {
      return;
    }
    const cssString = this.css;
    if (!this.stylesheet) {
      this.stylesheet = new CSSStyleSheet();
      await this.stylesheet.replace(cssString);
    }
    let styles = Array.from(this.renderRoot.adoptedStyleSheets);
    let hasStyles = styles.some((style) => isEqual(style.cssRules, this.stylesheet.cssRules));
    if (!hasStyles) {
      this.renderRoot.adoptedStyleSheets = [
        ...this.renderRoot.adoptedStyleSheets,
        this.stylesheet
      ];
    }
  }
  clone(settings) {
    const defaultSettings = {
      templateName: this.templateName,
      element: this.element,
      ast: this.ast,
      css: this.css,
      defaultState: this.defaultState,
      events: this.events,
      keys: this.keys,
      renderingEngine: this.renderingEngine,
      subTemplates: this.subTemplates,
      onCreated: this.onCreatedCallback,
      onThemeChanged: this.onThemeChangedCallback,
      onRendered: this.onRenderedCallback,
      parentTemplate: this.parentTemplate,
      onDestroyed: this.onDestroyedCallback,
      createComponent: this.createComponent
    };
    const templateSettings = {
      ...defaultSettings,
      ...settings
    };
    return new _a2(templateSettings);
  }
  parseEventString(eventString) {
    let eventType = "delegate";
    let keywords = ["deep", "global", "bind"];
    each(keywords, (keyword) => {
      if (eventString.startsWith(keyword)) {
        eventString = eventString.replace(keyword, "");
        eventType = keyword;
      }
    });
    eventString = eventString.trim();
    const getBubbledEvent = (eventName) => {
      const bubbleMap = {
        blur: "focusout",
        focus: "focusin",
        load: "DOMContentLoaded",
        unload: "beforeunload",
        mouseenter: "mouseover",
        mouseleave: "mouseout"
      };
      if (bubbleMap[eventName]) {
        eventName = bubbleMap[eventName];
      }
      return eventName;
    };
    let events6 = [];
    let parts = eventString.split(/\s+/);
    let addedEvents = false;
    let addedSelectors = false;
    const eventNames = [];
    const selectors = [];
    each(parts, (part, index) => {
      const value = part.replace(/(\,|\W)+$/, "").trim();
      const hasComma = part.includes(",");
      if (!addedEvents) {
        eventNames.push(getBubbledEvent(value));
        addedEvents = !hasComma;
      } else if (!addedSelectors) {
        const selectorParts = parts.slice(index).join(" ").split(",");
        each(selectorParts, (value2) => {
          selectors.push(value2.trim());
        });
        addedSelectors = true;
      }
    });
    each(eventNames, (eventName) => {
      if (!selectors.length) {
        selectors.push("");
      }
      each(selectors, (selector) => {
        events6.push({ eventName, eventType, selector });
      });
    });
    return events6;
  }
  attachEvents(events6 = this.events) {
    if (!this.parentNode || !this.renderRoot) {
      fatal("You must set a parent before attaching events");
    }
    this.removeEvents();
    this.eventController = new AbortController();
    if (!_a2.isServer && this.onThemeChangedCallback !== noop) {
      const observer = new MutationObserver(this.onThemeChanged);
      observer.observe(document.documentElement, {
        attributes: true,
        attributeFilter: ["class"]
      });
      this.observers.push(observer);
      $2("html").on("themechange", (event) => {
        this.onThemeChanged({
          additionalData: {
            event,
            ...event.detail
          }
        });
      }, { abortController: this.eventController });
    }
    each(events6, (userHandler, eventString) => {
      const subEvents = this.parseEventString(eventString);
      const template = this;
      each(subEvents, (event) => {
        const { eventName, selector, eventType } = event;
        if (selector) {
          $2(selector, { root: this.renderRoot }).on(eventName, noop, { abortController: this.eventController });
        }
        const eventHandler = function(event2) {
          var _a3, _b;
          if (eventType !== "global" && !template.isNodeInTemplate(event2.target)) {
            return;
          }
          const isDeep = selector && $2(event2.target).closest(selector).length == 0;
          if (!inArray(eventType, ["deep", "global"]) && isDeep) {
            return;
          }
          if (inArray(eventName, ["mouseover", "mouseout"]) && event2.relatedTarget && event2.target.contains(event2.relatedTarget)) {
            return;
          }
          const targetElement = this;
          const boundEvent = userHandler.bind(targetElement);
          const eventData = (event2 == null ? void 0 : event2.detail) || {};
          const elData = mapObject({ ...targetElement == null ? void 0 : targetElement.dataset }, (stringValue) => {
            let value;
            try {
              value = JSON.parse(stringValue);
            } catch (e6) {
              value = stringValue;
            }
            return value;
          });
          const elValue = (targetElement == null ? void 0 : targetElement.value) || ((_a3 = event2.target) == null ? void 0 : _a3.value) || ((_b = event2 == null ? void 0 : event2.detail) == null ? void 0 : _b.value);
          template.call(boundEvent, {
            additionalData: {
              event: event2,
              isDeep,
              target: targetElement,
              value: elValue,
              data: {
                ...elData,
                ...eventData
              }
            }
          });
        };
        const eventSettings = { abortController: this.eventController };
        if (eventType == "global") {
          $2(selector).on(eventName, eventHandler, eventSettings);
        } else if (eventType == "bind") {
          this.onRenderOnce = () => {
            this.$(selector).on(eventName, eventHandler, eventSettings);
            wrapFunction(this.onRenderOnce);
          };
        } else {
          $2(this.renderRoot).on(eventName, selector, eventHandler, eventSettings);
        }
      });
    });
  }
  removeEvents() {
    if (this.eventController) {
      this.eventController.abort("Template destroyed");
    }
  }
  removeObservers() {
    each(this.observers, (observer) => {
      observer.disconnect();
    });
  }
  bindKeys(keys3 = this.keys) {
    if (isServer) {
      return;
    }
    if (Object.keys(keys3).length == 0) {
      return;
    }
    const sequenceTimeout = 500;
    const eventSettings = { abortController: this.eventController };
    this.currentSequence = "";
    $2(document).on("keydown", (event) => {
      const key = getKeyFromEvent(event);
      let repeatedKey = key == this.currentKey;
      this.currentKey = key;
      this.currentSequence += key;
      each(this.keys, (handler, keySequence) => {
        keySequence = keySequence.replace(/\s*\+\s*/g, "+");
        const keySequences = keySequence.split(",");
        if (any(keySequences, (sequence) => this.currentSequence.endsWith(sequence))) {
          const inputFocused = document.activeElement && (["input", "select", "textarea"].includes(document.activeElement.tagName.toLowerCase()) || document.activeElement.isContentEditable);
          const eventResult = this.call(handler, {
            additionalData: {
              event,
              inputFocused,
              repeatedKey
            }
          });
          if (eventResult !== true) {
            event.preventDefault();
          }
        }
      });
      this.currentSequence += " ";
      clearTimeout(this.resetSequence);
      this.resetSequence = setTimeout(() => {
        this.currentSequence = "";
      }, sequenceTimeout);
    }, eventSettings).on("keyup", (event) => {
      this.currentKey = "";
    }, eventSettings);
  }
  bindKey(key, callback) {
    if (!key || !callback) {
      return;
    }
    const needsInit = Object.keys(this.keys).length == 0;
    this.keys[key] = callback;
    if (needsInit) {
      this.bindKeys();
    }
  }
  unbindKey(key) {
    delete this.keys[key];
  }
  // Find the direct child of the renderRoot that is an ancestor of the event.target
  // then confirm position
  isNodeInTemplate(node) {
    const getRootChild = (node2) => {
      while (node2 && node2.parentNode !== this.parentNode) {
        if (node2.parentNode === null && node2.host) {
          node2 = node2.host;
        } else {
          node2 = node2.parentNode;
        }
      }
      return node2;
    };
    const isNodeInRange = (node2, startNode = this.startNode, endNode = this.endNode) => {
      if (!startNode || !endNode) {
        return true;
      }
      if (node2 === null) {
        return false;
      }
      const startComparison = startNode.compareDocumentPosition(node2);
      const endComparison = endNode.compareDocumentPosition(node2);
      const isAfterStart = (startComparison & Node.DOCUMENT_POSITION_FOLLOWING) !== 0;
      const isBeforeEnd = (endComparison & Node.DOCUMENT_POSITION_PRECEDING) !== 0;
      return isAfterStart && isBeforeEnd;
    };
    return isNodeInRange(getRootChild(node));
  }
  render(additionalData = {}) {
    if (!this.initialized) {
      this.initialize();
    }
    const dataContext = {
      ...this.getDataContext(),
      ...additionalData
    };
    this.setDataContext(dataContext, { rerender: false });
    this.renderer.setData(dataContext);
    if (!this.rendered) {
      this.html = this.renderer.render();
      setTimeout(this.onRendered, 0);
    }
    this.rendered = true;
    this.destroyed = false;
    setTimeout(this.onUpdated, 0);
    return this.html;
  }
  /*******************************
             DOM Helpers
  *******************************/
  // Rendered DOM (either shadow or regular)
  $(selector, { root = this.renderRoot, filterTemplate = true, ...otherArgs } = {}) {
    if (!_a2.isServer && inArray(selector, ["body", "document", "html"])) {
      root = document;
    }
    if (!root) {
      root = globalThis;
    }
    if (root == this.renderRoot) {
      const $results = $2(selector, { root, ...otherArgs });
      return filterTemplate ? $results.filter((node) => this.isNodeInTemplate(node)) : $results;
    } else {
      return $2(selector, { root, ...otherArgs });
    }
  }
  $$(selector, args) {
    return this.$(selector, { root: this.renderRoot, pierceShadow: true, filterTemplate: true, ...args });
  }
  // calls callback if defined with consistent params and this context
  call(func, { params, additionalData = {}, firstArg, additionalArgs } = {}) {
    var _a3;
    const args = [];
    if (this.isPrototype) {
      return;
    }
    if (!params) {
      const element = this.element;
      params = {
        el: this.element,
        // provide 3 options for referring to self
        tpl: this.instance,
        self: this.instance,
        component: this.instance,
        $: this.$.bind(this),
        $$: this.$$.bind(this),
        reaction: this.reaction.bind(this),
        signal: this.signal.bind(this),
        afterFlush: Reaction.afterFlush,
        nonreactive: Reaction.nonreactive,
        flush: Reaction.flush,
        data: this.data,
        settings: (_a3 = this.element) == null ? void 0 : _a3.settings,
        state: this.state,
        isRendered: () => this.rendered,
        isServer: _a2.isServer,
        isClient: !_a2.isServer,
        dispatchEvent: this.dispatchEvent.bind(this),
        attachEvent: this.attachEvent.bind(this),
        bindKey: this.bindKey.bind(this),
        unbindKey: this.unbindKey.bind(this),
        abortController: this.eventController,
        helpers: TemplateHelpers,
        template: this,
        templateName: this.templateName,
        templates: _a2.renderedTemplates,
        findTemplate: this.findTemplate,
        findParent: this.findParent.bind(this),
        findChild: this.findChild.bind(this),
        findChildren: this.findChildren.bind(this),
        // not yet implemented
        content: this.instance.content,
        // on demand since forces recalculateStyle on body
        get darkMode() {
          return element.isDarkMode();
        },
        ...additionalData
      };
      args.push(params);
    }
    if (additionalArgs) {
      args.push(...additionalArgs);
    }
    if (isFunction(func)) {
      return func.apply(this.element, args);
    }
  }
  // attaches an external event handler making sure to remove the event when the component is destroyed
  attachEvent(selector, eventName, eventHandler, { eventSettings = {}, querySettings = { pierceShadow: true } } = {}) {
    return $2(selector, document, querySettings).on(eventName, eventHandler, {
      abortController: this.eventController,
      returnHandler: true,
      ...eventSettings
    });
  }
  // dispatches an event from this template
  dispatchEvent(eventName, eventData, eventSettings, { triggerCallback = true } = {}) {
    if (_a2.isServer) {
      return;
    }
    if (triggerCallback) {
      const callbackName = `on${capitalize(eventName)}`;
      const callback = this.element[callbackName];
      wrapFunction(callback).call(this.element, eventData);
    }
    return $2(this.element).dispatchEvent(eventName, eventData, eventSettings);
  }
  /*******************************
          Reactive Helpers
  *******************************/
  // reactions bound with this.reaction will be scoped to template
  // and be removed when the template is destroyed
  reaction(reaction) {
    this.reactions.push(Reaction.create(reaction));
  }
  signal(value, options) {
    return new Signal(value, options);
  }
  clearReactions() {
    each(this.reactions || [], (comp) => comp.stop());
  }
  /*******************************
          Template Helpers
  *******************************/
  findTemplate = (templateName) => _a2.findTemplate(templateName);
  findParent = (templateName) => _a2.findParentTemplate(this, templateName);
  findChild = (templateName) => _a2.findChildTemplate(this, templateName);
  findChildren = (templateName) => _a2.findChildTemplates(this, templateName);
  static addTemplate(template) {
    if (template.isPrototype) {
      return;
    }
    let templates = _a2.renderedTemplates.get(template.templateName) || [];
    templates.push(template);
    _a2.renderedTemplates.set(template.templateName, templates);
  }
  static removeTemplate(template) {
    if (template.isPrototype) {
      return;
    }
    let templates = _a2.renderedTemplates.get(template.templateName) || [];
    remove(templates, (thisTemplate) => thisTemplate.id == template.id);
    _a2.renderedTemplates.set(templates);
  }
  static getTemplates(templateName) {
    return _a2.renderedTemplates.get(templateName) || [];
  }
  static findTemplate(templateName) {
    return _a2.getTemplates(templateName)[0];
  }
  static findParentTemplate(template, templateName) {
    var _a3;
    let match;
    const isMatch = (component) => {
      if (match || !(component == null ? void 0 : component.templateName)) {
        return false;
      }
      if (templateName && (component == null ? void 0 : component.templateName) !== templateName) {
        return false;
      }
      return true;
    };
    if (!match) {
      let parentNode = (_a3 = template.element) == null ? void 0 : _a3.parentNode;
      while (parentNode) {
        if (isMatch(parentNode.component)) {
          match = {
            ...parentNode.component,
            ...parentNode.dataContext
          };
          break;
        }
        parentNode = parentNode.parentNode;
      }
    }
    while (template) {
      template = template.parentTemplate;
      if (isMatch(template)) {
        match = {
          ...template.instance,
          ...template.data
        };
        break;
      }
    }
    return match;
  }
  static findChildTemplates(template, templateName) {
    let result = [];
    function search(template2, templateName2) {
      if (!templateName2 || template2.templateName === templateName2) {
        result.push({
          ...template2.instance,
          ...template2.data
        });
      }
      if (template2._childTemplates) {
        template2._childTemplates.forEach((childTemplate) => {
          search(childTemplate, templateName2);
        });
      }
    }
    search(template, templateName);
    return result;
  }
  static findChildTemplate(template, templateName) {
    return _a2.findChildTemplates(template, templateName)[0];
  }
}, __publicField(_a2, "templateCount", 0), __publicField(_a2, "isServer", isServer), __publicField(_a2, "renderedTemplates", /* @__PURE__ */ new Map()), _a2);

// packages/component/src/helpers/adjust-property-from-attribute.js
var SPACE_REGEX = /\s+/mg;
var SPECIAL_ATTRIBUTES = ["disabled", "value"];
var reverseDashes = (string) => {
  if (isString(string)) {
    return string.split("-").reverse().join("-");
  }
  return string;
};
var tokenizeSpaces = (string) => {
  if (isString(string)) {
    return string.replaceAll(SPACE_REGEX, "-");
  }
  return string;
};
var adjustPropertyFromAttribute = ({ el, attribute, attributeValue, properties, componentSpec, oldValue }) => {
  var _a3;
  const checkSpecForAllowedValue = ({ attribute: attribute2, optionValue, optionAttributeValue }) => {
    optionValue = tokenizeSpaces(optionValue);
    let optionsToCheck = [optionValue];
    if (attribute2 && optionValue) {
      optionsToCheck.push(`${attribute2}-${attributeValue}`);
      optionsToCheck.push(`${attributeValue}-${attribute2}`);
    }
    optionsToCheck.push(reverseDashes(optionValue));
    optionsToCheck = unique(optionsToCheck);
    const matchingValue = firstMatch(
      optionsToCheck,
      (currentValue) => get(componentSpec.optionAttributes, currentValue)
    );
    if (!matchingValue) {
      return { matchingAttribute: void 0, matchingValue: void 0 };
    }
    if (inArray(attributeValue == null ? void 0 : attributeValue.constructor, [Object, Array, Function])) {
      return { matchingAttribute: void 0, matchingValue: void 0 };
    }
    const matchingAttribute = get(componentSpec.optionAttributes, matchingValue);
    return { matchingAttribute, matchingValue };
  };
  const setProperty = (attribute2, value) => {
    const property = kebabToCamel(attribute2);
    if (value !== void 0) {
      el[property] = value;
    }
    if (inArray(attribute2, SPECIAL_ATTRIBUTES)) {
      el.requestUpdate();
    }
  };
  const removeProperty = (attribute2) => {
    const property = kebabToCamel(attribute2);
    el[property] = null;
    if (inArray(attribute2, SPECIAL_ATTRIBUTES)) {
      el.requestUpdate();
    }
  };
  const isBooleanValue = (attribute2, attributeValue2) => {
    var _a4;
    const isBooleanType = componentSpec.propertyTypes[attribute2] == Boolean;
    const isIdentityBoolean = ((_a4 = componentSpec.optionAttributes) == null ? void 0 : _a4[attribute2]) == attribute2;
    const isAttributeClass = inArray(attribute2, componentSpec.attributeClasses);
    return (isBooleanType || isAttributeClass || isIdentityBoolean) && inArray(attributeValue2, ["", true, attribute2]);
  };
  if (componentSpec) {
    if (attribute == "class" && attributeValue) {
      const previousClasses = isString(oldValue) ? oldValue.split(" ") : [];
      const currentClasses = attributeValue.split(" ");
      const classesToRemove = difference(previousClasses, currentClasses);
      const classesToAdd = difference(currentClasses, previousClasses);
      each(classesToRemove, (className) => {
        adjustPropertyFromAttribute({
          el,
          attribute: className,
          attributeValue: null,
          componentSpec
        });
      });
      each(classesToAdd, (className) => {
        adjustPropertyFromAttribute({
          el,
          attribute: className,
          attributeValue: true,
          componentSpec
        });
      });
    } else if (inArray(attribute, componentSpec.attributes)) {
      if (isBooleanValue(attribute, attributeValue)) {
        attributeValue = true;
        setProperty(attribute, attributeValue);
        return;
      }
      if (attributeValue === null) {
        removeProperty(attribute);
        return;
      }
      const { matchingValue } = checkSpecForAllowedValue({
        attribute,
        optionValue: attributeValue
      });
      if (matchingValue) {
        setProperty(attribute, matchingValue);
      }
    } else if (attributeValue !== void 0) {
      const { matchingAttribute, matchingValue } = checkSpecForAllowedValue({
        optionValue: attribute,
        optionAttributeValue: attributeValue
      });
      if (matchingAttribute && attributeValue === null) {
        if (el[matchingAttribute] == attribute) {
          removeProperty(matchingAttribute);
        }
        return;
      }
      if (matchingAttribute && matchingValue) {
        setProperty(matchingAttribute, matchingValue);
      }
    }
  } else if (properties && attributeValue !== void 0 && attribute.includes("-")) {
    const propertyName = kebabToCamel(attribute);
    const attributeSettings = properties[attribute];
    if (propertyName !== attribute && (attributeSettings == null ? void 0 : attributeSettings.alias)) {
      const convertFunc = (_a3 = attributeSettings == null ? void 0 : attributeSettings.converter) == null ? void 0 : _a3.fromAttribute;
      let propertyValue = convertFunc ? convertFunc(attributeValue) : attributeValue;
      if (propertyValue) {
        setProperty(propertyName, propertyValue);
      }
      return;
    }
  }
};

// packages/component/src/web-component.js
var _WebComponentBase = class _WebComponentBase extends r4 {
  constructor() {
    super();
    this.renderCallbacks = [];
  }
  updated() {
    super.updated();
    each(this.renderCallbacks, (callback) => callback());
  }
  addRenderCallback(callback) {
    this.renderCallbacks.push(callback);
  }
  /*******************************
           Lit Properties
  *******************************/
  static getProperties({ properties = {}, defaultSettings, componentSpec }) {
    if (keys2(properties).length) {
      return properties;
    }
    if (componentSpec) {
      properties.class = { type: String, noAccessor: true, alias: true };
      each(componentSpec.attributes, (attributeName) => {
        const propertyType = componentSpec.propertyTypes[attributeName];
        const propertyName = kebabToCamel(attributeName);
        properties[propertyName] = _WebComponentBase.getPropertySettings({
          name: attributeName,
          type: propertyType
        });
      });
      each(componentSpec.properties, (attributeName) => {
        const propertyType = componentSpec.propertyTypes[attributeName];
        const propertyName = kebabToCamel(attributeName);
        properties[propertyName] = _WebComponentBase.getPropertySettings({
          name: attributeName,
          type: propertyType
        });
      });
      each(componentSpec.optionAttributes, (attributeValues, attributeName) => {
        const propertyName = kebabToCamel(attributeName);
        properties[propertyName] = { type: String, noAccessor: true, alias: true, attribute: attributeName };
      });
    }
    if (defaultSettings) {
      each(defaultSettings, (defaultValue, propertyName) => {
        properties[propertyName] = (defaultValue == null ? void 0 : defaultValue.type) ? defaultSettings : _WebComponentBase.getPropertySettings({
          name: propertyName,
          type: defaultValue == null ? void 0 : defaultValue.constructor,
          propertyOnly: isClassInstance(defaultValue)
          // cant serialize custom classes
        });
      });
    }
    each(properties, (propertySettings, propertyName) => {
      const attributeName = camelToKebab(propertyName);
      if (attributeName !== propertyName && !properties[attributeName] && properties[propertyName]) {
        properties[attributeName] = {
          ...properties[propertyName],
          noAccessor: true,
          alias: true
        };
      }
    });
    const specialAttrs = ["value", "checked"];
    each(specialAttrs, (attr) => {
      if (properties[attr]) {
      }
    });
    return properties;
  }
  static getPropertySettings({ name, type = String, propertyOnly = false } = {}) {
    if (isString(type)) {
      const types = {
        string: String,
        number: Number,
        boolean: Boolean,
        object: Object,
        array: Array,
        function: Function
      };
      type = types[type] || String;
    }
    let property = {
      type,
      attribute: true,
      hasChanged: (a3, b3) => {
        return !isEqual(a3, b3);
      }
    };
    if (propertyOnly || type == Function) {
      property.attribute = false;
      property.hasChanged = (newVal, oldVal) => {
        return true;
      };
    } else if (type == Boolean) {
      property.converter = {
        fromAttribute: (value, type2) => {
          if (inArray(value, ["false", "0", "null", "undefined"])) {
            return false;
          }
          if (inArray(value, ["", true, "true"])) {
            return true;
          }
          return Boolean(value);
        },
        toAttribute: (value, type2) => {
          return String(value);
        }
      };
    }
    return property;
  }
  /*******************************
      Settings / Template Data
  *******************************/
  /*
    This sets default settings for a component
  */
  setDefaultSettings({ defaultSettings = {}, componentSpec }) {
    this.defaultSettings = defaultSettings;
    each(defaultSettings, (setting, name) => {
      if ((setting == null ? void 0 : setting.default) !== void 0) {
        this.defaultSettings[name] = setting.default;
      } else {
        this.defaultSettings[name] = setting;
      }
    });
    if (componentSpec == null ? void 0 : componentSpec.defaultValues) {
      this.defaultSettings = {
        ...componentSpec.defaultValues,
        ...this.defaultSettings
      };
    }
  }
  /*
    This returns a list of settings which may include both attributes and properties
    as specified in the spec for the component. It will extend them from default settings
  */
  getSettingsFromConfig({ componentSpec, properties }) {
    let settings = {};
    each(properties, (propSettings, propertyName) => {
      if (propSettings.alias === true) {
        return;
      }
      const elementProp = this[propertyName];
      const setting = elementProp ?? this.defaultSettings[propertyName] ?? ((componentSpec == null ? void 0 : componentSpec.defaultSettings) || {})[propertyName];
      if (setting !== void 0) {
        settings[propertyName] = setting;
      }
      if (componentSpec && settings[elementProp] !== void 0) {
        settings[propertyName] = true;
      }
    });
    return settings;
  }
  /* Create a proxy object which returns the current setting
     we need this over a getter/setter because settings are
     destructured in function arguments which locks their value in time
     i.e. onCreated({settings}) { }
  */
  createSettingsProxy({ componentSpec, properties }) {
    let component = this;
    component.settingsVars = /* @__PURE__ */ new Map();
    return new Proxy({}, {
      get: (target, property) => {
        const settings = component.getSettings({
          componentSpec,
          properties
        });
        const setting = get(settings, property);
        let signal = component.settingsVars.get(property);
        if (signal) {
          signal.get();
        } else {
          signal = new Signal(setting);
          component.settingsVars.set(property, signal);
        }
        return setting;
      },
      set: (target, property, value, receiver) => {
        component.setSetting(property, value);
        let signal = component.settingsVars.get(property);
        if (signal) {
          signal.set(value);
        } else {
          signal = new Signal(value);
          component.settingsVars.set(property, signal);
        }
        return true;
      }
    });
  }
  /*
    This returns a list of styling classes to pass through to
    the template data context for the component based off
    component attributes
  */
  getUIClasses({ componentSpec, properties }) {
    if (!componentSpec) {
      return;
    }
    const classes = [];
    each(componentSpec.attributes, (attribute) => {
      var _a3, _b;
      const property = kebabToCamel(attribute);
      const value = this[property] || this[attribute];
      if (value) {
        const allowedValues = (_a3 = componentSpec.allowedValues) == null ? void 0 : _a3[attribute];
        const propertyType = (_b = componentSpec.propertyTypes) == null ? void 0 : _b[attribute];
        if (propertyType == "boolean") {
          classes.push(attribute);
        } else if (value == attribute && allowedValues && inArray(value, allowedValues)) {
          classes.push(attribute);
        } else if (allowedValues && inArray(value, allowedValues)) {
          classes.push(value);
        }
        if ((componentSpec.attributeClasses || []).includes(attribute)) {
          classes.push(attribute);
        }
      }
    });
    let classString = unique(classes).join(" ");
    if (classString) {
      classString += " ";
    }
    return classString;
  }
  isDarkMode() {
    return isServer ? void 0 : $2(this).cssVar("dark-mode") == "true" || $2("html").hasClass("dark");
  }
  /*******************************
            DOM Helpers
  *******************************/
  // Rendered DOM (either shadow or regular)
  $(selector, { root = (this == null ? void 0 : this.renderRoot) || this.shadowRoot } = {}) {
    if (!root) {
      console.error("Cannot query DOM until element has rendered.");
    }
    return $2(selector, { root });
  }
  // Original DOM (used for pulling slotted text)
  $$(selector) {
    return $2(selector, { root: this.originalDOM.content });
  }
  // calls callback if defined with consistent params and this context
  call(func, { firstArg, additionalArgs, args = [this.component, this.$.bind(this)] } = {}) {
    if (firstArg) {
      args.unshift(firstArg);
    }
    if (additionalArgs) {
      args.push(...additionalArgs);
    }
    if (isFunction(func)) {
      return func.apply(this, args);
    }
  }
};
__publicField(_WebComponentBase, "shadowRootOptions", { ...r4.shadowRootOptions, delegatesFocus: false });
// for use with light dom rendering
__publicField(_WebComponentBase, "scopedStyleSheet", null);
var WebComponentBase = _WebComponentBase;

// packages/component/src/define-component.js
var defineComponent = ({
  template = "",
  ast,
  css = "",
  pageCSS = "",
  tagName,
  delegatesFocus = false,
  templateName = kebabToCamel(tagName),
  createComponent: createComponent11 = noop,
  events: events6 = {},
  // event bindings
  keys: keys3 = {},
  // key bindings
  onCreated: onCreated4 = noop,
  onRendered: onRendered3 = noop,
  onDestroyed = noop,
  onThemeChanged = noop,
  onAttributeChanged = noop,
  defaultSettings = {},
  defaultState: defaultState2 = {},
  subTemplates = {},
  renderingEngine,
  properties,
  // allow overriding web component properties
  // only used by components that provide a spec
  componentSpec = false,
  plural = false,
  singularTag
} = {}) => {
  var _a3;
  if (!ast) {
    const compiler = new TemplateCompiler(template);
    ast = compiler.compile();
  }
  each(subTemplates, (template2) => {
    if (template2.css) {
      css += template2.css;
    }
  });
  if (pageCSS) {
    adoptStylesheet(pageCSS);
  }
  let litTemplate = new Template({
    templateName,
    isPrototype: true,
    renderingEngine,
    ast,
    css,
    events: events6,
    keys: keys3,
    defaultState: defaultState2,
    subTemplates,
    onCreated: onCreated4,
    onRendered: onRendered3,
    onDestroyed,
    onThemeChanged,
    createComponent: createComponent11
  });
  let webComponent;
  if (tagName) {
    webComponent = (_a3 = class extends WebComponentBase {
      static get styles() {
        return r(css);
      }
      defaultSettings = {};
      constructor() {
        super();
        this.css = css;
        this.componentSpec = componentSpec;
        this.settings = this.createSettingsProxy({ componentSpec, properties: webComponent.properties });
        this.setDefaultSettings({ defaultSettings, componentSpec });
      }
      // callback when added to dom
      connectedCallback() {
        super.connectedCallback();
      }
      triggerAttributeChange() {
        each(webComponent.properties, (propSettings, property) => {
          const attribute = camelToKebab(property);
          let newValue = this[property];
          if (!propSettings.alias && attribute && newValue === true) {
            this.setAttribute(attribute, "");
          }
          adjustPropertyFromAttribute({
            el: this,
            attribute,
            properties: webComponent.properties,
            attributeValue: newValue,
            componentSpec
          });
        });
      }
      willUpdate() {
        if (isServer) {
          this.triggerAttributeChange();
        }
        if (!this.template) {
          this.template = litTemplate.clone({
            data: this.getData(),
            element: this,
            renderRoot: this.renderRoot
          });
          if (!this.template.initialized) {
            this.template.initialize();
          }
          this.component = this.template.instance;
          this.dataContext = this.template.data;
        }
        super.willUpdate();
      }
      firstUpdated() {
        super.firstUpdated();
      }
      updated() {
        super.updated();
      }
      // callback if removed from dom
      disconnectedCallback() {
        super.disconnectedCallback();
        if (this.template) {
          this.template.onDestroyed();
        }
        litTemplate.onDestroyed();
      }
      // callback if moves doc
      adoptedCallback() {
        super.adoptedCallback();
        this.call(onMoved);
      }
      attributeChangedCallback(attribute, oldValue, newValue) {
        super.attributeChangedCallback(attribute, oldValue, newValue);
        adjustPropertyFromAttribute({
          el: this,
          attribute,
          attributeValue: newValue,
          properties: webComponent.properties,
          oldValue,
          componentSpec
        });
        this.call(onAttributeChanged, { args: [attribute, oldValue, newValue] });
      }
      /*******************************
                  Settings
      *******************************/
      getSettings() {
        return this.getSettingsFromConfig({ componentSpec, properties: webComponent.properties });
      }
      setSetting(name, value) {
        this[name] = value;
      }
      getData() {
        let settings = this.getSettings();
        let data = {
          ...settings
        };
        if (!isServer) {
          data.darkMode = this.isDarkMode();
        }
        if (componentSpec) {
          data.ui = this.getUIClasses({ componentSpec, properties: webComponent.properties });
        }
        if (plural === true) {
          data.plural = true;
        }
        return data;
      }
      render() {
        const data = {
          ...this.getData(),
          ...this.tpl
        };
        const html = this.template.render(data);
        return html;
      }
    }, __publicField(_a3, "template", litTemplate), __publicField(_a3, "properties", WebComponentBase.getProperties({
      properties,
      componentSpec,
      defaultSettings
    })), _a3);
    if (isClient && customElements.get(tagName)) {
      return webComponent;
    }
    customElements.define(tagName, webComponent);
  }
  return tagName ? webComponent : litTemplate;
};

// src/components/container/specs/container-component.json
var container_component_default = {
  tagName: "ui-container"
};

// src/components/container/container.html?raw
var container_default = "{{>slot}}\n";

// src/components/container/container-bundle.css?raw
var container_bundle_default = "/**\n  ---DO NOT EDIT THIS FILE DIRECTLY---\n  This CSS file was concatenated from files listed in the css/ folder as part of a build process\n  This is to allow for js import with @import links which will not be followed\n**/\n\n/* src/components/container/css/definition/content/container.css */\n@layer container.definition.content.container {\n  :host {\n    display: block;\n    max-width: 100%;\n  }\n  @media only screen and (max-width: 767px) {\n    :host {\n      width: auto;\n      margin-left: 1em;\n      margin-right: 1em;\n    }\n  }\n  @media only screen and (min-width: 768px) and (max-width: 991px) {\n    :host {\n      width: 723px;\n      margin-left: auto;\n      margin-right: auto;\n    }\n  }\n  @media only screen and (min-width: 992px) and (max-width: 1199px) {\n    :host {\n      width: 933px;\n      margin-left: auto;\n      margin-right: auto;\n    }\n  }\n  @media only screen and (min-width: 1200px) {\n    :host {\n      width: 1127px;\n      margin-left: auto;\n      margin-right: auto;\n    }\n  }\n  :host.text {\n    max-width: 700px;\n    line-height: 1.5;\n  }\n  :host.fluid {\n    width: 100%;\n  }\n}\n\n/* src/components/container/css/definition/variations/aligned.css */\n@layer container.definition.variations.aligned;\n\n/* src/components/container/css/definition/container-definition.css */\n\n/* src/components/container/css/theme/content/container-variables.css */\n@layer container.theme.content.container {\n  :host {\n  }\n}\n\n/* src/components/container/css/theme/variations/aligned-variables.css */\n@layer container.theme.variations.aligned {\n  :host {\n  }\n}\n\n/* src/components/container/css/theme/container-theme.css */\n\n/* src/components/container/css/container.css */\n";

// src/components/container/container.js
var createComponent = ({ $: $4 }) => ({});
var UIContainer = defineComponent({
  tagName: "ui-container",
  componentSpec: container_component_default,
  template: container_default,
  css: container_bundle_default,
  createComponent
});

// src/components/rail/specs/rail-component.json
var rail_component_default = {
  tagName: "ui-rail"
};

// src/components/rail/rail.html?raw
var rail_default = '<div class="rail"></div>\n';

// src/components/rail/rail-bundle.css?raw
var rail_bundle_default = "/**\n  ---DO NOT EDIT THIS FILE DIRECTLY---\n  This CSS file was concatenated from files listed in the css/ folder as part of a build process\n  This is to allow for js import with @import links which will not be followed\n**/\n\n/* src/components/rail/css/definition/content/rail.css */\n@layer rail.definition.content.rail;\n\n/* src/components/rail/css/definition/variations/aligned.css */\n@layer rail.definition.variations.aligned;\n\n/* src/components/rail/css/definition/rail-definition.css */\n\n/* src/components/rail/css/theme/content/rail-variables.css */\n@layer rail.theme.content.rail {\n  :host {\n  }\n}\n\n/* src/components/rail/css/theme/variations/aligned-variables.css */\n@layer rail.theme.variations.aligned {\n  :host {\n  }\n}\n\n/* src/components/rail/css/theme/rail-theme.css */\n\n/* src/components/rail/css/rail.css */\n";

// src/components/rail/rail.js
var createComponent2 = ({ $: $4 }) => ({});
var UIRail = defineComponent({
  tagName: "ui-rail",
  componentSpec: rail_component_default,
  template: rail_default,
  css: rail_bundle_default,
  createComponent: createComponent2
});

// src/components/button/specs/button-component.json
var button_component_default = {
  tagName: "ui-button",
  content: [
    "icon"
  ],
  contentAttributes: [
    "icon"
  ],
  types: [
    "emphasis",
    "toggle",
    "animated"
  ],
  variations: [
    "attached",
    "basic",
    "type",
    "circular",
    "color",
    "compact",
    "social",
    "positive",
    "warning",
    "negative",
    "info",
    "transparent",
    "floated",
    "fluid",
    "size",
    "inverted"
  ],
  states: [
    "hover",
    "focused",
    "active",
    "disabled",
    "loading"
  ],
  settings: [
    "icon-only",
    "icon-after",
    "href"
  ],
  attributes: [
    "icon",
    "emphasis",
    "toggle",
    "animated",
    "hover",
    "focused",
    "active",
    "disabled",
    "loading",
    "attached",
    "basic",
    "type",
    "circular",
    "color",
    "compact",
    "social",
    "positive",
    "warning",
    "negative",
    "info",
    "transparent",
    "floated",
    "fluid",
    "size",
    "inverted",
    "icon-only",
    "icon-after",
    "href"
  ],
  optionAttributes: {
    primary: "emphasis",
    secondary: "emphasis",
    "horizontal-animated": "animated",
    "vertical-animated": "animated",
    "fade-animated": "animated",
    disabled: "disabled",
    "clickable-disabled": "disabled",
    "top-attached": "attached",
    attached: "attached",
    "bottom-attached": "attached",
    "left-attached": "attached",
    "right-attached": "attached",
    basic: "basic",
    "very-basic": "basic",
    submit: "type",
    reset: "type",
    red: "color",
    orange: "color",
    yellow: "color",
    olive: "color",
    green: "color",
    teal: "color",
    blue: "color",
    violet: "color",
    purple: "color",
    pink: "color",
    brown: "color",
    grey: "color",
    black: "color",
    compact: "compact",
    "very-compact": "compact",
    instagram: "social",
    facebook: "social",
    twitter: "social",
    linkedin: "social",
    youtube: "social",
    positive: "positive",
    "subtle-positive": "positive",
    warning: "warning",
    "subtle-warning": "warning",
    negative: "negative",
    "subtle-negative": "negative",
    info: "info",
    "subtle-info": "info",
    "left-floated": "floated",
    "right-floated": "floated",
    mini: "size",
    tiny: "size",
    small: "size",
    medium: "size",
    large: "size",
    big: "size",
    huge: "size",
    massive: "size"
  },
  propertyTypes: {
    icon: "string",
    emphasis: "string",
    toggle: "boolean",
    animated: "string",
    hover: "boolean",
    focused: "boolean",
    active: "boolean",
    disabled: "string",
    loading: "boolean",
    attached: "string",
    basic: "string",
    type: "string",
    circular: "boolean",
    color: "string",
    compact: "string",
    social: "string",
    positive: "string",
    warning: "string",
    negative: "string",
    info: "string",
    transparent: "boolean",
    floated: "string",
    fluid: "boolean",
    size: "string",
    inverted: "boolean",
    "icon-only": "boolean",
    "icon-after": "boolean",
    href: "string"
  },
  allowedValues: {
    emphasis: [
      "primary",
      "secondary"
    ],
    animated: [
      "horizontal-animated",
      "vertical-animated",
      "fade-animated"
    ],
    disabled: [
      "disabled",
      "clickable-disabled"
    ],
    attached: [
      "top-attached",
      "attached",
      "bottom-attached",
      "left-attached",
      "right-attached"
    ],
    basic: [
      "basic",
      "very-basic"
    ],
    type: [
      "submit",
      "reset"
    ],
    color: [
      "red",
      "orange",
      "yellow",
      "olive",
      "green",
      "teal",
      "blue",
      "violet",
      "purple",
      "pink",
      "brown",
      "grey",
      "black"
    ],
    compact: [
      "compact",
      "very-compact"
    ],
    social: [
      "instagram",
      "facebook",
      "twitter",
      "linkedin",
      "youtube"
    ],
    positive: [
      "positive",
      "subtle-positive"
    ],
    warning: [
      "warning",
      "subtle-warning"
    ],
    negative: [
      "negative",
      "subtle-negative"
    ],
    info: [
      "info",
      "subtle-info"
    ],
    floated: [
      "left-floated",
      "right-floated"
    ],
    size: [
      "mini",
      "tiny",
      "small",
      "medium",
      "large",
      "big",
      "huge",
      "massive"
    ]
  },
  attributeClasses: [
    "icon",
    "animated",
    "disabled",
    "attached",
    "social"
  ],
  inheritedPluralVariations: [
    "inverted",
    "size",
    "floated",
    "compact",
    "color",
    "attached"
  ]
};

// src/components/button/button.html?raw
var button_default = '{#if href}\n  <a class="{ui}button" href="{href}">\n    {> content}\n  </a>\n{else}\n  <div class="{ui}button" tabindex="0" part="button">\n    {> content}\n  </div>\n{/if}\n\n{#snippet content}\n  {#if animated}\n    {> animated}\n  {else}\n    {#if isIconBefore}\n      {> icon}\n    {/if}\n    {#if not iconOnly}\n      <span class="text">\n        {> slot}\n      </span>\n    {/if}\n    {#if isIconAfter}\n      {> icon}\n    {/if}\n  {/if}\n{/snippet}\n\n{#snippet icon}\n  <ui-icon icon={icon} class="icon" part="icon"></ui-icon>\n{/snippet}\n\n{#snippet animated}\n  <span class="hidden content">\n    {>slot hidden}\n  </span>\n  <span class="visible content">\n    {>slot visible}\n  </span>\n{/snippet}\n';

// src/components/button/button-bundle.css?raw
var button_bundle_default = '/**\n  ---DO NOT EDIT THIS FILE DIRECTLY---\n  This CSS file was concatenated from files listed in the css/ folder as part of a build process\n  This is to allow for js import with @import links which will not be followed\n**/\n\n/* src/components/button/css/definition/content/button.css */\n@layer button.definition.content.button {\n  :host {\n    -webkit-user-select: none;\n    user-select: none;\n    font-size: 1rem;\n  }\n  *,\n  :after,\n  :before {\n    box-sizing: border-box;\n    user-select: none;\n    -webkit-user-select: none;\n    -webkit-touch-callout: none;\n  }\n  .button {\n    cursor: pointer;\n    display: inline-block;\n    min-height: 1em;\n    border: var(--button-border);\n    margin: 0em var(--button-horizontal-margin) var(--button-vertical-margin) 0em;\n    vertical-align: var(--button-vertical-align);\n    background: var(--button-background);\n    color: var(--button-text-color);\n    font-family: var(--button-font-family);\n    padding: var(--button-padding);\n    text-transform: var(--button-text-transform);\n    text-shadow: var(--button-text-shadow);\n    font-weight: var(--button-font-weight);\n    line-height: var(--button-line-height);\n    font-style: normal;\n    text-align: center;\n    text-decoration: none;\n    border-radius: var(--button-border-radius);\n    box-shadow: var(--button-box-shadow);\n    -webkit-user-select: none;\n    user-select: none;\n    transition: var(--button-transition);\n    will-change: var(--button-will-change);\n    -webkit-tap-highlight-color: var(--button-tap-color);\n    outline: var(--button-border);\n  }\n}\n\n/* src/components/button/css/definition/content/icon.css */\n@layer button.definition.content.icon {\n  .button ui-icon {\n    vertical-align: top;\n    opacity: var(--button-icon-opacity);\n  }\n  .button ui-icon:only-child {\n    margin: 0rem;\n  }\n}\n\n/* src/components/button/css/definition/content/label.css */\n@layer button.definition.content.label {\n  .button .label {\n  }\n}\n\n/* src/components/button/css/definition/plural/buttons.css */\n@layer button.definition.plural {\n  .buttons {\n    display: inline-flex;\n    flex-direction: row;\n    vertical-align: baseline;\n    margin: var(--button-vertical-margin) var(--button-horizontal-margin) 0em 0em;\n  }\n  .buttons:not(.basic):not(.inverted) {\n    box-shadow: var(--button-group-box-shadow);\n  }\n}\n\n/* src/components/button/css/definition/states/hover.css */\n@layer button.definition.states.hover {\n  @media (pointer: fine) {\n    .button.hover,\n    .button:hover {\n      background-color: var(--button-hover-background-color);\n      background-image: var(--button-hover-background-image);\n      box-shadow: var(--button-hover-box-shadow);\n      color: var(--button-hover-color);\n    }\n    .button.hover .icon,\n    .button:hover .icon {\n      opacity: var(--button-hover-icon-opacity);\n    }\n  }\n}\n\n/* src/components/button/css/definition/states/focus.css */\n@layer button.definition.states.focus {\n  .button.focused,\n  .button:focus {\n    background-color: var(--button-focus-background-color);\n    background-image: var(--button-focus-background-image);\n    color: var(--button-focus-color);\n    box-shadow: var(--button-focus-box-shadow);\n  }\n  .button.focused .icon,\n  .button:focus .icon {\n    opacity: var(--button-focus-icon-opacity);\n  }\n  .button:focus-visible {\n    box-shadow: var(--button-focus-box-shadow), var(--focused-ring-shadow) !important;\n  }\n}\n\n/* src/components/button/css/definition/states/pressed.css */\n@layer button.definition.states.pressed {\n  @media (pointer: fine) {\n    .button:active,\n    .active.button:active {\n      background-color: var(--button-pressed-background-color);\n      background-image: var(--button-pressed-background-image);\n      color: var(--button-pressed-color);\n      box-shadow: var(--button-pressed-box-shadow);\n    }\n  }\n  .pressed.button,\n  .active.pressed.button {\n    background-color: var(--button-pressed-background-color);\n    background-image: var(--button-pressed-background-image);\n    color: var(--button-pressed-color);\n    box-shadow: var(--button-pressed-box-shadow);\n  }\n}\n\n/* src/components/button/css/definition/states/active.css */\n@layer button.definition.states.active {\n  .active.button {\n    background-color: var(--button-active-background-color);\n    background-image: var(--button-active-background-image);\n    box-shadow: var(--button-active-box-shadow);\n    color: var(--button-active-color);\n  }\n  .active.button:hover {\n    background-color: var(--button-active-hover-background-color);\n    background-image: var(--button-active-hover-background-image);\n    color: var(--button-active-hover-color);\n    box-shadow: var(--button-active-hover-box-shadow);\n  }\n  .active.button:active {\n    background-color: var(--button-active-down-background-color);\n    background-image: var(--button-active-down-background-image);\n    color: var(--button-active-down-color);\n    box-shadow: var(--button-active-down-box-shadow);\n  }\n}\n\n/* src/components/button/css/definition/states/disabled.css */\n@layer button.definition.states.disabled {\n  .disabled.button,\n  .disabled.button:hover,\n  .disabled.active.button {\n    pointer-events: none;\n    cursor: var(--button-disabled-cursor);\n    opacity: var(--button-disabled-opacity) !important;\n    color: var(--button-disabled-color);\n    box-shadow: var(--button-disabled-box-shadow) !important;\n  }\n  .disabled.button.standard {\n    background-color: var(--button-disabled-background-color) !important;\n    background-image: var(--button-disabled-background-image) !important;\n  }\n  ui-button[disabled] {\n    cursor: var(--button-disabled-cursor);\n    pointer-events: none !important;\n  }\n  .clickable-disabled.button {\n    pointer-events: auto !important;\n    cursor: var(--button-clickable-disabled-cursor) !important;\n  }\n  .clickable-disabled.button:active {\n    box-shadow: var(--button-pressed-box-shadow) !important;\n  }\n  ui-button[clickable-disabled] {\n    pointer-events: auto !important;\n    cursor: var(--button-clickable-disabled-cursor) !important;\n  }\n}\n\n/* src/components/button/css/definition/states/loading.css */\n@layer button.definition.states.loading {\n  .loading.button:not(.icon) {\n    position: relative;\n    cursor: default;\n    text-shadow: none !important;\n    color: transparent !important;\n    opacity: var(--button-loading-opacity);\n    pointer-events: auto;\n    transition: var(--button-loading-transition);\n  }\n  .loading.icon.button .icon {\n    position: relative;\n    color: transparent !important;\n  }\n  .loading.icon.button > .icon:before,\n  .loading.button:not(.icon)::before {\n    position: absolute;\n    content: "";\n    top: 50%;\n    left: 50%;\n    margin: var(--loader-margin);\n    width: var(--loader-size);\n    height: var(--loader-size);\n    border-radius: var(--circular-radius);\n    border: var(--loader-line-width) solid var(--loader-fill-color);\n  }\n  .loading.icon.button > .icon:after,\n  .loading.button:not(.icon)::after {\n    position: absolute;\n    content: "";\n    top: 50%;\n    left: 50%;\n    margin: var(--loader-margin);\n    width: var(--loader-size);\n    height: var(--loader-size);\n    animation: button-spin var(--loader-speed) linear;\n    animation-iteration-count: infinite;\n    border-radius: var(--circular-radius);\n    border-color: var(--loader-line-color) transparent transparent;\n    border-style: solid;\n    border-width: var(--loader-line-width);\n    box-shadow: 0px 0px 0px 1px transparent;\n  }\n  @keyframes button-spin {\n    from {\n      transform: rotate(0deg);\n    }\n    to {\n      transform: rotate(360deg);\n    }\n  }\n  .loading.button.inverted .icon:before,\n  .loading.button.inverted:before {\n    border-color: var(--inverted-loader-fill-color);\n  }\n  .loading.button.inverted .icon:after,\n  .loading.button.inverted:after {\n    border-top-color: var(--inverted-loader-line-color);\n  }\n}\n\n/* src/components/button/css/definition/types/animated.css */\n@layer button.definition.types.animated {\n  .animated.button {\n    position: relative;\n    overflow: hidden;\n    padding-right: 0em !important;\n    vertical-align: var(--button-animated-vertical-align);\n    z-index: var(--button-animated-z-index);\n  }\n  .animated.button > .content {\n    display: inline-block;\n    box-sizing: border-box;\n    will-change: transform, opacity;\n  }\n  .animated.button > .visible.content {\n    position: relative;\n    margin-right: var(--button-horizontal-padding);\n  }\n  .animated.button > .hidden.content {\n    position: absolute;\n    width: 100%;\n  }\n  .animated.animated.button > .visible.content,\n  .animated.button > .hidden.content {\n    transition: right var(--button-animation-duration) var(--button-animation-easing) 0s;\n  }\n  .animated.button > .visible.content {\n    left: auto;\n    right: 0%;\n  }\n  .animated.button > .hidden.content {\n    top: 50%;\n    left: auto;\n    right: -100%;\n    margin-top: calc(var(--button-line-height) / 2 * -1);\n  }\n  .animated.button:focus > .visible.content,\n  .animated.button:hover > .visible.content {\n    left: auto;\n    right: 200%;\n  }\n  .animated.button:focus > .hidden.content,\n  .animated.button:hover > .hidden.content {\n    left: auto;\n    right: 0%;\n  }\n  .vertical-animated.button > .visible.content,\n  .vertical-animated.button > .hidden.content {\n    transition: top var(--button-animation-duration) var(--button-animation-easing), transform var(--button-animation-duration) var(--button-animation-easing);\n  }\n  .vertical-animated.button > .visible.content {\n    transform: translateY(0%);\n    right: auto;\n  }\n  .vertical-animated.button > .hidden.content {\n    top: -50%;\n    left: 0%;\n  }\n  .vertical-animated.button:focus > .visible.content,\n  .vertical-animated.button:hover > .visible.content {\n    transform: translateY(200%);\n    right: auto;\n  }\n  .vertical-animated.button:focus > .hidden.content,\n  .vertical-animated.button:hover > .hidden.content {\n    top: 50%;\n  }\n  .fade-animated.button > .visible.content,\n  .fade-animated.button > .hidden.content {\n    transition: opacity var(--button-animation-duration) var(--button-animation-easing), transform var(--button-animation-duration) var(--button-animation-easing);\n  }\n  .fade-animated.button > .visible.content {\n    left: auto;\n    right: auto;\n    opacity: 1;\n    transform: scale(1);\n  }\n  .fade-animated.button > .hidden.content {\n    opacity: 0;\n    left: 0%;\n    right: auto;\n    transform: scale(var(--button-fade-scale-high));\n  }\n  .fade-animated.button:focus > .visible.content,\n  .fade-animated.button:hover > .visible.content {\n    left: auto;\n    right: auto;\n    opacity: 0;\n    transform: scale(var(--button-fade-scale-low));\n  }\n  .fade-animated.button:focus > .hidden.content,\n  .fade-animated.button:hover > .hidden.content {\n    left: 0%;\n    right: auto;\n    opacity: 1;\n    transform: scale(1);\n  }\n}\n\n/* src/components/button/css/definition/types/emphasis.css */\n@layer button.definition.types.emphasis {\n  .primary.buttons .button,\n  .primary.button {\n    background-color: var(--button-primary-color);\n    color: var(--button-primary-text-color);\n    text-shadow: var(--button-primary-text-shadow);\n    background-image: var(--button-primary-background-image);\n  }\n  .primary.button {\n    box-shadow: var(--button-primary-box-shadow);\n  }\n  .primary.buttons .button:hover,\n  .primary.button:hover {\n    background-color: var(--button-primary-color-hover);\n    color: var(--button-primary-text-color);\n    text-shadow: var(--button-primary-text-shadow);\n    box-shadow: var(--button-hover-box-shadow);\n  }\n  .primary.buttons .button:focus,\n  .primary.button:focus {\n    background-color: var(--button-primary-color-focus);\n    color: var(--button-primary-text-color);\n    text-shadow: var(--button-primary-text-shadow);\n    box-shadow: var(--button-focus-box-shadow);\n  }\n  .primary.buttons .button.pressed,\n  .primary.buttons .button:active,\n  .primary.button.pressed,\n  .primary.button:active {\n    background-color: var(--button-primary-color-down);\n    color: var(--button-primary-text-color);\n    text-shadow: var(--button-primary-text-shadow);\n    box-shadow: var(--button-pressed-box-shadow);\n  }\n  .primary.buttons .active.button,\n  .primary.buttons .active.button:active,\n  .primary.active.button,\n  .primary.button .active.button:active {\n    background-color: var(--button-primary-color-active);\n    color: var(--button-primary-text-color);\n    text-shadow: var(--button-primary-text-shadow);\n    box-shadow: var(--button-active-box-shadow);\n  }\n  .secondary.buttons .button,\n  .secondary.button {\n    background-color: var(--button-secondary-color);\n    color: var(--button-secondary-text-color);\n    text-shadow: var(--button-secondary-text-shadow);\n    background-image: var(--button-colored-background-image);\n  }\n  .secondary.button {\n    box-shadow: var(--button-colored-box-shadow);\n  }\n  .secondary.buttons .button:hover,\n  .secondary.button:hover {\n    background-color: var(--button-secondary-color-hover);\n    color: var(--button-secondary-text-color);\n    text-shadow: var(--button-secondary-text-shadow);\n    box-shadow: var(--button-hover-box-shadow);\n  }\n  .secondary.buttons .button:focus,\n  .secondary.button:focus {\n    background-color: var(--button-secondary-color-focus);\n    color: var(--button-secondary-text-color);\n    text-shadow: var(--button-secondary-text-shadow);\n    box-shadow: var(--button-focus-box-shadow);\n  }\n  .secondary.buttons .button:active,\n  .secondary.buttons .button.pressed,\n  .secondary.button.pressed,\n  .secondary.button:active {\n    background-color: var(--button-secondary-color-down);\n    color: var(--button-secondary-text-color);\n    text-shadow: var(--button-secondary-text-shadow);\n    box-shadow: var(--button-pressed-box-shadow);\n  }\n  .secondary.buttons .active.button,\n  .secondary.buttons .active.button:active,\n  .secondary.active.button,\n  .secondary.button .active.button:active {\n    background-color: var(--button-secondary-color-active);\n    color: var(--button-secondary-text-color);\n    text-shadow: var(--button-secondary-text-shadow);\n    box-shadow: var(--button-active-box-shadow);\n  }\n}\n\n/* src/components/button/css/definition/types/icon.css */\n@layer button.definition.types.icon {\n  .icon-only.buttons .button,\n  .icon-only.button {\n    padding: var(--button-vertical-padding);\n  }\n  .icon-only.buttons .button > ui-icon,\n  .icon-only.button > ui-icon {\n    opacity: 1;\n    margin: 0em;\n    vertical-align: top;\n  }\n  .icon-after.buttons .button > ui-icon,\n  .icon-after.button > ui-icon {\n    margin-right: 0rem;\n    margin-left: var(--icon-distance-from-text);\n  }\n}\n\n/* src/components/button/css/definition/types/labeled.css */\n@layer button.definition.types.labeled {\n  .labeled.button:not(.icon) {\n    display: inline-flex;\n    flex-direction: row;\n    background: none !important;\n    padding: 0px !important;\n    border: none !important;\n    box-shadow: none !important;\n  }\n  .labeled.button > .button {\n    margin: 0px;\n  }\n  .labeled.button > .label {\n    display: flex;\n    align-items: var(--labeled-label-align);\n    margin: 0px 0px 0px var(--labeled-label-border-offset) !important;\n    padding: var(--labeled-label-padding);\n    font-size: var(--labeled-label-font-size);\n    border-color: var(--labeled-label-border-color);\n  }\n  .labeled.button > .tag.label::before {\n    width: var(--labeled-tag-label-size);\n    height: var(--labeled-tag-label-size);\n  }\n  .labeled.button:not([class*="left labeled"]) > .button {\n    border-top-right-radius: 0px;\n    border-bottom-right-radius: 0px;\n  }\n  .labeled.button:not([class*="left labeled"]) > .label {\n    border-top-left-radius: 0px;\n    border-bottom-left-radius: 0px;\n  }\n  [class*="left labeled"].button > .button {\n    border-top-left-radius: 0px;\n    border-bottom-left-radius: 0px;\n  }\n  [class*="left labeled"].button > .label {\n    border-top-right-radius: 0px;\n    border-bottom-right-radius: 0px;\n  }\n}\n\n/* src/components/button/css/definition/types/labeled-icon.css */\n@layer button.definition.types.labeled-icon {\n  .labeled.icon.buttons .button,\n  .labeled.icon.button {\n    position: relative;\n    padding-left: var(--labeled-icon-padding) !important;\n    padding-right: var(--horizontal-padding) !important;\n  }\n  .labeled.icon.buttons > .button > .icon,\n  .labeled.icon.button > .icon {\n    position: absolute;\n    height: 100%;\n    line-height: 1;\n    border-radius: 0px;\n    border-top-left-radius: inherit;\n    border-bottom-left-radius: inherit;\n    text-align: center;\n    margin: var(--labeled-icon-margin);\n    width: var(--labeled-icon-width);\n    background-color: var(--labeled-icon-background-color);\n    color: var(--labeled-icon-color);\n    box-shadow: var(--labeled-icon-left-shadow);\n  }\n  .labeled.icon.buttons > .button > .icon,\n  .labeled.icon.button > .icon {\n    top: 0em;\n    left: 0em;\n  }\n  [class*="right labeled"].icon.button {\n    padding-right: var(--labeled-icon-padding) !important;\n    padding-left: var(--horizontal-padding) !important;\n  }\n  [class*="right labeled"].icon.button > .icon {\n    left: auto;\n    right: 0em;\n    border-radius: 0px;\n    border-top-right-radius: inherit;\n    border-bottom-right-radius: inherit;\n    box-shadow: var(--labeled-icon-right-shadow);\n  }\n  .labeled.icon.buttons > .button > .icon::before,\n  .labeled.icon.button > .icon::before,\n  .labeled.icon.buttons > .button > .icon::after,\n  .labeled.icon.button > .icon::after {\n    display: block;\n    position: absolute;\n    width: 100%;\n    top: 50%;\n    text-align: center;\n    transform: translateY(-50%);\n  }\n  .labeled.icon.button > .icon.loading {\n    animation: none;\n  }\n  .labeled.icon.button > .icon.loading::before {\n    animation: labeled-button-icon-loading var(--loading-icon-duration) linear infinite;\n  }\n  @keyframes labeled-button-icon-loading {\n    from {\n      transform: translateY(-50%) rotate(0deg);\n    }\n    to {\n      transform: translateY(-50%) rotate(360deg);\n    }\n  }\n  .labeled.icon.buttons .button > .icon {\n    border-radius: 0em;\n  }\n  .labeled.icon.buttons .button:first-child > .icon {\n    border-top-left-radius: var(--border-radius);\n    border-bottom-left-radius: var(--border-radius);\n  }\n  .labeled.icon.buttons .button:last-child > .icon {\n    border-top-right-radius: var(--border-radius);\n    border-bottom-right-radius: var(--border-radius);\n  }\n  .vertical.labeled.icon.buttons .button:first-child > .icon {\n    border-radius: 0em;\n    border-top-left-radius: var(--border-radius);\n  }\n  .vertical.labeled.icon.buttons .button:last-child > .icon {\n    border-radius: 0em;\n    border-bottom-left-radius: var(--border-radius);\n  }\n  .fluid[class*="left labeled"].icon.button,\n  .fluid[class*="right labeled"].icon.button {\n    padding-left: var(--horizontal-padding) !important;\n    padding-right: var(--horizontal-padding) !important;\n  }\n}\n\n/* src/components/button/css/definition/types/transparent.css */\n@layer button.definition.types.transparent {\n  .transparent.button {\n    background-image: var(--button-transparent-background-image);\n    background-color: var(--button-transparent-background-color);\n    color: var(--button-transparent-text-color);\n    box-shadow: var(--button-transparent-box-shadow) !important;\n  }\n  .transparent.button:hover {\n    background-image: var(--button-transparent-hover-background-image);\n    background-color: var(--button-transparent-hover-background-color);\n    color: var(--button-transparent-hover-text-color);\n    box-shadow: var(--button-transparent-hover-box-shadow) !important;\n  }\n  .transparent.button:active {\n    background-image: var(--button-transparent-pressed-background-image);\n    background-color: var(--button-transparent-pressed-background-color);\n    color: var(--button-transparent-pressed-text-color);\n    box-shadow: var(--button-transparent-pressed-box-shadow) !important;\n  }\n  .transparent.button.active {\n    background-image: var(--button-transparent-active-background-image);\n    background-color: var(--button-transparent-active-background-color);\n    color: var(--button-transparent-active-text-color) !important;\n    box-shadow: var(--button-transparent-active-box-shadow) !important;\n  }\n  .transparent.inverted.button {\n    background-image: var(--button-transparent-inverted-background-image);\n    background-color: var(--button-transparent-inverted-background-color);\n    color: var(--button-transparent-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n    box-shadow: var(--button-transparent-inverted-box-shadow) !important;\n  }\n  .transparent.inverted.button:hover {\n    background-image: var(--button-transparent-inverted-hover-background-image);\n    background-color: var(--button-transparent-inverted-hover-background-color);\n    color: var(--button-transparent-inverted-hover-text-color);\n    box-shadow: var(--button-transparent-inverted-hover-box-shadow) !important;\n  }\n  .transparent.inverted.button:active {\n    background-image: var(--button-transparent-inverted-pressed-background-image);\n    background-color: var(--button-transparent-inverted-pressed-background-color);\n    color: var(--button-transparent-inverted-pressed-text-color);\n    box-shadow: var(--button-transparent-inverted-pressed-box-shadow) !important;\n  }\n  .transparent.inverted.button.active {\n    background-image: var(--button-transparent-inverted-active-background-image);\n    background-color: var(--button-transparent-inverted-active-background-color);\n    color: var(--button-transparent-inverted-active-text-color) !important;\n    box-shadow: var(--button-transparent-inverted-active-box-shadow) !important;\n  }\n}\n\n/* src/components/button/css/definition/types/toggle.css */\n@layer button.definition.types.toggle {\n  .toggle.buttons .active.button,\n  .buttons .button.toggle.active,\n  .button.toggle.active {\n    background-color: var(--button-toggle-active-background) !important;\n    color: var(--button-toggle-active-color) !important;\n    text-shadow: var(--button-toggle-active-text-shadow);\n  }\n  .button.toggle.active:hover {\n    background-color: var(--button-toggle-active-hover-background) !important;\n    color: var(--button-toggle-active-hover-color) !important;\n  }\n}\n\n/* src/components/button/css/definition/variations/basic.css */\n@layer button.definition.variations.basic {\n  .basic.buttons .button,\n  .basic.button {\n    background: var(--button-basic-background) !important;\n    color: var(--button-basic-text-color) !important;\n    font-weight: var(--button-basic-font-weight);\n    border-radius: var(--button-basic-border-radius);\n    text-transform: var(--button-basic-text-transform);\n    text-shadow: none !important;\n    box-shadow: var(--button-basic-box-shadow);\n  }\n  .basic.buttons {\n    box-shadow: var(--button-basic-group-box-shadow);\n    border: var(--button-basic-group-border);\n    border-radius: var(--button-border-radius);\n  }\n  .basic.buttons .button {\n    border-radius: 0em;\n  }\n  .basic.buttons .button:hover,\n  .basic.button:hover {\n    background: var(--button-basic-hover-background) !important;\n    color: var(--button-basic-hover-text-color) !important;\n    box-shadow: var(--button-basic-hover-box-shadow);\n  }\n  .basic.buttons .button:focus,\n  .basic.button:focus {\n    background: var(--button-basic-focus-background) !important;\n    color: var(--button-basic-focus-text-color) !important;\n    box-shadow: var(--button-basic-focus-box-shadow);\n  }\n  .basic.buttons .button:active,\n  .basic.button:active {\n    background: var(--button-basic-down-background) !important;\n    color: var(--button-basic-down-text-color) !important;\n    box-shadow: var(--button-basic-down-box-shadow);\n  }\n  .basic.buttons .active.button,\n  .basic.active.button {\n    background: var(--button-basic-active-background) !important;\n    box-shadow: var(--button-basic-active-box-shadow) !important;\n    color: var(--button-basic-active-text-color) !important;\n  }\n  .basic.buttons .active.button:hover,\n  .basic.active.button:hover {\n    background-color: var(--button-transparent-black);\n  }\n  .basic.buttons .button:hover {\n    box-shadow: var(--button-basic-hover-box-shadow) inset;\n  }\n  .basic.buttons .button:active {\n    box-shadow: var(--button-basic-down-box-shadow) inset;\n  }\n  .basic.buttons .active.button {\n    box-shadow: var(--button-basic-active-box-shadow) !important;\n  }\n  .basic.inverted.buttons .button,\n  .basic.inverted.button {\n    background-color: transparent !important;\n    color: var(--button-off-white) !important;\n    box-shadow: var(--button-basic-inverted-box-shadow) !important;\n  }\n  .basic.inverted.buttons .button:hover,\n  .basic.inverted.button:hover {\n    color: var(--button-white) !important;\n    box-shadow: var(--button-basic-inverted-hover-box-shadow) !important;\n  }\n  .basic.inverted.buttons .button:focus,\n  .basic.inverted.button:focus {\n    color: var(--button-white) !important;\n    box-shadow: var(--button-basic-inverted-focus-box-shadow) !important;\n  }\n  .basic.inverted.buttons .button:active,\n  .basic.inverted.button:active {\n    background-color: var(--button-transparent-white) !important;\n    color: var(--button-white) !important;\n    box-shadow: var(--button-basic-inverted-down-box-shadow) !important;\n  }\n  .basic.inverted.buttons .active.button,\n  .basic.inverted.active.button {\n    background-color: var(--button-transparent-white);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n    box-shadow: var(--button-basic-inverted-active-box-shadow);\n  }\n  .basic.inverted.buttons .active.button:hover,\n  .basic.inverted.active.button:hover {\n    background-color: var(--button-strong-transparent-white);\n    box-shadow: var(--button-basic-inverted-hover-box-shadow) !important;\n  }\n  .basic.buttons .button {\n    border-left: var(--button-basic-group-border);\n    box-shadow: none;\n  }\n  .basic.vertical.buttons .button {\n    border-left: none;\n  }\n  .basic.vertical.buttons .button {\n    border-left-width: 0px;\n    border-top: var(--button-basic-group-border);\n  }\n  .basic.vertical.buttons .button:first-child {\n    border-top-width: 0px;\n  }\n}\n\n/* src/components/button/css/definition/variations/attached.css */\n@layer button.definition.variations.attached {\n  .attached.button {\n    position: relative;\n    display: block;\n    margin: 0em;\n    border-radius: 0em;\n    box-shadow: var(--button-attached-box-shadow);\n  }\n  .attached.button:active {\n    box-shadow: var(--button-attached-pressed-box-shadow);\n  }\n  .top-attached.button {\n    border-radius: var(--button-border-radius) var(--button-border-radius) 0em 0em;\n  }\n  .bottom-attached.button {\n    border-radius: 0em 0em var(--button-border-radius) var(--button-border-radius);\n  }\n  .left-attached.button {\n    display: inline-block;\n    border-left: none;\n    text-align: right;\n    padding-right: var(--button-attached-horizontal-padding);\n    border-radius: var(--button-border-radius) 0em 0em var(--button-border-radius);\n  }\n  .right-attached.button {\n    display: inline-block;\n    text-align: left;\n    padding-left: var(--button-attached-horizontal-padding);\n    border-radius: 0em var(--button-border-radius) var(--button-border-radius) 0em;\n  }\n  .attached.buttons {\n    position: relative;\n    display: flex;\n    border-radius: 0em;\n    width: auto;\n    z-index: var(--button-attached-z-index);\n    margin-left: var(--button-attached-offset);\n    margin-right: var(--button-attached-offset);\n  }\n  .attached.buttons .button {\n    margin: 0em;\n  }\n  .attached.buttons .button:first-child {\n    border-radius: 0em;\n  }\n  .attached.buttons .button:last-child {\n    border-radius: 0em;\n  }\n  .top-attached.buttons {\n    margin-bottom: var(--button-attached-offset);\n    border-radius: var(--button-border-radius) var(--button-border-radius) 0em 0em;\n  }\n  .top-attached.buttons .button:first-child {\n    border-radius: var(--button-border-radius) 0em 0em 0em;\n  }\n  .top-attached.buttons .button:last-child {\n    border-radius: 0em var(--button-border-radius) 0em 0em;\n  }\n  .top-attached.buttons {\n    margin-top: var(--button-attached-offset);\n    border-radius: 0em 0em var(--button-border-radius) var(--button-border-radius);\n  }\n  .top-attached.buttons .button:first-child {\n    border-radius: 0em 0em 0em var(--button-border-radius);\n  }\n  .top-attached.buttons .button:last-child {\n    border-radius: 0em 0em var(--button-border-radius) 0em;\n  }\n  .left-attached.buttons {\n    display: inline-flex;\n    margin-right: 0em;\n    margin-left: var(--button-attached-offset);\n    border-radius: 0em var(--button-border-radius) var(--button-border-radius) 0em;\n  }\n  .left-attached.buttons .button:first-child {\n    margin-left: var(--button-attached-offset);\n    border-radius: 0em var(--button-border-radius) 0em 0em;\n  }\n  .left-attached.buttons .button:last-child {\n    margin-left: var(--button-attached-offset);\n    border-radius: 0em 0em var(--button-border-radius) 0em;\n  }\n  .right-attached.buttons {\n    display: inline-flex;\n    margin-left: 0em;\n    margin-right: var(--button-attached-offset);\n    border-radius: var(--button-border-radius) 0em 0em var(--button-border-radius);\n  }\n  .right-attached.buttons .button:first-child {\n    margin-left: var(--button-attached-offset);\n    border-radius: var(--button-border-radius) 0em 0em 0em;\n  }\n  .right-attached.buttons .button:last-child {\n    margin-left: var(--button-attached-offset);\n    border-radius: 0em 0em 0em var(--button-border-radius);\n  }\n}\n\n/* src/components/button/css/definition/variations/circular.css */\n@layer button.definition.variations.circular {\n  .circular.button {\n    border-radius: var(--circular-radius);\n  }\n  .circular.button > .icon {\n    width: 1em;\n    vertical-align: baseline;\n  }\n}\n\n/* src/components/button/css/definition/variations/colored.css */\n@layer button.definition.variations.colored {\n  .red.buttons,\n  .red.button {\n    --button-text-color: var(--button-red-text-color);\n    --button-text-shadow: var(--button-red-text-shadow);\n    --button-background: var(--button-red) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .red.buttons,\n  .red.button:hover {\n    --button-hover-color: var(--button-red-text-color);\n    --button-hover-text-shadow: var(--button-red-text-shadow);\n    --button-hover-background-color: var(--button-red-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .red.buttons,\n  .red.button:focus {\n    --button-focus-background-color: var(--button-red-focus);\n    --button-focus-color: var(--button-red-text-color);\n    --button-focus-text-shadow: var(--button-red-text-shadow);\n  }\n  .red.buttons,\n  .red.button.pressed,\n  .red.button:active {\n    --button-pressed-background-color: var(--button-red-pressed);\n    --button-pressed-color: var(--button-red-text-color);\n    --button-pressed-text-shadow: var(--button-red-text-shadow);\n  }\n  .red.buttons .active.button,\n  .red.buttons .active.button.pressed,\n  .red.buttons .active.button:active,\n  .red.active.button,\n  .red.button .active.button.pressed,\n  .red.button .active.button:active {\n    background-color: var(--button-red-active);\n    color: var(--button-red-text-color);\n    text-shadow: var(--button-red-text-shadow);\n  }\n  .orange.buttons,\n  .orange.button {\n    --button-text-color: var(--button-orange-text-color);\n    --button-text-shadow: var(--button-orange-text-shadow);\n    --button-background: var(--button-orange) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .orange.buttons,\n  .orange.button:hover {\n    --button-hover-color: var(--button-orange-text-color);\n    --button-hover-text-shadow: var(--button-orange-text-shadow);\n    --button-hover-background-color: var(--button-orange-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .orange.buttons,\n  .orange.button:focus {\n    --button-focus-background-color: var(--button-orange-focus);\n    --button-focus-color: var(--button-orange-text-color);\n    --button-focus-text-shadow: var(--button-orange-text-shadow);\n  }\n  .orange.buttons,\n  .orange.button.pressed,\n  .orange.button:active {\n    --button-pressed-background-color: var(--button-orange-pressed);\n    --button-pressed-color: var(--button-orange-text-color);\n    --button-pressed-text-shadow: var(--button-orange-text-shadow);\n  }\n  .orange.buttons .active.button,\n  .orange.buttons .active.button.pressed,\n  .orange.buttons .active.button:active,\n  .orange.active.button,\n  .orange.button .active.button.pressed,\n  .orange.button .active.button:active {\n    background-color: var(--button-orange-active);\n    color: var(--button-orange-text-color);\n    text-shadow: var(--button-orange-text-shadow);\n  }\n  .yellow.buttons,\n  .yellow.button {\n    --button-text-color: var(--button-yellow-text-color);\n    --button-text-shadow: var(--button-yellow-text-shadow);\n    --button-background: var(--button-yellow) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .yellow.buttons,\n  .yellow.button:hover {\n    --button-hover-color: var(--button-yellow-text-color);\n    --button-hover-text-shadow: var(--button-yellow-text-shadow);\n    --button-hover-background-color: var(--button-yellow-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .yellow.buttons,\n  .yellow.button:focus {\n    --button-focus-background-color: var(--button-yellow-focus);\n    --button-focus-color: var(--button-yellow-text-color);\n    --button-focus-text-shadow: var(--button-yellow-text-shadow);\n  }\n  .yellow.buttons,\n  .yellow.button.pressed,\n  .yellow.button:active {\n    --button-pressed-background-color: var(--button-yellow-pressed);\n    --button-pressed-color: var(--button-yellow-text-color);\n    --button-pressed-text-shadow: var(--button-yellow-text-shadow);\n  }\n  .yellow.buttons .active.button,\n  .yellow.buttons .active.button.pressed,\n  .yellow.buttons .active.button:active,\n  .yellow.active.button,\n  .yellow.button .active.button.pressed,\n  .yellow.button .active.button:active {\n    background-color: var(--button-yellow-active);\n    color: var(--button-yellow-text-color);\n    text-shadow: var(--button-yellow-text-shadow);\n  }\n  .olive.buttons,\n  .olive.button {\n    --button-text-color: var(--button-olive-text-color);\n    --button-text-shadow: var(--button-olive-text-shadow);\n    --button-background: var(--button-olive) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .olive.buttons,\n  .olive.button:hover {\n    --button-hover-color: var(--button-olive-text-color);\n    --button-hover-text-shadow: var(--button-olive-text-shadow);\n    --button-hover-background-color: var(--button-olive-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .olive.buttons,\n  .olive.button:focus {\n    --button-focus-background-color: var(--button-olive-focus);\n    --button-focus-color: var(--button-olive-text-color);\n    --button-focus-text-shadow: var(--button-olive-text-shadow);\n  }\n  .olive.buttons,\n  .olive.button.pressed,\n  .olive.button:active {\n    --button-pressed-background-color: var(--button-olive-pressed);\n    --button-pressed-color: var(--button-olive-text-color);\n    --button-pressed-text-shadow: var(--button-olive-text-shadow);\n  }\n  .olive.buttons .active.button,\n  .olive.buttons .active.button.pressed,\n  .olive.buttons .active.button:active,\n  .olive.active.button,\n  .olive.button .active.button.pressed,\n  .olive.button .active.button:active {\n    background-color: var(--button-olive-active);\n    color: var(--button-olive-text-color);\n    text-shadow: var(--button-olive-text-shadow);\n  }\n  .green.buttons,\n  .green.button {\n    --button-text-color: var(--button-green-text-color);\n    --button-text-shadow: var(--button-green-text-shadow);\n    --button-background: var(--button-green) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .green.buttons,\n  .green.button:hover {\n    --button-hover-color: var(--button-green-text-color);\n    --button-hover-text-shadow: var(--button-green-text-shadow);\n    --button-hover-background-color: var(--button-green-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .green.buttons,\n  .green.button:focus {\n    --button-focus-background-color: var(--button-green-focus);\n    --button-focus-color: var(--button-green-text-color);\n    --button-focus-text-shadow: var(--button-green-text-shadow);\n  }\n  .green.buttons,\n  .green.button.pressed,\n  .green.button:active {\n    --button-pressed-background-color: var(--button-green-pressed);\n    --button-pressed-color: var(--button-green-text-color);\n    --button-pressed-text-shadow: var(--button-green-text-shadow);\n  }\n  .green.buttons .active.button,\n  .green.buttons .active.button.pressed,\n  .green.buttons .active.button:active,\n  .green.active.button,\n  .green.button .active.button.pressed,\n  .green.button .active.button:active {\n    background-color: var(--button-green-active);\n    color: var(--button-green-text-color);\n    text-shadow: var(--button-green-text-shadow);\n  }\n  .teal.buttons,\n  .teal.button {\n    --button-text-color: var(--button-teal-text-color);\n    --button-text-shadow: var(--button-teal-text-shadow);\n    --button-background: var(--button-teal) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .teal.buttons,\n  .teal.button:hover {\n    --button-hover-color: var(--button-teal-text-color);\n    --button-hover-text-shadow: var(--button-teal-text-shadow);\n    --button-hover-background-color: var(--button-teal-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .teal.buttons,\n  .teal.button:focus {\n    --button-focus-background-color: var(--button-teal-focus);\n    --button-focus-color: var(--button-teal-text-color);\n    --button-focus-text-shadow: var(--button-teal-text-shadow);\n  }\n  .teal.buttons,\n  .teal.button.pressed,\n  .teal.button:active {\n    --button-pressed-background-color: var(--button-teal-pressed);\n    --button-pressed-color: var(--button-teal-text-color);\n    --button-pressed-text-shadow: var(--button-teal-text-shadow);\n  }\n  .teal.buttons .active.button,\n  .teal.buttons .active.button.pressed,\n  .teal.buttons .active.button:active,\n  .teal.active.button,\n  .teal.button .active.button.pressed,\n  .teal.button .active.button:active {\n    background-color: var(--button-teal-active);\n    color: var(--button-teal-text-color);\n    text-shadow: var(--button-teal-text-shadow);\n  }\n  .blue.buttons,\n  .blue.button {\n    --button-text-color: var(--button-blue-text-color);\n    --button-text-shadow: var(--button-blue-text-shadow);\n    --button-background: var(--button-blue) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .blue.buttons,\n  .blue.button:hover {\n    --button-hover-color: var(--button-blue-text-color);\n    --button-hover-text-shadow: var(--button-blue-text-shadow);\n    --button-hover-background-color: var(--button-blue-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .blue.buttons,\n  .blue.button:focus {\n    --button-focus-background-color: var(--button-blue-focus);\n    --button-focus-color: var(--button-blue-text-color);\n    --button-focus-text-shadow: var(--button-blue-text-shadow);\n  }\n  .blue.buttons,\n  .blue.button.pressed,\n  .blue.button:active {\n    --button-pressed-background-color: var(--button-blue-pressed);\n    --button-pressed-color: var(--button-blue-text-color);\n    --button-pressed-text-shadow: var(--button-blue-text-shadow);\n  }\n  .blue.buttons .active.button,\n  .blue.buttons .active.button.pressed,\n  .blue.buttons .active.button:active,\n  .blue.active.button,\n  .blue.button .active.button.pressed,\n  .blue.button .active.button:active {\n    background-color: var(--button-blue-active);\n    color: var(--button-blue-text-color);\n    text-shadow: var(--button-blue-text-shadow);\n  }\n  .violet.buttons,\n  .violet.button {\n    --button-text-color: var(--button-violet-text-color);\n    --button-text-shadow: var(--button-violet-text-shadow);\n    --button-background: var(--button-violet) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .violet.buttons,\n  .violet.button:hover {\n    --button-hover-color: var(--button-violet-text-color);\n    --button-hover-text-shadow: var(--button-violet-text-shadow);\n    --button-hover-background-color: var(--button-violet-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .violet.buttons,\n  .violet.button:focus {\n    --button-focus-background-color: var(--button-violet-focus);\n    --button-focus-color: var(--button-violet-text-color);\n    --button-focus-text-shadow: var(--button-violet-text-shadow);\n  }\n  .violet.buttons,\n  .violet.button.pressed,\n  .violet.button:active {\n    --button-pressed-background-color: var(--button-violet-pressed);\n    --button-pressed-color: var(--button-violet-text-color);\n    --button-pressed-text-shadow: var(--button-violet-text-shadow);\n  }\n  .violet.buttons .active.button,\n  .violet.buttons .active.button.pressed,\n  .violet.buttons .active.button:active,\n  .violet.active.button,\n  .violet.button .active.button.pressed,\n  .violet.button .active.button:active {\n    background-color: var(--button-violet-active);\n    color: var(--button-violet-text-color);\n    text-shadow: var(--button-violet-text-shadow);\n  }\n  .purple.buttons,\n  .purple.button {\n    --button-text-color: var(--button-purple-text-color);\n    --button-text-shadow: var(--button-purple-text-shadow);\n    --button-background: var(--button-purple) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .purple.buttons,\n  .purple.button:hover {\n    --button-hover-color: var(--button-purple-text-color);\n    --button-hover-text-shadow: var(--button-purple-text-shadow);\n    --button-hover-background-color: var(--button-purple-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .purple.buttons,\n  .purple.button:focus {\n    --button-focus-background-color: var(--button-purple-focus);\n    --button-focus-color: var(--button-purple-text-color);\n    --button-focus-text-shadow: var(--button-purple-text-shadow);\n  }\n  .purple.buttons,\n  .purple.button.pressed,\n  .purple.button:active {\n    --button-pressed-background-color: var(--button-purple-pressed);\n    --button-pressed-color: var(--button-purple-text-color);\n    --button-pressed-text-shadow: var(--button-purple-text-shadow);\n  }\n  .purple.buttons .active.button,\n  .purple.buttons .active.button.pressed,\n  .purple.buttons .active.button:active,\n  .purple.active.button,\n  .purple.button .active.button.pressed,\n  .purple.button .active.button:active {\n    background-color: var(--button-purple-active);\n    color: var(--button-purple-text-color);\n    text-shadow: var(--button-purple-text-shadow);\n  }\n  .pink.buttons,\n  .pink.button {\n    --button-text-color: var(--button-pink-text-color);\n    --button-text-shadow: var(--button-pink-text-shadow);\n    --button-background: var(--button-pink) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .pink.buttons,\n  .pink.button:hover {\n    --button-hover-color: var(--button-pink-text-color);\n    --button-hover-text-shadow: var(--button-pink-text-shadow);\n    --button-hover-background-color: var(--button-pink-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .pink.buttons,\n  .pink.button:focus {\n    --button-focus-background-color: var(--button-pink-focus);\n    --button-focus-color: var(--button-pink-text-color);\n    --button-focus-text-shadow: var(--button-pink-text-shadow);\n  }\n  .pink.buttons,\n  .pink.button.pressed,\n  .pink.button:active {\n    --button-pressed-background-color: var(--button-pink-pressed);\n    --button-pressed-color: var(--button-pink-text-color);\n    --button-pressed-text-shadow: var(--button-pink-text-shadow);\n  }\n  .pink.buttons .active.button,\n  .pink.buttons .active.button.pressed,\n  .pink.buttons .active.button:active,\n  .pink.active.button,\n  .pink.button .active.button.pressed,\n  .pink.button .active.button:active {\n    background-color: var(--button-pink-active);\n    color: var(--button-pink-text-color);\n    text-shadow: var(--button-pink-text-shadow);\n  }\n  .brown.buttons,\n  .brown.button {\n    --button-text-color: var(--button-brown-text-color);\n    --button-text-shadow: var(--button-brown-text-shadow);\n    --button-background: var(--button-brown) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .brown.buttons,\n  .brown.button:hover {\n    --button-hover-color: var(--button-brown-text-color);\n    --button-hover-text-shadow: var(--button-brown-text-shadow);\n    --button-hover-background-color: var(--button-brown-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .brown.buttons,\n  .brown.button:focus {\n    --button-focus-background-color: var(--button-brown-focus);\n    --button-focus-color: var(--button-brown-text-color);\n    --button-focus-text-shadow: var(--button-brown-text-shadow);\n  }\n  .brown.buttons,\n  .brown.button.pressed,\n  .brown.button:active {\n    --button-pressed-background-color: var(--button-brown-pressed);\n    --button-pressed-color: var(--button-brown-text-color);\n    --button-pressed-text-shadow: var(--button-brown-text-shadow);\n  }\n  .brown.buttons .active.button,\n  .brown.buttons .active.button.pressed,\n  .brown.buttons .active.button:active,\n  .brown.active.button,\n  .brown.button .active.button.pressed,\n  .brown.button .active.button:active {\n    background-color: var(--button-brown-active);\n    color: var(--button-brown-text-color);\n    text-shadow: var(--button-brown-text-shadow);\n  }\n  .grey.buttons,\n  .grey.button {\n    --button-text-color: var(--button-grey-text-color);\n    --button-text-shadow: var(--button-grey-text-shadow);\n    --button-background: var(--button-grey) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .grey.buttons,\n  .grey.button:hover {\n    --button-hover-color: var(--button-grey-text-color);\n    --button-hover-text-shadow: var(--button-grey-text-shadow);\n    --button-hover-background-color: var(--button-grey-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .grey.buttons,\n  .grey.button:focus {\n    --button-focus-background-color: var(--button-grey-focus);\n    --button-focus-color: var(--button-grey-text-color);\n    --button-focus-text-shadow: var(--button-grey-text-shadow);\n  }\n  .grey.buttons,\n  .grey.button.pressed,\n  .grey.button:active {\n    --button-pressed-background-color: var(--button-grey-pressed);\n    --button-pressed-color: var(--button-grey-text-color);\n    --button-pressed-text-shadow: var(--button-grey-text-shadow);\n  }\n  .grey.buttons .active.button,\n  .grey.buttons .active.button.pressed,\n  .grey.buttons .active.button:active,\n  .grey.active.button,\n  .grey.button .active.button.pressed,\n  .grey.button .active.button:active {\n    background-color: var(--button-grey-active);\n    color: var(--button-grey-text-color);\n    text-shadow: var(--button-grey-text-shadow);\n  }\n  .black.buttons,\n  .black.button {\n    --button-text-color: var(--button-black-text-color);\n    --button-text-shadow: var(--button-black-text-shadow);\n    --button-background: var(--button-black) var(--button-colored-background-image);\n    --button-box-shadow: var(--button-colored-box-shadow);\n  }\n  .black.buttons,\n  .black.button:hover {\n    --button-hover-color: var(--button-black-text-color);\n    --button-hover-text-shadow: var(--button-black-text-shadow);\n    --button-hover-background-color: var(--button-black-hover);\n    --button-hover-box-shadow: var(--button-colored-box-shadow);\n  }\n  .black.buttons,\n  .black.button:focus {\n    --button-focus-background-color: var(--button-black-focus);\n    --button-focus-color: var(--button-black-text-color);\n    --button-focus-text-shadow: var(--button-black-text-shadow);\n  }\n  .black.buttons,\n  .black.button.pressed,\n  .black.button:active {\n    --button-pressed-background-color: var(--button-black-pressed);\n    --button-pressed-color: var(--button-black-text-color);\n    --button-pressed-text-shadow: var(--button-black-text-shadow);\n  }\n  .black.buttons .active.button,\n  .black.buttons .active.button.pressed,\n  .black.buttons .active.button:active,\n  .black.active.button,\n  .black.button .active.button.pressed,\n  .black.button .active.button:active {\n    background-color: var(--button-black-active);\n    color: var(--button-black-text-color);\n    text-shadow: var(--button-black-text-shadow);\n  }\n}\n\n/* src/components/button/css/definition/variations/compact.css */\n@layer button.definition.variations.compact {\n  .compact.buttons .button,\n  .compact.button {\n    padding: var(--button-compact-vertical-padding) var(--button-compact-horizontal-padding);\n  }\n  .compact.icon.buttons .button,\n  .compact.icon.button {\n    padding: var(--button-compact-icon-padding);\n  }\n  .very-compact.buttons .button,\n  .very-compact.button {\n    padding: var(--button-very-compact-vertical-padding) var(--button-very-compact-horizontal-padding);\n  }\n  .very-compact.icon.buttons .button,\n  .very-compact.icon.button {\n    padding: var(--button-very-compact-icon-padding);\n  }\n}\n\n/* src/components/button/css/definition/variations/floated.css */\n@layer button.definition.variations.floated {\n  .left-floated.buttons,\n  .left-floated.button {\n    float: left;\n    margin-left: 0em;\n    margin-right: var(--button-floated-margin);\n  }\n  .right-floated.buttons,\n  .right-floated.button {\n    float: right;\n    margin-right: 0em;\n    margin-left: var(--button-floated-margin);\n  }\n}\n\n/* src/components/button/css/definition/variations/fluid.css */\n@layer button.definition.variations.fluid {\n  .fluid.buttons,\n  .fluid.button {\n    width: 100%;\n  }\n  .fluid.button {\n    display: block;\n  }\n  .two.buttons {\n    width: 100%;\n  }\n  .two.buttons > .button {\n    width: 50%;\n  }\n  .three.buttons {\n    width: 100%;\n  }\n  .three.buttons > .button {\n    width: 33.333%;\n  }\n  .four.buttons {\n    width: 100%;\n  }\n  .four.buttons > .button {\n    width: 25%;\n  }\n  .five.buttons {\n    width: 100%;\n  }\n  .five.buttons > .button {\n    width: 20%;\n  }\n  .six.buttons {\n    width: 100%;\n  }\n  .six.buttons > .button {\n    width: 16.666%;\n  }\n  .seven.buttons {\n    width: 100%;\n  }\n  .seven.buttons > .button {\n    width: 14.285%;\n  }\n  .eight.buttons {\n    width: 100%;\n  }\n  .eight.buttons > .button {\n    width: 12.500%;\n  }\n  .nine.buttons {\n    width: 100%;\n  }\n  .nine.buttons > .button {\n    width: 11.11%;\n  }\n  .ten.buttons {\n    width: 100%;\n  }\n  .ten.buttons > .button {\n    width: 10%;\n  }\n  .eleven.buttons {\n    width: 100%;\n  }\n  .eleven.buttons > .button {\n    width: 9.09%;\n  }\n  .twelve.buttons {\n    width: 100%;\n  }\n  .twelve.buttons > .button {\n    width: 8.3333%;\n  }\n  .fluid.vertical.buttons,\n  .fluid.vertical.buttons > .button {\n    display: flex;\n    width: auto;\n  }\n  .two.vertical.buttons > .button {\n    height: 50%;\n  }\n  .three.vertical.buttons > .button {\n    height: 33.333%;\n  }\n  .four.vertical.buttons > .button {\n    height: 25%;\n  }\n  .five.vertical.buttons > .button {\n    height: 20%;\n  }\n  .six.vertical.buttons > .button {\n    height: 16.666%;\n  }\n  .seven.vertical.buttons > .button {\n    height: 14.285%;\n  }\n  .eight.vertical.buttons > .button {\n    height: 12.500%;\n  }\n  .nine.vertical.buttons > .button {\n    height: 11.11%;\n  }\n  .ten.vertical.buttons > .button {\n    height: 10%;\n  }\n  .eleven.vertical.buttons > .button {\n    height: 9.09%;\n  }\n  .twelve.vertical.buttons > .button {\n    height: 8.3333%;\n  }\n}\n\n/* src/components/button/css/definition/variations/negative.css */\n@layer button.definition.variations.negative {\n  .negative.buttons .button,\n  .negative.button {\n    background-color: var(--button-negative-color);\n    color: var(--button-negative-text-color);\n    text-shadow: var(--button-negative-text-shadow);\n    background-image: var(--button-colored-background-image);\n  }\n  .negative.button {\n    box-shadow: var(--button-negative-box-shadow);\n  }\n  .negative.buttons .button:hover,\n  .negative.button:hover {\n    background-color: var(--button-negative-color-hover);\n    color: var(--button-negative-text-color);\n    text-shadow: var(--button-negative-text-shadow);\n    box-shadow: var(--button-hover-box-shadow);\n  }\n  .negative.buttons .button:focus,\n  .negative.button:focus {\n    background-color: var(--button-negative-color-focus);\n    color: var(--button-negative-text-color);\n    text-shadow: var(--button-negative-text-shadow);\n    box-shadow: var(--button-focus-box-shadow);\n  }\n  .negative.buttons .button.pressed,\n  .negative.button.pressed,\n  .negative.buttons .button:active,\n  .negative.button:active {\n    background-color: var(--button-negative-color-down);\n    color: var(--button-negative-text-color);\n    text-shadow: var(--button-negative-text-shadow);\n    box-shadow: var(--button-pressed-box-shadow);\n  }\n  .negative.buttons .active.button,\n  .negative.buttons .active.button:active,\n  .negative.active.button,\n  .negative.button .active.button:active {\n    background-color: var(--button-negative-color-active);\n    color: var(--button-negative-text-color);\n    text-shadow: var(--button-negative-text-shadow);\n    box-shadow: var(--button-active-box-shadow);\n  }\n  .subtle-negative.buttons .button,\n  .subtle-negative.button {\n    background-color: var(--button-subtle-negative-color);\n    color: var(--button-subtle-negative-text-color);\n    text-shadow: var(--button-subtle-negative-text-shadow);\n    background-image: var(--button-subtle-negative-background-image);\n  }\n  .subtle-negative.button {\n    box-shadow: var(--button-subtle-negative-box-shadow);\n  }\n  .subtle-negative.buttons .button:hover,\n  .subtle-negative.button:hover {\n    background-color: var(--button-subtle-negative-color-hover);\n    color: var(--button-subtle-negative-text-color);\n    text-shadow: var(--button-subtle-negative-text-shadow);\n    box-shadow: var(--button-hover-box-shadow);\n  }\n  .subtle-negative.buttons .button:focus,\n  .subtle-negative.button:focus {\n    background-color: var(--button-subtle-negative-color-focus);\n    color: var(--button-subtle-negative-text-color);\n    text-shadow: var(--button-subtle-negative-text-shadow);\n    box-shadow: var(--button-focus-box-shadow);\n  }\n  .subtle-negative.buttons .button.pressed,\n  .subtle-negative.button.pressed,\n  .subtle-negative.buttons .button:active,\n  .subtle-negative.button:active {\n    background-color: var(--button-subtle-negative-color-down);\n    color: var(--button-subtle-negative-text-color);\n    text-shadow: var(--button-subtle-negative-text-shadow);\n    box-shadow: var(--button-pressed-box-shadow);\n  }\n  .subtle-negative.buttons .active.button,\n  .subtle-negative.buttons .active.button:active,\n  .subtle-negative.active.button,\n  .subtle-negative.button .active.button:active {\n    background-color: var(--button-subtle-negative-color-active);\n    background-image: var(--button-subtle-negative-background-image);\n    color: var(--button-subtle-negative-text-color);\n    text-shadow: var(--button-subtle-negative-text-shadow);\n    box-shadow: var(--button-active-box-shadow);\n  }\n  .subtle-negative.buttons .button > .icon,\n  .subtle-negative.button > .icon {\n    color: var(--button-subtle-negative-text-color);\n  }\n}\n\n/* src/components/button/css/definition/variations/positive.css */\n@layer button.definition.variations.positive {\n  .positive.buttons .button,\n  .positive.button {\n    background-color: var(--button-positive-color);\n    color: var(--button-positive-text-color);\n    text-shadow: var(--button-positive-text-shadow);\n    background-image: var(--button-positive-background-image);\n  }\n  .positive.button {\n    box-shadow: var(--button-positive-box-shadow);\n  }\n  .positive.buttons .button:hover,\n  .positive.button:hover {\n    background-color: var(--button-positive-color-hover);\n    color: var(--button-positive-text-color);\n    text-shadow: var(--button-positive-text-shadow);\n    box-shadow: var(--button-hover-box-shadow);\n  }\n  .positive.buttons .button:focus,\n  .positive.button:focus {\n    background-color: var(--button-positive-color-focus);\n    color: var(--button-positive-text-color);\n    text-shadow: var(--button-positive-text-shadow);\n    box-shadow: var(--button-focus-box-shadow);\n  }\n  .positive.buttons .button.pressed,\n  .positive.button.pressed,\n  .positive.buttons .button:active,\n  .positive.button:active {\n    background-color: var(--button-positive-color-down);\n    color: var(--button-positive-text-color);\n    text-shadow: var(--button-positive-text-shadow);\n    box-shadow: var(--button-pressed-box-shadow);\n  }\n  .positive.buttons .active.button,\n  .positive.buttons .active.button:active,\n  .positive.active.button,\n  .positive.button .active.button:active {\n    background-color: var(--button-positive-color-active);\n    color: var(--button-positive-text-color);\n    text-shadow: var(--button-positive-text-shadow);\n    box-shadow: var(--button-active-box-shadow);\n  }\n  .subtle-positive.buttons .button,\n  .subtle-positive.button {\n    background-color: var(--button-subtle-positive-color);\n    color: var(--button-subtle-positive-text-color);\n    text-shadow: var(--button-subtle-positive-text-shadow);\n    background-image: var(--button-subtle-positive-background-image);\n  }\n  .subtle-positive.button {\n    box-shadow: var(--button-subtle-positive-box-shadow);\n  }\n  .subtle-positive.buttons .button:hover,\n  .subtle-positive.button:hover {\n    background-color: var(--button-subtle-positive-color-hover);\n    color: var(--button-subtle-positive-text-color);\n    text-shadow: var(--button-subtle-positive-text-shadow);\n    box-shadow: var(--button-hover-box-shadow);\n  }\n  .subtle-positive.buttons .button:focus,\n  .subtle-positive.button:focus {\n    background-color: var(--button-subtle-positive-color-focus);\n    color: var(--button-subtle-positive-text-color);\n    text-shadow: var(--button-subtle-positive-text-shadow);\n    box-shadow: var(--button-focus-box-shadow);\n  }\n  .subtle-positive.buttons .button.pressed,\n  .subtle-positive.button.pressed,\n  .subtle-positive.buttons .button:active,\n  .subtle-positive.button:active {\n    background-color: var(--button-subtle-positive-color-down);\n    color: var(--button-subtle-positive-text-color);\n    text-shadow: var(--button-subtle-positive-text-shadow);\n    box-shadow: var(--button-pressed-box-shadow);\n  }\n  .subtle-positive.buttons .active.button,\n  .subtle-positive.active.button,\n  .subtle-positive.buttons .active.button:active,\n  .subtle-positive.button .active.button:active {\n    background-color: var(--button-subtle-positive-color-active);\n    background-image: var(--button-subtle-positive-background-image);\n    color: var(--button-subtle-positive-text-color);\n    text-shadow: var(--button-subtle-positive-text-shadow);\n    box-shadow: var(--button-active-box-shadow);\n  }\n  .subtle-positive.buttons .button > .icon,\n  .subtle-positive.button > .icon {\n    color: var(--button-subtle-positive-text-color);\n  }\n}\n\n/* src/components/button/css/definition/variations/warning.css */\n@layer button.definition.variations.warning {\n  .warning.buttons .button,\n  .warning.button {\n    background-color: var(--button-warning-color);\n    color: var(--button-warning-text-color);\n    text-shadow: var(--button-warning-text-shadow);\n    background-image: var(--button-colored-background-image);\n  }\n  .warning.button {\n    box-shadow: var(--button-warning-box-shadow);\n  }\n  .warning.buttons .button:hover,\n  .warning.button:hover {\n    background-color: var(--button-warning-color-hover);\n    color: var(--button-warning-text-color);\n    text-shadow: var(--button-warning-text-shadow);\n    box-shadow: var(--button-hover-box-shadow);\n  }\n  .warning.buttons .button:focus,\n  .warning.button:focus {\n    background-color: var(--button-warning-color-focus);\n    color: var(--button-warning-text-color);\n    text-shadow: var(--button-warning-text-shadow);\n    box-shadow: var(--button-focus-box-shadow);\n  }\n  .warning.buttons .button:active,\n  .warning.button:active {\n    background-color: var(--button-warning-color-down);\n    color: var(--button-warning-text-color);\n    text-shadow: var(--button-warning-text-shadow);\n  }\n  .warning.buttons .active.button,\n  .warning.buttons .active.button:active,\n  .warning.active.button,\n  .warning.button .active.button:active {\n    background-color: var(--button-warning-color-active);\n    color: var(--button-warning-text-color);\n    text-shadow: var(--button-warning-text-shadow);\n  }\n  .subtle-warning.buttons .button,\n  .subtle-warning.button {\n    background-color: var(--button-subtle-warning-color);\n    color: var(--button-subtle-warning-text-color);\n    text-shadow: var(--button-subtle-warning-text-shadow);\n    background-image: var(--button-subtle-warning-background-image);\n  }\n  .subtle-warning.button {\n    box-shadow: var(--button-subtle-warning-box-shadow);\n  }\n  .subtle-warning.buttons .button:hover,\n  .subtle-warning.button:hover {\n    background-color: var(--button-subtle-warning-color-hover);\n    color: var(--button-subtle-warning-text-color);\n    text-shadow: var(--button-subtle-warning-text-shadow);\n    box-shadow: var(--button-hover-box-shadow);\n  }\n  .subtle-warning.buttons .button:focus,\n  .subtle-warning.button:focus {\n    background-color: var(--button-subtle-warning-color-focus);\n    color: var(--button-subtle-warning-text-color);\n    text-shadow: var(--button-subtle-warning-text-shadow);\n    box-shadow: var(--button-focus-box-shadow);\n  }\n  .subtle-warning.buttons .button:active,\n  .subtle-warning.button:active {\n    background-color: var(--button-subtle-warning-color-down);\n    color: var(--button-subtle-warning-text-color);\n    text-shadow: var(--button-subtle-warning-text-shadow);\n    box-shadow: var(--button-pressed-box-shadow);\n  }\n  .subtle-warning.buttons .active.button,\n  .subtle-warning.buttons .active.button:active,\n  .subtle-warning.active.button,\n  .subtle-warning.button .active.button:active {\n    background-color: var(--button-subtle-warning-color-active);\n    background-image: var(--button-subtle-warning-background-image);\n    color: var(--button-subtle-warning-text-color);\n    text-shadow: var(--button-subtle-warning-text-shadow);\n    box-shadow: var(--button-active-box-shadow);\n  }\n  .subtle-warning.buttons .button > .icon,\n  .subtle-warning.button > .icon {\n    color: var(--button-subtle-warning-text-color);\n  }\n}\n\n/* src/components/button/css/definition/variations/info.css */\n@layer button.definition.variations.info {\n  .info.buttons .button,\n  .info.button {\n    background-color: var(--button-info-color);\n    color: var(--button-info-text-color);\n    text-shadow: var(--button-info-text-shadow);\n    background-image: var(--button-colored-background-image);\n  }\n  .info.button {\n    box-shadow: var(--button-info-box-shadow);\n  }\n  .info.buttons .button:hover,\n  .info.button:hover {\n    background-color: var(--button-info-color-hover);\n    color: var(--button-info-text-color);\n    text-shadow: var(--button-info-text-shadow);\n  }\n  .info.buttons .button:focus,\n  .info.button:focus {\n    background-color: var(--button-info-color-focus);\n    color: var(--button-info-text-color);\n    text-shadow: var(--button-info-text-shadow);\n  }\n  .info.buttons .button.pressed,\n  .info.button.pressed,\n  .info.buttons .button:active,\n  .info.button:active {\n    background-color: var(--button-info-color-down);\n    color: var(--button-info-text-color);\n    text-shadow: var(--button-info-text-shadow);\n  }\n  .info.buttons .active.button,\n  .info.buttons .active.button:active,\n  .info.active.button,\n  .info.button .active.button:active {\n    background-color: var(--button-info-color-active);\n    color: var(--button-info-text-color);\n    text-shadow: var(--button-info-text-shadow);\n  }\n  .subtle-info.buttons .button,\n  .subtle-info.button {\n    background-color: var(--button-subtle-info-color);\n    color: var(--button-subtle-info-text-color);\n    text-shadow: var(--button-subtle-info-text-shadow);\n    background-image: var(--button-subtle-info-background-image);\n  }\n  .subtle-info.button {\n    box-shadow: var(--button-subtle-info-box-shadow);\n  }\n  .subtle-info.buttons .button:hover,\n  .subtle-info.button:hover {\n    background-color: var(--button-subtle-info-color-hover);\n    color: var(--button-subtle-info-text-color);\n    text-shadow: var(--button-subtle-info-text-shadow);\n  }\n  .subtle-info.buttons .button:focus,\n  .subtle-info.button:focus {\n    background-color: var(--button-subtle-info-color-focus);\n    color: var(--button-subtle-info-text-color);\n    text-shadow: var(--button-subtle-info-text-shadow);\n  }\n  .subtle-info.buttons .button.pressed,\n  .subtle-info.button.pressed,\n  .subtle-info.buttons .button:active,\n  .subtle-info.button:active {\n    background-color: var(--button-subtle-info-color-down);\n    color: var(--button-subtle-info-text-color);\n    text-shadow: var(--button-subtle-info-text-shadow);\n  }\n  .subtle-info.buttons .active.button,\n  .subtle-info.buttons .active.button:active,\n  .subtle-info.active.button,\n  .subtle-info.button .active.button:active {\n    background-color: var(--button-subtle-info-color-active);\n    background-image: var(--button-subtle-info-background-image);\n    color: var(--button-subtle-info-text-color);\n    text-shadow: var(--button-subtle-info-text-shadow);\n  }\n  .subtle-info.buttons .button > .icon,\n  .subtle-info.button > .icon {\n    color: var(--button-subtle-info-text-color);\n  }\n}\n\n/* src/components/button/css/definition/variations/sizing.css */\n@layer button.definition.variations.sizing {\n  .mini.button {\n    font-size: var(--button-mini);\n  }\n  .tiny.button {\n    font-size: var(--button-tiny);\n  }\n  .small.button {\n    font-size: var(--button-small);\n  }\n  :host {\n    font-size: var(--button-medium);\n  }\n  .large.button {\n    font-size: var(--button-large);\n  }\n  .big.button {\n    font-size: var(--button-big);\n  }\n  .huge.button {\n    font-size: var(--button-huge);\n  }\n  .massive.button {\n    font-size: var(--button-massive);\n  }\n  .mini.buttons {\n    --button-medium: var(--button-mini);\n  }\n  .tiny.buttons {\n    --button-medium: var(--button-tiny);\n  }\n  .small.buttons {\n    --button-medium: var(--button-small);\n  }\n  .large.buttons {\n    --button-medium: var(--button-large);\n  }\n  .big.buttons {\n    --button-medium: var(--button-big);\n  }\n  .huge.buttons {\n    --button-medium: var(--button-huge);\n  }\n  .massive.buttons {\n    --button-medium: var(--button-massive);\n  }\n}\n\n/* src/components/button/css/definition/variations/social.css */\n@layer button.definition.variations.social {\n  .social.button .icon {\n    opacity: 1;\n  }\n  .facebook.button {\n    background-color: var(--facebook-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n    background-image: var(--button-colored-background-image);\n    box-shadow: var(--button-colored-box-shadow);\n  }\n  .facebook.button:hover {\n    background-color: var(--facebook-hover-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .facebook.button:active {\n    background-color: var(--facebook-down-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .twitter.button {\n    background-color: var(--twitter-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n    background-image: var(--button-colored-background-image);\n    box-shadow: var(--button-colored-box-shadow);\n  }\n  .twitter.button:hover {\n    background-color: var(--twitter-hover-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .twitter.button:active {\n    background-color: var(--twitter-down-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .linkedin.button {\n    background-color: var(--linked-in-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .linkedin.button:hover {\n    background-color: var(--linked-in-hover-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .linkedin.button:active {\n    background-color: var(--linked-in-down-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .youtube.button {\n    background-color: var(--youtube-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n    background-image: var(--button-colored-background-image);\n    box-shadow: var(--button-colored-box-shadow);\n  }\n  .youtube.button:hover {\n    background-color: var(--youtube-hover-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .youtube.button:active {\n    background-color: var(--youtube-down-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .instagram.button {\n    background-color: var(--instagram-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n    background-image: var(--button-instagram-background-image);\n    box-shadow: var(--button-colored-box-shadow);\n  }\n  .instagram.button:hover {\n    background-color: var(--instagram-hover-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .instagram.button:active {\n    background-color: var(--instagram-down-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .pinterest.button {\n    background-color: var(--pinterest-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n    background-image: var(--button-colored-background-image);\n    box-shadow: var(--button-colored-box-shadow);\n  }\n  .pinterest.button:hover {\n    background-color: var(--pinterest-hover-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n  .pinterest.button:active {\n    background-color: var(--pinterest-down-color);\n    color: var(--button-inverted-text-color);\n    text-shadow: var(--button-inverted-text-shadow);\n  }\n}\n\n/* src/components/button/css/definition/variations/vertical.css */\n@layer button.definition.variations.vertical {\n  .vertical.buttons {\n    display: inline-flex;\n    flex-direction: column;\n  }\n  .vertical.buttons .button {\n    display: block;\n    float: none;\n    width: 100%;\n    margin: var(--vertical-group-offset);\n    box-shadow: var(--vertical-box-shadow);\n    border-radius: 0em;\n  }\n  .vertical.buttons .button:first-child {\n    border-top-left-radius: var(--border-radius);\n    border-top-right-radius: var(--border-radius);\n  }\n  .vertical.buttons .button:last-child {\n    margin-bottom: 0px;\n    border-bottom-left-radius: var(--border-radius);\n    border-bottom-right-radius: var(--border-radius);\n  }\n  .vertical.buttons .button:only-child {\n    border-radius: var(--border-radius);\n  }\n}\n\n/* src/components/button/css/definition/button-definition.css */\n\n/* src/components/button/css/theme/content/button-variables.css */\n@layer button.theme.content.button {\n  :host {\n    --button-vertical-align: baseline;\n    --button-vertical-margin: 0em;\n    --button-horizontal-margin: var(--3px);\n    --button-background-color: oklch(0.98 0 0 / 1);\n    --button-background-image: var(--subtle-gradient);\n    --button-background: var(--button-background-color) var(--button-background-image);\n    --button-line-height: 1em;\n    --button-vertical-padding: var(--input-vertical-padding);\n    --button-horizontal-padding: var(--relative-19px);\n    --button-padding: var(--button-vertical-padding) var(--button-horizontal-padding);\n    --button-text-transform: none;\n    --button-tap-color: transparent;\n    --button-font-family: var(--page-font);\n    --button-font-weight: var(--bold);\n    --button-text-color: var(--black-80);\n    --button-inverted-text-color: var(--white-80);\n    --button-text-shadow: none;\n    --button-inverted-text-shadow: var(--button-text-shadow);\n    --button-border-radius: var(--border-radius);\n    --button-border: none;\n    --button-border-color: var(--black-border-color);\n    --button-border-width: 1px;\n    --button-sharpen-box-shadow: 0px -1px 0px 0px rgba(0, 0, 0, 0.05) inset;\n    --button-border-box-shadow: 0px 0px 0px var(--button-border-width) var(--button-border-color) inset;\n    --button-shadow-box-shadow: var(--subtle-shadow);\n    --button-box-shadow:\n      var(--button-sharpen-box-shadow),\n      var(--button-border-box-shadow),\n      var(--button-shadow-box-shadow) ;\n    --button-transition-duration: var(--duration);\n    --button-transition-easing: var(--easing);\n    --button-transition:\n      opacity var(--button-transition-duration) var(--button-transition-easing),\n      background-color var(--button-transition-duration) var(--button-transition-easing),\n      color var(--button-transition-duration) var(--button-transition-easing),\n      box-shadow var(--button-transition-duration) var(--button-transition-easing),\n      background var(--button-transition-duration) var(--button-transition-easing) ;\n    --button-will-change: initial;\n  }\n}\n\n/* src/components/button/css/theme/content/icon-variables.css */\n@layer button.theme.content.icon {\n  :host {\n    --button-icon-opacity: 0.4;\n  }\n}\n\n/* src/components/button/css/theme/content/label-variables.css */\n@layer button.theme.content.label {\n  :host {\n    --labeled-label-font-size: var(--medium);\n    --labeled-label-align: center;\n    --labeled-label-padding: "";\n    --labeled-label-font-size: var(--relative-medium);\n    --labeled-label-border-color: var(--border-color);\n    --labeled-label-border-offset: -var(--border-box-shadow-width);\n    --labeled-tag-label-size: 1.85em;\n    --labeled-icon-margin: 0em;\n    --labeled-icon-width: 1em + calc(var(--vertical-padding) * 2);\n    --labeled-icon-background-color: rgba(0, 0, 0, 0.05);\n    --labeled-icon-padding: calc(var(--horizontal-padding) + var(--labeled-icon-width));\n    --labeled-icon-border: transparent;\n    --labeled-icon-color: "";\n    --labeled-icon-left-shadow: -1px 0px 0px 0px var(--labeled-icon-border) inset;\n    --labeled-icon-right-shadow: 1px 0px 0px 0px var(--labeled-icon-border) inset;\n  }\n}\n\n/* src/components/button/css/theme/content/or-variables.css */\n@layer button.theme.content.or {\n  :host {\n    --button-or-text: "or";\n    --button-or-gap: 0.3em;\n    --button-or-height: calc(var(--button-vertical-padding) * 2) + 1em;\n    --button-or-z-index: 3;\n    --button-or-circle-distance-to-edge: var(--button-vertical-padding);\n    --button-or-circle-size: calc(var(--button-or-height) - var(--button-or-circle-distance-to-edge));\n    --button-or-line-height: var(--button-or-circle-size);\n    --button-or-box-shadow: var(--button-border-box-shadow), var(--button-shadow-box-shadow);\n    --button-or-vertical-offset: calc(var(--button-or-circle-size) / 2 * -1);\n    --button-or-horizontal-offset: calc(var(--button-or-circle-size) / 2 * -1 );\n    --button-or-background-color: var(--white);\n    --button-or-text-shadow: var(--button-text-shadow);\n    --button-or-text-style: var(--normal);\n    --button-or-text-weight: var(--bold);\n    --button-or-text-color: var(--light-text-color);\n    --button-or-spacer-height: var(--button-vertical-padding);\n    --button-or-spacer-color: transparent;\n  }\n}\n\n/* src/components/button/css/theme/plural/buttons-variables.css */\n@layer button.theme.plural {\n  :host {\n    --button-group-box-shadow: none;\n    --button-group-button-box-shadow: var(--button-box-shadow);\n    --button-vertical-box-shadow: none;\n    --button-group-button-offset: 0px 0px 0px 0px;\n    --button-vertical-group-offset: 0px 0px 0px 0px;\n  }\n}\n\n/* src/components/button/css/theme/types/emphasis-variables.css */\n@layer button.theme.types.emphasis {\n  :host {\n    --button-primary-color: var(--primary-color);\n    --button-primary-background-image: var(--button-colored-background-image);\n    --button-primary-box-shadow: var(--button-colored-box-shadow);\n    --button-primary-text-color: var(--button-inverted-text-color);\n    --button-primary-text-shadow: var(--button-inverted-text-shadow);\n    --button-secondary-color: var(--secondary-color);\n    --button-secondary-background-image: var(--button-colored-background-image);\n    --button-secondary-box-shadow: var(--button-colored-box-shadow);\n    --button-secondary-text-color: var(--button-inverted-text-color);\n    --button-secondary-text-shadow: var(--button-inverted-text-shadow);\n    --button-primary-color-hover: oklch(from var(--button-primary-color) calc(l + var(--hover-lightness)) c h);\n    --button-secondary-color-hover: oklch(from var(--button-secondary-color) calc(l + var(--hover-lightness)) c h);\n    --button-primary-color-focus: oklch(from var(--button-primary-color) calc(l + var(--focus-lightness)) c h);\n    --button-secondary-color-focus: oklch(from var(--button-secondary-color) calc(l + var(--focus-lightness)) c h);\n    --button-primary-color-down: oklch(from var(--button-primary-color) calc(l + var(--down-lightness)) c h);\n    --button-secondary-color-down: oklch(from var(--button-secondary-color) calc(l + var(--down-lightness)) c h);\n    --button-primary-color-active: oklch(from var(--button-primary-color) calc(l + var(--active-lightness)) c h);\n    --button-secondary-color-active: oklch(from var(--button-secondary-color) calc(l + var(--active-lightness)) c h);\n    --button-light-primary-text-color: var(--button-inverted-text-color);\n    --button-light-secondary-text-color: var(--button-inverted-text-color);\n  }\n}\n\n/* src/components/button/css/theme/types/icon-variables.css */\n@layer button.theme.types.icon {\n  ui-button {\n  }\n}\n\n/* src/components/button/css/theme/types/labeled-variables.css */\n@layer button.theme.types.labeled {\n  ui-button {\n  }\n}\n\n/* src/components/button/css/theme/types/labeled-icon-variables.css */\n@layer button.theme.types.labeled-icon {\n  ui-button {\n  }\n}\n\n/* src/components/button/css/theme/types/toggle-variables.css */\n@layer button.theme.types.toggle {\n  :host {\n    --button-toggle-active-background: #CFF3D8;\n    --button-toggle-active-color: #22592D;\n    --button-toggle-active-text-shadow: var(--button-text-shadow);\n    --button-toggle-active-hover-background: #CFFFD8;\n    --button-toggle-active-hover-color: #22592D;\n  }\n}\n\n/* src/components/button/css/theme/types/animated-variables.css */\n@layer button.theme.types.animated {\n  :host {\n    --button-animated-vertical-align: middle;\n    --button-animated-z-index: 1;\n    --button-animation-duration: 0.3s;\n    --button-animation-easing: ease;\n    --button-fade-scale-high: 1.5;\n    --button-fade-scale-low: 0.75;\n  }\n}\n\n/* src/components/button/css/theme/types/transparent-variables.css */\n@layer button.theme.types.transparent {\n  :host {\n    --button-transparent-background-image: linear-gradient(rgba(255, 255, 255, 0.05), rgba(0, 0, 0, 0.08));\n    --button-transparent-background-color: rgba(0, 0, 0, 0.03);\n    --button-transparent-text-color: var(--button-text-color);\n    --button-transparent-box-shadow: var(--button-box-shadow);\n    --button-transparent-hover-background-image: linear-gradient(rgba(255, 255, 255, 0.08), rgba(0, 0, 0, 0.1));\n    --button-transparent-hover-background-color: var(--subtle-transparent-white);\n    --button-transparent-hover-text-color: var(--button-hover-color);\n    --button-transparent-hover-box-shadow: var(--button-hover-box-shadow);\n    --button-transparent-pressed-background-image: var(--button-transparent-hover-background-image);\n    --button-transparent-pressed-background-color: var(--transparent-white);\n    --button-transparent-pressed-text-color: var(--button-pressed-color);\n    --button-transparent-pressed-box-shadow: var(--button-pressed-box-shadow);\n    --button-transparent-active-background-image: var(--button-background-image);\n    --button-transparent-active-background-color: rgba(0, 0, 0, 0.02);\n    --button-transparent-active-text-color: var(--button-green);\n    --button-transparent-active-box-shadow: var(--button-box-shadow);\n    --button-transparent-inverted-background-image: linear-gradient(rgba(255, 255, 255, 0.05), rgba(0, 0, 0, 0.08));\n    --button-transparent-inverted-background-color: rgba(255, 255, 255, 0.03);\n    --button-transparent-inverted-text-color: var(--button-inverted-text-color);\n    --button-transparent-inverted-box-shadow: var(--button-box-shadow);\n    --button-transparent-inverted-hover-background-image: var(--button-hover-background-image);\n    --button-transparent-inverted-hover-background-color: var(--subtle-transparent-white);\n    --button-transparent-inverted-hover-text-color: var(--button-inverted-text-color);\n    --button-transparent-inverted-hover-box-shadow: var(--button-hover-box-shadow);\n    --button-transparent-inverted-pressed-background-image: var(--button-pressed-background-image);\n    --button-transparent-inverted-pressed-background-color: var(--transparent-white);\n    --button-transparent-inverted-pressed-text-color: var(--button-inverted-text-color);\n    --button-transparent-inverted-pressed-box-shadow: var(--button-pressed-box-shadow);\n    --button-transparent-inverted-active-background-image: var(--button-background-image);\n    --button-transparent-inverted-active-background-color: var(--subtle-transparent-white);\n    --button-transparent-inverted-active-text-color: #FFFFFF;\n    --button-transparent-inverted-active-box-shadow: var(--button-box-shadow);\n  }\n}\n\n/* src/components/button/css/theme/states/hover-variables.css */\n@layer button.theme.states.hover {\n  :host {\n    --button-hover-background-color: #FFFFFF;\n    --button-hover-background-image: var(--button-background-image);\n    --button-hover-box-shadow:\n      0 -1px 0 0 rgba(0, 0, 0, 0.05) inset,\n      0 0 0 1px rgba(0, 0, 0, 0.13) inset,\n      0 1px 3px rgba(0, 0, 0, 0.25) ;\n    --button-hover-color: var(--black-90);\n    --button-hover-icon-opacity: 0.85;\n  }\n}\n\n/* src/components/button/css/theme/states/focus-variables.css */\n@layer button.theme.states.focus {\n  :host {\n    --button-focus-background-color: var(--button-hover-background-color);\n    --button-focus-background-image: var(--button-hover-background-image);\n    --button-focus-box-shadow: var(--button-hover-box-shadow);\n    --button-focus-color: var(--button-hover-color);\n    --button-focus-icon-opacity: 0.85;\n  }\n}\n\n/* src/components/button/css/theme/states/pressed-variables.css */\n@layer button.theme.states.pressed {\n  :host {\n    --button-pressed-background-color: var(--button-background-color);\n    --button-pressed-background-image: var(--button-background-image);\n    --button-pressed-color: var(--black-90);\n    --button-pressed-shadow-box-shadow: var(--inset-shadow);\n    --button-pressed-box-shadow:\n      var(--button-sharpen-box-shadow),\n      var(--button-border-box-shadow),\n      var(--button-pressed-shadow-box-shadow) ;\n  }\n}\n\n/* src/components/button/css/theme/states/active-variables.css */\n@layer button.theme.states.active {\n  :host {\n    --button-active-background-color: #DFDFDF;\n    --button-active-background-image: var(--button-background-image);\n    --button-active-color: var(--black-90);\n    --button-active-shadow-box-shadow: var(--subtle-inset-shadow);\n    --button-active-box-shadow:\n      var(--button-sharpen-box-shadow),\n      var(--button-border-box-shadow),\n      var(--button-active-shadow-box-shadow) ;\n    --button-active-hover-background-color: #DADADA;\n    --button-active-hover-background-image: var(--button-active-background-image);\n    --button-active-hover-color: var(--button-active-color);\n    --button-active-hover-box-shadow: var(--button-active-box-shadow);\n    --button-active-down-background-color: var(--button-active-background-color);\n    --button-active-down-background-image: var(--button-active-background-image);\n    --button-active-down-color: var(--button-active-color);\n    --button-active-down-box-shadow: var(--button-active-box-shadow);\n  }\n}\n\n/* src/components/button/css/theme/states/disabled-variables.css */\n@layer button.theme.states.disabled {\n  :host {\n    --button-disabled-cursor: not-allowed;\n    --button-disabled-opacity: 0.4;\n    --button-disabled-background-color: #FFFFFF;\n    --button-disabled-background-image: var(--button-background-image);\n    --button-disabled-border-box-shadow: 0px 0px 0px var(--button-border-width) rgba(0, 0, 0, 0.1) inset;\n    --button-disabled-shadow-box-shadow: 0px 2px 3px rgba(0, 0, 0, 0.04);\n    --button-disabled-color: var(--black-20);\n    --button-disabled-box-shadow:\n      var(--button-sharpen-box-shadow),\n      var(--button-disabled-border-box-shadow),\n      var(--button-disabled-shadow-box-shadow) ;\n    --button-clickable-disabled-cursor: not-allowed;\n  }\n}\n\n/* src/components/button/css/theme/states/loading-variables.css */\n@layer button.theme.states.loading {\n  :host {\n    --button-loading-icon-duration: 2s;\n    --button-loading-opacity: 1;\n    --button-loading-transition: opacity var(--button-transition-duration) var(--button-transition-easing) ;\n  }\n}\n\n/* src/components/button/css/theme/variations/attached-variables.css */\n@layer button.theme.variations.attached {\n  :host {\n    --button-attached-offset: -1px;\n    --button-attached-border-shadow: 0px 0px 0px 1px var(--button-border-color);\n    --button-attached-box-shadow: var(--button-attached-border-shadow), var(--button-shadow-box-shadow) ;\n    --button-attached-horizontal-padding: var(--relative-12px);\n    --button-attached-z-index: 2;\n    --button-attached-pressed-box-shadow: 0 2px 2px rgba(0, 0, 0, 0.08) inset, var(--button-attached-box-shadow) ;\n  }\n}\n\n/* src/components/button/css/theme/variations/basic-variables.css */\n@layer button.theme.variations.basic {\n  :host {\n    --button-basic-border-radius: var(--button-border-radius);\n    --button-basic-border-size: 1px;\n    --button-basic-text-color: var(--button-text-color);\n    --button-basic-colored-border-size: 1px;\n    --button-basic-background: transparent none;\n    --button-basic-font-weight: var(--button-font-weight);\n    --button-basic-border: 1px solid var(--button-border-color);\n    --button-basic-box-shadow: 0px 0px 0px var(--button-basic-border-size) var(--button-border-color) inset;\n    --button-basic-loading-color: var(--button-off-white);\n    --button-basic-text-transform: none;\n    --button-basic-hover-background: #FFFFFF;\n    --button-basic-hover-text-color: var(--button-hover-color);\n    --button-basic-hover-box-shadow: 0px 0px 0px var(--button-basic-border-size) var(--selected-border-color) inset, 0px 0px 0px 0px var(--button-border-color) inset ;\n    --button-basic-focus-background: var(--button-basic-hover-background);\n    --button-basic-focus-text-color: var(--button-basic-hover-text-color);\n    --button-basic-focus-box-shadow: var(--button-basic-hover-box-shadow);\n    --button-basic-down-background: #F8F8F8;\n    --button-basic-down-text-color: var(--button-pressed-text-color);\n    --button-basic-down-box-shadow: 0px 0px 0px var(--button-basic-border-size) rgba(0, 0, 0, 0.15) inset, 0px 1px 4px 0px var(--button-border-color) inset ;\n    --button-basic-active-background: var(--button-transparent-black);\n    --button-basic-active-box-shadow: "";\n    --button-basic-active-text-color: var(--button-selected-text-color);\n    --button-basic-inverted-background: transparent;\n    --button-basic-inverted-focus-background: transparent;\n    --button-basic-inverted-down-background: var(--button-transparent-white);\n    --button-basic-inverted-active-background: var(--button-transparent-white);\n    --button-basic-inverted-box-shadow: 0px 0px 0px var(--button-inverted-border-size) rgba(255, 255, 255, 0.5) inset;\n    --button-basic-inverted-hover-box-shadow: 0px 0px 0px var(--button-inverted-border-size) rgba(255, 255, 255, 1) inset;\n    --button-basic-inverted-focus-box-shadow: 0px 0px 0px var(--button-inverted-border-size) rgba(255, 255, 255, 1) inset;\n    --button-basic-inverted-down-box-shadow: 0px 0px 0px var(--button-inverted-border-size) rgba(255, 255, 255, 0.9) inset;\n    --button-basic-inverted-active-box-shadow: 0px 0px 0px var(--button-inverted-border-size) rgba(255, 255, 255, 0.7) inset;\n    --button-basic-inverted-color: var(--button-dark-white);\n    --button-basic-inverted-hover-color: var(--button-dark-white-hover);\n    --button-basic-inverted-down-color: var(--button-dark-white-active);\n    --button-basic-inverted-active-color: var(--button-inverted-text-color);\n    --button-basic-group-border: var(--button-basic-border-size) solid var(--button-border-color);\n    --button-basic-group-box-shadow: none;\n  }\n}\n\n/* src/components/button/css/theme/variations/circular-variables.css */\n@layer button.theme.variations.circular;\n\n/* src/components/button/css/theme/variations/colored-variables.css */\n@layer button.theme.variations.colored {\n  :host {\n    --button-colored-background-image: var(--button-background-image);\n    --button-colored-box-shadow:\n      0 -1px 0 0 rgba(0, 0, 0, 0.05) inset,\n      0 0 0 1px rgba(0, 0, 0, 0.13) inset,\n      0 1px 3px rgba(0, 0, 0, 0.15) ;\n    --button-inverted-text-shadow: 1px 1px 1px rgba(0, 0, 0, 0.3);\n    --button-red: var(--red);\n    --button-orange: var(--orange);\n    --button-yellow: var(--yellow);\n    --button-olive: var(--olive);\n    --button-green: var(--green);\n    --button-teal: var(--teal);\n    --button-blue: var(--blue);\n    --button-violet: var(--violet);\n    --button-purple: var(--purple);\n    --button-pink: var(--pink);\n    --button-brown: var(--brown);\n    --button-grey: var(--grey);\n    --button-black: var(--black);\n    --button-colored-hover-lightness: 0.05;\n    --button-colored-hover-hue: 2;\n    --button-red-hover: oklch(from var(--button-red) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-orange-hover: oklch(from var(--button-orange) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-yellow-hover: oklch(from var(--button-yellow) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-olive-hover: oklch(from var(--button-olive) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-green-hover: oklch(from var(--button-green) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-teal-hover: oklch(from var(--button-teal) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-blue-hover: oklch(from var(--button-blue) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-violet-hover: oklch(from var(--button-violet) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-purple-hover: oklch(from var(--button-purple) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-pink-hover: oklch(from var(--button-pink) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-brown-hover: oklch(from var(--button-brown) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-grey-hover: oklch(from var(--button-grey) calc(l + var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-black-hover: oklch(from var(--button-black) calc(l - var(--button-colored-hover-lightness)) c calc(h + var(--button-colored-hover-hue)));\n    --button-colored-focus-lightness: 0.08;\n    --button-colored-focus-hue: 2;\n    --button-red-focus: oklch(from var(--button-red) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-orange-focus: oklch(from var(--button-orange) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-yellow-focus: oklch(from var(--button-yellow) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-olive-focus: oklch(from var(--button-olive) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-green-focus: oklch(from var(--button-green) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-teal-focus: oklch(from var(--button-teal) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-blue-focus: oklch(from var(--button-blue) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-violet-focus: oklch(from var(--button-violet) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-purple-focus: oklch(from var(--button-purple) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-pink-focus: oklch(from var(--button-pink) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-brown-focus: oklch(from var(--button-brown) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-grey-focus: oklch(from var(--button-grey) calc(l + var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-black-focus: oklch(from var(--button-black) calc(l - var(--button-colored-focus-lightness)) c calc(h + var(--button-colored-focus-hue)));\n    --button-colored-pressed-lightness: -0.02;\n    --button-colored-pressed-hue: 2;\n    --button-red-pressed: oklch(from var(--button-red) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-orange-pressed: oklch(from var(--button-orange) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-yellow-pressed: oklch(from var(--button-yellow) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-olive-pressed: oklch(from var(--button-olive) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-green-pressed: oklch(from var(--button-green) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-teal-pressed: oklch(from var(--button-teal) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-blue-pressed: oklch(from var(--button-blue) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-violet-pressed: oklch(from var(--button-violet) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-purple-pressed: oklch(from var(--button-purple) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-pink-pressed: oklch(from var(--button-pink) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-brown-pressed: oklch(from var(--button-brown) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-grey-pressed: oklch(from var(--button-grey) calc(l + var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-black-pressed: oklch(from var(--button-black) calc(l - var(--button-colored-pressed-lightness)) c calc(h + var(--button-colored-pressed-hue)));\n    --button-brown-text-color: var(--button-inverted-text-color);\n    --button-brown-text-shadow: var(--button-inverted-text-shadow);\n    --button-red-text-color: var(--button-inverted-text-color);\n    --button-red-text-shadow: var(--button-inverted-text-shadow);\n    --button-orange-text-color: var(--button-inverted-text-color);\n    --button-orange-text-shadow: var(--button-inverted-text-shadow);\n    --button-green-text-color: var(--button-inverted-text-color);\n    --button-green-text-shadow: var(--button-inverted-text-shadow);\n    --button-blue-text-color: var(--button-inverted-text-color);\n    --button-blue-text-shadow: var(--button-inverted-text-shadow);\n    --button-violet-text-color: var(--button-inverted-text-color);\n    --button-violet-text-shadow: var(--button-inverted-text-shadow);\n    --button-purple-text-color: var(--button-inverted-text-color);\n    --button-purple-text-shadow: var(--button-inverted-text-shadow);\n    --button-pink-text-color: var(--button-inverted-text-color);\n    --button-pink-text-shadow: var(--button-inverted-text-shadow);\n    --button-black-text-color: var(--button-inverted-text-color);\n    --button-black-text-shadow: var(--button-inverted-text-shadow);\n    --button-olive-text-color: var(--button-inverted-text-color);\n    --button-olive-text-shadow: var(--button-inverted-text-shadow);\n    --button-yellow-text-color: var(--button-inverted-text-color);\n    --button-yellow-text-shadow: var(--button-inverted-text-shadow);\n    --button-teal-text-color: var(--button-inverted-text-color);\n    --button-teal-text-shadow: var(--button-inverted-text-shadow);\n    --button-grey-text-color: var(--button-inverted-text-color);\n    --button-grey-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-brown-text-color: var(--button-inverted-text-color);\n    --button-light-brown-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-red-text-color: var(--button-inverted-text-color);\n    --button-light-red-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-orange-text-color: var(--button-inverted-text-color);\n    --button-light-orange-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-green-text-color: var(--button-inverted-text-color);\n    --button-light-green-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-blue-text-color: var(--button-inverted-text-color);\n    --button-light-blue-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-violet-text-color: var(--button-inverted-text-color);\n    --button-light-violet-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-purple-text-color: var(--button-inverted-text-color);\n    --button-light-purple-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-pink-text-color: var(--button-inverted-text-color);\n    --button-light-pink-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-black-text-color: var(--button-inverted-text-color);\n    --button-light-black-text-shadow: var(--button-inverted-text-shadow);\n    --button-light-olive-text-color: var(--button-text-color);\n    --button-light-olive-text-shadow: var(--button-text-shadow);\n    --button-light-yellow-text-color: var(--button-text-color);\n    --button-light-yellow-text-shadow: var(--button-text-shadow);\n    --button-light-teal-text-color: var(--button-text-color);\n    --button-light-teal-text-shadow: var(--button-text-shadow);\n    --button-light-grey-text-color: var(--button-text-color);\n    --button-light-grey-text-shadow: var(--button-text-shadow);\n  }\n}\n\n/* src/components/button/css/theme/variations/compact-variables.css */\n@layer button.theme.variations.compact {\n  :host {\n    --button-compact-vertical-padding: var(--6px);\n    --button-compact-horizontal-padding: var(--8px);\n    --button-compact-icon-padding: var(--button-compact-vertical-padding);\n    --button-very-compact-reduction-factor: 0.4;\n    --button-very-compact-vertical-padding: var(--5px);\n    --button-very-compact-horizontal-padding: var(--5px);\n    --button-very-compact-icon-padding: var(--button-very-compact-vertical-padding);\n  }\n}\n\n/* src/components/button/css/theme/variations/floated-variables.css */\n@layer button.theme.variations.floated {\n  :host {\n    --button-floated-margin: 0.25em;\n  }\n}\n\n/* src/components/button/css/theme/variations/fluid-variables.css */\n@layer button.theme.variations.fluid {\n  ui-button {\n  }\n}\n\n/* src/components/button/css/theme/variations/negative-variables.css */\n@layer button.theme.variations.negative {\n  :host {\n    --button-negative-color: var(--negative-color);\n    --button-negative-background-image: var(--button-colored-background-image);\n    --button-negative-text-color: var(--button-inverted-text-color);\n    --button-negative-text-shadow: var(--button-inverted-text-shadow);\n    --button-negative-box-shadow: var(--button-colored-box-shadow);\n    --button-negative-color-hover: oklch(from var(--button-negative-color) calc(l + var(--hover-lightness)) c h);\n    --button-negative-color-focus: oklch(from var(--button-negative-color) calc(l + var(--focus-lightness)) c h);\n    --button-negative-color-down: oklch(from var(--button-negative-color) calc(l + var(--down-lightness)) c h);\n    --button-negative-color-active: oklch(from var(--button-negative-color) calc(l + var(--active-lightness)) c h);\n    --button-subtle-negative-color: #FFFAFA;\n    --button-subtle-negative-background-image: var(--button-colored-background-image);\n    --button-subtle-negative-text-color: rgba(145, 50, 50, 0.9);\n    --button-subtle-negative-text-shadow: var(--button-text-shadow);\n    --button-subtle-negative-box-shadow: var(--button-box-shadow);\n    --button-subtle-negative-color-hover: #FFEAEA;\n    --button-subtle-negative-color-focus: #FFEAEA;\n    --button-subtle-negative-color-down: #FFEAEA;\n    --button-subtle-negative-color-active: #F1FFF7;\n  }\n}\n\n/* src/components/button/css/theme/variations/warning-variables.css */\n@layer button.theme.variations.warning {\n  :host {\n    --button-warning-color: var(--warning-color);\n    --button-warning-background-image: var(--button-colored-background-image);\n    --button-warning-text-color: var(--button-inverted-text-color);\n    --button-warning-text-shadow: var(--button-inverted-text-shadow);\n    --button-warning-box-shadow: var(--button-colored-box-shadow);\n    --button-warning-color-hover: oklch(from var(--button-warning-color) calc(l + var(--hover-lightness)) c h);\n    --button-warning-color-focus: oklch(from var(--button-warning-color) calc(l + var(--focus-lightness)) c h);\n    --button-warning-color-down: oklch(from var(--button-warning-color) calc(l + var(--down-lightness)) c h);\n    --button-warning-color-active: oklch(from var(--button-warning-color) calc(l + var(--active-lightness)) c h);\n    --button-subtle-warning-color: #FFFDF5;\n    --button-subtle-warning-background-image: var(--button-colored-background-image);\n    --button-subtle-warning-text-color: rgba(135, 105, 23, 0.9);\n    --button-subtle-warning-text-shadow: var(--button-text-shadow);\n    --button-subtle-warning-box-shadow: var(--button-box-shadow);\n    --button-subtle-warning-color-hover: #FFF5DD;\n    --button-subtle-warning-color-focus: #FFF5DD;\n    --button-subtle-warning-color-down: #FFF5DD;\n    --button-subtle-warning-color-active: #FFFDEA;\n  }\n}\n\n/* src/components/button/css/theme/variations/info-variables.css */\n@layer button.theme.variations.info {\n  :host {\n    --button-info-color: var(--info-color);\n    --button-info-background-image: var(--button-colored-background-image);\n    --button-info-text-color: var(--button-inverted-text-color);\n    --button-info-text-shadow: var(--button-inverted-text-shadow);\n    --button-info-box-shadow: var(--button-colored-box-shadow);\n    --button-info-color-hover: oklch(from var(--button-info-color) calc(l + var(--hover-lightness)) c h);\n    --button-info-color-focus: oklch(from var(--button-info-color) calc(l + var(--focus-lightness)) c h);\n    --button-info-color-down: oklch(from var(--button-info-color) calc(l + var(--down-lightness)) c h);\n    --button-info-color-active: oklch(from var(--button-info-color) calc(l + var(--active-lightness)) c h);\n    --button-subtle-info-color: #F8FEFF;\n    --button-subtle-info-background-image: var(--button-colored-background-image);\n    --button-subtle-info-text-color: rgba(23, 94, 135, 0.9);\n    --button-subtle-info-text-shadow: var(--button-text-shadow);\n    --button-subtle-info-box-shadow: var(--button-box-shadow);\n    --button-subtle-info-color-hover: #DEFBFF;\n    --button-subtle-info-color-focus: #DEFBFF;\n    --button-subtle-info-color-down: #DEFBFF;\n    --button-subtle-info-color-active: #E4FBFF;\n  }\n}\n\n/* src/components/button/css/theme/variations/positive-variables.css */\n@layer button.theme.variations.positive {\n  :host {\n    --button-positive-color: var(--positive-color);\n    --button-positive-background-image: var(--button-colored-background-image);\n    --button-positive-text-color: var(--button-inverted-text-color);\n    --button-positive-text-shadow: var(--button-inverted-text-shadow);\n    --button-positive-box-shadow: var(--button-colored-box-shadow);\n    --button-positive-color-hover: oklch(from var(--positive-color) calc(l + var(--hover-lightness)) c h);\n    --button-positive-color-focus: oklch(from var(--positive-color) calc(l + var(--focus-lightness)) c h);\n    --button-positive-color-down: oklch(from var(--positive-color) calc(l + var(--down-lightness)) c h);\n    --button-positive-color-active: oklch(from var(--positive-color) calc(l + var(--active-lightness)) c h);\n    --button-subtle-positive-color: #F3FFF6;\n    --button-subtle-positive-background-image: var(--button-colored-background-image);\n    --button-subtle-positive-text-color: rgba(38, 127, 81, 0.9);\n    --button-subtle-positive-text-shadow: var(--button-text-shadow);\n    --button-subtle-positive-box-shadow: var(--button-box-shadow);\n    --button-subtle-positive-color-hover: #EAFFEA;\n    --button-subtle-positive-color-focus: #EAFFEA;\n    --button-subtle-positive-color-down: #EAFFEA;\n    --button-subtle-positive-color-active: #F1FFF7;\n  }\n}\n\n/* src/components/button/css/theme/variations/sizing-variables.css */\n@layer button.theme.variations.sizing {\n  :host {\n    --button-mini: var(--mini);\n    --button-tiny: var(--tiny);\n    --button-small: var(--small);\n    --button-medium: inherit;\n    --button-large: var(--large);\n    --button-big: var(--big);\n    --button-huge: var(--huge);\n    --button-massive: var(--massive);\n  }\n}\n\n/* src/components/button/css/theme/variations/social-variables.css */\n@layer button.theme.variations.social {\n  :host {\n    --button-instagram-background-image: var(--instagram-gradient);\n    --facebook-hover-color: oklch(from var(--facebook-color) calc(l - 0.05) c calc(h + 10));\n    --twitter-hover-color: oklch(from var(--twitter-color) calc(l - 0.05) c calc(h + 10));\n    --linked-in-hover-color: oklch(from var(--linked-in-color) calc(l - 0.05) c calc(h + 10));\n    --youtube-hover-color: oklch(from var(--youtube-color) calc(l - 0.05) c calc(h + 10));\n    --instagram-hover-color: oklch(from var(--instagram-color) calc(l - 0.05) c calc(h + 10));\n    --pinterest-hover-color: oklch(from var(--pinterest-color) calc(l - 0.05) c calc(h + 10));\n    --facebook-down-color: oklch(from var(--facebook-color) calc(l - 0.1) c h);\n    --twitter-down-color: oklch(from var(--twitter-color) calc(l - 0.1) c h);\n    --linked-in-down-color: oklch(from var(--linked-in-color) calc(l - 0.1) c h);\n    --youtube-down-color: oklch(from var(--youtube-color) calc(l - 0.1) c h);\n    --instagram-down-color: oklch(from var(--instagram-color) calc(l - 0.1) c h);\n    --pinterest-down-color: oklch(from var(--pinterest-color) calc(l - 0.1) c h);\n    --facebook-focus-color: oklch(from var(--facebook-color) calc(l - 0.08) c calc(h + 15));\n    --twitter-focus-color: oklch(from var(--twitter-color) calc(l - 0.08) c calc(h + 15));\n    --linked-in-focus-color: oklch(from var(--linked-in-color) calc(l - 0.08) c calc(h + 15));\n    --youtube-focus-color: oklch(from var(--youtube-color) calc(l - 0.08) c calc(h + 15));\n    --instagram-focus-color: oklch(from var(--instagram-color) calc(l - 0.08) c calc(h + 15));\n    --pinterest-focus-color: oklch(from var(--pinterest-color) calc(l - 0.08) c calc(h + 15));\n  }\n}\n\n/* src/components/button/css/theme/variations/vertical-variables.css */\n@layer button.theme.variations.vertical {\n  ui-button {\n  }\n}\n\n/* src/components/button/css/theme/button-theme.css */\n\n/* src/components/button/css/button.css */\n';

// src/components/button/button.js
var createComponent3 = ({ el, self, settings, data, $: $4 }) => ({
  isIconBefore() {
    return settings.icon && !settings.iconAfter;
  },
  isIconAfter() {
    return settings.icon && settings.iconAfter;
  },
  isSubmitKey(keyCode) {
    const submitKeys = {
      13: "Space",
      32: "Enter"
    };
    return get(submitKeys, String(keyCode));
  },
  performAction() {
    const formActions = ["submit", "reset"];
    if (inArray(settings.type, formActions)) {
      const form = self.getForm();
      if (form) {
        $4(form).trigger(settings.type);
      }
    }
  },
  getForm() {
    return $4(el).closest("form").el();
  },
  isDisabled() {
    return settings.state == "disabled";
  }
});
var events = {
  "touchstart .button"({ event, self, $: $4 }) {
    $4(this).addClass("pressed");
  },
  "touchend .button"({ event, self, $: $4 }) {
    $4(this).removeClass("pressed");
  },
  "click .button"({ event, self, $: $4 }) {
    self.performAction();
    $4(this).blur();
  },
  "keydown .button"({ event, self, $: $4 }) {
    let $button = $4(this);
    if (self.isSubmitKey(event.keyCode)) {
      $button.addClass("pressed");
      self.performAction();
      event.preventDefault();
    }
    if (event.key == "Escape") {
      $button.blur();
    }
  },
  "keyup .button"({ event, self, $: $4 }) {
    let $button = $4(this);
    if (self.isSubmitKey(event.keyCode)) {
      $button.removeClass("pressed");
    }
  }
};
var UIButton = defineComponent({
  tagName: "ui-button",
  componentSpec: button_component_default,
  template: button_default,
  css: button_bundle_default,
  createComponent: createComponent3,
  events
});

// src/components/button/parts/or/button-or.css?raw
var button_or_default = "/*-------------------\n      Or Buttons\n--------------------*/\n:host {\n  align-self: center;\n}\n.or {\n  position: relative;\n  width: var(--button-or-gap);\n  height: var(--button-or-height);\n  z-index: var(--button-or-z-index);\n}\n.or .shape {\n  position: absolute;\n  text-align: center;\n  border-radius: var(--circular-radius);\n\n  top: 50%;\n  left: 50%;\n  background-color: var(--button-or-background-color);\n  text-shadow: var(--button-or-text-shadow);\n\n  margin-top: var(--button-or-vertical-offset);\n  margin-left: var(--button-or-horizontal-offset);\n\n  width: var(--button-or-circle-size);\n  height: var(--button-or-circle-size);\n\n  line-height: var(--button-or-line-height);\n  color: var(--button-or-text-color);\n\n  font-style: var(--button-or-text-style);\n  font-weight: var(--button-or-text-weight);\n\n  box-shadow: var(--button-or-box-shadow);\n}\n\n";

// src/components/button/parts/or/button-or.html?raw
var button_or_default2 = '<div class="{{ui}} or" part="or">\n  <div class="shape"><slot>or</slot></div>\n</div>\n';

// src/components/button/parts/or/button-or.js
var ButtonOr = defineComponent({
  template: button_or_default2,
  css: button_or_default
});

// src/components/button/plural/buttons.html?raw
var buttons_default = '<div class="{{ui}} buttons">\n  {{>slot}}\n</div>\n';

// src/components/button/button-page.css?raw
var button_page_default = "ui-buttons ui-button::part(button) {\n  flex: 1 0 auto;\n  border-radius: 0em;\n  margin: var(--button-group-button-offset);\n}\nui-buttons > ui-button:first-child::part(button) {\n  border-left: none;\n  margin-left: 0em;\n  border-top-left-radius: var(--button-border-radius);\n  border-bottom-left-radius: var(--button-border-radius);\n}\nui-buttons > ui-button:last-child::part(button) {\n  border-top-right-radius: var(--button-border-radius);\n  border-bottom-right-radius: var(--button-border-radius);\n}\n";

// src/components/button/plural/buttons.js
var UIButtons = defineComponent({
  tagName: "ui-buttons",
  singularTag: "ui-button",
  plural: true,
  delegateFocus: true,
  componentSpec: button_component_default,
  template: buttons_default,
  css: button_bundle_default,
  pageCSS: button_page_default
});

// src/components/card/specs/card-component.json
var card_component_default = {
  tagName: "ui-card",
  content: [
    "icon",
    "header",
    "description",
    "subheader",
    "image"
  ],
  contentAttributes: [
    "icon",
    "header",
    "description",
    "subheader",
    "image"
  ],
  variations: [
    "fluid",
    "link",
    "horizontal"
  ],
  states: [
    "hover",
    "focused",
    "disabled"
  ],
  settings: [
    "href"
  ],
  attributes: [
    "icon",
    "header",
    "description",
    "subheader",
    "image",
    "hover",
    "focused",
    "disabled",
    "fluid",
    "link",
    "horizontal",
    "href"
  ],
  optionAttributes: {
    disabled: "disabled",
    "clickable-disabled": "disabled"
  },
  propertyTypes: {
    icon: "string",
    header: "string",
    description: "string",
    subheader: "string",
    image: "string",
    hover: "boolean",
    focused: "boolean",
    disabled: "string",
    fluid: "boolean",
    link: "boolean",
    horizontal: "boolean",
    href: "string"
  },
  allowedValues: {
    disabled: [
      "disabled",
      "clickable-disabled"
    ]
  },
  attributeClasses: [
    "icon",
    "disabled"
  ]
};

// src/components/card/card.html?raw
var card_default = '{#if href}\n  <a class="{ui}card" href="{href}">\n    {> content}\n  </a>\n{else}\n  <div class="{ui}card" part="card">\n    {> content}\n  </div>\n{/if}\n\n{#snippet content}\n  {#if horizontal}\n    {>image}\n    {>icon}\n    <div class="content">\n      {>header}\n      {>subheader}\n      {>description}\n      {> slot}\n    </div>\n  {else}\n    {>image}\n    <div class="content">\n      {>icon}\n      {>header}\n      {>subheader}\n      {>description}\n      {> slot}\n    </div>\n  {/if}\n{/snippet}\n\n{#snippet icon}\n  <div class="icon" part="icon">\n    {#if icon}\n      <ui-icon icon={icon}></ui-icon>\n    {/if}\n    {> slot icon}\n  </div>\n{/snippet}\n\n{#snippet header}\n  <div class="header" part="header">\n    {header}\n    {> slot header}\n  </div>\n{/snippet}\n\n{#snippet subheader}\n  <div class="subheader" part="subheader">\n    {subheader}\n    {> slot subheader}\n  </div>\n{/snippet}\n\n{#snippet image}\n  <div class="image" part="image">\n    {#if image}\n      <img src="{image}" part="image-img">\n    {/if}\n    {> slot image}\n  </div>\n{/snippet}\n\n{#snippet description}\n  <div class="description" part="description">\n    {description}\n    {> slot description}\n  </div>\n{/snippet}\n\n{#snippet meta}\n  <div class="meta" part="meta">\n    {#each value in meta}\n      <span>{value}</span>\n    {/each}\n    {> slot meta}\n  </div>\n{/snippet}\n';

// src/components/card/card-bundle.css?raw
var card_bundle_default = '/**\n  ---DO NOT EDIT THIS FILE DIRECTLY---\n  This CSS file was concatenated from files listed in the css/ folder as part of a build process\n  This is to allow for js import with @import links which will not be followed\n**/\n\n/* src/components/card/css/definition/content/card.css */\n@layer card.definition.content.card {\n  :host {\n    display: inline-block;\n    text-align: var(--card-text-align);\n    margin: var(--card-margin);\n  }\n  .card {\n    display: flex;\n    flex-direction: var(--card-flex-direction);\n    gap: var(--card-gap);\n    text-decoration: none;\n    border-radius: var(--card-border-radius);\n    border: var(--card-border);\n    transition: var(--card-transition);\n    box-shadow: var(--card-box-shadow);\n    background: var(--card-background);\n    padding: var(--card-padding);\n    width: var(--card-width);\n  }\n  .card > :first-child {\n    border-radius: inherit;\n    border-bottom-left-radius: 0;\n    border-bottom-right-radius: 0;\n  }\n  .card > :last-child {\n    border-radius: inherit;\n    border-top-left-radius: 0;\n    border-top-right-radius: 0;\n  }\n}\n\n/* src/components/card/css/definition/content/description.css */\n@layer card.definition.content.description {\n  ::slotted(.description),\n  .description {\n    color: var(--card-description-color);\n    font-size: var(--card-description-font-size);\n    transition: var(--card-description-transition);\n    line-height: var(--card-description-line-height);\n  }\n}\n\n/* src/components/card/css/definition/content/header.css */\n@layer card.definition.content.header {\n  ::slotted(.header),\n  .header {\n    color: var(--card-header-color);\n    font-size: var(--card-header-font-size);\n    font-weight: var(--card-header-font-weight);\n    transition: var(--card-header-transition);\n  }\n}\n\n/* src/components/card/css/definition/content/subheader.css */\n@layer card.definition.content.subheader {\n  ::slotted(.subheader),\n  .subheader {\n    color: var(--card-subheader-color);\n    font-size: var(--card-subheader-font-size);\n    font-weight: var(--card-subheader-font-weight);\n    transition: var(--card-subheader-transition);\n  }\n}\n\n/* src/components/card/css/definition/content/image.css */\n@layer card.definition.content.image {\n  .image {\n    overflow: hidden;\n    margin: var(--card-reverse-padding) var(--card-reverse-padding) 1em;\n  }\n  ::slotted(.image),\n  ::slotted(ui-image),\n  .image img {\n    display: block;\n    width: var(--card-image-width);\n    max-width: var(--card-image-max-width);\n    object-fit: contain;\n  }\n}\n\n/* src/components/card/css/definition/content/icon.css */\n@layer card.definition.content.icon {\n  ::slotted(ui-icon),\n  ::slotted(.icon),\n  .icon ui-icon {\n    font-size: var(--card-icon-font-size);\n    margin: var(--card-icon-margin);\n    color: var(--card-icon-color);\n  }\n}\n\n/* src/components/card/css/definition/content/meta.css */\n@layer card.definition.content.meta {\n  ::slotted(.meta),\n  .meta {\n    margin-top: var(--card-meta-margin);\n    padding-top: var(--card-meta-spacing);\n    border-top: var(--card-meta-border);\n    display: flex;\n    gap: var(--card-meta-gap);\n  }\n  .meta > * {\n    color: var(--card-meta-text-color);\n    font-weight: bold;\n  }\n}\n\n/* src/components/card/css/definition/states/disabled.css */\n@layer card.definition.states.disabled {\n  .disabled {\n    pointer-events: none;\n    opacity: var(--disabled-opacity);\n  }\n  .clickable-disabled {\n    pointer-events: allowed;\n  }\n}\n\n/* src/components/card/css/definition/plural/cards.css */\n@layer card.definition.plural {\n  :host(ui-cards) {\n    display: block;\n    container: host / inline-size;\n    margin: var(--cards-margin);\n  }\n  .component {\n    container: component / inline-size;\n  }\n  .cards {\n    display: grid;\n    gap: var(--cards-gap);\n    grid-auto-rows: 1fr;\n    width: 100%;\n  }\n  ::slotted(ui-card) {\n    display: contents;\n    margin: 0;\n  }\n}\n\n/* src/components/card/css/definition/variations/basic.css */\n@layer card.definition.variations.basic {\n  .basic.card {\n    background: var(--card-basic-background);\n    box-shadow: var(--card-basic-box-shadow);\n    border: var(--card-basic-border);\n  }\n}\n\n/* src/components/card/css/definition/variations/count.css */\n@layer card.definition.variations.count {\n  .cards.one {\n    grid-template-columns: 1fr;\n  }\n  .cards.two {\n    grid-template-columns: repeat(2, 1fr);\n  }\n  .cards.three {\n    grid-template-columns: repeat(3, 1fr);\n  }\n  .cards.four {\n    grid-template-columns: repeat(4, 1fr);\n  }\n  .cards.five {\n    grid-template-columns: repeat(5, 1fr);\n  }\n  .cards.six {\n    grid-template-columns: repeat(6, 1fr);\n  }\n  .cards.seven {\n    grid-template-columns: repeat(7, 1fr);\n  }\n  .cards.eight {\n    grid-template-columns: repeat(8, 1fr);\n  }\n  .cards ::slotted(*) {\n    --card-width: none;\n  }\n}\n\n/* src/components/card/css/definition/variations/fluid.css */\n@layer card.definition.variations.fluid {\n  :host([fluid]),\n  .fluid.card {\n    --card-width: auto;\n    --card-image-max-width: none;\n  }\n}\n\n/* src/components/card/css/definition/variations/horizontal.css */\n@layer card.definition.variations.horizontal {\n  .horizontal {\n    flex-direction: var(--card-horizontal-flex-direction);\n    gap: var(--card-horizontal-gap);\n    text-align: left;\n  }\n  .horizontal ::slotted(.image),\n  .horizontal ::slotted(ui-image),\n  .horizontal .image {\n    margin: var(--card-reverse-padding);\n    max-width: var(--card-horizontal-image-max-width);\n  }\n  .horizontal ::slotted(ui-icon),\n  .horizontal ::slotted(.icon),\n  .horizontal .icon ui-icon {\n    font-size: var(--card-horizontal-icon-font-size);\n    margin: var(--card-horizontal-icon-margin);\n  }\n  .horizontal ::slotted(.header),\n  .horizontal .header {\n    font-size: var(--card-horizontal-header-size);\n  }\n  .horizontal :first-child {\n    border-radius: inherit;\n    border-top-right-radius: 0;\n    border-bottom-right-radius: 0;\n  }\n  .horizontal :last-child {\n    border-radius: inherit;\n    border-top-left-radius: 0;\n    border-bottom-left-radius: 0;\n  }\n}\n\n/* src/components/card/css/definition/variations/link.css */\n@layer card.definition.variations.link {\n  .link.card,\n  a.card {\n    cursor: pointer;\n    color: inherit;\n  }\n  .link.card:hover,\n  a.card:hover {\n    background: var(--card-link-hover-background);\n    box-shadow: var(--card-link-hover-box-shadow);\n    border: var(--card-link-hover-border);\n  }\n  .link.card:hover ::slotted(.header),\n  .link.card:hover .header,\n  a.card:hover ::slotted(.header),\n  a.card:hover .header {\n    color: var(--card-link-hover-header-color);\n  }\n  .link.card:hover ::slotted(ui-icon),\n  .link.card:hover ::slotted(.icon),\n  .link.card:hover .icon ui-icon,\n  a.card:hover ::slotted(ui-icon),\n  a.card:hover ::slotted(.icon),\n  a.card:hover .icon ui-icon {\n    color: var(--card-link-hover-icon-color);\n  }\n}\n\n/* src/components/card/css/definition/variations/spaced.css */\n@layer card.definition.variations.spaced {\n  .cards.spaced {\n    gap: var(--cards-spaced-gap);\n  }\n  .cards.very-spaced {\n    gap: var(--cards-very-spaced-gap);\n  }\n}\n\n/* src/components/card/css/definition/variations/doubling.css */\n@layer card.definition.variations.doubling {\n  @container component (max-width: var(--card-doubling-breakpoint)) {\n    .doubling.cards {\n    }\n  }\n}\n\n/* src/components/card/css/definition/variations/stackable.css */\n@layer card.definition.variations.stackable {\n  .component {\n    --card-stackable-comparison: max(calc(100cqi - var(--card-stackable-breakpoint)), 0px);\n    width: --card-stackable-comparison;\n  }\n  @container component style(--card-stackable-comparison: 0) {\n    .stackable.cards {\n      display: flex;\n      flex-direction: column;\n    }\n  }\n}\n\n/* src/components/card/css/definition/card-definition.css */\n\n/* src/components/card/css/theme/content/card-variables.css */\n@layer card.theme.content.card {\n  :host {\n    --card-margin: 0px 5px 5px 0px;\n    --card-text-align: center;\n    --card-padding: var(--spacing);\n    --card-reverse-padding: calc(var(--spacing) * -1);\n    --card-flex-direction: column;\n    --card-border-radius: var(--border-radius);\n    --card-transition: var(--transition);\n    --card-background: var(--ui-background-emphasis);\n    --card-box-shadow: 0px 0px 5px var(--standard-5);\n    --card-text-align: center;\n    --card-border: var(--internal-border);\n    --card-gap: 0;\n    --card-width: 290px;\n  }\n}\n\n/* src/components/card/css/theme/content/description-variables.css */\n@layer card.theme.content.description {\n  :host {\n    --card-description-font-size: var(--relative-15px);\n    --card-description-color: var(--standard-60);\n    --card-description-line-height: inherit;\n    --card-description-transition: var(--transition);\n  }\n}\n\n/* src/components/card/css/theme/content/header-variables.css */\n@layer card.theme.content.header {\n  :host {\n    --card-header-font-size: var(--relative-20px);\n    --card-header-font-weight: var(--bold);\n    --card-header-transition: var(--transition);\n    --card-header-color: var(--standard-100);\n  }\n}\n\n/* src/components/card/css/theme/content/subheader-variables.css */\n@layer card.theme.content.subheader {\n  :host {\n    --card-subheader-font-size: var(--relative-16px);\n    --card-subheader-font-weight: var(--bold);\n    --card-subheader-transition: var(--transition);\n    --card-subheader-color: var(--standard-80);\n  }\n}\n\n/* src/components/card/css/theme/content/image-variables.css */\n@layer card.theme.content.image {\n  :host {\n    --card-image-margin: -1.5em -1.5em 1.5em;\n    --card-image-width: 100%;\n    --card-image-max-width: 100%;\n  }\n}\n\n/* src/components/card/css/theme/content/icon-variables.css */\n@layer card.theme.content.icon {\n  :host {\n    --card-icon-font-size: var(--relative-32px);\n    --card-icon-color: var(--standard-40);\n    --card-icon-margin: 0 0 var(--compact-spacing) 0;\n  }\n}\n\n/* src/components/card/css/theme/content/meta-variables.css */\n@layer card.theme.content.meta {\n  :host {\n    --card-meta-margin: var(--compact-spacing) 0 0;\n    --card-meta-padding: var(--compact-spacing) 0 0;\n    --card-meta-border: var(--border);\n    --card-meta-gap: var(--compact-spacing);\n    --card-meta-text-color: var(--standard-90);\n  }\n}\n\n/* src/components/card/css/theme/plural/cards-variables.css */\n@layer card.theme.plural {\n  :host {\n    --cards-gap: var(--spacing);\n    --cards-margin: var(--vertical-spacing);\n  }\n}\n\n/* src/components/card/css/theme/variations/basic-variables.css */\n@layer card.theme.variations.basic {\n  :host {\n    --card-basic-background: transparent;\n    --card-basic-box-shadow: var(--floating-shadow);\n    --card-basic-border: var(--card-border);\n  }\n}\n\n/* src/components/card/css/theme/variations/count-variables.css */\n@layer card.theme.variations.count;\n\n/* src/components/card/css/theme/variations/fluid-variables.css */\n@layer card.theme.variations.fluid {\n  :host {\n  }\n}\n\n/* src/components/card/css/theme/variations/horizontal-variables.css */\n@layer card.theme.variations.horizontal {\n  :host {\n    --card-horizontal-flex-direction: row;\n    --card-horizontal-gap: var(--padding);\n    --card-horizontal-image-max-width: 125px;\n    --card-horizontal-icon-size: var(--massive);\n    --card-horizontal-icon-margin: 0 0 0 var(--spacing);\n    --card-horizontal-header-size: var(--large);\n    --card-horizontal-icon-font-size: var(--massive);\n  }\n}\n\n/* src/components/card/css/theme/variations/link-variables.css */\n@layer card.theme.variations.link {\n  :host {\n    --card-link-hover-background: oklch(0.98 0.01 227.13);\n    --card-link-hover-box-shadow: 0px 0px 5px var(--standard-5);\n    --card-link-hover-border: 1px solid var(--primary-text-color);\n    --card-link-hover-header-color: var(--primary-text-color);\n    --card-link-hover-icon-color: var(--primary-text-color);\n  }\n  @container style(--dark-mode: true) {\n    .card {\n      --card-link-hover-background: oklch(0.17 0.04 225.68);\n      --card-link-hover-box-shadow: oklch(0.58 0.14 233.34 / 0.25) 0px 0px 7px 2px;\n      --card-link-hover-border: 1px solid var(--primary-text-color);\n    }\n  }\n}\n\n/* src/components/card/css/theme/variations/spaced-variables.css */\n@layer card.theme.variations.spaced {\n  :host {\n    --cards-spaced-gap: 2rem;\n    --cards-very-spaced-gap: 3rem;\n  }\n}\n\n/* src/components/card/css/theme/variations/doubling-variables.css */\n@layer card.theme.variations.doubling {\n  :host {\n  }\n}\n\n/* src/components/card/css/theme/variations/stackable-variables.css */\n@layer card.theme.variations.stackable {\n  @property --card-stackable-comparison { syntax: "<length>"; inherits: true; initial-value: 1px; }\n  :host {\n    --card-stackable-breakpoint: var(--largest-mobile-screen);\n  }\n}\n\n/* src/components/card/css/theme/card-theme.css */\n\n/* src/components/card/css/card.css */\n';

// src/components/card/card-page.css?raw
var card_page_default = '/* CSS Properties must be declared in global scope */\n@property --card-stackable-comparison {\n  syntax: "<length>";\n  inherits: true;\n  initial-value: 1px;\n}\n';

// src/components/card/card.js
var createComponent4 = ({ $: $4 }) => ({});
var UICard = defineComponent({
  tagName: "ui-card",
  componentSpec: card_component_default,
  template: card_default,
  css: card_bundle_default,
  pageCSS: card_page_default,
  createComponent: createComponent4
});

// src/components/card/specs/cards-component.json
var cards_component_default = {
  tagName: "ui-cards",
  variations: [
    "doubling",
    "stackable",
    "spaced",
    "count"
  ],
  attributes: [
    "doubling",
    "stackable",
    "spaced",
    "count"
  ],
  optionAttributes: {
    spaced: "spaced",
    "very-spaced": "spaced",
    two: "count",
    three: "count",
    four: "count",
    five: "count",
    six: "count"
  },
  propertyTypes: {
    doubling: "boolean",
    stackable: "boolean",
    spaced: "string",
    count: "string"
  },
  allowedValues: {
    spaced: [
      "spaced",
      "very-spaced"
    ],
    count: [
      "two",
      "three",
      "four",
      "five",
      "six"
    ]
  }
};

// src/components/card/plural/cards.html?raw
var cards_default = '<div class="component">\n  <div class="{{ui}}cards" part="cards">\n    {{>slot}}\n  </div>\n</div>\n';

// src/components/card/plural/cards.js
var UICards = defineComponent({
  tagName: "ui-cards",
  singularTag: "ui-card",
  plural: true,
  delegateFocus: true,
  componentSpec: cards_component_default,
  template: cards_default,
  css: card_bundle_default
});

// src/components/icon/specs/icon-component.json
var icon_component_default = {
  tagName: "ui-icon",
  content: [
    "icon"
  ],
  contentAttributes: [
    "icon"
  ],
  variations: [
    "link",
    "fitted",
    "colored",
    "size",
    "spin",
    "inverted"
  ],
  states: [
    "disabled",
    "loading"
  ],
  settings: [
    "href",
    "target"
  ],
  attributes: [
    "icon",
    "disabled",
    "loading",
    "link",
    "fitted",
    "colored",
    "size",
    "spin",
    "inverted",
    "href",
    "target"
  ],
  optionAttributes: {
    airplay: "icon",
    "alert-circle": "icon",
    "alert-octagon": "icon",
    "alert-triangle": "icon",
    "align-center": "icon",
    "align-justify": "icon",
    "align-left": "icon",
    "align-right": "icon",
    anchor: "icon",
    aperture: "icon",
    archive: "icon",
    "arrow-down": "icon",
    "arrow-down-circle": "icon",
    "arrow-down-left": "icon",
    "arrow-down-right": "icon",
    "arrow-left": "icon",
    "arrow-left-circle": "icon",
    "arrow-right": "icon",
    "arrow-right-circle": "icon",
    "arrow-up": "icon",
    "arrow-up-circle": "icon",
    "arrow-up-left": "icon",
    "arrow-up-right": "icon",
    "at-sign": "icon",
    award: "icon",
    "bar-chart": "icon",
    "bar-chart-2": "icon",
    battery: "icon",
    "battery-charging": "icon",
    bell: "icon",
    "bell-off": "icon",
    bluetooth: "icon",
    bold: "icon",
    book: "icon",
    "book-open": "icon",
    bookmark: "icon",
    box: "icon",
    briefcase: "icon",
    calendar: "icon",
    camera: "icon",
    "camera-off": "icon",
    cast: "icon",
    check: "icon",
    "check-circle": "icon",
    "check-square": "icon",
    "chevron-down": "icon",
    "chevron-left": "icon",
    "chevron-right": "icon",
    "chevron-up": "icon",
    "chevrons-down": "icon",
    "chevrons-left": "icon",
    "chevrons-right": "icon",
    "chevrons-up": "icon",
    chrome: "icon",
    circle: "icon",
    clipboard: "icon",
    clock: "icon",
    cloud: "icon",
    "cloud-drizzle": "icon",
    "cloud-lightning": "icon",
    "cloud-off": "icon",
    "cloud-rain": "icon",
    "cloud-snow": "icon",
    code: "icon",
    codepen: "icon",
    codesandbox: "icon",
    coffee: "icon",
    columns: "icon",
    command: "icon",
    compass: "icon",
    copy: "icon",
    "corner-down-left": "icon",
    "corner-down-right": "icon",
    "corner-left-down": "icon",
    "corner-left-up": "icon",
    "corner-right-down": "icon",
    "corner-right-up": "icon",
    "corner-up-left": "icon",
    "corner-up-right": "icon",
    cpu: "icon",
    "credit-card": "icon",
    crop: "icon",
    crosshair: "icon",
    currentColor: "icon",
    database: "icon",
    delete: "icon",
    disc: "icon",
    divide: "icon",
    "divide-circle": "icon",
    "divide-square": "icon",
    "dollar-sign": "icon",
    download: "icon",
    "download-cloud": "icon",
    dribbble: "icon",
    droplet: "icon",
    edit: "icon",
    "edit-2": "icon",
    "edit-3": "icon",
    "external-link": "icon",
    eye: "icon",
    "eye-off": "icon",
    facebook: "icon",
    "fast-forward": "icon",
    feather: "icon",
    figma: "icon",
    file: "icon",
    "file-minus": "icon",
    "file-plus": "icon",
    "file-text": "icon",
    film: "icon",
    filter: "icon",
    flag: "icon",
    folder: "icon",
    "folder-minus": "icon",
    "folder-plus": "icon",
    framer: "icon",
    frown: "icon",
    github: "icon",
    gitlab: "icon",
    globe: "icon",
    grid: "icon",
    "hard-drive": "icon",
    hash: "icon",
    headphones: "icon",
    heart: "icon",
    "help-circle": "icon",
    hexagon: "icon",
    home: "icon",
    image: "icon",
    inbox: "icon",
    info: "icon",
    instagram: "icon",
    italic: "icon",
    key: "icon",
    layers: "icon",
    layout: "icon",
    "life-buoy": "icon",
    linkify: "icon",
    "linkify-2": "icon",
    linkedin: "icon",
    list: "icon",
    loader: "icon",
    lock: "icon",
    "log-in": "icon",
    "log-out": "icon",
    mail: "icon",
    map: "icon",
    "map-pin": "icon",
    maximize: "icon",
    "maximize-2": "icon",
    meh: "icon",
    menu: "icon",
    "message-circle": "icon",
    "message-square": "icon",
    mic: "icon",
    "mic-off": "icon",
    minimize: "icon",
    "minimize-2": "icon",
    minus: "icon",
    "minus-circle": "icon",
    "minus-square": "icon",
    monitor: "icon",
    moon: "icon",
    "more-horizontal": "icon",
    "more-vertical": "icon",
    "mouse-pointer": "icon",
    move: "icon",
    music: "icon",
    navigation: "icon",
    "navigation-2": "icon",
    octagon: "icon",
    package: "icon",
    paperclip: "icon",
    pause: "icon",
    "pause-circle": "icon",
    "pen-tool": "icon",
    percent: "icon",
    phone: "icon",
    "phone-call": "icon",
    "phone-forwarded": "icon",
    "phone-incoming": "icon",
    "phone-missed": "icon",
    "phone-off": "icon",
    "phone-outgoing": "icon",
    "pie-chart": "icon",
    play: "icon",
    "play-circle": "icon",
    plus: "icon",
    "plus-circle": "icon",
    "plus-square": "icon",
    pocket: "icon",
    power: "icon",
    printer: "icon",
    radio: "icon",
    "refresh-ccw": "icon",
    "refresh-cw": "icon",
    repeat: "icon",
    rewind: "icon",
    "rotate-ccw": "icon",
    "rotate-cw": "icon",
    rss: "icon",
    save: "icon",
    scissors: "icon",
    search: "icon",
    send: "icon",
    server: "icon",
    settings: "icon",
    share: "icon",
    "share-2": "icon",
    shield: "icon",
    "shield-off": "icon",
    "shopping-bag": "icon",
    "shopping-cart": "icon",
    shuffle: "icon",
    sidebar: "icon",
    "skip-back": "icon",
    "skip-forward": "icon",
    slack: "icon",
    slash: "icon",
    sliders: "icon",
    smartphone: "icon",
    smile: "icon",
    speaker: "icon",
    square: "icon",
    star: "icon",
    "stop-circle": "icon",
    sun: "icon",
    sunrise: "icon",
    sunset: "icon",
    table: "icon",
    tablet: "icon",
    tag: "icon",
    target: "icon",
    terminal: "icon",
    thermometer: "icon",
    "thumbs-down": "icon",
    "thumbs-up": "icon",
    "toggle-left": "icon",
    "toggle-right": "icon",
    tool: "icon",
    trash: "icon",
    "trash-2": "icon",
    trello: "icon",
    "trending-down": "icon",
    "trending-up": "icon",
    triangle: "icon",
    truck: "icon",
    tv: "icon",
    twitch: "icon",
    twitter: "icon",
    type: "icon",
    umbrella: "icon",
    underline: "icon",
    unlock: "icon",
    upload: "icon",
    "upload-cloud": "icon",
    user: "icon",
    "user-check": "icon",
    "user-minus": "icon",
    "user-plus": "icon",
    "user-x": "icon",
    users: "icon",
    video: "icon",
    "video-off": "icon",
    voicemail: "icon",
    volume: "icon",
    "volume-1": "icon",
    "volume-2": "icon",
    "volume-x": "icon",
    watch: "icon",
    wifi: "icon",
    "wifi-off": "icon",
    wind: "icon",
    x: "icon",
    "x-circle": "icon",
    "x-octagon": "icon",
    "x-square": "icon",
    youtube: "icon",
    zap: "icon",
    "zap-off": "icon",
    "zoom-in": "icon",
    "zoom-out": "icon",
    red: "colored",
    orange: "colored",
    yellow: "colored",
    olive: "colored",
    green: "colored",
    teal: "colored",
    blue: "colored",
    violet: "colored",
    purple: "colored",
    pink: "colored",
    brown: "colored",
    grey: "colored",
    black: "colored",
    mini: "size",
    tiny: "size",
    small: "size",
    medium: "size",
    large: "size",
    big: "size",
    huge: "size",
    massive: "size"
  },
  propertyTypes: {
    icon: "string",
    disabled: "boolean",
    loading: "boolean",
    link: "boolean",
    fitted: "boolean",
    colored: "string",
    size: "string",
    spin: "boolean",
    inverted: "boolean",
    href: "string",
    target: "string"
  },
  allowedValues: {
    icon: [
      "airplay",
      "alert-circle",
      "alert-octagon",
      "alert-triangle",
      "align-center",
      "align-justify",
      "align-left",
      "align-right",
      "anchor",
      "aperture",
      "archive",
      "arrow-down",
      "arrow-down-circle",
      "arrow-down-left",
      "arrow-down-right",
      "arrow-left",
      "arrow-left-circle",
      "arrow-right",
      "arrow-right-circle",
      "arrow-up",
      "arrow-up-circle",
      "arrow-up-left",
      "arrow-up-right",
      "at-sign",
      "award",
      "bar-chart",
      "bar-chart-2",
      "battery",
      "battery-charging",
      "bell",
      "bell-off",
      "bluetooth",
      "bold",
      "book",
      "book-open",
      "bookmark",
      "box",
      "briefcase",
      "calendar",
      "camera",
      "camera-off",
      "cast",
      "check",
      "check-circle",
      "check-square",
      "chevron-down",
      "chevron-left",
      "chevron-right",
      "chevron-up",
      "chevrons-down",
      "chevrons-left",
      "chevrons-right",
      "chevrons-up",
      "chrome",
      "circle",
      "clipboard",
      "clock",
      "cloud",
      "cloud-drizzle",
      "cloud-lightning",
      "cloud-off",
      "cloud-rain",
      "cloud-snow",
      "code",
      "codepen",
      "codesandbox",
      "coffee",
      "columns",
      "command",
      "compass",
      "copy",
      "corner-down-left",
      "corner-down-right",
      "corner-left-down",
      "corner-left-up",
      "corner-right-down",
      "corner-right-up",
      "corner-up-left",
      "corner-up-right",
      "cpu",
      "credit-card",
      "crop",
      "crosshair",
      "currentColor",
      "database",
      "delete",
      "disc",
      "divide",
      "divide-circle",
      "divide-square",
      "dollar-sign",
      "download",
      "download-cloud",
      "dribbble",
      "droplet",
      "edit",
      "edit-2",
      "edit-3",
      "external-link",
      "eye",
      "eye-off",
      "facebook",
      "fast-forward",
      "feather",
      "figma",
      "file",
      "file-minus",
      "file-plus",
      "file-text",
      "film",
      "filter",
      "flag",
      "folder",
      "folder-minus",
      "folder-plus",
      "framer",
      "frown",
      "github",
      "gitlab",
      "globe",
      "grid",
      "hard-drive",
      "hash",
      "headphones",
      "heart",
      "help-circle",
      "hexagon",
      "home",
      "image",
      "inbox",
      "info",
      "instagram",
      "italic",
      "key",
      "layers",
      "layout",
      "life-buoy",
      "linkify",
      "linkify-2",
      "linkedin",
      "list",
      "loader",
      "lock",
      "log-in",
      "log-out",
      "mail",
      "map",
      "map-pin",
      "maximize",
      "maximize-2",
      "meh",
      "menu",
      "message-circle",
      "message-square",
      "mic",
      "mic-off",
      "minimize",
      "minimize-2",
      "minus",
      "minus-circle",
      "minus-square",
      "monitor",
      "moon",
      "more-horizontal",
      "more-vertical",
      "mouse-pointer",
      "move",
      "music",
      "navigation",
      "navigation-2",
      "octagon",
      "package",
      "paperclip",
      "pause",
      "pause-circle",
      "pen-tool",
      "percent",
      "phone",
      "phone-call",
      "phone-forwarded",
      "phone-incoming",
      "phone-missed",
      "phone-off",
      "phone-outgoing",
      "pie-chart",
      "play",
      "play-circle",
      "plus",
      "plus-circle",
      "plus-square",
      "pocket",
      "power",
      "printer",
      "radio",
      "refresh-ccw",
      "refresh-cw",
      "repeat",
      "rewind",
      "rotate-ccw",
      "rotate-cw",
      "rss",
      "save",
      "scissors",
      "search",
      "send",
      "server",
      "settings",
      "share",
      "share-2",
      "shield",
      "shield-off",
      "shopping-bag",
      "shopping-cart",
      "shuffle",
      "sidebar",
      "skip-back",
      "skip-forward",
      "slack",
      "slash",
      "sliders",
      "smartphone",
      "smile",
      "speaker",
      "square",
      "star",
      "stop-circle",
      "sun",
      "sunrise",
      "sunset",
      "table",
      "tablet",
      "tag",
      "target",
      "terminal",
      "thermometer",
      "thumbs-down",
      "thumbs-up",
      "toggle-left",
      "toggle-right",
      "tool",
      "trash",
      "trash-2",
      "trello",
      "trending-down",
      "trending-up",
      "triangle",
      "truck",
      "tv",
      "twitch",
      "twitter",
      "type",
      "umbrella",
      "underline",
      "unlock",
      "upload",
      "upload-cloud",
      "user",
      "user-check",
      "user-minus",
      "user-plus",
      "user-x",
      "users",
      "video",
      "video-off",
      "voicemail",
      "volume",
      "volume-1",
      "volume-2",
      "volume-x",
      "watch",
      "wifi",
      "wifi-off",
      "wind",
      "x",
      "x-circle",
      "x-octagon",
      "x-square",
      "youtube",
      "zap",
      "zap-off",
      "zoom-in",
      "zoom-out"
    ],
    colored: [
      "red",
      "orange",
      "yellow",
      "olive",
      "green",
      "teal",
      "blue",
      "violet",
      "purple",
      "pink",
      "brown",
      "grey",
      "black"
    ],
    size: [
      "mini",
      "tiny",
      "small",
      "medium",
      "large",
      "big",
      "huge",
      "massive"
    ]
  }
};

// src/components/icon/icon-bundle.css?raw
var icon_bundle_default = `/**
  ---DO NOT EDIT THIS FILE DIRECTLY---
  This CSS file was concatenated from files listed in the css/ folder as part of a build process
  This is to allow for js import with @import links which will not be followed
**/

/* src/components/icon/css/definition/content/icon.css */
@layer icon.definition.singular {
  :host {
    display: inline-block;
    height: 1em;
    font-style: normal;
    font-weight: normal;
    text-decoration: inherit;
    text-align: center;
    margin: 0em var(--icon-distance-from-text) 0em 0em;
    font-size: inherit;
    vertical-align: text-top;
  }
  .icon {
    display: inherit;
    vertical-align: top;
    opacity: var(--icon-opacity);
    width: var(--icon-width);
    height: var(--icon-height);
    background-color: currentColor;
    -webkit-mask-image: linear-gradient(transparent, transparent);
    mask-image: linear-gradient(transparent, transparent);
    -webkit-mask-repeat: no-repeat;
    mask-repeat: no-repeat;
    -webkit-mask-size: 100% 100%;
    mask-size: 100% 100%;
    backface-visibility: hidden;
    fill: currentColor;
    speak: none;
  }
  .icon.activity {
    -webkit-mask-image: var(--icon-activity-svg);
    mask-image: var(--icon-activity-svg);
  }
  .icon.airplay {
    -webkit-mask-image: var(--icon-airplay-svg);
    mask-image: var(--icon-airplay-svg);
  }
  .icon.alert-circle {
    -webkit-mask-image: var(--icon-alert-circle-svg);
    mask-image: var(--icon-alert-circle-svg);
  }
  .icon.alert-octagon {
    -webkit-mask-image: var(--icon-alert-octagon-svg);
    mask-image: var(--icon-alert-octagon-svg);
  }
  .icon.alert-triangle {
    -webkit-mask-image: var(--icon-alert-triangle-svg);
    mask-image: var(--icon-alert-triangle-svg);
  }
  .icon.align-center {
    -webkit-mask-image: var(--icon-align-center-svg);
    mask-image: var(--icon-align-center-svg);
  }
  .icon.align-justify {
    -webkit-mask-image: var(--icon-align-justify-svg);
    mask-image: var(--icon-align-justify-svg);
  }
  .icon.align-left {
    -webkit-mask-image: var(--icon-align-left-svg);
    mask-image: var(--icon-align-left-svg);
  }
  .icon.align-right {
    -webkit-mask-image: var(--icon-align-right-svg);
    mask-image: var(--icon-align-right-svg);
  }
  .icon.anchor {
    -webkit-mask-image: var(--icon-anchor-svg);
    mask-image: var(--icon-anchor-svg);
  }
  .icon.aperture {
    -webkit-mask-image: var(--icon-aperture-svg);
    mask-image: var(--icon-aperture-svg);
  }
  .icon.archive {
    -webkit-mask-image: var(--icon-archive-svg);
    mask-image: var(--icon-archive-svg);
  }
  .icon.arrow-down-circle {
    -webkit-mask-image: var(--icon-arrow-down-circle-svg);
    mask-image: var(--icon-arrow-down-circle-svg);
  }
  .icon.arrow-down-left {
    -webkit-mask-image: var(--icon-arrow-down-left-svg);
    mask-image: var(--icon-arrow-down-left-svg);
  }
  .icon.arrow-down-right {
    -webkit-mask-image: var(--icon-arrow-down-right-svg);
    mask-image: var(--icon-arrow-down-right-svg);
  }
  .icon.arrow-down {
    -webkit-mask-image: var(--icon-arrow-down-svg);
    mask-image: var(--icon-arrow-down-svg);
  }
  .icon.arrow-left-circle {
    -webkit-mask-image: var(--icon-arrow-left-circle-svg);
    mask-image: var(--icon-arrow-left-circle-svg);
  }
  .icon.arrow-left {
    -webkit-mask-image: var(--icon-arrow-left-svg);
    mask-image: var(--icon-arrow-left-svg);
  }
  .icon.arrow-right-circle {
    -webkit-mask-image: var(--icon-arrow-right-circle-svg);
    mask-image: var(--icon-arrow-right-circle-svg);
  }
  .icon.arrow-right {
    -webkit-mask-image: var(--icon-arrow-right-svg);
    mask-image: var(--icon-arrow-right-svg);
  }
  .icon.arrow-up-circle {
    -webkit-mask-image: var(--icon-arrow-up-circle-svg);
    mask-image: var(--icon-arrow-up-circle-svg);
  }
  .icon.arrow-up-left {
    -webkit-mask-image: var(--icon-arrow-up-left-svg);
    mask-image: var(--icon-arrow-up-left-svg);
  }
  .icon.arrow-up-right {
    -webkit-mask-image: var(--icon-arrow-up-right-svg);
    mask-image: var(--icon-arrow-up-right-svg);
  }
  .icon.arrow-up {
    -webkit-mask-image: var(--icon-arrow-up-svg);
    mask-image: var(--icon-arrow-up-svg);
  }
  .icon.at-sign {
    -webkit-mask-image: var(--icon-at-sign-svg);
    mask-image: var(--icon-at-sign-svg);
  }
  .icon.award {
    -webkit-mask-image: var(--icon-award-svg);
    mask-image: var(--icon-award-svg);
  }
  .icon.bar-chart-2 {
    -webkit-mask-image: var(--icon-bar-chart-2-svg);
    mask-image: var(--icon-bar-chart-2-svg);
  }
  .icon.bar-chart {
    -webkit-mask-image: var(--icon-bar-chart-svg);
    mask-image: var(--icon-bar-chart-svg);
  }
  .icon.battery-charging {
    -webkit-mask-image: var(--icon-battery-charging-svg);
    mask-image: var(--icon-battery-charging-svg);
  }
  .icon.battery {
    -webkit-mask-image: var(--icon-battery-svg);
    mask-image: var(--icon-battery-svg);
  }
  .icon.bell-off {
    -webkit-mask-image: var(--icon-bell-off-svg);
    mask-image: var(--icon-bell-off-svg);
  }
  .icon.bell {
    -webkit-mask-image: var(--icon-bell-svg);
    mask-image: var(--icon-bell-svg);
  }
  .icon.bluetooth {
    -webkit-mask-image: var(--icon-bluetooth-svg);
    mask-image: var(--icon-bluetooth-svg);
  }
  .icon.bold {
    -webkit-mask-image: var(--icon-bold-svg);
    mask-image: var(--icon-bold-svg);
  }
  .icon.bookmark {
    -webkit-mask-image: var(--icon-bookmark-svg);
    mask-image: var(--icon-bookmark-svg);
  }
  .icon.book-open {
    -webkit-mask-image: var(--icon-book-open-svg);
    mask-image: var(--icon-book-open-svg);
  }
  .icon.book {
    -webkit-mask-image: var(--icon-book-svg);
    mask-image: var(--icon-book-svg);
  }
  .icon.box {
    -webkit-mask-image: var(--icon-box-svg);
    mask-image: var(--icon-box-svg);
  }
  .icon.briefcase {
    -webkit-mask-image: var(--icon-briefcase-svg);
    mask-image: var(--icon-briefcase-svg);
  }
  .icon.calendar {
    -webkit-mask-image: var(--icon-calendar-svg);
    mask-image: var(--icon-calendar-svg);
  }
  .icon.camera-off {
    -webkit-mask-image: var(--icon-camera-off-svg);
    mask-image: var(--icon-camera-off-svg);
  }
  .icon.camera {
    -webkit-mask-image: var(--icon-camera-svg);
    mask-image: var(--icon-camera-svg);
  }
  .icon.cast {
    -webkit-mask-image: var(--icon-cast-svg);
    mask-image: var(--icon-cast-svg);
  }
  .icon.check-circle {
    -webkit-mask-image: var(--icon-check-circle-svg);
    mask-image: var(--icon-check-circle-svg);
  }
  .icon.check-square {
    -webkit-mask-image: var(--icon-check-square-svg);
    mask-image: var(--icon-check-square-svg);
  }
  .icon.check {
    -webkit-mask-image: var(--icon-check-svg);
    mask-image: var(--icon-check-svg);
  }
  .icon.chevron-down {
    -webkit-mask-image: var(--icon-chevron-down-svg);
    mask-image: var(--icon-chevron-down-svg);
  }
  .icon.chevron-left {
    -webkit-mask-image: var(--icon-chevron-left-svg);
    mask-image: var(--icon-chevron-left-svg);
  }
  .icon.chevron-right {
    -webkit-mask-image: var(--icon-chevron-right-svg);
    mask-image: var(--icon-chevron-right-svg);
  }
  .icon.chevrons-down {
    -webkit-mask-image: var(--icon-chevrons-down-svg);
    mask-image: var(--icon-chevrons-down-svg);
  }
  .icon.chevrons-left {
    -webkit-mask-image: var(--icon-chevrons-left-svg);
    mask-image: var(--icon-chevrons-left-svg);
  }
  .icon.chevrons-right {
    -webkit-mask-image: var(--icon-chevrons-right-svg);
    mask-image: var(--icon-chevrons-right-svg);
  }
  .icon.chevrons-up {
    -webkit-mask-image: var(--icon-chevrons-up-svg);
    mask-image: var(--icon-chevrons-up-svg);
  }
  .icon.chevron-up {
    -webkit-mask-image: var(--icon-chevron-up-svg);
    mask-image: var(--icon-chevron-up-svg);
  }
  .icon.chrome {
    -webkit-mask-image: var(--icon-chrome-svg);
    mask-image: var(--icon-chrome-svg);
  }
  .icon.circle {
    -webkit-mask-image: var(--icon-circle-svg);
    mask-image: var(--icon-circle-svg);
  }
  .icon.clipboard {
    -webkit-mask-image: var(--icon-clipboard-svg);
    mask-image: var(--icon-clipboard-svg);
  }
  .icon.clock {
    -webkit-mask-image: var(--icon-clock-svg);
    mask-image: var(--icon-clock-svg);
  }
  .icon.cloud-drizzle {
    -webkit-mask-image: var(--icon-cloud-drizzle-svg);
    mask-image: var(--icon-cloud-drizzle-svg);
  }
  .icon.cloud-lightning {
    -webkit-mask-image: var(--icon-cloud-lightning-svg);
    mask-image: var(--icon-cloud-lightning-svg);
  }
  .icon.cloud-off {
    -webkit-mask-image: var(--icon-cloud-off-svg);
    mask-image: var(--icon-cloud-off-svg);
  }
  .icon.cloud-rain {
    -webkit-mask-image: var(--icon-cloud-rain-svg);
    mask-image: var(--icon-cloud-rain-svg);
  }
  .icon.cloud-snow {
    -webkit-mask-image: var(--icon-cloud-snow-svg);
    mask-image: var(--icon-cloud-snow-svg);
  }
  .icon.cloud {
    -webkit-mask-image: var(--icon-cloud-svg);
    mask-image: var(--icon-cloud-svg);
  }
  .icon.codepen {
    -webkit-mask-image: var(--icon-codepen-svg);
    mask-image: var(--icon-codepen-svg);
  }
  .icon.codesandbox {
    -webkit-mask-image: var(--icon-codesandbox-svg);
    mask-image: var(--icon-codesandbox-svg);
  }
  .icon.code {
    -webkit-mask-image: var(--icon-code-svg);
    mask-image: var(--icon-code-svg);
  }
  .icon.coffee {
    -webkit-mask-image: var(--icon-coffee-svg);
    mask-image: var(--icon-coffee-svg);
  }
  .icon.columns {
    -webkit-mask-image: var(--icon-columns-svg);
    mask-image: var(--icon-columns-svg);
  }
  .icon.command {
    -webkit-mask-image: var(--icon-command-svg);
    mask-image: var(--icon-command-svg);
  }
  .icon.compass {
    -webkit-mask-image: var(--icon-compass-svg);
    mask-image: var(--icon-compass-svg);
  }
  .icon.copy {
    -webkit-mask-image: var(--icon-copy-svg);
    mask-image: var(--icon-copy-svg);
  }
  .icon.corner-down-left {
    -webkit-mask-image: var(--icon-corner-down-left-svg);
    mask-image: var(--icon-corner-down-left-svg);
  }
  .icon.corner-down-right {
    -webkit-mask-image: var(--icon-corner-down-right-svg);
    mask-image: var(--icon-corner-down-right-svg);
  }
  .icon.corner-left-down {
    -webkit-mask-image: var(--icon-corner-left-down-svg);
    mask-image: var(--icon-corner-left-down-svg);
  }
  .icon.corner-left-up {
    -webkit-mask-image: var(--icon-corner-left-up-svg);
    mask-image: var(--icon-corner-left-up-svg);
  }
  .icon.corner-right-down {
    -webkit-mask-image: var(--icon-corner-right-down-svg);
    mask-image: var(--icon-corner-right-down-svg);
  }
  .icon.corner-right-up {
    -webkit-mask-image: var(--icon-corner-right-up-svg);
    mask-image: var(--icon-corner-right-up-svg);
  }
  .icon.corner-up-left {
    -webkit-mask-image: var(--icon-corner-up-left-svg);
    mask-image: var(--icon-corner-up-left-svg);
  }
  .icon.corner-up-right {
    -webkit-mask-image: var(--icon-corner-up-right-svg);
    mask-image: var(--icon-corner-up-right-svg);
  }
  .icon.cpu {
    -webkit-mask-image: var(--icon-cpu-svg);
    mask-image: var(--icon-cpu-svg);
  }
  .icon.credit-card {
    -webkit-mask-image: var(--icon-credit-card-svg);
    mask-image: var(--icon-credit-card-svg);
  }
  .icon.crop {
    -webkit-mask-image: var(--icon-crop-svg);
    mask-image: var(--icon-crop-svg);
  }
  .icon.crosshair {
    -webkit-mask-image: var(--icon-crosshair-svg);
    mask-image: var(--icon-crosshair-svg);
  }
  .icon.database {
    -webkit-mask-image: var(--icon-database-svg);
    mask-image: var(--icon-database-svg);
  }
  .icon.delete {
    -webkit-mask-image: var(--icon-delete-svg);
    mask-image: var(--icon-delete-svg);
  }
  .icon.disc {
    -webkit-mask-image: var(--icon-disc-svg);
    mask-image: var(--icon-disc-svg);
  }
  .icon.divide-circle {
    -webkit-mask-image: var(--icon-divide-circle-svg);
    mask-image: var(--icon-divide-circle-svg);
  }
  .icon.divide-square {
    -webkit-mask-image: var(--icon-divide-square-svg);
    mask-image: var(--icon-divide-square-svg);
  }
  .icon.divide {
    -webkit-mask-image: var(--icon-divide-svg);
    mask-image: var(--icon-divide-svg);
  }
  .icon.dollar-sign {
    -webkit-mask-image: var(--icon-dollar-sign-svg);
    mask-image: var(--icon-dollar-sign-svg);
  }
  .icon.download-cloud {
    -webkit-mask-image: var(--icon-download-cloud-svg);
    mask-image: var(--icon-download-cloud-svg);
  }
  .icon.download {
    -webkit-mask-image: var(--icon-download-svg);
    mask-image: var(--icon-download-svg);
  }
  .icon.dribbble {
    -webkit-mask-image: var(--icon-dribbble-svg);
    mask-image: var(--icon-dribbble-svg);
  }
  .icon.droplet {
    -webkit-mask-image: var(--icon-droplet-svg);
    mask-image: var(--icon-droplet-svg);
  }
  .icon.edit-2 {
    -webkit-mask-image: var(--icon-edit-2-svg);
    mask-image: var(--icon-edit-2-svg);
  }
  .icon.edit-3 {
    -webkit-mask-image: var(--icon-edit-3-svg);
    mask-image: var(--icon-edit-3-svg);
  }
  .icon.edit {
    -webkit-mask-image: var(--icon-edit-svg);
    mask-image: var(--icon-edit-svg);
  }
  .icon.external-link {
    -webkit-mask-image: var(--icon-external-link-svg);
    mask-image: var(--icon-external-link-svg);
  }
  .icon.eye-off {
    -webkit-mask-image: var(--icon-eye-off-svg);
    mask-image: var(--icon-eye-off-svg);
  }
  .icon.eye {
    -webkit-mask-image: var(--icon-eye-svg);
    mask-image: var(--icon-eye-svg);
  }
  .icon.facebook {
    -webkit-mask-image: var(--icon-facebook-svg);
    mask-image: var(--icon-facebook-svg);
  }
  .icon.fast-forward {
    -webkit-mask-image: var(--icon-fast-forward-svg);
    mask-image: var(--icon-fast-forward-svg);
  }
  .icon.feather {
    -webkit-mask-image: var(--icon-feather-svg);
    mask-image: var(--icon-feather-svg);
  }
  .icon.figma {
    -webkit-mask-image: var(--icon-figma-svg);
    mask-image: var(--icon-figma-svg);
  }
  .icon.file-minus {
    -webkit-mask-image: var(--icon-file-minus-svg);
    mask-image: var(--icon-file-minus-svg);
  }
  .icon.file-plus {
    -webkit-mask-image: var(--icon-file-plus-svg);
    mask-image: var(--icon-file-plus-svg);
  }
  .icon.file {
    -webkit-mask-image: var(--icon-file-svg);
    mask-image: var(--icon-file-svg);
  }
  .icon.file-text {
    -webkit-mask-image: var(--icon-file-text-svg);
    mask-image: var(--icon-file-text-svg);
  }
  .icon.film {
    -webkit-mask-image: var(--icon-film-svg);
    mask-image: var(--icon-film-svg);
  }
  .icon.filter {
    -webkit-mask-image: var(--icon-filter-svg);
    mask-image: var(--icon-filter-svg);
  }
  .icon.flag {
    -webkit-mask-image: var(--icon-flag-svg);
    mask-image: var(--icon-flag-svg);
  }
  .icon.folder-minus {
    -webkit-mask-image: var(--icon-folder-minus-svg);
    mask-image: var(--icon-folder-minus-svg);
  }
  .icon.folder-plus {
    -webkit-mask-image: var(--icon-folder-plus-svg);
    mask-image: var(--icon-folder-plus-svg);
  }
  .icon.folder {
    -webkit-mask-image: var(--icon-folder-svg);
    mask-image: var(--icon-folder-svg);
  }
  .icon.framer {
    -webkit-mask-image: var(--icon-framer-svg);
    mask-image: var(--icon-framer-svg);
  }
  .icon.frown {
    -webkit-mask-image: var(--icon-frown-svg);
    mask-image: var(--icon-frown-svg);
  }
  .icon.gift {
    -webkit-mask-image: var(--icon-gift-svg);
    mask-image: var(--icon-gift-svg);
  }
  .icon.git-branch {
    -webkit-mask-image: var(--icon-git-branch-svg);
    mask-image: var(--icon-git-branch-svg);
  }
  .icon.git-commit {
    -webkit-mask-image: var(--icon-git-commit-svg);
    mask-image: var(--icon-git-commit-svg);
  }
  .icon.github {
    -webkit-mask-image: var(--icon-github-svg);
    mask-image: var(--icon-github-svg);
  }
  .icon.gitlab {
    -webkit-mask-image: var(--icon-gitlab-svg);
    mask-image: var(--icon-gitlab-svg);
  }
  .icon.git-merge {
    -webkit-mask-image: var(--icon-git-merge-svg);
    mask-image: var(--icon-git-merge-svg);
  }
  .icon.git-pull-request {
    -webkit-mask-image: var(--icon-git-pull-request-svg);
    mask-image: var(--icon-git-pull-request-svg);
  }
  .icon.globe {
    -webkit-mask-image: var(--icon-globe-svg);
    mask-image: var(--icon-globe-svg);
  }
  .icon.grid {
    -webkit-mask-image: var(--icon-grid-svg);
    mask-image: var(--icon-grid-svg);
  }
  .icon.hard-drive {
    -webkit-mask-image: var(--icon-hard-drive-svg);
    mask-image: var(--icon-hard-drive-svg);
  }
  .icon.hash {
    -webkit-mask-image: var(--icon-hash-svg);
    mask-image: var(--icon-hash-svg);
  }
  .icon.headphones {
    -webkit-mask-image: var(--icon-headphones-svg);
    mask-image: var(--icon-headphones-svg);
  }
  .icon.heart {
    -webkit-mask-image: var(--icon-heart-svg);
    mask-image: var(--icon-heart-svg);
  }
  .icon.help-circle {
    -webkit-mask-image: var(--icon-help-circle-svg);
    mask-image: var(--icon-help-circle-svg);
  }
  .icon.hexagon {
    -webkit-mask-image: var(--icon-hexagon-svg);
    mask-image: var(--icon-hexagon-svg);
  }
  .icon.home {
    -webkit-mask-image: var(--icon-home-svg);
    mask-image: var(--icon-home-svg);
  }
  .icon.image {
    -webkit-mask-image: var(--icon-image-svg);
    mask-image: var(--icon-image-svg);
  }
  .icon.inbox {
    -webkit-mask-image: var(--icon-inbox-svg);
    mask-image: var(--icon-inbox-svg);
  }
  .icon.info {
    -webkit-mask-image: var(--icon-info-svg);
    mask-image: var(--icon-info-svg);
  }
  .icon.instagram {
    -webkit-mask-image: var(--icon-instagram-svg);
    mask-image: var(--icon-instagram-svg);
  }
  .icon.italic {
    -webkit-mask-image: var(--icon-italic-svg);
    mask-image: var(--icon-italic-svg);
  }
  .icon.key {
    -webkit-mask-image: var(--icon-key-svg);
    mask-image: var(--icon-key-svg);
  }
  .icon.layers {
    -webkit-mask-image: var(--icon-layers-svg);
    mask-image: var(--icon-layers-svg);
  }
  .icon.layout {
    -webkit-mask-image: var(--icon-layout-svg);
    mask-image: var(--icon-layout-svg);
  }
  .icon.life-buoy {
    -webkit-mask-image: var(--icon-life-buoy-svg);
    mask-image: var(--icon-life-buoy-svg);
  }
  .icon.linkify-2 {
    -webkit-mask-image: var(--icon-linkify-2-svg);
    mask-image: var(--icon-linkify-2-svg);
  }
  .icon.linkedin {
    -webkit-mask-image: var(--icon-linkedin-svg);
    mask-image: var(--icon-linkedin-svg);
  }
  .icon.linkify {
    -webkit-mask-image: var(--icon-linkify-svg);
    mask-image: var(--icon-linkify-svg);
  }
  .icon.list {
    -webkit-mask-image: var(--icon-list-svg);
    mask-image: var(--icon-list-svg);
  }
  .icon.loader {
    -webkit-mask-image: var(--icon-loader-svg);
    mask-image: var(--icon-loader-svg);
  }
  .icon.lock {
    -webkit-mask-image: var(--icon-lock-svg);
    mask-image: var(--icon-lock-svg);
  }
  .icon.log-in {
    -webkit-mask-image: var(--icon-log-in-svg);
    mask-image: var(--icon-log-in-svg);
  }
  .icon.log-out {
    -webkit-mask-image: var(--icon-log-out-svg);
    mask-image: var(--icon-log-out-svg);
  }
  .icon.mail {
    -webkit-mask-image: var(--icon-mail-svg);
    mask-image: var(--icon-mail-svg);
  }
  .icon.map-pin {
    -webkit-mask-image: var(--icon-map-pin-svg);
    mask-image: var(--icon-map-pin-svg);
  }
  .icon.map {
    -webkit-mask-image: var(--icon-map-svg);
    mask-image: var(--icon-map-svg);
  }
  .icon.maximize-2 {
    -webkit-mask-image: var(--icon-maximize-2-svg);
    mask-image: var(--icon-maximize-2-svg);
  }
  .icon.maximize {
    -webkit-mask-image: var(--icon-maximize-svg);
    mask-image: var(--icon-maximize-svg);
  }
  .icon.meh {
    -webkit-mask-image: var(--icon-meh-svg);
    mask-image: var(--icon-meh-svg);
  }
  .icon.menu {
    -webkit-mask-image: var(--icon-menu-svg);
    mask-image: var(--icon-menu-svg);
  }
  .icon.message-circle {
    -webkit-mask-image: var(--icon-message-circle-svg);
    mask-image: var(--icon-message-circle-svg);
  }
  .icon.message-square {
    -webkit-mask-image: var(--icon-message-square-svg);
    mask-image: var(--icon-message-square-svg);
  }
  .icon.mic-off {
    -webkit-mask-image: var(--icon-mic-off-svg);
    mask-image: var(--icon-mic-off-svg);
  }
  .icon.mic {
    -webkit-mask-image: var(--icon-mic-svg);
    mask-image: var(--icon-mic-svg);
  }
  .icon.minimize-2 {
    -webkit-mask-image: var(--icon-minimize-2-svg);
    mask-image: var(--icon-minimize-2-svg);
  }
  .icon.minimize {
    -webkit-mask-image: var(--icon-minimize-svg);
    mask-image: var(--icon-minimize-svg);
  }
  .icon.minus-circle {
    -webkit-mask-image: var(--icon-minus-circle-svg);
    mask-image: var(--icon-minus-circle-svg);
  }
  .icon.minus-square {
    -webkit-mask-image: var(--icon-minus-square-svg);
    mask-image: var(--icon-minus-square-svg);
  }
  .icon.minus {
    -webkit-mask-image: var(--icon-minus-svg);
    mask-image: var(--icon-minus-svg);
  }
  .icon.monitor {
    -webkit-mask-image: var(--icon-monitor-svg);
    mask-image: var(--icon-monitor-svg);
  }
  .icon.moon {
    -webkit-mask-image: var(--icon-moon-svg);
    mask-image: var(--icon-moon-svg);
  }
  .icon.more-horizontal {
    -webkit-mask-image: var(--icon-more-horizontal-svg);
    mask-image: var(--icon-more-horizontal-svg);
  }
  .icon.more-vertical {
    -webkit-mask-image: var(--icon-more-vertical-svg);
    mask-image: var(--icon-more-vertical-svg);
  }
  .icon.mouse-pointer {
    -webkit-mask-image: var(--icon-mouse-pointer-svg);
    mask-image: var(--icon-mouse-pointer-svg);
  }
  .icon.move {
    -webkit-mask-image: var(--icon-move-svg);
    mask-image: var(--icon-move-svg);
  }
  .icon.music {
    -webkit-mask-image: var(--icon-music-svg);
    mask-image: var(--icon-music-svg);
  }
  .icon.navigation-2 {
    -webkit-mask-image: var(--icon-navigation-2-svg);
    mask-image: var(--icon-navigation-2-svg);
  }
  .icon.navigation {
    -webkit-mask-image: var(--icon-navigation-svg);
    mask-image: var(--icon-navigation-svg);
  }
  .icon.octagon {
    -webkit-mask-image: var(--icon-octagon-svg);
    mask-image: var(--icon-octagon-svg);
  }
  .icon.package {
    -webkit-mask-image: var(--icon-package-svg);
    mask-image: var(--icon-package-svg);
  }
  .icon.paperclip {
    -webkit-mask-image: var(--icon-paperclip-svg);
    mask-image: var(--icon-paperclip-svg);
  }
  .icon.pause-circle {
    -webkit-mask-image: var(--icon-pause-circle-svg);
    mask-image: var(--icon-pause-circle-svg);
  }
  .icon.pause {
    -webkit-mask-image: var(--icon-pause-svg);
    mask-image: var(--icon-pause-svg);
  }
  .icon.pen-tool {
    -webkit-mask-image: var(--icon-pen-tool-svg);
    mask-image: var(--icon-pen-tool-svg);
  }
  .icon.percent {
    -webkit-mask-image: var(--icon-percent-svg);
    mask-image: var(--icon-percent-svg);
  }
  .icon.phone-call {
    -webkit-mask-image: var(--icon-phone-call-svg);
    mask-image: var(--icon-phone-call-svg);
  }
  .icon.phone-forwarded {
    -webkit-mask-image: var(--icon-phone-forwarded-svg);
    mask-image: var(--icon-phone-forwarded-svg);
  }
  .icon.phone-incoming {
    -webkit-mask-image: var(--icon-phone-incoming-svg);
    mask-image: var(--icon-phone-incoming-svg);
  }
  .icon.phone-missed {
    -webkit-mask-image: var(--icon-phone-missed-svg);
    mask-image: var(--icon-phone-missed-svg);
  }
  .icon.phone-off {
    -webkit-mask-image: var(--icon-phone-off-svg);
    mask-image: var(--icon-phone-off-svg);
  }
  .icon.phone-outgoing {
    -webkit-mask-image: var(--icon-phone-outgoing-svg);
    mask-image: var(--icon-phone-outgoing-svg);
  }
  .icon.phone {
    -webkit-mask-image: var(--icon-phone-svg);
    mask-image: var(--icon-phone-svg);
  }
  .icon.pie-chart {
    -webkit-mask-image: var(--icon-pie-chart-svg);
    mask-image: var(--icon-pie-chart-svg);
  }
  .icon.play-circle {
    -webkit-mask-image: var(--icon-play-circle-svg);
    mask-image: var(--icon-play-circle-svg);
  }
  .icon.play {
    -webkit-mask-image: var(--icon-play-svg);
    mask-image: var(--icon-play-svg);
  }
  .icon.plus-circle {
    -webkit-mask-image: var(--icon-plus-circle-svg);
    mask-image: var(--icon-plus-circle-svg);
  }
  .icon.plus-square {
    -webkit-mask-image: var(--icon-plus-square-svg);
    mask-image: var(--icon-plus-square-svg);
  }
  .icon.plus {
    -webkit-mask-image: var(--icon-plus-svg);
    mask-image: var(--icon-plus-svg);
  }
  .icon.pocket {
    -webkit-mask-image: var(--icon-pocket-svg);
    mask-image: var(--icon-pocket-svg);
  }
  .icon.power {
    -webkit-mask-image: var(--icon-power-svg);
    mask-image: var(--icon-power-svg);
  }
  .icon.printer {
    -webkit-mask-image: var(--icon-printer-svg);
    mask-image: var(--icon-printer-svg);
  }
  .icon.radio {
    -webkit-mask-image: var(--icon-radio-svg);
    mask-image: var(--icon-radio-svg);
  }
  .icon.refresh-ccw {
    -webkit-mask-image: var(--icon-refresh-ccw-svg);
    mask-image: var(--icon-refresh-ccw-svg);
  }
  .icon.refresh-cw {
    -webkit-mask-image: var(--icon-refresh-cw-svg);
    mask-image: var(--icon-refresh-cw-svg);
  }
  .icon.repeat {
    -webkit-mask-image: var(--icon-repeat-svg);
    mask-image: var(--icon-repeat-svg);
  }
  .icon.rewind {
    -webkit-mask-image: var(--icon-rewind-svg);
    mask-image: var(--icon-rewind-svg);
  }
  .icon.rotate-ccw {
    -webkit-mask-image: var(--icon-rotate-ccw-svg);
    mask-image: var(--icon-rotate-ccw-svg);
  }
  .icon.rotate-cw {
    -webkit-mask-image: var(--icon-rotate-cw-svg);
    mask-image: var(--icon-rotate-cw-svg);
  }
  .icon.rss {
    -webkit-mask-image: var(--icon-rss-svg);
    mask-image: var(--icon-rss-svg);
  }
  .icon.save {
    -webkit-mask-image: var(--icon-save-svg);
    mask-image: var(--icon-save-svg);
  }
  .icon.scissors {
    -webkit-mask-image: var(--icon-scissors-svg);
    mask-image: var(--icon-scissors-svg);
  }
  .icon.search {
    -webkit-mask-image: var(--icon-search-svg);
    mask-image: var(--icon-search-svg);
  }
  .icon.send {
    -webkit-mask-image: var(--icon-send-svg);
    mask-image: var(--icon-send-svg);
  }
  .icon.server {
    -webkit-mask-image: var(--icon-server-svg);
    mask-image: var(--icon-server-svg);
  }
  .icon.settings {
    -webkit-mask-image: var(--icon-settings-svg);
    mask-image: var(--icon-settings-svg);
  }
  .icon.share-2 {
    -webkit-mask-image: var(--icon-share-2-svg);
    mask-image: var(--icon-share-2-svg);
  }
  .icon.share {
    -webkit-mask-image: var(--icon-share-svg);
    mask-image: var(--icon-share-svg);
  }
  .icon.shield-off {
    -webkit-mask-image: var(--icon-shield-off-svg);
    mask-image: var(--icon-shield-off-svg);
  }
  .icon.shield {
    -webkit-mask-image: var(--icon-shield-svg);
    mask-image: var(--icon-shield-svg);
  }
  .icon.shopping-bag {
    -webkit-mask-image: var(--icon-shopping-bag-svg);
    mask-image: var(--icon-shopping-bag-svg);
  }
  .icon.shopping-cart {
    -webkit-mask-image: var(--icon-shopping-cart-svg);
    mask-image: var(--icon-shopping-cart-svg);
  }
  .icon.shuffle {
    -webkit-mask-image: var(--icon-shuffle-svg);
    mask-image: var(--icon-shuffle-svg);
  }
  .icon.sidebar {
    -webkit-mask-image: var(--icon-sidebar-svg);
    mask-image: var(--icon-sidebar-svg);
  }
  .icon.skip-back {
    -webkit-mask-image: var(--icon-skip-back-svg);
    mask-image: var(--icon-skip-back-svg);
  }
  .icon.skip-forward {
    -webkit-mask-image: var(--icon-skip-forward-svg);
    mask-image: var(--icon-skip-forward-svg);
  }
  .icon.slack {
    -webkit-mask-image: var(--icon-slack-svg);
    mask-image: var(--icon-slack-svg);
  }
  .icon.slash {
    -webkit-mask-image: var(--icon-slash-svg);
    mask-image: var(--icon-slash-svg);
  }
  .icon.sliders {
    -webkit-mask-image: var(--icon-sliders-svg);
    mask-image: var(--icon-sliders-svg);
  }
  .icon.smartphone {
    -webkit-mask-image: var(--icon-smartphone-svg);
    mask-image: var(--icon-smartphone-svg);
  }
  .icon.smile {
    -webkit-mask-image: var(--icon-smile-svg);
    mask-image: var(--icon-smile-svg);
  }
  .icon.speaker {
    -webkit-mask-image: var(--icon-speaker-svg);
    mask-image: var(--icon-speaker-svg);
  }
  .icon.square {
    -webkit-mask-image: var(--icon-square-svg);
    mask-image: var(--icon-square-svg);
  }
  .icon.star {
    -webkit-mask-image: var(--icon-star-svg);
    mask-image: var(--icon-star-svg);
  }
  .icon.stop-circle {
    -webkit-mask-image: var(--icon-stop-circle-svg);
    mask-image: var(--icon-stop-circle-svg);
  }
  .icon.sunrise {
    -webkit-mask-image: var(--icon-sunrise-svg);
    mask-image: var(--icon-sunrise-svg);
  }
  .icon.sunset {
    -webkit-mask-image: var(--icon-sunset-svg);
    mask-image: var(--icon-sunset-svg);
  }
  .icon.sun {
    -webkit-mask-image: var(--icon-sun-svg);
    mask-image: var(--icon-sun-svg);
  }
  .icon.table {
    -webkit-mask-image: var(--icon-table-svg);
    mask-image: var(--icon-table-svg);
  }
  .icon.tablet {
    -webkit-mask-image: var(--icon-tablet-svg);
    mask-image: var(--icon-tablet-svg);
  }
  .icon.tag {
    -webkit-mask-image: var(--icon-tag-svg);
    mask-image: var(--icon-tag-svg);
  }
  .icon.target {
    -webkit-mask-image: var(--icon-target-svg);
    mask-image: var(--icon-target-svg);
  }
  .icon.terminal {
    -webkit-mask-image: var(--icon-terminal-svg);
    mask-image: var(--icon-terminal-svg);
  }
  .icon.thermometer {
    -webkit-mask-image: var(--icon-thermometer-svg);
    mask-image: var(--icon-thermometer-svg);
  }
  .icon.thumbs-down {
    -webkit-mask-image: var(--icon-thumbs-down-svg);
    mask-image: var(--icon-thumbs-down-svg);
  }
  .icon.thumbs-up {
    -webkit-mask-image: var(--icon-thumbs-up-svg);
    mask-image: var(--icon-thumbs-up-svg);
  }
  .icon.toggle-left {
    -webkit-mask-image: var(--icon-toggle-left-svg);
    mask-image: var(--icon-toggle-left-svg);
  }
  .icon.toggle-right {
    -webkit-mask-image: var(--icon-toggle-right-svg);
    mask-image: var(--icon-toggle-right-svg);
  }
  .icon.tool {
    -webkit-mask-image: var(--icon-tool-svg);
    mask-image: var(--icon-tool-svg);
  }
  .icon.trash-2 {
    -webkit-mask-image: var(--icon-trash-2-svg);
    mask-image: var(--icon-trash-2-svg);
  }
  .icon.trash {
    -webkit-mask-image: var(--icon-trash-svg);
    mask-image: var(--icon-trash-svg);
  }
  .icon.trello {
    -webkit-mask-image: var(--icon-trello-svg);
    mask-image: var(--icon-trello-svg);
  }
  .icon.trending-down {
    -webkit-mask-image: var(--icon-trending-down-svg);
    mask-image: var(--icon-trending-down-svg);
  }
  .icon.trending-up {
    -webkit-mask-image: var(--icon-trending-up-svg);
    mask-image: var(--icon-trending-up-svg);
  }
  .icon.triangle {
    -webkit-mask-image: var(--icon-triangle-svg);
    mask-image: var(--icon-triangle-svg);
  }
  .icon.truck {
    -webkit-mask-image: var(--icon-truck-svg);
    mask-image: var(--icon-truck-svg);
  }
  .icon.tv {
    -webkit-mask-image: var(--icon-tv-svg);
    mask-image: var(--icon-tv-svg);
  }
  .icon.twitch {
    -webkit-mask-image: var(--icon-twitch-svg);
    mask-image: var(--icon-twitch-svg);
  }
  .icon.twitter {
    -webkit-mask-image: var(--icon-twitter-svg);
    mask-image: var(--icon-twitter-svg);
  }
  .icon.type {
    -webkit-mask-image: var(--icon-type-svg);
    mask-image: var(--icon-type-svg);
  }
  .icon.umbrella {
    -webkit-mask-image: var(--icon-umbrella-svg);
    mask-image: var(--icon-umbrella-svg);
  }
  .icon.underline {
    -webkit-mask-image: var(--icon-underline-svg);
    mask-image: var(--icon-underline-svg);
  }
  .icon.unlock {
    -webkit-mask-image: var(--icon-unlock-svg);
    mask-image: var(--icon-unlock-svg);
  }
  .icon.upload-cloud {
    -webkit-mask-image: var(--icon-upload-cloud-svg);
    mask-image: var(--icon-upload-cloud-svg);
  }
  .icon.upload {
    -webkit-mask-image: var(--icon-upload-svg);
    mask-image: var(--icon-upload-svg);
  }
  .icon.user-check {
    -webkit-mask-image: var(--icon-user-check-svg);
    mask-image: var(--icon-user-check-svg);
  }
  .icon.user-minus {
    -webkit-mask-image: var(--icon-user-minus-svg);
    mask-image: var(--icon-user-minus-svg);
  }
  .icon.user-plus {
    -webkit-mask-image: var(--icon-user-plus-svg);
    mask-image: var(--icon-user-plus-svg);
  }
  .icon.users {
    -webkit-mask-image: var(--icon-users-svg);
    mask-image: var(--icon-users-svg);
  }
  .icon.user {
    -webkit-mask-image: var(--icon-user-svg);
    mask-image: var(--icon-user-svg);
  }
  .icon.user-x {
    -webkit-mask-image: var(--icon-user-x-svg);
    mask-image: var(--icon-user-x-svg);
  }
  .icon.video-off {
    -webkit-mask-image: var(--icon-video-off-svg);
    mask-image: var(--icon-video-off-svg);
  }
  .icon.video {
    -webkit-mask-image: var(--icon-video-svg);
    mask-image: var(--icon-video-svg);
  }
  .icon.voicemail {
    -webkit-mask-image: var(--icon-voicemail-svg);
    mask-image: var(--icon-voicemail-svg);
  }
  .icon.volume-1 {
    -webkit-mask-image: var(--icon-volume-1-svg);
    mask-image: var(--icon-volume-1-svg);
  }
  .icon.volume-2 {
    -webkit-mask-image: var(--icon-volume-2-svg);
    mask-image: var(--icon-volume-2-svg);
  }
  .icon.volume {
    -webkit-mask-image: var(--icon-volume-svg);
    mask-image: var(--icon-volume-svg);
  }
  .icon.volume-x {
    -webkit-mask-image: var(--icon-volume-x-svg);
    mask-image: var(--icon-volume-x-svg);
  }
  .icon.watch {
    -webkit-mask-image: var(--icon-watch-svg);
    mask-image: var(--icon-watch-svg);
  }
  .icon.wifi-off {
    -webkit-mask-image: var(--icon-wifi-off-svg);
    mask-image: var(--icon-wifi-off-svg);
  }
  .icon.wifi {
    -webkit-mask-image: var(--icon-wifi-svg);
    mask-image: var(--icon-wifi-svg);
  }
  .icon.wind {
    -webkit-mask-image: var(--icon-wind-svg);
    mask-image: var(--icon-wind-svg);
  }
  .icon.x-circle {
    -webkit-mask-image: var(--icon-x-circle-svg);
    mask-image: var(--icon-x-circle-svg);
  }
  .icon.x-octagon {
    -webkit-mask-image: var(--icon-x-octagon-svg);
    mask-image: var(--icon-x-octagon-svg);
  }
  .icon.x-square {
    -webkit-mask-image: var(--icon-x-square-svg);
    mask-image: var(--icon-x-square-svg);
  }
  .icon.x {
    -webkit-mask-image: var(--icon-x-svg);
    mask-image: var(--icon-x-svg);
  }
  .icon.youtube {
    -webkit-mask-image: var(--icon-youtube-svg);
    mask-image: var(--icon-youtube-svg);
  }
  .icon.zap-off {
    -webkit-mask-image: var(--icon-zap-off-svg);
    mask-image: var(--icon-zap-off-svg);
  }
  .icon.zap {
    -webkit-mask-image: var(--icon-zap-svg);
    mask-image: var(--icon-zap-svg);
  }
  .icon.zoom-in {
    -webkit-mask-image: var(--icon-zoom-in-svg);
    mask-image: var(--icon-zoom-in-svg);
  }
  .icon.zoom-out {
    -webkit-mask-image: var(--icon-zoom-out-svg);
    mask-image: var(--icon-zoom-out-svg);
  }
}

/* src/components/icon/css/definition/group/icons.css */
@layer icon.definition.plural;

/* src/components/icon/css/definition/states/disabled.css */
@layer icon.definition.states.disabled {
  .disabled.icon {
    cursor: default !important;
    opacity: var(--icon-disabled-opacity) !important;
  }
}

/* src/components/icon/css/definition/states/loading.css */
@layer icon.definition.states.loading;

/* src/components/icon/css/definition/variations/circular.css */
@layer icon.definition.variations.circular {
  i.circular.icon {
    border-radius: 500em !important;
    line-height: 1 !important;
    padding: var(--circular-padding) !important;
    box-shadow: var(--circular-shadow);
    width: var(--circular-size) !important;
    height: var(--circular-size) !important;
  }
  i.circular.inverted.icon {
    border: none;
    box-shadow: none;
  }
}

/* src/components/icon/css/definition/variations/colored.css */
@layer icon.definition.variations.colored {
  .red.icon {
    color: var(--icon-red);
  }
  .orange.icon {
    color: var(--icon-orange);
  }
  .yellow.icon {
    color: var(--icon-yellow);
  }
  .olive.icon {
    color: var(--icon-olive);
  }
  .green.icon {
    color: var(--icon-green);
  }
  .teal.icon {
    color: var(--icon-teal);
  }
  .blue.icon {
    color: var(--icon-blue);
  }
  .violet.icon {
    color: var(--icon-violet);
  }
  .purple.icon {
    color: var(--icon-purple);
  }
  .pink.icon {
    color: var(--icon-pink);
  }
  .brown.icon {
    color: var(--icon-brown);
  }
  .grey.icon {
    color: var(--icon-grey);
  }
  .black.icon {
    color: var(--icon-black);
  }
}

/* src/components/icon/css/definition/variations/fitted.css */
@layer icon.definition.variations.fitted {
  :host([fitted]) {
    margin: 0rem;
  }
}

/* src/components/icon/css/definition/variations/link.css */
@layer icon.definition.variations.links {
  .hitbox {
    display: inline-block;
    cursor: pointer;
    box-sizing: border-box;
    margin: calc(var(--icon-hitbox-area) * -1);
    padding: var(--icon-hitbox-area);
    color: var(--icon-link-color);
  }
  .hitbox:hover {
    color: var(--icon-link-hover-color);
  }
  .link.icon,
  .link.icons {
    cursor: pointer;
    opacity: var(--icon-link-opacity);
    color: var(--icon-link-color);
    transition: var(--icon-link-transition);
  }
  .link.icon:hover,
  .link.icons:hover {
    opacity: var(--icon-link-hover-opacity);
    color: var(--icon-link-hover-color);
  }
}

/* src/components/icon/css/definition/variations/sizing.css */
@layer icon.definition.variations.sizing {
  .mini.icons .icon,
  .mini.icon {
    font-size: var(--icon-mini);
  }
  .tiny.icons .icon,
  .tiny.icon {
    font-size: var(--icon-tiny);
  }
  .small.icons .icon,
  .small.icon {
    font-size: var(--icon-small);
  }
  .icons .icon,
  .icon {
  }
  .large.icons .icon,
  .large.icon {
    font-size: var(--icon-large);
  }
  .big.icons .icon,
  .big.icon {
    font-size: var(--icon-big);
  }
  .huge.icons .icon,
  .huge.icon {
    font-size: var(--icon-huge);
  }
  .massive.icons .icon,
  .massive.icon {
    font-size: var(--icon-massive);
  }
}

/* src/components/icon/css/definition/icon-definition.css */

/* src/components/icon/css/theme/content/icon-variables.css */
@layer icon.theme.content.icon {
  :host {
    --icon-width: 1em;
    --icon-height: 1em;
    --icon-opacity: 1;
    --icon-distance-from-text: var(--relative-3px);
  }
}

/* src/components/icon/css/theme/group/icons-variables.css */
@layer icon.theme.plural {
  ui-icon {
  }
}

/* src/components/icon/css/theme/states/disabled-variables.css */
@layer icon.theme.states.disabled {
  :host {
    --icon-disabled-opacity: 0.2;
  }
}

/* src/components/icon/css/theme/states/loading-variables.css */
@layer icon.theme.states.loading {
  :host {
  }
}

/* src/components/icon/css/theme/variations/link-variables.css */
@layer icon.theme.variations.link {
  :host {
    --icon-link-opacity: 0.6;
    --icon-link-color: inherit;
    --icon-link-transition: opacity var(--duration) var(--easing), color var(--duration) var(--easing) ;
    --icon-link-hover-opacity: 1;
    --icon-link-hover-color: inherit;
    --icon-hitbox-area: 5px;
  }
}

/* src/components/icon/css/theme/variations/colored-variables.css */
@layer icon.theme.variations.colored {
  :host {
    --icon-red: var(--red);
    --icon-orange: var(--orange);
    --icon-yellow: var(--yellow);
    --icon-olive: var(--olive);
    --icon-green: var(--green);
    --icon-teal: var(--teal);
    --icon-blue: var(--blue);
    --icon-violet: var(--violet);
    --icon-purple: var(--purple);
    --icon-pink: var(--pink);
    --icon-brown: var(--brown);
    --icon-grey: var(--grey);
    --icon-black: var(--black);
  }
}

/* src/components/icon/css/theme/variations/sizing-variables.css */
@layer icon.theme.variations.sizing {
  :host {
    --icon-mini: var(--10px);
    --icon-tiny: var(--11px);
    --icon-small: var(--13px);
    --icon-medium: var(--medium);
    --icon-large: var(--16px);
    --icon-big: var(--24px);
    --icon-huge: var(--32px);
    --icon-massive: var(--64px);
  }
}

/* src/components/icon/css/theme/overrides/feather-icons.css */
@layer icon.theme.overrides.feather {
  :host {
    --icon-activity-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-activity"><polyline points="22 12 18 12 15 21 9 3 6 12 2 12"></polyline></svg>');
    --icon-airplay-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-airplay"><path d="M5 17H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2h-1"></path><polygon points="12 15 17 21 7 21 12 15"></polygon></svg>');
    --icon-alert-circle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-alert-circle"><circle cx="12" cy="12" r="10"></circle><line x1="12" y1="8" x2="12" y2="12"></line><line x1="12" y1="16" x2="12.01" y2="16"></line></svg>');
    --icon-alert-octagon-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-alert-octagon"><polygon points="7.86 2 16.14 2 22 7.86 22 16.14 16.14 22 7.86 22 2 16.14 2 7.86 7.86 2"></polygon><line x1="12" y1="8" x2="12" y2="12"></line><line x1="12" y1="16" x2="12.01" y2="16"></line></svg>');
    --icon-alert-triangle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-alert-triangle"><path d="M10.29 3.86L1.82 18a2 2 0 0 0 1.71 3h16.94a2 2 0 0 0 1.71-3L13.71 3.86a2 2 0 0 0-3.42 0z"></path><line x1="12" y1="9" x2="12" y2="13"></line><line x1="12" y1="17" x2="12.01" y2="17"></line></svg>');
    --icon-align-center-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-align-center"><line x1="18" y1="10" x2="6" y2="10"></line><line x1="21" y1="6" x2="3" y2="6"></line><line x1="21" y1="14" x2="3" y2="14"></line><line x1="18" y1="18" x2="6" y2="18"></line></svg>');
    --icon-align-justify-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-align-justify"><line x1="21" y1="10" x2="3" y2="10"></line><line x1="21" y1="6" x2="3" y2="6"></line><line x1="21" y1="14" x2="3" y2="14"></line><line x1="21" y1="18" x2="3" y2="18"></line></svg>');
    --icon-align-left-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-align-left"><line x1="17" y1="10" x2="3" y2="10"></line><line x1="21" y1="6" x2="3" y2="6"></line><line x1="21" y1="14" x2="3" y2="14"></line><line x1="17" y1="18" x2="3" y2="18"></line></svg>');
    --icon-align-right-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-align-right"><line x1="21" y1="10" x2="7" y2="10"></line><line x1="21" y1="6" x2="3" y2="6"></line><line x1="21" y1="14" x2="3" y2="14"></line><line x1="21" y1="18" x2="7" y2="18"></line></svg>');
    --icon-anchor-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-anchor"><circle cx="12" cy="5" r="3"></circle><line x1="12" y1="22" x2="12" y2="8"></line><path d="M5 12H2a10 10 0 0 0 20 0h-3"></path></svg>');
    --icon-aperture-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-aperture"><circle cx="12" cy="12" r="10"></circle><line x1="14.31" y1="8" x2="20.05" y2="17.94"></line><line x1="9.69" y1="8" x2="21.17" y2="8"></line><line x1="7.38" y1="12" x2="13.12" y2="2.06"></line><line x1="9.69" y1="16" x2="3.95" y2="6.06"></line><line x1="14.31" y1="16" x2="2.83" y2="16"></line><line x1="16.62" y1="12" x2="10.88" y2="21.94"></line></svg>');
    --icon-archive-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-archive"><polyline points="21 8 21 21 3 21 3 8"></polyline><rect x="1" y="3" width="22" height="5"></rect><line x1="10" y1="12" x2="14" y2="12"></line></svg>');
    --icon-arrow-down-circle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-arrow-down-circle"><circle cx="12" cy="12" r="10"></circle><polyline points="8 12 12 16 16 12"></polyline><line x1="12" y1="8" x2="12" y2="16"></line></svg>');
    --icon-arrow-down-left-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-arrow-down-left"><line x1="17" y1="7" x2="7" y2="17"></line><polyline points="17 17 7 17 7 7"></polyline></svg>');
    --icon-arrow-down-right-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-arrow-down-right"><line x1="7" y1="7" x2="17" y2="17"></line><polyline points="17 7 17 17 7 17"></polyline></svg>');
    --icon-arrow-down-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-arrow-down"><line x1="12" y1="5" x2="12" y2="19"></line><polyline points="19 12 12 19 5 12"></polyline></svg>');
    --icon-arrow-left-circle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-arrow-left-circle"><circle cx="12" cy="12" r="10"></circle><polyline points="12 8 8 12 12 16"></polyline><line x1="16" y1="12" x2="8" y2="12"></line></svg>');
    --icon-arrow-left-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-arrow-left"><line x1="19" y1="12" x2="5" y2="12"></line><polyline points="12 19 5 12 12 5"></polyline></svg>');
    --icon-arrow-right-circle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-arrow-right-circle"><circle cx="12" cy="12" r="10"></circle><polyline points="12 16 16 12 12 8"></polyline><line x1="8" y1="12" x2="16" y2="12"></line></svg>');
    --icon-arrow-right-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-arrow-right"><line x1="5" y1="12" x2="19" y2="12"></line><polyline points="12 5 19 12 12 19"></polyline></svg>');
    --icon-arrow-up-circle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-arrow-up-circle"><circle cx="12" cy="12" r="10"></circle><polyline points="16 12 12 8 8 12"></polyline><line x1="12" y1="16" x2="12" y2="8"></line></svg>');
    --icon-arrow-up-left-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-arrow-up-left"><line x1="17" y1="17" x2="7" y2="7"></line><polyline points="7 17 7 7 17 7"></polyline></svg>');
    --icon-arrow-up-right-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-arrow-up-right"><line x1="7" y1="17" x2="17" y2="7"></line><polyline points="7 7 17 7 17 17"></polyline></svg>');
    --icon-arrow-up-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-arrow-up"><line x1="12" y1="19" x2="12" y2="5"></line><polyline points="5 12 12 5 19 12"></polyline></svg>');
    --icon-at-sign-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-at-sign"><circle cx="12" cy="12" r="4"></circle><path d="M16 8v5a3 3 0 0 0 6 0v-1a10 10 0 1 0-3.92 7.94"></path></svg>');
    --icon-award-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-award"><circle cx="12" cy="8" r="7"></circle><polyline points="8.21 13.89 7 23 12 20 17 23 15.79 13.88"></polyline></svg>');
    --icon-bar-chart-2-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-bar-chart-2"><line x1="18" y1="20" x2="18" y2="10"></line><line x1="12" y1="20" x2="12" y2="4"></line><line x1="6" y1="20" x2="6" y2="14"></line></svg>');
    --icon-bar-chart-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-bar-chart"><line x1="12" y1="20" x2="12" y2="10"></line><line x1="18" y1="20" x2="18" y2="4"></line><line x1="6" y1="20" x2="6" y2="16"></line></svg>');
    --icon-battery-charging-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-battery-charging"><path d="M5 18H3a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h3.19M15 6h2a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2h-3.19"></path><line x1="23" y1="13" x2="23" y2="11"></line><polyline points="11 6 7 12 13 12 9 18"></polyline></svg>');
    --icon-battery-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-battery"><rect x="1" y="6" width="18" height="12" rx="2" ry="2"></rect><line x1="23" y1="13" x2="23" y2="11"></line></svg>');
    --icon-bell-off-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-bell-off"><path d="M13.73 21a2 2 0 0 1-3.46 0"></path><path d="M18.63 13A17.89 17.89 0 0 1 18 8"></path><path d="M6.26 6.26A5.86 5.86 0 0 0 6 8c0 7-3 9-3 9h14"></path><path d="M18 8a6 6 0 0 0-9.33-5"></path><line x1="1" y1="1" x2="23" y2="23"></line></svg>');
    --icon-bell-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-bell"><path d="M18 8A6 6 0 0 0 6 8c0 7-3 9-3 9h18s-3-2-3-9"></path><path d="M13.73 21a2 2 0 0 1-3.46 0"></path></svg>');
    --icon-bluetooth-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-bluetooth"><polyline points="6.5 6.5 17.5 17.5 12 23 12 1 17.5 6.5 6.5 17.5"></polyline></svg>');
    --icon-bold-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-bold"><path d="M6 4h8a4 4 0 0 1 4 4 4 4 0 0 1-4 4H6z"></path><path d="M6 12h9a4 4 0 0 1 4 4 4 4 0 0 1-4 4H6z"></path></svg>');
    --icon-bookmark-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-bookmark"><path d="M19 21l-7-5-7 5V5a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2z"></path></svg>');
    --icon-book-open-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-book-open"><path d="M2 3h6a4 4 0 0 1 4 4v14a3 3 0 0 0-3-3H2z"></path><path d="M22 3h-6a4 4 0 0 0-4 4v14a3 3 0 0 1 3-3h7z"></path></svg>');
    --icon-book-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-book"><path d="M4 19.5A2.5 2.5 0 0 1 6.5 17H20"></path><path d="M6.5 2H20v20H6.5A2.5 2.5 0 0 1 4 19.5v-15A2.5 2.5 0 0 1 6.5 2z"></path></svg>');
    --icon-box-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-box"><path d="M21 16V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l7-4A2 2 0 0 0 21 16z"></path><polyline points="3.27 6.96 12 12.01 20.73 6.96"></polyline><line x1="12" y1="22.08" x2="12" y2="12"></line></svg>');
    --icon-briefcase-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-briefcase"><rect x="2" y="7" width="20" height="14" rx="2" ry="2"></rect><path d="M16 21V5a2 2 0 0 0-2-2h-4a2 2 0 0 0-2 2v16"></path></svg>');
    --icon-calendar-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-calendar"><rect x="3" y="4" width="18" height="18" rx="2" ry="2"></rect><line x1="16" y1="2" x2="16" y2="6"></line><line x1="8" y1="2" x2="8" y2="6"></line><line x1="3" y1="10" x2="21" y2="10"></line></svg>');
    --icon-camera-off-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-camera-off"><line x1="1" y1="1" x2="23" y2="23"></line><path d="M21 21H3a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h3m3-3h6l2 3h4a2 2 0 0 1 2 2v9.34m-7.72-2.06a4 4 0 1 1-5.56-5.56"></path></svg>');
    --icon-camera-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-camera"><path d="M23 19a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h4l2-3h6l2 3h4a2 2 0 0 1 2 2z"></path><circle cx="12" cy="13" r="4"></circle></svg>');
    --icon-cast-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-cast"><path d="M2 16.1A5 5 0 0 1 5.9 20M2 12.05A9 9 0 0 1 9.95 20M2 8V6a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2h-6"></path><line x1="2" y1="20" x2="2.01" y2="20"></line></svg>');
    --icon-check-circle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-check-circle"><path d="M22 11.08V12a10 10 0 1 1-5.93-9.14"></path><polyline points="22 4 12 14.01 9 11.01"></polyline></svg>');
    --icon-check-square-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-check-square"><polyline points="9 11 12 14 22 4"></polyline><path d="M21 12v7a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h11"></path></svg>');
    --icon-check-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-check"><polyline points="20 6 9 17 4 12"></polyline></svg>');
    --icon-chevron-down-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-down"><polyline points="6 9 12 15 18 9"></polyline></svg>');
    --icon-chevron-left-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-left"><polyline points="15 18 9 12 15 6"></polyline></svg>');
    --icon-chevron-right-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-right"><polyline points="9 18 15 12 9 6"></polyline></svg>');
    --icon-chevrons-down-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevrons-down"><polyline points="7 13 12 18 17 13"></polyline><polyline points="7 6 12 11 17 6"></polyline></svg>');
    --icon-chevrons-left-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevrons-left"><polyline points="11 17 6 12 11 7"></polyline><polyline points="18 17 13 12 18 7"></polyline></svg>');
    --icon-chevrons-right-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevrons-right"><polyline points="13 17 18 12 13 7"></polyline><polyline points="6 17 11 12 6 7"></polyline></svg>');
    --icon-chevrons-up-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevrons-up"><polyline points="17 11 12 6 7 11"></polyline><polyline points="17 18 12 13 7 18"></polyline></svg>');
    --icon-chevron-up-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-up"><polyline points="18 15 12 9 6 15"></polyline></svg>');
    --icon-chrome-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chrome"><circle cx="12" cy="12" r="10"></circle><circle cx="12" cy="12" r="4"></circle><line x1="21.17" y1="8" x2="12" y2="8"></line><line x1="3.95" y1="6.06" x2="8.54" y2="14"></line><line x1="10.88" y1="21.94" x2="15.46" y2="14"></line></svg>');
    --icon-circle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-circle"><circle cx="12" cy="12" r="10"></circle></svg>');
    --icon-clipboard-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-clipboard"><path d="M16 4h2a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2h2"></path><rect x="8" y="2" width="8" height="4" rx="1" ry="1"></rect></svg>');
    --icon-clock-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-clock"><circle cx="12" cy="12" r="10"></circle><polyline points="12 6 12 12 16 14"></polyline></svg>');
    --icon-cloud-drizzle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-cloud-drizzle"><line x1="8" y1="19" x2="8" y2="21"></line><line x1="8" y1="13" x2="8" y2="15"></line><line x1="16" y1="19" x2="16" y2="21"></line><line x1="16" y1="13" x2="16" y2="15"></line><line x1="12" y1="21" x2="12" y2="23"></line><line x1="12" y1="15" x2="12" y2="17"></line><path d="M20 16.58A5 5 0 0 0 18 7h-1.26A8 8 0 1 0 4 15.25"></path></svg>');
    --icon-cloud-lightning-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-cloud-lightning"><path d="M19 16.9A5 5 0 0 0 18 7h-1.26a8 8 0 1 0-11.62 9"></path><polyline points="13 11 9 17 15 17 11 23"></polyline></svg>');
    --icon-cloud-off-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-cloud-off"><path d="M22.61 16.95A5 5 0 0 0 18 10h-1.26a8 8 0 0 0-7.05-6M5 5a8 8 0 0 0 4 15h9a5 5 0 0 0 1.7-.3"></path><line x1="1" y1="1" x2="23" y2="23"></line></svg>');
    --icon-cloud-rain-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-cloud-rain"><line x1="16" y1="13" x2="16" y2="21"></line><line x1="8" y1="13" x2="8" y2="21"></line><line x1="12" y1="15" x2="12" y2="23"></line><path d="M20 16.58A5 5 0 0 0 18 7h-1.26A8 8 0 1 0 4 15.25"></path></svg>');
    --icon-cloud-snow-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-cloud-snow"><path d="M20 17.58A5 5 0 0 0 18 8h-1.26A8 8 0 1 0 4 16.25"></path><line x1="8" y1="16" x2="8.01" y2="16"></line><line x1="8" y1="20" x2="8.01" y2="20"></line><line x1="12" y1="18" x2="12.01" y2="18"></line><line x1="12" y1="22" x2="12.01" y2="22"></line><line x1="16" y1="16" x2="16.01" y2="16"></line><line x1="16" y1="20" x2="16.01" y2="20"></line></svg>');
    --icon-cloud-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-cloud"><path d="M18 10h-1.26A8 8 0 1 0 9 20h9a5 5 0 0 0 0-10z"></path></svg>');
    --icon-codepen-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-codepen"><polygon points="12 2 22 8.5 22 15.5 12 22 2 15.5 2 8.5 12 2"></polygon><line x1="12" y1="22" x2="12" y2="15.5"></line><polyline points="22 8.5 12 15.5 2 8.5"></polyline><polyline points="2 15.5 12 8.5 22 15.5"></polyline><line x1="12" y1="2" x2="12" y2="8.5"></line></svg>');
    --icon-codesandbox-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-codesandbox"><path d="M21 16V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l7-4A2 2 0 0 0 21 16z"></path><polyline points="7.5 4.21 12 6.81 16.5 4.21"></polyline><polyline points="7.5 19.79 7.5 14.6 3 12"></polyline><polyline points="21 12 16.5 14.6 16.5 19.79"></polyline><polyline points="3.27 6.96 12 12.01 20.73 6.96"></polyline><line x1="12" y1="22.08" x2="12" y2="12"></line></svg>');
    --icon-code-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-code"><polyline points="16 18 22 12 16 6"></polyline><polyline points="8 6 2 12 8 18"></polyline></svg>');
    --icon-coffee-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-coffee"><path d="M18 8h1a4 4 0 0 1 0 8h-1"></path><path d="M2 8h16v9a4 4 0 0 1-4 4H6a4 4 0 0 1-4-4V8z"></path><line x1="6" y1="1" x2="6" y2="4"></line><line x1="10" y1="1" x2="10" y2="4"></line><line x1="14" y1="1" x2="14" y2="4"></line></svg>');
    --icon-columns-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-columns"><path d="M12 3h7a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2h-7m0-18H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h7m0-18v18"></path></svg>');
    --icon-command-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-command"><path d="M18 3a3 3 0 0 0-3 3v12a3 3 0 0 0 3 3 3 3 0 0 0 3-3 3 3 0 0 0-3-3H6a3 3 0 0 0-3 3 3 3 0 0 0 3 3 3 3 0 0 0 3-3V6a3 3 0 0 0-3-3 3 3 0 0 0-3 3 3 3 0 0 0 3 3h12a3 3 0 0 0 3-3 3 3 0 0 0-3-3z"></path></svg>');
    --icon-compass-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-compass"><circle cx="12" cy="12" r="10"></circle><polygon points="16.24 7.76 14.12 14.12 7.76 16.24 9.88 9.88 16.24 7.76"></polygon></svg>');
    --icon-copy-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-copy"><rect x="9" y="9" width="13" height="13" rx="2" ry="2"></rect><path d="M5 15H4a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h9a2 2 0 0 1 2 2v1"></path></svg>');
    --icon-corner-down-left-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-corner-down-left"><polyline points="9 10 4 15 9 20"></polyline><path d="M20 4v7a4 4 0 0 1-4 4H4"></path></svg>');
    --icon-corner-down-right-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-corner-down-right"><polyline points="15 10 20 15 15 20"></polyline><path d="M4 4v7a4 4 0 0 0 4 4h12"></path></svg>');
    --icon-corner-left-down-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-corner-left-down"><polyline points="14 15 9 20 4 15"></polyline><path d="M20 4h-7a4 4 0 0 0-4 4v12"></path></svg>');
    --icon-corner-left-up-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-corner-left-up"><polyline points="14 9 9 4 4 9"></polyline><path d="M20 20h-7a4 4 0 0 1-4-4V4"></path></svg>');
    --icon-corner-right-down-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-corner-right-down"><polyline points="10 15 15 20 20 15"></polyline><path d="M4 4h7a4 4 0 0 1 4 4v12"></path></svg>');
    --icon-corner-right-up-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-corner-right-up"><polyline points="10 9 15 4 20 9"></polyline><path d="M4 20h7a4 4 0 0 0 4-4V4"></path></svg>');
    --icon-corner-up-left-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-corner-up-left"><polyline points="9 14 4 9 9 4"></polyline><path d="M20 20v-7a4 4 0 0 0-4-4H4"></path></svg>');
    --icon-corner-up-right-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-corner-up-right"><polyline points="15 14 20 9 15 4"></polyline><path d="M4 20v-7a4 4 0 0 1 4-4h12"></path></svg>');
    --icon-cpu-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-cpu"><rect x="4" y="4" width="16" height="16" rx="2" ry="2"></rect><rect x="9" y="9" width="6" height="6"></rect><line x1="9" y1="1" x2="9" y2="4"></line><line x1="15" y1="1" x2="15" y2="4"></line><line x1="9" y1="20" x2="9" y2="23"></line><line x1="15" y1="20" x2="15" y2="23"></line><line x1="20" y1="9" x2="23" y2="9"></line><line x1="20" y1="14" x2="23" y2="14"></line><line x1="1" y1="9" x2="4" y2="9"></line><line x1="1" y1="14" x2="4" y2="14"></line></svg>');
    --icon-credit-card-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-credit-card"><rect x="1" y="4" width="22" height="16" rx="2" ry="2"></rect><line x1="1" y1="10" x2="23" y2="10"></line></svg>');
    --icon-crop-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-crop"><path d="M6.13 1L6 16a2 2 0 0 0 2 2h15"></path><path d="M1 6.13L16 6a2 2 0 0 1 2 2v15"></path></svg>');
    --icon-crosshair-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-crosshair"><circle cx="12" cy="12" r="10"></circle><line x1="22" y1="12" x2="18" y2="12"></line><line x1="6" y1="12" x2="2" y2="12"></line><line x1="12" y1="6" x2="12" y2="2"></line><line x1="12" y1="22" x2="12" y2="18"></line></svg>');
    --icon-database-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-database"><ellipse cx="12" cy="5" rx="9" ry="3"></ellipse><path d="M21 12c0 1.66-4 3-9 3s-9-1.34-9-3"></path><path d="M3 5v14c0 1.66 4 3 9 3s9-1.34 9-3V5"></path></svg>');
    --icon-delete-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-delete"><path d="M21 4H8l-7 8 7 8h13a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2z"></path><line x1="18" y1="9" x2="12" y2="15"></line><line x1="12" y1="9" x2="18" y2="15"></line></svg>');
    --icon-disc-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-disc"><circle cx="12" cy="12" r="10"></circle><circle cx="12" cy="12" r="3"></circle></svg>');
    --icon-divide-circle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-divide-circle"><line x1="8" y1="12" x2="16" y2="12"></line><line x1="12" y1="16" x2="12" y2="16"></line><line x1="12" y1="8" x2="12" y2="8"></line><circle cx="12" cy="12" r="10"></circle></svg>');
    --icon-divide-square-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-divide-square"><rect x="3" y="3" width="18" height="18" rx="2" ry="2"></rect><line x1="8" y1="12" x2="16" y2="12"></line><line x1="12" y1="16" x2="12" y2="16"></line><line x1="12" y1="8" x2="12" y2="8"></line></svg>');
    --icon-divide-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-divide"><circle cx="12" cy="6" r="2"></circle><line x1="5" y1="12" x2="19" y2="12"></line><circle cx="12" cy="18" r="2"></circle></svg>');
    --icon-dollar-sign-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-dollar-sign"><line x1="12" y1="1" x2="12" y2="23"></line><path d="M17 5H9.5a3.5 3.5 0 0 0 0 7h5a3.5 3.5 0 0 1 0 7H6"></path></svg>');
    --icon-download-cloud-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-download-cloud"><polyline points="8 17 12 21 16 17"></polyline><line x1="12" y1="12" x2="12" y2="21"></line><path d="M20.88 18.09A5 5 0 0 0 18 9h-1.26A8 8 0 1 0 3 16.29"></path></svg>');
    --icon-download-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-download"><path d="M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4"></path><polyline points="7 10 12 15 17 10"></polyline><line x1="12" y1="15" x2="12" y2="3"></line></svg>');
    --icon-dribbble-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-dribbble"><circle cx="12" cy="12" r="10"></circle><path d="M8.56 2.75c4.37 6.03 6.02 9.42 8.03 17.72m2.54-15.38c-3.72 4.35-8.94 5.66-16.88 5.85m19.5 1.9c-3.5-.93-6.63-.82-8.94 0-2.58.92-5.01 2.86-7.44 6.32"></path></svg>');
    --icon-droplet-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-droplet"><path d="M12 2.69l5.66 5.66a8 8 0 1 1-11.31 0z"></path></svg>');
    --icon-edit-2-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-edit-2"><path d="M17 3a2.828 2.828 0 1 1 4 4L7.5 20.5 2 22l1.5-5.5L17 3z"></path></svg>');
    --icon-edit-3-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-edit-3"><path d="M12 20h9"></path><path d="M16.5 3.5a2.121 2.121 0 0 1 3 3L7 19l-4 1 1-4L16.5 3.5z"></path></svg>');
    --icon-edit-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-edit"><path d="M11 4H4a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2v-7"></path><path d="M18.5 2.5a2.121 2.121 0 0 1 3 3L12 15l-4 1 1-4 9.5-9.5z"></path></svg>');
    --icon-external-link-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-external-link"><path d="M18 13v6a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h6"></path><polyline points="15 3 21 3 21 9"></polyline><line x1="10" y1="14" x2="21" y2="3"></line></svg>');
    --icon-eye-off-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-eye-off"><path d="M17.94 17.94A10.07 10.07 0 0 1 12 20c-7 0-11-8-11-8a18.45 18.45 0 0 1 5.06-5.94M9.9 4.24A9.12 9.12 0 0 1 12 4c7 0 11 8 11 8a18.5 18.5 0 0 1-2.16 3.19m-6.72-1.07a3 3 0 1 1-4.24-4.24"></path><line x1="1" y1="1" x2="23" y2="23"></line></svg>');
    --icon-eye-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-eye"><path d="M1 12s4-8 11-8 11 8 11 8-4 8-11 8-11-8-11-8z"></path><circle cx="12" cy="12" r="3"></circle></svg>');
    --icon-facebook-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-facebook"><path d="M18 2h-3a5 5 0 0 0-5 5v3H7v4h3v8h4v-8h3l1-4h-4V7a1 1 0 0 1 1-1h3z"></path></svg>');
    --icon-fast-forward-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-fast-forward"><polygon points="13 19 22 12 13 5 13 19"></polygon><polygon points="2 19 11 12 2 5 2 19"></polygon></svg>');
    --icon-feather-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-feather"><path d="M20.24 12.24a6 6 0 0 0-8.49-8.49L5 10.5V19h8.5z"></path><line x1="16" y1="8" x2="2" y2="22"></line><line x1="17.5" y1="15" x2="9" y2="15"></line></svg>');
    --icon-figma-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-figma"><path d="M5 5.5A3.5 3.5 0 0 1 8.5 2H12v7H8.5A3.5 3.5 0 0 1 5 5.5z"></path><path d="M12 2h3.5a3.5 3.5 0 1 1 0 7H12V2z"></path><path d="M12 12.5a3.5 3.5 0 1 1 7 0 3.5 3.5 0 1 1-7 0z"></path><path d="M5 19.5A3.5 3.5 0 0 1 8.5 16H12v3.5a3.5 3.5 0 1 1-7 0z"></path><path d="M5 12.5A3.5 3.5 0 0 1 8.5 9H12v7H8.5A3.5 3.5 0 0 1 5 12.5z"></path></svg>');
    --icon-file-minus-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-file-minus"><path d="M14 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V8z"></path><polyline points="14 2 14 8 20 8"></polyline><line x1="9" y1="15" x2="15" y2="15"></line></svg>');
    --icon-file-plus-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-file-plus"><path d="M14 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V8z"></path><polyline points="14 2 14 8 20 8"></polyline><line x1="12" y1="18" x2="12" y2="12"></line><line x1="9" y1="15" x2="15" y2="15"></line></svg>');
    --icon-file-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-file"><path d="M13 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V9z"></path><polyline points="13 2 13 9 20 9"></polyline></svg>');
    --icon-file-text-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-file-text"><path d="M14 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V8z"></path><polyline points="14 2 14 8 20 8"></polyline><line x1="16" y1="13" x2="8" y2="13"></line><line x1="16" y1="17" x2="8" y2="17"></line><polyline points="10 9 9 9 8 9"></polyline></svg>');
    --icon-film-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-film"><rect x="2" y="2" width="20" height="20" rx="2.18" ry="2.18"></rect><line x1="7" y1="2" x2="7" y2="22"></line><line x1="17" y1="2" x2="17" y2="22"></line><line x1="2" y1="12" x2="22" y2="12"></line><line x1="2" y1="7" x2="7" y2="7"></line><line x1="2" y1="17" x2="7" y2="17"></line><line x1="17" y1="17" x2="22" y2="17"></line><line x1="17" y1="7" x2="22" y2="7"></line></svg>');
    --icon-filter-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-filter"><polygon points="22 3 2 3 10 12.46 10 19 14 21 14 12.46 22 3"></polygon></svg>');
    --icon-flag-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-flag"><path d="M4 15s1-1 4-1 5 2 8 2 4-1 4-1V3s-1 1-4 1-5-2-8-2-4 1-4 1z"></path><line x1="4" y1="22" x2="4" y2="15"></line></svg>');
    --icon-folder-minus-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-folder-minus"><path d="M22 19a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h5l2 3h9a2 2 0 0 1 2 2z"></path><line x1="9" y1="14" x2="15" y2="14"></line></svg>');
    --icon-folder-plus-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-folder-plus"><path d="M22 19a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h5l2 3h9a2 2 0 0 1 2 2z"></path><line x1="12" y1="11" x2="12" y2="17"></line><line x1="9" y1="14" x2="15" y2="14"></line></svg>');
    --icon-folder-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-folder"><path d="M22 19a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h5l2 3h9a2 2 0 0 1 2 2z"></path></svg>');
    --icon-framer-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-framer"><path d="M5 16V9h14V2H5l14 14h-7m-7 0l7 7v-7m-7 0h7"></path></svg>');
    --icon-frown-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-frown"><circle cx="12" cy="12" r="10"></circle><path d="M16 16s-1.5-2-4-2-4 2-4 2"></path><line x1="9" y1="9" x2="9.01" y2="9"></line><line x1="15" y1="9" x2="15.01" y2="9"></line></svg>');
    --icon-gift-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-gift"><polyline points="20 12 20 22 4 22 4 12"></polyline><rect x="2" y="7" width="20" height="5"></rect><line x1="12" y1="22" x2="12" y2="7"></line><path d="M12 7H7.5a2.5 2.5 0 0 1 0-5C11 2 12 7 12 7z"></path><path d="M12 7h4.5a2.5 2.5 0 0 0 0-5C13 2 12 7 12 7z"></path></svg>');
    --icon-git-branch-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-git-branch"><line x1="6" y1="3" x2="6" y2="15"></line><circle cx="18" cy="6" r="3"></circle><circle cx="6" cy="18" r="3"></circle><path d="M18 9a9 9 0 0 1-9 9"></path></svg>');
    --icon-git-commit-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-git-commit"><circle cx="12" cy="12" r="4"></circle><line x1="1.05" y1="12" x2="7" y2="12"></line><line x1="17.01" y1="12" x2="22.96" y2="12"></line></svg>');
    --icon-github-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-github"><path d="M9 19c-5 1.5-5-2.5-7-3m14 6v-3.87a3.37 3.37 0 0 0-.94-2.61c3.14-.35 6.44-1.54 6.44-7A5.44 5.44 0 0 0 20 4.77 5.07 5.07 0 0 0 19.91 1S18.73.65 16 2.48a13.38 13.38 0 0 0-7 0C6.27.65 5.09 1 5.09 1A5.07 5.07 0 0 0 5 4.77a5.44 5.44 0 0 0-1.5 3.78c0 5.42 3.3 6.61 6.44 7A3.37 3.37 0 0 0 9 18.13V22"></path></svg>');
    --icon-gitlab-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-gitlab"><path d="M22.65 14.39L12 22.13 1.35 14.39a.84.84 0 0 1-.3-.94l1.22-3.78 2.44-7.51A.42.42 0 0 1 4.82 2a.43.43 0 0 1 .58 0 .42.42 0 0 1 .11.18l2.44 7.49h8.1l2.44-7.51A.42.42 0 0 1 18.6 2a.43.43 0 0 1 .58 0 .42.42 0 0 1 .11.18l2.44 7.51L23 13.45a.84.84 0 0 1-.35.94z"></path></svg>');
    --icon-git-merge-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-git-merge"><circle cx="18" cy="18" r="3"></circle><circle cx="6" cy="6" r="3"></circle><path d="M6 21V9a9 9 0 0 0 9 9"></path></svg>');
    --icon-git-pull-request-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-git-pull-request"><circle cx="18" cy="18" r="3"></circle><circle cx="6" cy="6" r="3"></circle><path d="M13 6h3a2 2 0 0 1 2 2v7"></path><line x1="6" y1="9" x2="6" y2="21"></line></svg>');
    --icon-globe-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-globe"><circle cx="12" cy="12" r="10"></circle><line x1="2" y1="12" x2="22" y2="12"></line><path d="M12 2a15.3 15.3 0 0 1 4 10 15.3 15.3 0 0 1-4 10 15.3 15.3 0 0 1-4-10 15.3 15.3 0 0 1 4-10z"></path></svg>');
    --icon-grid-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-grid"><rect x="3" y="3" width="7" height="7"></rect><rect x="14" y="3" width="7" height="7"></rect><rect x="14" y="14" width="7" height="7"></rect><rect x="3" y="14" width="7" height="7"></rect></svg>');
    --icon-hard-drive-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-hard-drive"><line x1="22" y1="12" x2="2" y2="12"></line><path d="M5.45 5.11L2 12v6a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-6l-3.45-6.89A2 2 0 0 0 16.76 4H7.24a2 2 0 0 0-1.79 1.11z"></path><line x1="6" y1="16" x2="6.01" y2="16"></line><line x1="10" y1="16" x2="10.01" y2="16"></line></svg>');
    --icon-hash-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-hash"><line x1="4" y1="9" x2="20" y2="9"></line><line x1="4" y1="15" x2="20" y2="15"></line><line x1="10" y1="3" x2="8" y2="21"></line><line x1="16" y1="3" x2="14" y2="21"></line></svg>');
    --icon-headphones-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-headphones"><path d="M3 18v-6a9 9 0 0 1 18 0v6"></path><path d="M21 19a2 2 0 0 1-2 2h-1a2 2 0 0 1-2-2v-3a2 2 0 0 1 2-2h3zM3 19a2 2 0 0 0 2 2h1a2 2 0 0 0 2-2v-3a2 2 0 0 0-2-2H3z"></path></svg>');
    --icon-heart-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-heart"><path d="M20.84 4.61a5.5 5.5 0 0 0-7.78 0L12 5.67l-1.06-1.06a5.5 5.5 0 0 0-7.78 7.78l1.06 1.06L12 21.23l7.78-7.78 1.06-1.06a5.5 5.5 0 0 0 0-7.78z"></path></svg>');
    --icon-help-circle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-help-circle"><circle cx="12" cy="12" r="10"></circle><path d="M9.09 9a3 3 0 0 1 5.83 1c0 2-3 3-3 3"></path><line x1="12" y1="17" x2="12.01" y2="17"></line></svg>');
    --icon-hexagon-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-hexagon"><path d="M21 16V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l7-4A2 2 0 0 0 21 16z"></path></svg>');
    --icon-home-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-home"><path d="M3 9l9-7 9 7v11a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2z"></path><polyline points="9 22 9 12 15 12 15 22"></polyline></svg>');
    --icon-image-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-image"><rect x="3" y="3" width="18" height="18" rx="2" ry="2"></rect><circle cx="8.5" cy="8.5" r="1.5"></circle><polyline points="21 15 16 10 5 21"></polyline></svg>');
    --icon-inbox-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-inbox"><polyline points="22 12 16 12 14 15 10 15 8 12 2 12"></polyline><path d="M5.45 5.11L2 12v6a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-6l-3.45-6.89A2 2 0 0 0 16.76 4H7.24a2 2 0 0 0-1.79 1.11z"></path></svg>');
    --icon-info-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-info"><circle cx="12" cy="12" r="10"></circle><line x1="12" y1="16" x2="12" y2="12"></line><line x1="12" y1="8" x2="12.01" y2="8"></line></svg>');
    --icon-instagram-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-instagram"><rect x="2" y="2" width="20" height="20" rx="5" ry="5"></rect><path d="M16 11.37A4 4 0 1 1 12.63 8 4 4 0 0 1 16 11.37z"></path><line x1="17.5" y1="6.5" x2="17.51" y2="6.5"></line></svg>');
    --icon-italic-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-italic"><line x1="19" y1="4" x2="10" y2="4"></line><line x1="14" y1="20" x2="5" y2="20"></line><line x1="15" y1="4" x2="9" y2="20"></line></svg>');
    --icon-key-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-key"><path d="M21 2l-2 2m-7.61 7.61a5.5 5.5 0 1 1-7.778 7.778 5.5 5.5 0 0 1 7.777-7.777zm0 0L15.5 7.5m0 0l3 3L22 7l-3-3m-3.5 3.5L19 4"></path></svg>');
    --icon-layers-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-layers"><polygon points="12 2 2 7 12 12 22 7 12 2"></polygon><polyline points="2 17 12 22 22 17"></polyline><polyline points="2 12 12 17 22 12"></polyline></svg>');
    --icon-layout-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-layout"><rect x="3" y="3" width="18" height="18" rx="2" ry="2"></rect><line x1="3" y1="9" x2="21" y2="9"></line><line x1="9" y1="21" x2="9" y2="9"></line></svg>');
    --icon-life-buoy-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-life-buoy"><circle cx="12" cy="12" r="10"></circle><circle cx="12" cy="12" r="4"></circle><line x1="4.93" y1="4.93" x2="9.17" y2="9.17"></line><line x1="14.83" y1="14.83" x2="19.07" y2="19.07"></line><line x1="14.83" y1="9.17" x2="19.07" y2="4.93"></line><line x1="14.83" y1="9.17" x2="18.36" y2="5.64"></line><line x1="4.93" y1="19.07" x2="9.17" y2="14.83"></line></svg>');
    --icon-linkify-2-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-link-2"><path d="M15 7h3a5 5 0 0 1 5 5 5 5 0 0 1-5 5h-3m-6 0H6a5 5 0 0 1-5-5 5 5 0 0 1 5-5h3"></path><line x1="8" y1="12" x2="16" y2="12"></line></svg>');
    --icon-linkedin-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-linkedin"><path d="M16 8a6 6 0 0 1 6 6v7h-4v-7a2 2 0 0 0-2-2 2 2 0 0 0-2 2v7h-4v-7a6 6 0 0 1 6-6z"></path><rect x="2" y="9" width="4" height="12"></rect><circle cx="4" cy="4" r="2"></circle></svg>');
    --icon-linkify-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-link"><path d="M10 13a5 5 0 0 0 7.54.54l3-3a5 5 0 0 0-7.07-7.07l-1.72 1.71"></path><path d="M14 11a5 5 0 0 0-7.54-.54l-3 3a5 5 0 0 0 7.07 7.07l1.71-1.71"></path></svg>');
    --icon-list-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-list"><line x1="8" y1="6" x2="21" y2="6"></line><line x1="8" y1="12" x2="21" y2="12"></line><line x1="8" y1="18" x2="21" y2="18"></line><line x1="3" y1="6" x2="3.01" y2="6"></line><line x1="3" y1="12" x2="3.01" y2="12"></line><line x1="3" y1="18" x2="3.01" y2="18"></line></svg>');
    --icon-loader-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-loader"><line x1="12" y1="2" x2="12" y2="6"></line><line x1="12" y1="18" x2="12" y2="22"></line><line x1="4.93" y1="4.93" x2="7.76" y2="7.76"></line><line x1="16.24" y1="16.24" x2="19.07" y2="19.07"></line><line x1="2" y1="12" x2="6" y2="12"></line><line x1="18" y1="12" x2="22" y2="12"></line><line x1="4.93" y1="19.07" x2="7.76" y2="16.24"></line><line x1="16.24" y1="7.76" x2="19.07" y2="4.93"></line></svg>');
    --icon-lock-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-lock"><rect x="3" y="11" width="18" height="11" rx="2" ry="2"></rect><path d="M7 11V7a5 5 0 0 1 10 0v4"></path></svg>');
    --icon-log-in-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-log-in"><path d="M15 3h4a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2h-4"></path><polyline points="10 17 15 12 10 7"></polyline><line x1="15" y1="12" x2="3" y2="12"></line></svg>');
    --icon-log-out-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-log-out"><path d="M9 21H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h4"></path><polyline points="16 17 21 12 16 7"></polyline><line x1="21" y1="12" x2="9" y2="12"></line></svg>');
    --icon-mail-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-mail"><path d="M4 4h16c1.1 0 2 .9 2 2v12c0 1.1-.9 2-2 2H4c-1.1 0-2-.9-2-2V6c0-1.1.9-2 2-2z"></path><polyline points="22,6 12,13 2,6"></polyline></svg>');
    --icon-map-pin-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-map-pin"><path d="M21 10c0 7-9 13-9 13s-9-6-9-13a9 9 0 0 1 18 0z"></path><circle cx="12" cy="10" r="3"></circle></svg>');
    --icon-map-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-map"><polygon points="1 6 1 22 8 18 16 22 23 18 23 2 16 6 8 2 1 6"></polygon><line x1="8" y1="2" x2="8" y2="18"></line><line x1="16" y1="6" x2="16" y2="22"></line></svg>');
    --icon-maximize-2-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-maximize-2"><polyline points="15 3 21 3 21 9"></polyline><polyline points="9 21 3 21 3 15"></polyline><line x1="21" y1="3" x2="14" y2="10"></line><line x1="3" y1="21" x2="10" y2="14"></line></svg>');
    --icon-maximize-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-maximize"><path d="M8 3H5a2 2 0 0 0-2 2v3m18 0V5a2 2 0 0 0-2-2h-3m0 18h3a2 2 0 0 0 2-2v-3M3 16v3a2 2 0 0 0 2 2h3"></path></svg>');
    --icon-meh-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-meh"><circle cx="12" cy="12" r="10"></circle><line x1="8" y1="15" x2="16" y2="15"></line><line x1="9" y1="9" x2="9.01" y2="9"></line><line x1="15" y1="9" x2="15.01" y2="9"></line></svg>');
    --icon-menu-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-menu"><line x1="3" y1="12" x2="21" y2="12"></line><line x1="3" y1="6" x2="21" y2="6"></line><line x1="3" y1="18" x2="21" y2="18"></line></svg>');
    --icon-message-circle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-message-circle"><path d="M21 11.5a8.38 8.38 0 0 1-.9 3.8 8.5 8.5 0 0 1-7.6 4.7 8.38 8.38 0 0 1-3.8-.9L3 21l1.9-5.7a8.38 8.38 0 0 1-.9-3.8 8.5 8.5 0 0 1 4.7-7.6 8.38 8.38 0 0 1 3.8-.9h.5a8.48 8.48 0 0 1 8 8v.5z"></path></svg>');
    --icon-message-square-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-message-square"><path d="M21 15a2 2 0 0 1-2 2H7l-4 4V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2z"></path></svg>');
    --icon-mic-off-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-mic-off"><line x1="1" y1="1" x2="23" y2="23"></line><path d="M9 9v3a3 3 0 0 0 5.12 2.12M15 9.34V4a3 3 0 0 0-5.94-.6"></path><path d="M17 16.95A7 7 0 0 1 5 12v-2m14 0v2a7 7 0 0 1-.11 1.23"></path><line x1="12" y1="19" x2="12" y2="23"></line><line x1="8" y1="23" x2="16" y2="23"></line></svg>');
    --icon-mic-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-mic"><path d="M12 1a3 3 0 0 0-3 3v8a3 3 0 0 0 6 0V4a3 3 0 0 0-3-3z"></path><path d="M19 10v2a7 7 0 0 1-14 0v-2"></path><line x1="12" y1="19" x2="12" y2="23"></line><line x1="8" y1="23" x2="16" y2="23"></line></svg>');
    --icon-minimize-2-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-minimize-2"><polyline points="4 14 10 14 10 20"></polyline><polyline points="20 10 14 10 14 4"></polyline><line x1="14" y1="10" x2="21" y2="3"></line><line x1="3" y1="21" x2="10" y2="14"></line></svg>');
    --icon-minimize-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-minimize"><path d="M8 3v3a2 2 0 0 1-2 2H3m18 0h-3a2 2 0 0 1-2-2V3m0 18v-3a2 2 0 0 1 2-2h3M3 16h3a2 2 0 0 1 2 2v3"></path></svg>');
    --icon-minus-circle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-minus-circle"><circle cx="12" cy="12" r="10"></circle><line x1="8" y1="12" x2="16" y2="12"></line></svg>');
    --icon-minus-square-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-minus-square"><rect x="3" y="3" width="18" height="18" rx="2" ry="2"></rect><line x1="8" y1="12" x2="16" y2="12"></line></svg>');
    --icon-minus-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-minus"><line x1="5" y1="12" x2="19" y2="12"></line></svg>');
    --icon-monitor-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-monitor"><rect x="2" y="3" width="20" height="14" rx="2" ry="2"></rect><line x1="8" y1="21" x2="16" y2="21"></line><line x1="12" y1="17" x2="12" y2="21"></line></svg>');
    --icon-moon-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-moon"><path d="M21 12.79A9 9 0 1 1 11.21 3 7 7 0 0 0 21 12.79z"></path></svg>');
    --icon-more-horizontal-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-more-horizontal"><circle cx="12" cy="12" r="1"></circle><circle cx="19" cy="12" r="1"></circle><circle cx="5" cy="12" r="1"></circle></svg>');
    --icon-more-vertical-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-more-vertical"><circle cx="12" cy="12" r="1"></circle><circle cx="12" cy="5" r="1"></circle><circle cx="12" cy="19" r="1"></circle></svg>');
    --icon-mouse-pointer-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-mouse-pointer"><path d="M3 3l7.07 16.97 2.51-7.39 7.39-2.51L3 3z"></path><path d="M13 13l6 6"></path></svg>');
    --icon-move-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-move"><polyline points="5 9 2 12 5 15"></polyline><polyline points="9 5 12 2 15 5"></polyline><polyline points="15 19 12 22 9 19"></polyline><polyline points="19 9 22 12 19 15"></polyline><line x1="2" y1="12" x2="22" y2="12"></line><line x1="12" y1="2" x2="12" y2="22"></line></svg>');
    --icon-music-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-music"><path d="M9 18V5l12-2v13"></path><circle cx="6" cy="18" r="3"></circle><circle cx="18" cy="16" r="3"></circle></svg>');
    --icon-navigation-2-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-navigation-2"><polygon points="12 2 19 21 12 17 5 21 12 2"></polygon></svg>');
    --icon-navigation-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-navigation"><polygon points="3 11 22 2 13 21 11 13 3 11"></polygon></svg>');
    --icon-octagon-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-octagon"><polygon points="7.86 2 16.14 2 22 7.86 22 16.14 16.14 22 7.86 22 2 16.14 2 7.86 7.86 2"></polygon></svg>');
    --icon-package-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-package"><line x1="16.5" y1="9.4" x2="7.5" y2="4.21"></line><path d="M21 16V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l7-4A2 2 0 0 0 21 16z"></path><polyline points="3.27 6.96 12 12.01 20.73 6.96"></polyline><line x1="12" y1="22.08" x2="12" y2="12"></line></svg>');
    --icon-paperclip-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-paperclip"><path d="M21.44 11.05l-9.19 9.19a6 6 0 0 1-8.49-8.49l9.19-9.19a4 4 0 0 1 5.66 5.66l-9.2 9.19a2 2 0 0 1-2.83-2.83l8.49-8.48"></path></svg>');
    --icon-pause-circle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-pause-circle"><circle cx="12" cy="12" r="10"></circle><line x1="10" y1="15" x2="10" y2="9"></line><line x1="14" y1="15" x2="14" y2="9"></line></svg>');
    --icon-pause-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-pause"><rect x="6" y="4" width="4" height="16"></rect><rect x="14" y="4" width="4" height="16"></rect></svg>');
    --icon-pen-tool-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-pen-tool"><path d="M12 19l7-7 3 3-7 7-3-3z"></path><path d="M18 13l-1.5-7.5L2 2l3.5 14.5L13 18l5-5z"></path><path d="M2 2l7.586 7.586"></path><circle cx="11" cy="11" r="2"></circle></svg>');
    --icon-percent-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-percent"><line x1="19" y1="5" x2="5" y2="19"></line><circle cx="6.5" cy="6.5" r="2.5"></circle><circle cx="17.5" cy="17.5" r="2.5"></circle></svg>');
    --icon-phone-call-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-phone-call"><path d="M15.05 5A5 5 0 0 1 19 8.95M15.05 1A9 9 0 0 1 23 8.94m-1 7.98v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.5 19.5 0 0 1-6-6 19.79 19.79 0 0 1-3.07-8.67A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91a16 16 0 0 0 6 6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7A2 2 0 0 1 22 16.92z"></path></svg>');
    --icon-phone-forwarded-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-phone-forwarded"><polyline points="19 1 23 5 19 9"></polyline><line x1="15" y1="5" x2="23" y2="5"></line><path d="M22 16.92v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.5 19.5 0 0 1-6-6 19.79 19.79 0 0 1-3.07-8.67A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91a16 16 0 0 0 6 6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7A2 2 0 0 1 22 16.92z"></path></svg>');
    --icon-phone-incoming-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-phone-incoming"><polyline points="16 2 16 8 22 8"></polyline><line x1="23" y1="1" x2="16" y2="8"></line><path d="M22 16.92v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.5 19.5 0 0 1-6-6 19.79 19.79 0 0 1-3.07-8.67A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91a16 16 0 0 0 6 6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7A2 2 0 0 1 22 16.92z"></path></svg>');
    --icon-phone-missed-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-phone-missed"><line x1="23" y1="1" x2="17" y2="7"></line><line x1="17" y1="1" x2="23" y2="7"></line><path d="M22 16.92v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.5 19.5 0 0 1-6-6 19.79 19.79 0 0 1-3.07-8.67A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91a16 16 0 0 0 6 6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7A2 2 0 0 1 22 16.92z"></path></svg>');
    --icon-phone-off-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-phone-off"><path d="M10.68 13.31a16 16 0 0 0 3.41 2.6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7 2 2 0 0 1 1.72 2v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.42 19.42 0 0 1-3.33-2.67m-2.67-3.34a19.79 19.79 0 0 1-3.07-8.63A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91"></path><line x1="23" y1="1" x2="1" y2="23"></line></svg>');
    --icon-phone-outgoing-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-phone-outgoing"><polyline points="23 7 23 1 17 1"></polyline><line x1="16" y1="8" x2="23" y2="1"></line><path d="M22 16.92v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.5 19.5 0 0 1-6-6 19.79 19.79 0 0 1-3.07-8.67A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91a16 16 0 0 0 6 6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7A2 2 0 0 1 22 16.92z"></path></svg>');
    --icon-phone-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-phone"><path d="M22 16.92v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.5 19.5 0 0 1-6-6 19.79 19.79 0 0 1-3.07-8.67A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91a16 16 0 0 0 6 6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7A2 2 0 0 1 22 16.92z"></path></svg>');
    --icon-pie-chart-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-pie-chart"><path d="M21.21 15.89A10 10 0 1 1 8 2.83"></path><path d="M22 12A10 10 0 0 0 12 2v10z"></path></svg>');
    --icon-play-circle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-play-circle"><circle cx="12" cy="12" r="10"></circle><polygon points="10 8 16 12 10 16 10 8"></polygon></svg>');
    --icon-play-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-play"><polygon points="5 3 19 12 5 21 5 3"></polygon></svg>');
    --icon-plus-circle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-plus-circle"><circle cx="12" cy="12" r="10"></circle><line x1="12" y1="8" x2="12" y2="16"></line><line x1="8" y1="12" x2="16" y2="12"></line></svg>');
    --icon-plus-square-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-plus-square"><rect x="3" y="3" width="18" height="18" rx="2" ry="2"></rect><line x1="12" y1="8" x2="12" y2="16"></line><line x1="8" y1="12" x2="16" y2="12"></line></svg>');
    --icon-plus-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-plus"><line x1="12" y1="5" x2="12" y2="19"></line><line x1="5" y1="12" x2="19" y2="12"></line></svg>');
    --icon-pocket-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-pocket"><path d="M4 3h16a2 2 0 0 1 2 2v6a10 10 0 0 1-10 10A10 10 0 0 1 2 11V5a2 2 0 0 1 2-2z"></path><polyline points="8 10 12 14 16 10"></polyline></svg>');
    --icon-power-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-power"><path d="M18.36 6.64a9 9 0 1 1-12.73 0"></path><line x1="12" y1="2" x2="12" y2="12"></line></svg>');
    --icon-printer-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-printer"><polyline points="6 9 6 2 18 2 18 9"></polyline><path d="M6 18H4a2 2 0 0 1-2-2v-5a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2h-2"></path><rect x="6" y="14" width="12" height="8"></rect></svg>');
    --icon-radio-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-radio"><circle cx="12" cy="12" r="2"></circle><path d="M16.24 7.76a6 6 0 0 1 0 8.49m-8.48-.01a6 6 0 0 1 0-8.49m11.31-2.82a10 10 0 0 1 0 14.14m-14.14 0a10 10 0 0 1 0-14.14"></path></svg>');
    --icon-refresh-ccw-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-refresh-ccw"><polyline points="1 4 1 10 7 10"></polyline><polyline points="23 20 23 14 17 14"></polyline><path d="M20.49 9A9 9 0 0 0 5.64 5.64L1 10m22 4l-4.64 4.36A9 9 0 0 1 3.51 15"></path></svg>');
    --icon-refresh-cw-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-refresh-cw"><polyline points="23 4 23 10 17 10"></polyline><polyline points="1 20 1 14 7 14"></polyline><path d="M3.51 9a9 9 0 0 1 14.85-3.36L23 10M1 14l4.64 4.36A9 9 0 0 0 20.49 15"></path></svg>');
    --icon-repeat-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-repeat"><polyline points="17 1 21 5 17 9"></polyline><path d="M3 11V9a4 4 0 0 1 4-4h14"></path><polyline points="7 23 3 19 7 15"></polyline><path d="M21 13v2a4 4 0 0 1-4 4H3"></path></svg>');
    --icon-rewind-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-rewind"><polygon points="11 19 2 12 11 5 11 19"></polygon><polygon points="22 19 13 12 22 5 22 19"></polygon></svg>');
    --icon-rotate-ccw-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-rotate-ccw"><polyline points="1 4 1 10 7 10"></polyline><path d="M3.51 15a9 9 0 1 0 2.13-9.36L1 10"></path></svg>');
    --icon-rotate-cw-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-rotate-cw"><polyline points="23 4 23 10 17 10"></polyline><path d="M20.49 15a9 9 0 1 1-2.12-9.36L23 10"></path></svg>');
    --icon-rss-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-rss"><path d="M4 11a9 9 0 0 1 9 9"></path><path d="M4 4a16 16 0 0 1 16 16"></path><circle cx="5" cy="19" r="1"></circle></svg>');
    --icon-save-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-save"><path d="M19 21H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h11l5 5v11a2 2 0 0 1-2 2z"></path><polyline points="17 21 17 13 7 13 7 21"></polyline><polyline points="7 3 7 8 15 8"></polyline></svg>');
    --icon-scissors-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-scissors"><circle cx="6" cy="6" r="3"></circle><circle cx="6" cy="18" r="3"></circle><line x1="20" y1="4" x2="8.12" y2="15.88"></line><line x1="14.47" y1="14.48" x2="20" y2="20"></line><line x1="8.12" y1="8.12" x2="12" y2="12"></line></svg>');
    --icon-search-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-search"><circle cx="11" cy="11" r="8"></circle><line x1="21" y1="21" x2="16.65" y2="16.65"></line></svg>');
    --icon-send-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-send"><line x1="22" y1="2" x2="11" y2="13"></line><polygon points="22 2 15 22 11 13 2 9 22 2"></polygon></svg>');
    --icon-server-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-server"><rect x="2" y="2" width="20" height="8" rx="2" ry="2"></rect><rect x="2" y="14" width="20" height="8" rx="2" ry="2"></rect><line x1="6" y1="6" x2="6.01" y2="6"></line><line x1="6" y1="18" x2="6.01" y2="18"></line></svg>');
    --icon-settings-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-settings"><circle cx="12" cy="12" r="3"></circle><path d="M19.4 15a1.65 1.65 0 0 0 .33 1.82l.06.06a2 2 0 0 1 0 2.83 2 2 0 0 1-2.83 0l-.06-.06a1.65 1.65 0 0 0-1.82-.33 1.65 1.65 0 0 0-1 1.51V21a2 2 0 0 1-2 2 2 2 0 0 1-2-2v-.09A1.65 1.65 0 0 0 9 19.4a1.65 1.65 0 0 0-1.82.33l-.06.06a2 2 0 0 1-2.83 0 2 2 0 0 1 0-2.83l.06-.06a1.65 1.65 0 0 0 .33-1.82 1.65 1.65 0 0 0-1.51-1H3a2 2 0 0 1-2-2 2 2 0 0 1 2-2h.09A1.65 1.65 0 0 0 4.6 9a1.65 1.65 0 0 0-.33-1.82l-.06-.06a2 2 0 0 1 0-2.83 2 2 0 0 1 2.83 0l.06.06a1.65 1.65 0 0 0 1.82.33H9a1.65 1.65 0 0 0 1-1.51V3a2 2 0 0 1 2-2 2 2 0 0 1 2 2v.09a1.65 1.65 0 0 0 1 1.51 1.65 1.65 0 0 0 1.82-.33l.06-.06a2 2 0 0 1 2.83 0 2 2 0 0 1 0 2.83l-.06.06a1.65 1.65 0 0 0-.33 1.82V9a1.65 1.65 0 0 0 1.51 1H21a2 2 0 0 1 2 2 2 2 0 0 1-2 2h-.09a1.65 1.65 0 0 0-1.51 1z"></path></svg>');
    --icon-share-2-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-share-2"><circle cx="18" cy="5" r="3"></circle><circle cx="6" cy="12" r="3"></circle><circle cx="18" cy="19" r="3"></circle><line x1="8.59" y1="13.51" x2="15.42" y2="17.49"></line><line x1="15.41" y1="6.51" x2="8.59" y2="10.49"></line></svg>');
    --icon-share-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-share"><path d="M4 12v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-8"></path><polyline points="16 6 12 2 8 6"></polyline><line x1="12" y1="2" x2="12" y2="15"></line></svg>');
    --icon-shield-off-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-shield-off"><path d="M19.69 14a6.9 6.9 0 0 0 .31-2V5l-8-3-3.16 1.18"></path><path d="M4.73 4.73L4 5v7c0 6 8 10 8 10a20.29 20.29 0 0 0 5.62-4.38"></path><line x1="1" y1="1" x2="23" y2="23"></line></svg>');
    --icon-shield-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-shield"><path d="M12 22s8-4 8-10V5l-8-3-8 3v7c0 6 8 10 8 10z"></path></svg>');
    --icon-shopping-bag-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-shopping-bag"><path d="M6 2L3 6v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2V6l-3-4z"></path><line x1="3" y1="6" x2="21" y2="6"></line><path d="M16 10a4 4 0 0 1-8 0"></path></svg>');
    --icon-shopping-cart-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-shopping-cart"><circle cx="9" cy="21" r="1"></circle><circle cx="20" cy="21" r="1"></circle><path d="M1 1h4l2.68 13.39a2 2 0 0 0 2 1.61h9.72a2 2 0 0 0 2-1.61L23 6H6"></path></svg>');
    --icon-shuffle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-shuffle"><polyline points="16 3 21 3 21 8"></polyline><line x1="4" y1="20" x2="21" y2="3"></line><polyline points="21 16 21 21 16 21"></polyline><line x1="15" y1="15" x2="21" y2="21"></line><line x1="4" y1="4" x2="9" y2="9"></line></svg>');
    --icon-sidebar-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-sidebar"><rect x="3" y="3" width="18" height="18" rx="2" ry="2"></rect><line x1="9" y1="3" x2="9" y2="21"></line></svg>');
    --icon-skip-back-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-skip-back"><polygon points="19 20 9 12 19 4 19 20"></polygon><line x1="5" y1="19" x2="5" y2="5"></line></svg>');
    --icon-skip-forward-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-skip-forward"><polygon points="5 4 15 12 5 20 5 4"></polygon><line x1="19" y1="5" x2="19" y2="19"></line></svg>');
    --icon-slack-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-slack"><path d="M14.5 10c-.83 0-1.5-.67-1.5-1.5v-5c0-.83.67-1.5 1.5-1.5s1.5.67 1.5 1.5v5c0 .83-.67 1.5-1.5 1.5z"></path><path d="M20.5 10H19V8.5c0-.83.67-1.5 1.5-1.5s1.5.67 1.5 1.5-.67 1.5-1.5 1.5z"></path><path d="M9.5 14c.83 0 1.5.67 1.5 1.5v5c0 .83-.67 1.5-1.5 1.5S8 21.33 8 20.5v-5c0-.83.67-1.5 1.5-1.5z"></path><path d="M3.5 14H5v1.5c0 .83-.67 1.5-1.5 1.5S2 16.33 2 15.5 2.67 14 3.5 14z"></path><path d="M14 14.5c0-.83.67-1.5 1.5-1.5h5c.83 0 1.5.67 1.5 1.5s-.67 1.5-1.5 1.5h-5c-.83 0-1.5-.67-1.5-1.5z"></path><path d="M15.5 19H14v1.5c0 .83.67 1.5 1.5 1.5s1.5-.67 1.5-1.5-.67-1.5-1.5-1.5z"></path><path d="M10 9.5C10 8.67 9.33 8 8.5 8h-5C2.67 8 2 8.67 2 9.5S2.67 11 3.5 11h5c.83 0 1.5-.67 1.5-1.5z"></path><path d="M8.5 5H10V3.5C10 2.67 9.33 2 8.5 2S7 2.67 7 3.5 7.67 5 8.5 5z"></path></svg>');
    --icon-slash-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-slash"><circle cx="12" cy="12" r="10"></circle><line x1="4.93" y1="4.93" x2="19.07" y2="19.07"></line></svg>');
    --icon-sliders-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-sliders"><line x1="4" y1="21" x2="4" y2="14"></line><line x1="4" y1="10" x2="4" y2="3"></line><line x1="12" y1="21" x2="12" y2="12"></line><line x1="12" y1="8" x2="12" y2="3"></line><line x1="20" y1="21" x2="20" y2="16"></line><line x1="20" y1="12" x2="20" y2="3"></line><line x1="1" y1="14" x2="7" y2="14"></line><line x1="9" y1="8" x2="15" y2="8"></line><line x1="17" y1="16" x2="23" y2="16"></line></svg>');
    --icon-smartphone-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-smartphone"><rect x="5" y="2" width="14" height="20" rx="2" ry="2"></rect><line x1="12" y1="18" x2="12.01" y2="18"></line></svg>');
    --icon-smile-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-smile"><circle cx="12" cy="12" r="10"></circle><path d="M8 14s1.5 2 4 2 4-2 4-2"></path><line x1="9" y1="9" x2="9.01" y2="9"></line><line x1="15" y1="9" x2="15.01" y2="9"></line></svg>');
    --icon-speaker-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-speaker"><rect x="4" y="2" width="16" height="20" rx="2" ry="2"></rect><circle cx="12" cy="14" r="4"></circle><line x1="12" y1="6" x2="12.01" y2="6"></line></svg>');
    --icon-square-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-square"><rect x="3" y="3" width="18" height="18" rx="2" ry="2"></rect></svg>');
    --icon-star-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-star"><polygon points="12 2 15.09 8.26 22 9.27 17 14.14 18.18 21.02 12 17.77 5.82 21.02 7 14.14 2 9.27 8.91 8.26 12 2"></polygon></svg>');
    --icon-stop-circle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-stop-circle"><circle cx="12" cy="12" r="10"></circle><rect x="9" y="9" width="6" height="6"></rect></svg>');
    --icon-sunrise-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-sunrise"><path d="M17 18a5 5 0 0 0-10 0"></path><line x1="12" y1="2" x2="12" y2="9"></line><line x1="4.22" y1="10.22" x2="5.64" y2="11.64"></line><line x1="1" y1="18" x2="3" y2="18"></line><line x1="21" y1="18" x2="23" y2="18"></line><line x1="18.36" y1="11.64" x2="19.78" y2="10.22"></line><line x1="23" y1="22" x2="1" y2="22"></line><polyline points="8 6 12 2 16 6"></polyline></svg>');
    --icon-sunset-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-sunset"><path d="M17 18a5 5 0 0 0-10 0"></path><line x1="12" y1="9" x2="12" y2="2"></line><line x1="4.22" y1="10.22" x2="5.64" y2="11.64"></line><line x1="1" y1="18" x2="3" y2="18"></line><line x1="21" y1="18" x2="23" y2="18"></line><line x1="18.36" y1="11.64" x2="19.78" y2="10.22"></line><line x1="23" y1="22" x2="1" y2="22"></line><polyline points="16 5 12 9 8 5"></polyline></svg>');
    --icon-sun-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-sun"><circle cx="12" cy="12" r="5"></circle><line x1="12" y1="1" x2="12" y2="3"></line><line x1="12" y1="21" x2="12" y2="23"></line><line x1="4.22" y1="4.22" x2="5.64" y2="5.64"></line><line x1="18.36" y1="18.36" x2="19.78" y2="19.78"></line><line x1="1" y1="12" x2="3" y2="12"></line><line x1="21" y1="12" x2="23" y2="12"></line><line x1="4.22" y1="19.78" x2="5.64" y2="18.36"></line><line x1="18.36" y1="5.64" x2="19.78" y2="4.22"></line></svg>');
    --icon-table-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-table"><path d="M9 3H5a2 2 0 0 0-2 2v4m6-6h10a2 2 0 0 1 2 2v4M9 3v18m0 0h10a2 2 0 0 0 2-2V9M9 21H5a2 2 0 0 1-2-2V9m0 0h18"></path></svg>');
    --icon-tablet-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-tablet"><rect x="4" y="2" width="16" height="20" rx="2" ry="2"></rect><line x1="12" y1="18" x2="12.01" y2="18"></line></svg>');
    --icon-tag-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-tag"><path d="M20.59 13.41l-7.17 7.17a2 2 0 0 1-2.83 0L2 12V2h10l8.59 8.59a2 2 0 0 1 0 2.82z"></path><line x1="7" y1="7" x2="7.01" y2="7"></line></svg>');
    --icon-target-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-target"><circle cx="12" cy="12" r="10"></circle><circle cx="12" cy="12" r="6"></circle><circle cx="12" cy="12" r="2"></circle></svg>');
    --icon-terminal-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-terminal"><polyline points="4 17 10 11 4 5"></polyline><line x1="12" y1="19" x2="20" y2="19"></line></svg>');
    --icon-thermometer-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-thermometer"><path d="M14 14.76V3.5a2.5 2.5 0 0 0-5 0v11.26a4.5 4.5 0 1 0 5 0z"></path></svg>');
    --icon-thumbs-down-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-thumbs-down"><path d="M10 15v4a3 3 0 0 0 3 3l4-9V2H5.72a2 2 0 0 0-2 1.7l-1.38 9a2 2 0 0 0 2 2.3zm7-13h2.67A2.31 2.31 0 0 1 22 4v7a2.31 2.31 0 0 1-2.33 2H17"></path></svg>');
    --icon-thumbs-up-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-thumbs-up"><path d="M14 9V5a3 3 0 0 0-3-3l-4 9v11h11.28a2 2 0 0 0 2-1.7l1.38-9a2 2 0 0 0-2-2.3zM7 22H4a2 2 0 0 1-2-2v-7a2 2 0 0 1 2-2h3"></path></svg>');
    --icon-toggle-left-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-toggle-left"><rect x="1" y="5" width="22" height="14" rx="7" ry="7"></rect><circle cx="8" cy="12" r="3"></circle></svg>');
    --icon-toggle-right-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-toggle-right"><rect x="1" y="5" width="22" height="14" rx="7" ry="7"></rect><circle cx="16" cy="12" r="3"></circle></svg>');
    --icon-tool-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-tool"><path d="M14.7 6.3a1 1 0 0 0 0 1.4l1.6 1.6a1 1 0 0 0 1.4 0l3.77-3.77a6 6 0 0 1-7.94 7.94l-6.91 6.91a2.12 2.12 0 0 1-3-3l6.91-6.91a6 6 0 0 1 7.94-7.94l-3.76 3.76z"></path></svg>');
    --icon-trash-2-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-trash-2"><polyline points="3 6 5 6 21 6"></polyline><path d="M19 6v14a2 2 0 0 1-2 2H7a2 2 0 0 1-2-2V6m3 0V4a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v2"></path><line x1="10" y1="11" x2="10" y2="17"></line><line x1="14" y1="11" x2="14" y2="17"></line></svg>');
    --icon-trash-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-trash"><polyline points="3 6 5 6 21 6"></polyline><path d="M19 6v14a2 2 0 0 1-2 2H7a2 2 0 0 1-2-2V6m3 0V4a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v2"></path></svg>');
    --icon-trello-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-trello"><rect x="3" y="3" width="18" height="18" rx="2" ry="2"></rect><rect x="7" y="7" width="3" height="9"></rect><rect x="14" y="7" width="3" height="5"></rect></svg>');
    --icon-trending-down-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-trending-down"><polyline points="23 18 13.5 8.5 8.5 13.5 1 6"></polyline><polyline points="17 18 23 18 23 12"></polyline></svg>');
    --icon-trending-up-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-trending-up"><polyline points="23 6 13.5 15.5 8.5 10.5 1 18"></polyline><polyline points="17 6 23 6 23 12"></polyline></svg>');
    --icon-triangle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-triangle"><path d="M10.29 3.86L1.82 18a2 2 0 0 0 1.71 3h16.94a2 2 0 0 0 1.71-3L13.71 3.86a2 2 0 0 0-3.42 0z"></path></svg>');
    --icon-truck-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-truck"><rect x="1" y="3" width="15" height="13"></rect><polygon points="16 8 20 8 23 11 23 16 16 16 16 8"></polygon><circle cx="5.5" cy="18.5" r="2.5"></circle><circle cx="18.5" cy="18.5" r="2.5"></circle></svg>');
    --icon-tv-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-tv"><rect x="2" y="7" width="20" height="15" rx="2" ry="2"></rect><polyline points="17 2 12 7 7 2"></polyline></svg>');
    --icon-twitch-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-twitch"><path d="M21 2H3v16h5v4l4-4h5l4-4V2zm-10 9V7m5 4V7"></path></svg>');
    --icon-twitter-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-twitter"><path d="M23 3a10.9 10.9 0 0 1-3.14 1.53 4.48 4.48 0 0 0-7.86 3v1A10.66 10.66 0 0 1 3 4s-4 9 5 13a11.64 11.64 0 0 1-7 2c9 5 20 0 20-11.5a4.5 4.5 0 0 0-.08-.83A7.72 7.72 0 0 0 23 3z"></path></svg>');
    --icon-type-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-type"><polyline points="4 7 4 4 20 4 20 7"></polyline><line x1="9" y1="20" x2="15" y2="20"></line><line x1="12" y1="4" x2="12" y2="20"></line></svg>');
    --icon-umbrella-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-umbrella"><path d="M23 12a11.05 11.05 0 0 0-22 0zm-5 7a3 3 0 0 1-6 0v-7"></path></svg>');
    --icon-underline-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-underline"><path d="M6 3v7a6 6 0 0 0 6 6 6 6 0 0 0 6-6V3"></path><line x1="4" y1="21" x2="20" y2="21"></line></svg>');
    --icon-unlock-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-unlock"><rect x="3" y="11" width="18" height="11" rx="2" ry="2"></rect><path d="M7 11V7a5 5 0 0 1 9.9-1"></path></svg>');
    --icon-upload-cloud-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-upload-cloud"><polyline points="16 16 12 12 8 16"></polyline><line x1="12" y1="12" x2="12" y2="21"></line><path d="M20.39 18.39A5 5 0 0 0 18 9h-1.26A8 8 0 1 0 3 16.3"></path><polyline points="16 16 12 12 8 16"></polyline></svg>');
    --icon-upload-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-upload"><path d="M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4"></path><polyline points="17 8 12 3 7 8"></polyline><line x1="12" y1="3" x2="12" y2="15"></line></svg>');
    --icon-user-check-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-user-check"><path d="M16 21v-2a4 4 0 0 0-4-4H5a4 4 0 0 0-4 4v2"></path><circle cx="8.5" cy="7" r="4"></circle><polyline points="17 11 19 13 23 9"></polyline></svg>');
    --icon-user-minus-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-user-minus"><path d="M16 21v-2a4 4 0 0 0-4-4H5a4 4 0 0 0-4 4v2"></path><circle cx="8.5" cy="7" r="4"></circle><line x1="23" y1="11" x2="17" y2="11"></line></svg>');
    --icon-user-plus-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-user-plus"><path d="M16 21v-2a4 4 0 0 0-4-4H5a4 4 0 0 0-4 4v2"></path><circle cx="8.5" cy="7" r="4"></circle><line x1="20" y1="8" x2="20" y2="14"></line><line x1="23" y1="11" x2="17" y2="11"></line></svg>');
    --icon-users-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-users"><path d="M17 21v-2a4 4 0 0 0-4-4H5a4 4 0 0 0-4 4v2"></path><circle cx="9" cy="7" r="4"></circle><path d="M23 21v-2a4 4 0 0 0-3-3.87"></path><path d="M16 3.13a4 4 0 0 1 0 7.75"></path></svg>');
    --icon-user-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-user"><path d="M20 21v-2a4 4 0 0 0-4-4H8a4 4 0 0 0-4 4v2"></path><circle cx="12" cy="7" r="4"></circle></svg>');
    --icon-user-x-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-user-x"><path d="M16 21v-2a4 4 0 0 0-4-4H5a4 4 0 0 0-4 4v2"></path><circle cx="8.5" cy="7" r="4"></circle><line x1="18" y1="8" x2="23" y2="13"></line><line x1="23" y1="8" x2="18" y2="13"></line></svg>');
    --icon-video-off-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-video-off"><path d="M16 16v1a2 2 0 0 1-2 2H3a2 2 0 0 1-2-2V7a2 2 0 0 1 2-2h2m5.66 0H14a2 2 0 0 1 2 2v3.34l1 1L23 7v10"></path><line x1="1" y1="1" x2="23" y2="23"></line></svg>');
    --icon-video-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-video"><polygon points="23 7 16 12 23 17 23 7"></polygon><rect x="1" y="5" width="15" height="14" rx="2" ry="2"></rect></svg>');
    --icon-voicemail-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-voicemail"><circle cx="5.5" cy="11.5" r="4.5"></circle><circle cx="18.5" cy="11.5" r="4.5"></circle><line x1="5.5" y1="16" x2="18.5" y2="16"></line></svg>');
    --icon-volume-1-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-volume-1"><polygon points="11 5 6 9 2 9 2 15 6 15 11 19 11 5"></polygon><path d="M15.54 8.46a5 5 0 0 1 0 7.07"></path></svg>');
    --icon-volume-2-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-volume-2"><polygon points="11 5 6 9 2 9 2 15 6 15 11 19 11 5"></polygon><path d="M19.07 4.93a10 10 0 0 1 0 14.14M15.54 8.46a5 5 0 0 1 0 7.07"></path></svg>');
    --icon-volume-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-volume"><polygon points="11 5 6 9 2 9 2 15 6 15 11 19 11 5"></polygon></svg>');
    --icon-volume-x-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-volume-x"><polygon points="11 5 6 9 2 9 2 15 6 15 11 19 11 5"></polygon><line x1="23" y1="9" x2="17" y2="15"></line><line x1="17" y1="9" x2="23" y2="15"></line></svg>');
    --icon-watch-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-watch"><circle cx="12" cy="12" r="7"></circle><polyline points="12 9 12 12 13.5 13.5"></polyline><path d="M16.51 17.35l-.35 3.83a2 2 0 0 1-2 1.82H9.83a2 2 0 0 1-2-1.82l-.35-3.83m.01-10.7l.35-3.83A2 2 0 0 1 9.83 1h4.35a2 2 0 0 1 2 1.82l.35 3.83"></path></svg>');
    --icon-wifi-off-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-wifi-off"><line x1="1" y1="1" x2="23" y2="23"></line><path d="M16.72 11.06A10.94 10.94 0 0 1 19 12.55"></path><path d="M5 12.55a10.94 10.94 0 0 1 5.17-2.39"></path><path d="M10.71 5.05A16 16 0 0 1 22.58 9"></path><path d="M1.42 9a15.91 15.91 0 0 1 4.7-2.88"></path><path d="M8.53 16.11a6 6 0 0 1 6.95 0"></path><line x1="12" y1="20" x2="12.01" y2="20"></line></svg>');
    --icon-wifi-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-wifi"><path d="M5 12.55a11 11 0 0 1 14.08 0"></path><path d="M1.42 9a16 16 0 0 1 21.16 0"></path><path d="M8.53 16.11a6 6 0 0 1 6.95 0"></path><line x1="12" y1="20" x2="12.01" y2="20"></line></svg>');
    --icon-wind-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-wind"><path d="M9.59 4.59A2 2 0 1 1 11 8H2m10.59 11.41A2 2 0 1 0 14 16H2m15.73-8.27A2.5 2.5 0 1 1 19.5 12H2"></path></svg>');
    --icon-x-circle-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-x-circle"><circle cx="12" cy="12" r="10"></circle><line x1="15" y1="9" x2="9" y2="15"></line><line x1="9" y1="9" x2="15" y2="15"></line></svg>');
    --icon-x-octagon-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-x-octagon"><polygon points="7.86 2 16.14 2 22 7.86 22 16.14 16.14 22 7.86 22 2 16.14 2 7.86 7.86 2"></polygon><line x1="15" y1="9" x2="9" y2="15"></line><line x1="9" y1="9" x2="15" y2="15"></line></svg>');
    --icon-x-square-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-x-square"><rect x="3" y="3" width="18" height="18" rx="2" ry="2"></rect><line x1="9" y1="9" x2="15" y2="15"></line><line x1="15" y1="9" x2="9" y2="15"></line></svg>');
    --icon-x-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-x"><line x1="18" y1="6" x2="6" y2="18"></line><line x1="6" y1="6" x2="18" y2="18"></line></svg>');
    --icon-youtube-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-youtube"><path d="M22.54 6.42a2.78 2.78 0 0 0-1.94-2C18.88 4 12 4 12 4s-6.88 0-8.6.46a2.78 2.78 0 0 0-1.94 2A29 29 0 0 0 1 11.75a29 29 0 0 0 .46 5.33A2.78 2.78 0 0 0 3.4 19c1.72.46 8.6.46 8.6.46s6.88 0 8.6-.46a2.78 2.78 0 0 0 1.94-2 29 29 0 0 0 .46-5.25 29 29 0 0 0-.46-5.33z"></path><polygon points="9.75 15.02 15.5 11.75 9.75 8.48 9.75 15.02"></polygon></svg>');
    --icon-zap-off-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-zap-off"><polyline points="12.41 6.75 13 2 10.57 4.92"></polyline><polyline points="18.57 12.91 21 10 15.66 10"></polyline><polyline points="8 8 3 14 12 14 11 22 16 16"></polyline><line x1="1" y1="1" x2="23" y2="23"></line></svg>');
    --icon-zap-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-zap"><polygon points="13 2 3 14 12 14 11 22 21 10 12 10 13 2"></polygon></svg>');
    --icon-zoom-in-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-zoom-in"><circle cx="11" cy="11" r="8"></circle><line x1="21" y1="21" x2="16.65" y2="16.65"></line><line x1="11" y1="8" x2="11" y2="14"></line><line x1="8" y1="11" x2="14" y2="11"></line></svg>');
    --icon-zoom-out-svg: url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-zoom-out"><circle cx="11" cy="11" r="8"></circle><line x1="21" y1="21" x2="16.65" y2="16.65"></line><line x1="8" y1="11" x2="14" y2="11"></line></svg>');
  }
}

/* src/components/icon/css/theme/icon-theme.css */

/* src/components/icon/css/icon.css */
`;

// src/components/icon/icon.html?raw
var icon_default = '{#if either href link}\n  <a href={href} target={target} class="hitbox">\n    {>content}\n  </a>\n{else}\n  {> content}\n{/if}\n\n{#snippet content}\n  <i class="{ui}icon" part="icon"></i>\n{/snippet}\n';

// src/components/icon/icon.js
var createComponent5 = ({ self, $: $4 }) => ({});
var UIIcon = defineComponent({
  tagName: "ui-icon",
  componentSpec: icon_component_default,
  template: icon_default,
  css: icon_bundle_default,
  createComponent: createComponent5
});

// src/components/input/specs/input-component.json
var input_component_default = {
  tagName: "ui-input",
  content: [
    "placeholder",
    "icon",
    "label"
  ],
  contentAttributes: [
    "placeholder",
    "icon",
    "label"
  ],
  types: [
    "search"
  ],
  variations: [
    "fluid",
    "size"
  ],
  settings: [
    "name",
    "type",
    "debounced",
    "debounce-interval",
    "clearable",
    "value"
  ],
  attributes: [
    "placeholder",
    "icon",
    "label",
    "search",
    "fluid",
    "size",
    "name",
    "type",
    "debounced",
    "debounce-interval",
    "clearable",
    "value"
  ],
  optionAttributes: {
    mini: "size",
    tiny: "size",
    small: "size",
    medium: "size",
    large: "size",
    big: "size",
    huge: "size",
    massive: "size"
  },
  propertyTypes: {
    placeholder: "string",
    icon: "string",
    label: "string",
    search: "boolean",
    fluid: "boolean",
    size: "string",
    name: "string",
    type: "string",
    debounced: "boolean",
    clearable: "string",
    value: "string"
  },
  allowedValues: {
    size: [
      "mini",
      "tiny",
      "small",
      "medium",
      "large",
      "big",
      "huge",
      "massive"
    ]
  },
  attributeClasses: [
    "icon",
    "label"
  ],
  defaultValues: {
    name: "",
    type: "text",
    debounced: false,
    "debounce-interval": 150,
    clearable: "",
    value: ""
  }
};

// src/components/input/input.html?raw
var input_default = '<div class="{ui}{classMap getStateClasses}input" part="input">\n  <input type="{type}" placeholder="{placeholder}" name={name} value={value} part="input-field">\n  {#if icon}\n    {#if isClearable}\n      <ui-icon icon="x" link class="clickable icon" part="icon"></ui-icon>\n    {else}\n      <ui-icon icon={getIcon} class="icon" part="icon"></ui-icon>\n    {/if}\n  {/if}\n  {#if label}\n    <div class="label" part="label">\n      {label}\n    </div>\n  {/if}\n</div>\n';

// src/components/input/input-bundle.css?raw
var input_bundle_default = '/**\n  ---DO NOT EDIT THIS FILE DIRECTLY---\n  This CSS file was concatenated from files listed in the css/ folder as part of a build process\n  This is to allow for js import with @import links which will not be followed\n**/\n\n/* src/components/input/css/definition/content/input.css */\n@layer input.definition.content.input {\n  * {\n    box-sizing: border-box;\n  }\n  .input {\n    cursor: text;\n    display: inline-flex;\n    position: relative;\n    font-style: normal;\n    font-weight: var(--input-font-weight);\n    font-family: var(--input-font-family);\n    line-height: var(--input-line-height);\n    color: var(--input-text-color);\n    background: var(--input-background);\n    border: var(--input-border);\n    border-radius: var(--input-border-radius);\n    transition: var(--input-transition);\n    box-shadow: var(--input-box-shadow);\n    gap: var(--input-item-spacing);\n    text-align: var(--input-text-align);\n    align-items: center;\n  }\n  .input input {\n    width: var(--input-width);\n    padding: var(--input-padding);\n    background-color: transparent;\n    margin: 0em;\n    border-radius: inherit;\n    outline: none;\n    max-width: 100%;\n    flex: 1 0 auto;\n    text-align: inherit;\n    font-size: inherit;\n    font-family: inherit;\n    color: inherit;\n    border: none;\n    -webkit-tap-highlight-color: rgba(255, 255, 255, 0);\n    z-index: var(--page-layer-1);\n  }\n  .input input::placeholder {\n    color: var(--input-placeholder-color);\n  }\n  .input .icon {\n    position: absolute;\n    z-index: var(--input-icon-index);\n    right: var(--input-icon-right);\n    width: var(--input-icon-width);\n    pointer-events: none;\n    margin: 0rem;\n  }\n  .input .icon.clickable {\n    pointer-events: auto;\n    cursor: pointer;\n  }\n  .input .icon + .label {\n    right: var(--input-label-with-icon-right);\n  }\n  .input .label {\n    position: absolute;\n    z-index: var(--page-layer-2);\n    pointer-events: none;\n    right: var(--input-label-right);\n    display: inline-block;\n    text-wrap: nowrap;\n    margin-left: auto;\n    line-height: 1;\n    font-weight: var(--input-label-font-weight);\n    color: var(--input-label-color);\n    font-size: var(--input-label-font-size);\n    padding: var(--input-label-padding);\n    border: var(--input-label-border);\n    border-radius: var(--input-label-border-radius);\n  }\n}\n\n/* src/components/input/css/definition/types/search.css */\n@layer input.definition.types.search {\n  .search.input {\n    border-radius: var(--circular-radius);\n  }\n}\n\n/* src/components/input/css/definition/states/focused.css */\n@layer input.definition.states.focus {\n  .input.focus,\n  .input:focus-within {\n    border-color: var(--input-focused-border-color);\n    background: var(--input-focused-background);\n    color: var(--input-focused-color);\n    box-shadow: var(--input-focused-box-shadow);\n  }\n  .input:focus-within > input::placeholder,\n  .input.focus > input::placeholder {\n    color: var(--input-placeholder-focused-color);\n  }\n}\n\n/* src/components/input/css/definition/states/loading.css */\n@layer input.definition.states.loading {\n  .loading.input:not(.icon) {\n    position: relative;\n    cursor: default;\n    text-shadow: none !important;\n    color: transparent !important;\n    opacity: var(--input-loading-opacity);\n    pointer-events: auto;\n    transition: var(--input-loading-transition);\n  }\n  .loading.icon.input .icon {\n    position: relative;\n    color: transparent !important;\n  }\n  .loading.icon.input > .icon:before,\n  .loading.input:not(.icon)::before {\n    position: absolute;\n    content: "";\n    top: 50%;\n    left: 50%;\n    margin: var(--loader-margin);\n    width: var(--loader-size);\n    height: var(--loader-size);\n    border-radius: var(--circular-radius);\n    border: var(--loader-line-width) solid var(--loader-fill-color);\n  }\n  .loading.icon.input > .icon:after,\n  .loading.input:not(.icon)::after {\n    position: absolute;\n    content: "";\n    top: 50%;\n    left: 50%;\n    margin: var(--loader-margin);\n    width: var(--loader-size);\n    height: var(--loader-size);\n    animation: input-spin var(--loader-speed) linear;\n    animation-iteration-count: infinite;\n    border-radius: var(--circular-radius);\n    border-color: var(--loader-line-color) transparent transparent;\n    border-style: solid;\n    border-width: var(--loader-line-width);\n    box-shadow: 0px 0px 0px 1px transparent;\n  }\n  @keyframes input-spin {\n    from {\n      transform: rotate(0deg);\n    }\n    to {\n      transform: rotate(360deg);\n    }\n  }\n  .loading.input.inverted .icon:before,\n  .loading.input.inverted:before {\n    border-color: var(--inverted-loader-fill-color);\n  }\n  .loading.input.inverted .icon:after,\n  .loading.input.inverted:after {\n    border-top-color: var(--inverted-loader-line-color);\n  }\n}\n\n/* src/components/input/css/definition/states/disabled.css */\n@layer input.definition.states.disabled {\n  .disabled.input,\n  .disabled.input:hover,\n  .disabled.active.input {\n    cursor: var(--input-disabled-cursor);\n    opacity: var(--input-disabled-opacity) !important;\n    color: var(--input-disabled-color);\n    background-color: var(--input-disabled-background-color) !important;\n    background-image: var(--input-disabled-background-image) !important;\n    box-shadow: var(--input-disabled-box-shadow) !important;\n  }\n  ui-input[disabled] {\n    cursor: var(--input-disabled-cursor);\n    pointer-events: none !important;\n  }\n  .clickable-disabled.input {\n    pointer-events: auto !important;\n    cursor: var(--input-clickable-disabled-cursor) !important;\n  }\n  .clickable-disabled.input:active {\n    box-shadow: var(--input-pressed-box-shadow) !important;\n  }\n  ui-input[clickable-disabled] {\n    pointer-events: auto !important;\n    cursor: var(--input-clickable-disabled-cursor) !important;\n  }\n}\n\n/* src/components/input/css/definition/variations/sizing.css */\n@layer input.definition.variations.sizing {\n  .mini {\n    font-size: var(--input-mini);\n  }\n  .tiny {\n    font-size: var(--input-tiny);\n  }\n  .small {\n    font-size: var(--input-small);\n  }\n  :host {\n    font-size: var(--input-medium);\n  }\n  .large {\n    font-size: var(--input-large);\n  }\n  .big {\n    font-size: var(--input-big);\n  }\n  .huge {\n    font-size: var(--input-huge);\n  }\n  .massive {\n    font-size: var(--input-massive);\n  }\n}\n\n/* src/components/input/css/definition/variations/fluid.css */\n@layer input.definition.variations.fluid {\n  .fluid {\n    display: flex;\n    flex-grow: 1;\n    max-width: 100%;\n  }\n  .fluid input {\n    width: auto;\n  }\n}\n\n/* src/components/input/css/definition/input-definition.css */\n\n/* src/components/input/css/theme/content/input-variables.css */\n@layer input.theme.content.input {\n  :host {\n    --input-background: var(--inverted-100);\n    --input-width: 12em;\n    --input-font-family: var(--page-font);\n    --input-font-weight: var(--normal);\n    --input-text-color: var(--text-color);\n    --input-line-height: var(--relative-17px);\n    --input-text-align: left;\n    --input-box-shadow: var(--subtle-inset-shadow);\n    --input-border: var(--border);\n    --input-border-radius: var(--border-radius);\n    --input-item-spacing: 5px;\n    --input-placeholder-color: var(--standard-15);\n    --input-placeholder-focused-color: var(--standard-20);\n    --input-transition: box-shadow var(--duration) var(--easing), border-color var(--duration) var(--easing) ;\n    --input-icon-right: var(--input-horizontal-padding);\n    --input-icon-width: 1em;\n    --input-icon-index: var(--page-layer-2);\n    --input-label-right: var(--input-horizontal-padding);\n    --input-label-font-size: var(--relative-11px);\n    --input-label-font-weight: var(--bold);\n    --input-label-padding: var(--relative-2px) var(--relative-3px);\n    --input-label-color: var(--standard-20);\n    --input-label-border: var(--border);\n    --input-label-border-radius: var(--border-radius);\n    --input-label-with-icon-right: calc( 1em + var(--input-icon-width) + var(--input-icon-right) );\n  }\n}\n\n/* src/components/input/css/theme/types/search-variables.css */\n@layer input.theme.types.search {\n  :host {\n    --inputSearchBorderRadius: var(--circular-radius);\n  }\n}\n\n/* src/components/input/css/theme/states/disabled-variables.css */\n@layer input.theme.states.disabled {\n  :host {\n    --input-disabled-cursor: default;\n    --input-disabled-opacity: 1;\n    --input-disabled-background-color: #FFFFFF;\n    --input-disabled-background-image: var(--button-background-image);\n    --input-disabled-border-box-shadow: 0px 0px 0px var(--button-border-width) rgba(0, 0, 0, 0.1) inset;\n    --input-disabled-shadow-box-shadow: 0px 2px 3px rgba(0, 0, 0, 0.04);\n    --input-disabled-color: var(--black-20);\n    --input-disabled-box-shadow:\n      var(--button-sharpen-box-shadow),\n      var(--button-disabled-border-box-shadow),\n      var(--button-disabled-shadow-box-shadow) ;\n    --input-clickable-disabled-cursor: not-allowed;\n  }\n}\n\n/* src/components/input/css/theme/states/loading-variables.css */\n@layer input.theme.states.loading {\n  :host {\n    --button-loading-icon-duration: 2s;\n    --button-loading-opacity: 1;\n    --button-loading-transition: opacity var(--button-transition-duration) var(--button-transition-easing) ;\n  }\n}\n\n/* src/components/input/css/theme/states/focused-variables.css */\n@layer input.theme.states.focused {\n  :host {\n    --input-focused-border-color: var(--form-focused-border-color);\n    --input-focused-background: var(--input-background);\n    --input-focused-color: var(--input-text-color);\n    --input-focused-placeholder-color: var(--white-15);\n    --input-focused-box-shadow: none;\n    --input-placeholder-focused-color: var(--standard-20);\n  }\n}\n\n/* src/components/input/css/theme/variations/aligned-variables.css */\n@layer input.theme.variations.aligned {\n  :host {\n  }\n}\n\n/* src/components/input/css/theme/variations/sizing-variables.css */\n@layer input.theme.variations.sizing {\n  :host {\n    --input-mini: var(--mini);\n    --input-tiny: var(--tiny);\n    --input-small: var(--small);\n    --input-medium: inherit;\n    --input-large: var(--large);\n    --input-big: var(--big);\n    --input-huge: var(--huge);\n    --input-massive: var(--massive);\n  }\n}\n\n/* src/components/input/css/theme/input-theme.css */\n\n/* src/components/input/css/input.css */\n';

// src/components/input/input.js
var defaultState = {
  focused: false
};
var createComponent6 = ({ $: $4, el, self, state, dispatchEvent, settings }) => ({
  initialize() {
    if (settings.search) {
      self.configureSearch();
    }
  },
  // allow default styling for search
  configureSearch() {
    settings.placeholder = settings.placeholder || "Search...";
    settings.icon = settings.icon || "search";
    settings.clearable = settings.clearable ?? true;
    settings.debounce = true;
  },
  hasValue() {
    return (settings.value || "").length > 0;
  },
  isClearable() {
    return settings.clearable && self.hasValue();
  },
  getStateClasses() {
    return {
      focus: state.focused.get()
    };
  },
  getIcon() {
    if (settings.clearable && self.hasValue()) {
      return "x";
    }
    return settings.icon;
  },
  setValue(value) {
    el.value = value;
    $4("input").val(value);
    dispatchEvent("input", { value });
  },
  setValueDebounced: debounce((value) => {
    self.setValue(value);
  }, { delay: settings.debounceInterval })
});
var events2 = {
  "click ui-icon"({ $: $4, self }) {
    if (self.isClearable()) {
      self.setValue("");
    }
  },
  "focus input"({ state }) {
    state.focused.set(true);
  },
  "blur input"({ state, dispatchEvent, el }) {
    state.focused.set(false);
    dispatchEvent("change", { value: el.value });
  },
  "input input"({ el, self, value, settings }) {
    if (settings.debounced) {
      self.setValueDebounced(value);
    } else {
      self.setValue(value);
    }
  }
};
var UIInput = defineComponent({
  tagName: "ui-input",
  componentSpec: input_component_default,
  template: input_default,
  css: input_bundle_default,
  createComponent: createComponent6,
  events: events2,
  defaultState
});

// src/components/label/specs/label-component.json
var label_component_default = {
  tagName: "ui-label",
  types: [
    "emphasis"
  ],
  variations: [
    "badge",
    "size"
  ],
  attributes: [
    "emphasis",
    "badge",
    "size"
  ],
  optionAttributes: {
    secondary: "emphasis",
    outline: "emphasis",
    mini: "size",
    tiny: "size",
    small: "size",
    medium: "size",
    large: "size",
    big: "size",
    huge: "size",
    massive: "size"
  },
  propertyTypes: {
    emphasis: "string",
    badge: "boolean",
    size: "string"
  },
  allowedValues: {
    emphasis: [
      "secondary",
      "outline"
    ],
    size: [
      "mini",
      "tiny",
      "small",
      "medium",
      "large",
      "big",
      "huge",
      "massive"
    ]
  }
};

// src/components/label/label.html?raw
var label_default = '<div class="{ui}label" part="label">\n  {#if text}\n    {text}\n  {else}\n    {>slot}\n  {/if}\n  {#if detail}\n    <span class="detail">{detail}</span>\n  {/if}\n</div>\n';

// src/components/label/label-bundle.css?raw
var label_bundle_default = "/**\n  ---DO NOT EDIT THIS FILE DIRECTLY---\n  This CSS file was concatenated from files listed in the css/ folder as part of a build process\n  This is to allow for js import with @import links which will not be followed\n**/\n\n/* src/components/label/css/definition/content/label.css */\n@layer label.definition.content.label {\n  :host {\n    display: inline-flex;\n    margin: var(--label-margin);\n  }\n  :host::last-child {\n    margin-right: 0rem;\n  }\n  .label {\n    display: inline-flex;\n    padding: var(--label-padding);\n    background: var(--label-background);\n    color: var(--label-color);\n    border-radius: var(--label-border-radius);\n    font-weight: var(--label-font-weight);\n    min-width: var(--label-min-width);\n  }\n}\n\n/* src/components/label/css/definition/types/emphasis.css */\n@layer label.definition.types.emphasis {\n  .secondary.label {\n    background: var(--label-secondary-background);\n    color: var(--label-secondary-text-color);\n  }\n  .outline.label {\n    background: var(--label-outline-background);\n    outline: var(--label-outline);\n    color: var(--label-outline-text-color);\n  }\n}\n\n/* src/components/label/css/definition/types/badge.css */\n@layer label.definition.types.badge {\n  .badge.label {\n    padding: var(--label-badge-padding);\n  }\n}\n\n/* src/components/label/css/definition/variations/sizing.css */\n@layer label.definition.variations.sizing {\n  .mini.label {\n    font-size: var(--label-mini);\n  }\n  .tiny.label {\n    font-size: var(--label-tiny);\n  }\n  .small.label {\n    font-size: var(--label-small);\n  }\n  :host {\n    font-size: var(--label-medium);\n  }\n  .large.label {\n    font-size: var(--label-large);\n  }\n  .big.label {\n    font-size: var(--label-big);\n  }\n  .huge.label {\n    font-size: var(--label-huge);\n  }\n  .massive.label {\n    font-size: var(--label-massive);\n  }\n  .mini.labels {\n    --label-medium: var(--label-mini);\n  }\n  .tiny.labels {\n    --label-medium: var(--label-tiny);\n  }\n  .small.labels {\n    --label-medium: var(--label-small);\n  }\n  .large.labels {\n    --label-medium: var(--label-large);\n  }\n  .big.labels {\n    --label-medium: var(--label-big);\n  }\n  .huge.labels {\n    --label-medium: var(--label-huge);\n  }\n  .massive.labels {\n    --label-medium: var(--label-massive);\n  }\n}\n\n/* src/components/label/css/definition/variations/aligned.css */\n@layer label.definition.variations.aligned;\n\n/* src/components/label/css/definition/label-definition.css */\n\n/* src/components/label/css/theme/content/label-variables.css */\n@layer label.theme.content.label {\n  :host {\n    --label-vertical-padding: var(--relative-3px);\n    --label-horizontal-padding: var(--relative-6px);\n    --label-padding: var(--label-vertical-padding) var(--label-horizontal-padding);\n    --label-color: var(--inverted-90);\n    --label-background: var(--standard-90);\n    --label-border-radius: var(--relative-5px);\n    --label-min-width: 0px;\n    --label-font-weight: var(--bold);\n    --label-vertical-margin: calc(var(--label-vertical-padding) * -1);\n    --label-horizontal-margin: 4px;\n    --label-margin: var(--label-vertical-margin) var(--label-horizontal-margin);\n  }\n}\n\n/* src/components/label/css/theme/types/emphasis-variables.css */\n@layer label.theme.types.emphasis {\n  :host {\n    --label-secondary-background: var(--standard-10);\n    --label-secondary-text-color: var(--standard-90);\n    --label-outline-background: transparent;\n    --label-outline: var(--internal-border);\n    --label-outline-text-color: var(--standard-90);\n  }\n}\n\n/* src/components/label/css/theme/types/badge-variables.css */\n@layer label.theme.types.badge {\n  :host {\n    --label-badge-vertical-padding: var(--label-vertical-padding);\n    --label-badge-horizontal-padding: var(--relative-4px);\n    --label-badge-padding: var(--label-badge-vertical-padding) var(--label-badge-horizontal-padding);\n  }\n}\n\n/* src/components/label/css/theme/variations/sizing-variables.css */\n@layer label.theme.variations.sizing {\n  :host {\n    --label-mini: var(--9px);\n    --label-tiny: var(--10px);\n    --label-small: var(--11px);\n    --label-medium: inherit;\n    --label-large: var(--15px);\n    --label-big: var(--16px);\n    --label-huge: var(--18px);\n    --label-massive: var(--24px);\n  }\n}\n\n/* src/components/label/css/theme/variations/aligned-variables.css */\n@layer label.theme.variations.aligned {\n  :host {\n  }\n}\n\n/* src/components/label/css/theme/label-theme.css */\n\n/* src/components/label/css/label.css */\n";

// src/components/label/label.js
var createComponent7 = ({ $: $4 }) => ({});
var UILabel = defineComponent({
  tagName: "ui-label",
  componentSpec: label_component_default,
  template: label_default,
  css: label_bundle_default,
  createComponent: createComponent7
});

// src/components/menu/specs/menu-item-component.json
var menu_item_component_default = {
  tagName: "menu-item",
  content: [
    "icon",
    "label",
    "badge",
    "href",
    "value"
  ],
  contentAttributes: [
    "icon",
    "label",
    "badge",
    "href",
    "value"
  ],
  states: [
    "hover",
    "focused",
    "active",
    "disabled"
  ],
  attributes: [
    "icon",
    "label",
    "badge",
    "href",
    "value",
    "hover",
    "focused",
    "active",
    "disabled"
  ],
  propertyTypes: {
    icon: "string",
    label: "string",
    badge: "string",
    href: "string",
    value: "string",
    hover: "boolean",
    focused: "boolean",
    active: "boolean",
    disabled: "boolean"
  },
  attributeClasses: [
    "icon"
  ]
};

// src/components/menu/menu-bundle.css?raw
var menu_bundle_default = "/**\n  ---DO NOT EDIT THIS FILE DIRECTLY---\n  This CSS file was concatenated from files listed in the css/ folder as part of a build process\n  This is to allow for js import with @import links which will not be followed\n**/\n\n/* src/components/menu/css/definition/content/menu.css */\n@layer menu.definition.content.menu {\n  ui-menu {\n    display: block;\n    margin: var(--menu-margin);\n    padding: var(--menu-padding);\n    box-shadow: var(--menu-box-shadow);\n    border: var(--menu-border);\n    font-size: var(--menu-font-size);\n  }\n  .menu {\n    display: flex;\n    flex-direction: row;\n    font-weight: var(--menu-font-weight);\n    gap: var(--menu-gap);\n    background: var(--menu-background);\n    align-items: var(--menu-align-items);\n    justify-content: var(--menu-justify-content);\n  }\n}\n\n/* src/components/menu/css/definition/content/item.css */\n@layer menu.definition.content.item {\n  .item {\n    display: block;\n    cursor: pointer;\n    background: var(--menu-item-background);\n    margin: var(--menu-item-margin);\n    padding: var(--menu-item-padding);\n    border: var(--menu-item-border);\n    color: var(--menu-item-color);\n    font-weight: var(--menu-item-font-weight);\n    line-height: var(--menu-item-line-height);\n    box-shadow: var(--menu-item-box-shadow);\n    border-radius: var(--menu-item-border-radius);\n    text-align: var(--menu-item-text-align);\n    text-decoration: var(--menu-item-text-decoration);\n  }\n  .item:hover,\n  .item.hover {\n    background: var(--menu-item-hover-background);\n    margin: var(--menu-item-hover-margin);\n    padding: var(--menu-item-hover-padding);\n    border: var(--menu-item-hover-border);\n    color: var(--menu-item-hover-color);\n    box-shadow: var(--menu-item-hover-box-shadow);\n    border-radius: var(--menu-item-hover-border-radius);\n  }\n  .active.item {\n    cursor: default;\n    background: var(--menu-item-active-background);\n    margin: var(--menu-item-active-margin);\n    padding: var(--menu-item-active-padding);\n    border: var(--menu-item-active-border);\n    box-shadow: var(--menu-item-active-box-shadow);\n    font-weight: var(--menu-item-active-font-weight);\n    color: var(--menu-item-active-color);\n    border-radius: var(--menu-item-active-border-radius);\n  }\n}\n\n/* src/components/menu/css/definition/types/selection.css */\n@layer menu.definition.types.selection {\n  .selection.menu {\n    gap: var(--menu-selection-gap);\n  }\n  .selection.menu ::slotted(*),\n  .selection.menu menu-item {\n    --menu-item-padding: var(--menu-selection-item-padding);\n    --menu-item-border-radius: var(--menu-selection-item-border-radius);\n    --menu-item-color: var(--menu-selection-item-color);\n    --menu-item-hover-background: var(--menu-selection-item-hover-background);\n    --menu-item-hover-border-radius: var(--menu-selection-item-border-radius);\n    --menu-item-hover-color: var(--menu-selection-item-hover-color);\n    --menu-item-hover-box-shadow: var(--menu-selection-item-hover-box-shadow);\n    --menu-item-active-background: var(--menu-selection-item-active-background);\n    --menu-item-active-border-radius: var(--menu-selection-item-border-radius);\n    --menu-item-active-padding: var(--menu-selection-item-active-padding);\n    --menu-item-active-color: var(--menu-selection-item-active-color);\n    --menu-item-active-box-shadow: var(--menu-selection-item-active-box-shadow);\n  }\n}\n\n/* src/components/menu/css/definition/variations/evenly-spaced.css */\n@layer menu.definition.variations.equalWidth {\n  .evenly-spaced.menu {\n    display: grid;\n    grid-auto-flow: column;\n    grid-auto-columns: minmax(0, 1fr);\n    --menu-item-text-align: var(--menu-evenly-spaced-item-text-align) ;\n  }\n}\n\n/* src/components/menu/css/definition/variations/fitted.css */\n@layer menu.definition.variations.fitted {\n  :host([fitted]),\n  .fitted.menu {\n    margin: 0;\n  }\n}\n\n/* src/components/menu/css/definition/variations/inset.css */\n@layer menu.definition.variations.inset {\n  .inset.menu {\n    border: var(--menu-inset-border);\n    border-radius: var(--menu-inset-border-radius);\n    padding: var(--menu-inset-padding);\n    background: var(--menu-inset-background);\n  }\n}\n\n/* src/components/menu/css/definition/variations/vertical.css */\n@layer menu.definition.variations.vertical {\n  .vertical.menu {\n    flex-direction: column;\n    align-items: var(--menu-vertical-align-items);\n    text-align: var(--menu-vertical-text-align);\n  }\n}\n\n/* src/components/menu/css/definition/menu-definition.css */\n\n/* src/components/menu/css/theme/content/menu-variables.css */\n@layer menu.theme.content.menu {\n  :host {\n    --menu-margin: var(--vertically-spaced);\n    --menu-font-weight: var(--normal);\n    --menu-gap: var(--4px);\n    --menu-align-items: flex-start;\n    --menu-font-size: var(--medium);\n    --menu-justify-content: flex-start;\n    --menu-padding: 0;\n    --menu-box-shadow: none;\n    --menu-background: none;\n    --menu-border: none;\n  }\n}\n\n/* src/components/menu/css/theme/content/menu-item-variables.css */\n@layer menu.theme.content.menuItem {\n  :host {\n    --menu-item-background-color: transparent;\n    --menu-item-background-image: none;\n    --menu-item-background: var(--menu-item-background-color) var(--menu-item-background-image);\n    --menu-item-margin: 0;\n    --menu-item-line-height: 1;\n    --menu-item-font-weight: var(--normal);\n    --menu-item-padding: var(--7px) var(--6px);\n    --menu-item-border: none;\n    --menu-item-border-radius: none;\n    --menu-item-color: var(--standard-60);\n    --menu-item-text-align: inherit;\n    --menu-item-box-shadow: none;\n    --menu-item-text-decoration: none;\n    --menu-item-hover-background-color: var(--menu-item-background-color);\n    --menu-item-hover-background-image: var(--menu-item-background-image);\n    --menu-item-hover-background: var(--menu-item-hover-background-color) var(--menu-item-hover-background-image);\n    --menu-item-hover-margin: var(--menu-item-margin);\n    --menu-item-hover-padding: var(--menu-item-padding);\n    --menu-item-hover-color: var(--standard-100);\n    --menu-item-hover-border: var(--menu-item-border);\n    --menu-item-hover-box-shadow: var(--menu-item-box-shadow);\n    --menu-item-hover-border-radius: var(--menu-item-border-radius);\n    --menu-item-active-background-color: var(--menu-item-active-background-color);\n    --menu-item-active-background-image: var(--menu-item-active-background-image);\n    --menu-item-active-font-weight: var(--bold);\n    --menu-item-active-background: var(--menu-item-background);\n    --menu-item-active-margin: var(--menu-item-margin);\n    --menu-item-active-padding: var(--menu-item-padding);\n    --menu-item-active-color: var(--primary-text-color);\n    --menu-item-active-border: var(--menu-item-border);\n    --menu-item-active-box-shadow: var(--menu-item-box-shadow);\n    --menu-item-active-border-radius: var(--menu-item-border-radius);\n  }\n  html.dark {\n    --menu-item-color: var(--standard-30);\n    --menu-item-hover-color: var(--standard-100);\n    --menu-item-active-color: var(--primary-text-color);\n  }\n}\n\n/* src/components/menu/css/theme/types/selection-variables.css */\n@layer menu.theme.type.selection {\n  :host {\n    --menu-selection-gap: 6px;\n    --menu-selection-item-padding: 7px 6px;\n    --menu-selection-item-border-radius: var(--border-radius);\n    --menu-selection-item-color: var(--standard-30);\n    --menu-selection-item-hover-padding: var(--menu-selection-item-padding);\n    --menu-selection-item-hover-background: var(--standard-10);\n    --menu-selection-item-hover-color: #013A4F;\n    --menu-selection-item-hover-box-shadow: none;\n    --menu-selection-item-active-padding: var(--menu-selection-item-padding);\n    --menu-selection-item-active-background: #D0EBF3;\n    --menu-selection-item-active-color: var(--primary-text-color);\n    --menu-selection-item-active-box-shadow: 0px 1px 6px rgb(85 147 167 / 77%) inset;\n  }\n  @container style(--dark-mode: true) {\n    :host {\n      --menu-selection-item-hover-background: transparent;\n      --menu-selection-item-hover-color: var(--standard-90);\n      --menu-selection-item-active-background: #35B7F1;\n      --menu-selection-item-active-color: var(--black-90);\n      --menu-selection-item-active-box-shadow: 0px 0px 10px rgb(0 92 165) inset;\n    }\n  }\n}\n\n/* src/components/menu/css/theme/variations/evenly-spaced-variables.css */\n@layer menu.theme.variations.evenlySpaced {\n  :host {\n    --menu-evenly-spaced-item-text-align: center;\n  }\n}\n\n/* src/components/menu/css/theme/variations/vertical-variables.css */\n@layer menu.theme.variations.vertical {\n  :host {\n    --menu-vertical-align-items: stretch;\n    --menu-vertical-text-align: center;\n  }\n}\n\n/* src/components/menu/css/theme/variations/inset-variables.css */\n@layer menu.theme.variations.inset {\n  :host {\n    --menu-inset-padding: 3px 4px;\n    --menu-inset-border-radius: var(--border-radius);\n    --menu-inset-border: var(--internal-border);\n    --menu-inset-background: var(--inverted-15);\n  }\n}\n\n/* src/components/menu/css/theme/menu-theme.css */\n\n/* src/components/menu/css/menu.css */\n";

// src/components/menu/content/item/menu-item.html?raw
var menu_item_default = '{{#snippet content}}\n  {{#if icon}}\n    <ui-icon icon={{icon}}></ui-icon>\n  {{/if}}\n  {{>slot}}\n{{/snippet}}\n\n{{#if href}}\n  <a class="{{ui}}item" href="{{href}}" part="item">\n    {{>content}}\n  </a>\n{{else}}\n  <div class="{{ui}}item" part="item">\n    {{>content}}\n  </div>\n{{/if}}\n';

// src/components/menu/content/item/menu-item.js
var onCreated = ({ data }) => {
};
var events3 = {
  "touchstart .menu"({ event, tpl, $: $4 }) {
    $4(this).addClass("pressed");
  },
  "touchend .menu"({ event, tpl, $: $4 }) {
    $4(this).removeClass("pressed");
  }
};
var MenuItem = defineComponent({
  tagName: "menu-item",
  events: events3,
  onCreated,
  componentSpec: menu_item_component_default,
  template: menu_item_default,
  css: menu_bundle_default
});

// src/components/menu/specs/menu-component.json
var menu_component_default = {
  tagName: "ui-menu",
  content: [
    "item"
  ],
  types: [
    "selection"
  ],
  variations: [
    "evenly-spaced",
    "fitted",
    "vertical",
    "inset"
  ],
  settings: [
    "items",
    "value"
  ],
  attributes: [
    "item",
    "selection",
    "evenly-spaced",
    "fitted",
    "vertical",
    "inset",
    "items",
    "value"
  ],
  propertyTypes: {
    item: "string",
    selection: "boolean",
    "evenly-spaced": "boolean",
    fitted: "boolean",
    vertical: "boolean",
    inset: "boolean",
    items: "array",
    value: "string"
  },
  defaultValues: {
    items: [],
    value: ""
  }
};

// src/components/menu/menu.html?raw
var menu_default = '<div class="{ui}menu" part="menu">\n  {#each item in items}\n    <menu-item\n      active={isValueActive value item}\n      href={item.href}\n      data-value={item.value}\n      exportparts="item"\n    >\n      {item.label}\n      {#if item.badge}\n        <ui-label outline badge>{item.badge}</ui-label>\n      {/if}\n    </menu-item>\n  {else}\n    {>slot}\n  {/each}\n</div>\n';

// src/components/menu/menu-page.css?raw
var menu_page_default = "ui-menu[selection] menu-item {\n  --menu-item-padding: var(--menu-selection-item-padding);\n  --menu-item-border-radius: var(--menu-selection-item-border-radius);\n  --menu-item-color: var(--menu-selection-item-color);\n\n  --menu-item-hover-background: var(--menu-selection-item-hover-background);\n  --menu-item-hover-border-radius: var(--menu-selection-item-border-radius);\n  --menu-item-hover-color: var(--menu-selection-item-hover-color);\n  --menu-item-hover-box-shadow: var(--menu-selection-item-hover-box-shadow);\n\n  --menu-item-active-background: var(--menu-selection-item-active-background);\n  --menu-item-active-border-radius: var(--menu-selection-item-border-radius);\n  --menu-item-active-padding: var(--menu-selection-item-active-padding);\n  --menu-item-active-color: var(--menu-selection-item-active-color);\n  --menu-item-active-box-shadow: var(--menu-selection-item-active-box-shadow);\n}\n";

// src/components/menu/menu.js
var createComponent8 = ({ settings, self, $: $4, dispatchEvent }) => ({
  setValue(value) {
    settings.value = value;
    dispatchEvent("change", { value });
  },
  getValue(item) {
    return item.value || item.href;
  },
  isValueActive(activeValue, item) {
    if (item.active) {
      return true;
    }
    if (activeValue !== void 0) {
      return activeValue == self.getValue(item);
    }
    return false;
  },
  selectIndex(eq) {
    const value = $4("menu-item").eq(eq).attr("data-value");
    if (value !== void 0) {
      self.setValue(value);
    }
  }
});
var onCreated2 = ({ settings }) => {
};
var onRendered = function({ $: $4 }) {
};
var events4 = {
  "click menu-item"({ self, data }) {
    self.setValue(data.value);
  }
};
var UIMenu = defineComponent({
  tagName: "ui-menu",
  componentSpec: menu_component_default,
  template: menu_default,
  css: menu_bundle_default,
  pageCSS: menu_page_default,
  createComponent: createComponent8,
  events: events4,
  onCreated: onCreated2,
  onRendered
});

// src/components/segment/specs/segment-component.json
var segment_component_default = {
  tagName: "ui-menu",
  types: [
    "placeholder"
  ],
  attributes: [
    "placeholder"
  ],
  propertyTypes: {
    placeholder: "boolean"
  }
};

// src/components/segment/segment.html?raw
var segment_default = '<div class="segment">\n  {{>slot}}\n</div>\n';

// src/components/segment/segment-bundle.css?raw
var segment_bundle_default = "/**\n  ---DO NOT EDIT THIS FILE DIRECTLY---\n  This CSS file was concatenated from files listed in the css/ folder as part of a build process\n  This is to allow for js import with @import links which will not be followed\n**/\n\n/* src/components/segment/css/definition/content/segment.css */\n@layer segment.definition {\n  @layer segment.definition.content.segment;\n}\n\n/* src/components/segment/css/definition/variations/aligned.css */\n@layer segment.definition {\n  @layer segment.definition.variations.aligned;\n}\n\n/* src/components/segment/css/definition/segment-definition.css */\n@layer segment.definition;\n\n/* src/components/segment/css/theme/segment-theme.css */\n@layer segment.theme;\n\n/* src/components/segment/css/segment.css */\n";

// src/components/segment/segment.js
var createComponent9 = ({ $: $4 }) => ({});
var UISegment = defineComponent({
  tagName: "ui-segment",
  componentSpec: segment_component_default,
  template: segment_default,
  css: segment_bundle_default,
  createComponent: createComponent9
});

// src/components/modal/specs/modal-component.json
var modal_component_default = {
  tagName: "ui-modal",
  types: [
    "glass"
  ],
  variations: [
    "aligned",
    "size"
  ],
  settings: [
    "closeable"
  ],
  attributes: [
    "glass",
    "aligned",
    "size",
    "closeable"
  ],
  optionAttributes: {
    "top-aligned": "aligned",
    tiny: "size",
    small: "size",
    medium: "size",
    large: "size",
    big: "size"
  },
  propertyTypes: {
    glass: "boolean",
    aligned: "string",
    size: "string",
    closeable: "boolean"
  },
  allowedValues: {
    aligned: [
      "top-aligned"
    ],
    size: [
      "tiny",
      "small",
      "medium",
      "large",
      "big"
    ]
  },
  defaultValues: {
    closeable: true
  }
};

// src/components/modal/modal.html?raw
var modal_default = '<dialog part="dialog">\n  {{#if not closeable}}\n    <ui-icon link x class="close"></ui-icon>\n  {{/if}}\n  <div class="{{ui}}modal" part="modal">\n    {{>slot}}\n  </div>\n</dialog>\n';

// src/components/modal/modal-bundle.css?raw
var modal_bundle_default = '/**\n  ---DO NOT EDIT THIS FILE DIRECTLY---\n  This CSS file was concatenated from files listed in the css/ folder as part of a build process\n  This is to allow for js import with @import links which will not be followed\n**/\n\n/* src/components/modal/css/definition/content/modal.css */\n@layer modal.definition.content.modal {\n  dialog {\n    position: fixed;\n    width: inherit;\n    outline: none;\n    border: none;\n    background-color: transparent;\n    overflow: visible;\n  }\n  dialog {\n    display: none;\n    flex-direction: column;\n    opacity: 0;\n    scale: 0.8;\n    transition: var(--modal-dialog-transition);\n  }\n  dialog[open] {\n    display: flex;\n    opacity: 1;\n    scale: 1;\n  }\n  @starting-style {\n    dialog[open] {\n      opacity: 0;\n      scale: 0.8;\n    }\n  }\n  dialog::backdrop {\n    background-color: rgb(0 0 0 / 0%);\n    transition: var(--modal-dimmer-transition);\n  }\n  dialog[open]::backdrop {\n    background: var(--modal-dimmer-background);\n  }\n  @starting-style {\n    dialog[open]::backdrop {\n      background: rgb(0 0 0 / 0%);\n    }\n  }\n  dialog .modal {\n    background: var(--modal-background);\n    max-width: var(--modal-max-width);\n    border-radius: var(--modal-border-radius);\n    box-shadow: 0px 0px 0px rgba(0, 0, 0, 0);\n    transition: var(--modal-transition);\n  }\n  dialog[open] .modal {\n    box-shadow: var(--modal-box-shadow);\n  }\n  @starting-style {\n    dialog[open] .modal {\n      box-shadow: 0px 0px 0px rgba(0, 0, 0, 0);\n    }\n  }\n  dialog ::slotted(.content) {\n    padding: var(--padding);\n  }\n  dialog .close {\n    cursor: pointer;\n    align-self: flex-end;\n    color: #FFF;\n    margin: 0;\n    font-size: 22px;\n    padding: 1rem;\n    opacity: 0.6;\n    transition: var(--transition);\n  }\n  dialog .close:hover {\n    opacity: 1;\n  }\n  dialog .close + .modal {\n    margin-right: 3rem;\n  }\n}\n\n/* src/components/modal/css/definition/types/glass.css */\n@layer modal.definition.types.glass {\n  .glass.modal {\n    -webkit-backdrop-filter: var(--modal-glass-backdrop-filter);\n    backdrop-filter: var(--modal-glass-backdrop-filter);\n    box-shadow: var(--modal-glass-box-shadow);\n    background: var(--modal-glass-background);\n  }\n}\n\n/* src/components/modal/css/definition/variations/aligned.css */\n@layer modal.definition.variations.aligned;\n\n/* src/components/modal/css/definition/variations/sizing.css */\n@layer modal.definition.variations.sizing {\n  :host {\n    width: var(--modal-medium);\n  }\n  :host([size="mini"]),\n  :host([mini]),\n  :host.mini {\n    width: var(--modal-mini);\n  }\n  :host([size="tiny"]),\n  :host([tiny]),\n  :host.tiny {\n    width: var(--modal-tiny);\n  }\n  :host([size="small"]),\n  :host([small]),\n  :host.small {\n    width: var(--modal-small);\n  }\n  :host([size="large"]),\n  :host([large]),\n  :host.large {\n    width: var(--modal-large);\n  }\n  :host([size="big"]),\n  :host([big]),\n  :host.big {\n    width: var(--modal-big);\n  }\n  :host([size="huge"]),\n  :host([huge]),\n  :host.huge {\n    width: var(--modal-huge);\n  }\n  :host([size="massive"]),\n  :host([massive]),\n  :host.massive {\n    width: var(--modal-massive);\n  }\n}\n\n/* src/components/modal/css/definition/modal-definition.css */\n\n/* src/components/modal/css/theme/content/modal-variables.css */\n@layer modal.theme.content.modal {\n  :host {\n    --modal-box-shadow: 2px 5px 15px rgba(0, 0, 0, 0.3);\n    --modal-border-radius: var(--border-radius);\n    --modal-background: var(--white);\n    --modal-dimmer-background: var(--black-50);\n    --modal-max-width: calc(100vw - 2rem);\n    --modal-transition: all 300ms ease 100ms;\n    --modal-dialog-transition-duration: 200ms;\n    --modal-dialog-transition:\n      opacity var(--modal-dialog-transition-duration) ease,\n      scale var(--modal-dialog-transition-duration) ease,\n      overlay var(--modal-dialog-transition-duration) ease allow-discrete,\n      display var(--modal-dialog-transition-duration) ease allow-discrete;\n    --modal-dimmer-transition-duration: 700ms;\n    --modal-dimmer-transition:\n      display var(--modal-dimmer-transition-duration) allow-discrete,\n      overlay var(--modal-dimmer-transition-duration) allow-discrete,\n      background var(--modal-dimmer-transition-duration);\n  }\n}\n\n/* src/components/modal/css/theme/types/glass-variables.css */\n@layer modal.theme.types.glass {\n  :host {\n    --modal-glass-background: none transparent;\n    --modal-glass-blur: 7px;\n    --modal-glass-backdrop-filter: blur(var(--modal-glass-blur));\n    --modal-glass-box-shadow:\n      inset -0.75px -0.5px rgba(255, 255, 255, 0.1),\n      inset +0.75px +0.5px rgba(255, 255, 255, 0.025),\n      3px 2px 10px rgba(0, 0, 0, 0.25),\n      inset 0px 0px 10px 5px rgba(255, 255, 255, 0.025),\n      inset 0px 0px 40px 5px rgba(255, 255, 255, 0.025) ;\n  }\n}\n\n/* src/components/modal/css/theme/variations/aligned-variables.css */\n@layer modal.theme.variations.aligned {\n  :host {\n  }\n}\n\n/* src/components/modal/css/theme/variations/sizing-variables.css */\n@layer modal.theme.variations.sizing {\n  :host {\n    --modal-mini: 320px;\n    --modal-tiny: 400px;\n    --modal-small: 500px;\n    --modal-medium: 700px;\n    --modal-large: 850px;\n    --modal-big: 1100px;\n    --modal-huge: 1300px;\n    --modal-massive: 1600px;\n  }\n}\n\n/* src/components/modal/css/theme/modal-theme.css */\n\n/* src/components/modal/css/modal.css */\n';

// src/components/modal/modal.js
var createComponent10 = ({ $: $4, dispatchEvent }) => ({
  show(callback = noop) {
    if (callback() !== false) {
      $4("dialog").get(0).showModal();
    }
    dispatchEvent("show");
  },
  hide(callback = noop) {
    if (callback() !== false) {
      $4("dialog").get(0).close();
    }
    dispatchEvent("hide");
  }
});
var onCreated3 = ({}) => {
};
var onRendered2 = function({}) {
};
var events5 = {
  "click ui-icon.close"({ event, self }) {
    self.hide();
  },
  "click dialog"({ $: $4, event, settings, self }) {
    if (settings.closeable && $4(event.target).is("dialog")) {
      self.hide();
    }
  }
};
var UIModal = defineComponent({
  tagName: "ui-modal",
  componentSpec: modal_component_default,
  template: modal_default,
  css: modal_bundle_default,
  createComponent: createComponent10,
  events: events5,
  onCreated: onCreated3,
  onRendered: onRendered2
});
export {
  MenuItem,
  UIButton,
  UIButtons,
  UICard,
  UICards,
  UIContainer,
  UIIcon,
  UIInput,
  UILabel,
  UIMenu,
  UIModal,
  UIRail,
  UISegment
};
/*! Bundled license information:

@lit/reactive-element/css-tag.js:
  (**
   * @license
   * Copyright 2019 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

@lit/reactive-element/reactive-element.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-html/lit-html.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-element/lit-element.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-html/is-server.js:
  (**
   * @license
   * Copyright 2022 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-html/directive-helpers.js:
  (**
   * @license
   * Copyright 2020 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-html/directive.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-html/async-directive.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-html/directives/if-defined.js:
  (**
   * @license
   * Copyright 2018 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-html/directives/unsafe-html.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)

lit-html/directives/repeat.js:
  (**
   * @license
   * Copyright 2017 Google LLC
   * SPDX-License-Identifier: BSD-3-Clause
   *)
*/
//# sourceMappingURL=semantic-ui.js.map
